import { writable, derived } from "svelte/store"

const NOTIFICATION_TIMEOUT = 3500

const createNotificationStore = () => {
  const _notifications = writable([])

  const send = (title, description, dismissable, type = "info") => {
    _notifications.update(state => {
      return [...state, { id: id(), type, title, description, dismissable }]
    })
  }

  let timers = []

  const notifications = derived(_notifications, ($_notifications, set) => {
    set($_notifications)
    if ($_notifications.length > 0) {
      const timeout = setTimeout(() => {
        _notifications.update(state => {
          state.shift()
          return state
        })
      }, NOTIFICATION_TIMEOUT)
      return () => {
        clearTimeout(timeout)
      }
    }
  })

  const remove = (notification) => {
    _notifications.update((current) => current.filter((n) => n.id != notification.id));
  };

  const { subscribe } = notifications

  return {
    subscribe,
    send,
    remove,
    error: (title, description, dismissable) => send(title, description, dismissable, "error"),
    warning: (title, description, dismissable) => send(title, description, dismissable, "warning"),
    info: (title, description, dismissable) => send(title, description, dismissable, "info"),
    success: (title, description, dismissable) => send(title, description, dismissable, "success")
  }
}

function id() {
  return '_' + Math.random().toString(36).substr(2, 9);
};

export const notifications = createNotificationStore()