/// <reference types="svelte" />
import { SvelteComponentTyped } from "svelte";

export interface ButtonProps
  extends svelte.JSX.HTMLAttributes<HTMLElementTagNameMap["a"]> {
  /**
   * @default "primary"
   */
  kind?: "primary" | "secondary" | "white";

  /**
   * @default false
   */
  full?: boolean;

  /**
   * @default false
   */
  disabled?: boolean;

  /**
   * padding size to be applied to button
   * @default "small"
   */
  size?: "small" | "medium" | "large";

  /**
   * type for button
   * @default "button"
   */
  type?: "button" | "submit";

  /**
   * If button is submitting
   * @default false
   */
  loading?: boolean;

  /**
   * Set the `href` to render button as <a> tag
   * @default null
   */
  href?: string;
}

export default class Button extends SvelteComponentTyped<
  ButtonProps,
  {
    click: WindowEventMap["click"];
    mouseover: WindowEventMap["mouseover"];
    mouseenter: WindowEventMap["mouseenter"];
    mouseleave: WindowEventMap["mouseleave"];
  },
  { default: {} }
> {}
