/// <reference types="svelte" />
import { SvelteComponentTyped } from "svelte";

export interface CheckBoxProps
  extends svelte.JSX.HTMLAttributes<HTMLElementTagNameMap["input"]> {
  /**
   * Binding to checked state of input
   * @default false
   */
  checked?: boolean;

  /**
   * Set label for, Input id and name
   * @default ""
   */
  name?: string;

  /**
   * If the checkbox belongs to a group
   * @default []
   */
  group?: string[];

  /**
   * Label text to display over input
   * @default ""
   */
  label?: string;

  /**
   * Value for checkbox
   * @default ""
   */
  value?: string | number;

  /**
   * set height and width of checkbox
   * @default "small"
   */
  size?: small | medium | large;

  /**
   * Set button to disabled
   * @default false
   */
  disabled?: boolean;

  /**
   * If the checkbox has an error
   * @default false
   */
  hasError?: boolean;

  /**
   * Error Message to display
   * @default ""
   */
  errorMessage?: string;

  use?: undefined;
}

export default class CheckBox extends SvelteComponentTyped<
  CheckBoxProps,
  { click: WindowEventMap["click"]; change: WindowEventMap["change"] },
  {}
> {}
