/// <reference types="svelte" />
import { SvelteComponentTyped } from "svelte";

export interface SelectMenuOptions {
  label: string;
  value: any;
}

export interface SelectProps
  extends svelte.JSX.HTMLAttributes<HTMLElementTagNameMap["select"]> {
  /**
   * List of options
   */
  options?: selectMenuOptions[];

  /**
   * Set the Selected Option at the start
   * @default null
   */
  selectedOption?: undefined;

  /**
   * Bind to inputs value
   */
  value?: any | undefined;

  /**
   * Set label for, Input id and name
   */
  name?: string;

  /**
   * If the selected element should display a value
   * before anything is selected
   * this only works when selectedOption is not set
   * @default ""
   */
  placeholder?: string;

  /**
   * Label text to display over input
   * @default ""
   */
  label?: string;

  /**
   * Set width to 100%
   * @default false
   */
  full?: boolean;

  /**
   * Input is invalid
   * @default false
   */
  hasError?: boolean;

  use?: undefined;
}

export default class Select extends SvelteComponentTyped<
  SelectProps,
  { change: WindowEventMap["change"] },
  {}
> {}
