/// <reference types="svelte" />
import { SvelteComponentTyped } from "svelte";

export interface TextInputProps
  extends svelte.JSX.HTMLAttributes<HTMLElementTagNameMap["input"]> {
  /**
   * Label to display above the button
   * @default ""
   */
  label?: string;

  /**
   * Name and Id of input
   * @default ""
   */
  name?: string;

  /**
   * @default false
   */
  full?: boolean;

  /**
   * @default false
   */
  disabled?: boolean;

  /**
   * Bind to value of input
   * @default ""
   */
  value?: string;

  /**
   * Placeholder text for input
   * @default ""
   */
  placeholder?: string;

  /**
   * Input is invalid
   * @default false
   */
  hasError?: boolean;

  /**
   * showLoading icon
   * @default false
   */
  isLoading?: boolean;

  /**
   * text size of input
   * @default "medium"
   */
  size?: small | medium | large;

  /**
   * ref to input element
   * @default null
   */
  input?: null | HTMLInputElement;

  use?: undefined;
}

export default class TextInput extends SvelteComponentTyped<
  TextInputProps,
  {
    focus: WindowEventMap["focus"];
    focusout: WindowEventMap["focusout"];
    keydown: WindowEventMap["keydown"];
    keyup: WindowEventMap["keyup"];
  },
  { leading: {}; trailing: {} }
> {}
