/// <reference types="svelte" />
import { SvelteComponentTyped } from "svelte";

export interface ModalProps
  extends svelte.JSX.HTMLAttributes<HTMLElementTagNameMap["div"]> {
  /**
   * Is Modal Open
   * @default false
   */
  open?: boolean;

  /**
   * Content can overflow out of modal
   * helpful for things like popups, menus ect..
   * @default true
   */
  hideOverflow?: boolean;

  /**
   * A tailwind class which is appenedend to the modals styling
   * useful for defining a maxium width on the modal
   * @default ""
   */
  maxWidth?: string;

  /**
   * Render exit icon in modal
   * @default false
   */
  showExit?: boolean;

  /**
   * If true the false the modal will render with a transparent background
   * @default true
   */
  showBackground?: boolean;

  /**
   * The Modals trapFocus configuration
   * configuartion options - @see {@link https://github.com/focus-trap/focus-trap#createoptions}
   * @default { allowOutsideClick: true, clickOutsideDeactivates: true, escapeDeactivates: false, }
   */
  trapFocusConfig?: {
    allowOutsideClick: true;
    clickOutsideDeactivates: true;
    escapeDeactivates: false;
  };
}

export default class Modal extends SvelteComponentTyped<
  ModalProps,
  { close: CustomEvent<any> },
  { default: {}; content: {}; footer: {}; header: {} }
> {}
