/// <reference types="svelte" />
import type { SvelteComponentTyped } from "svelte";

export interface ModalProps
  extends svelte.JSX.HTMLAttributes<HTMLElementTagNameMap["div"]> {
  /**
   * Is Modal Open
   * @default false
   */
  open?: boolean;

  /**
   * Can close the Dialog by clicking outside
   * @default true
   */
  dismissable?: boolean;

  /**
   * set max width
   * @default "md"
   */
  width?: "sm" | "md" | "lg" | "xl" | "2xl";

  /**
   * Render exit icon in modal
   * @default "outside"
   */
  closeButton?: "inside";
  outside;
  none;

  /**
   * If true the false the modal will render with a transparent background
   * @default true
   */
  showBackground?: boolean;

  /**
   * Title of the modal
   * @default ""
   */
  heading?: string;

  /**
   * Sub title of the modal
   * @default ""
   */
  description?: string;

  /**
   * Number for nested panels
   * @default 1
   */
  depth?: number;
}

export default class Modal extends SvelteComponentTyped<
  ModalProps,
  { close: CustomEvent<any>; closed: CustomEvent<any> },
  { default: {}; content: {}; footer: {}; header: {} }
> {}
