function noop() { }
const identity = x => x;
function assign(tar, src) {
    // @ts-ignore
    for (const k in src)
        tar[k] = src[k];
    return tar;
}
function run(fn) {
    return fn();
}
function blank_object() {
    return Object.create(null);
}
function run_all(fns) {
    fns.forEach(run);
}
function is_function(thing) {
    return typeof thing === 'function';
}
function safe_not_equal(a, b) {
    return a != a ? b == b : a !== b || ((a && typeof a === 'object') || typeof a === 'function');
}
function is_empty(obj) {
    return Object.keys(obj).length === 0;
}
function subscribe(store, ...callbacks) {
    if (store == null) {
        return noop;
    }
    const unsub = store.subscribe(...callbacks);
    return unsub.unsubscribe ? () => unsub.unsubscribe() : unsub;
}
function component_subscribe(component, store, callback) {
    component.$$.on_destroy.push(subscribe(store, callback));
}
function create_slot(definition, ctx, $$scope, fn) {
    if (definition) {
        const slot_ctx = get_slot_context(definition, ctx, $$scope, fn);
        return definition[0](slot_ctx);
    }
}
function get_slot_context(definition, ctx, $$scope, fn) {
    return definition[1] && fn
        ? assign($$scope.ctx.slice(), definition[1](fn(ctx)))
        : $$scope.ctx;
}
function get_slot_changes(definition, $$scope, dirty, fn) {
    if (definition[2] && fn) {
        const lets = definition[2](fn(dirty));
        if ($$scope.dirty === undefined) {
            return lets;
        }
        if (typeof lets === 'object') {
            const merged = [];
            const len = Math.max($$scope.dirty.length, lets.length);
            for (let i = 0; i < len; i += 1) {
                merged[i] = $$scope.dirty[i] | lets[i];
            }
            return merged;
        }
        return $$scope.dirty | lets;
    }
    return $$scope.dirty;
}
function update_slot_base(slot, slot_definition, ctx, $$scope, slot_changes, get_slot_context_fn) {
    if (slot_changes) {
        const slot_context = get_slot_context(slot_definition, ctx, $$scope, get_slot_context_fn);
        slot.p(slot_context, slot_changes);
    }
}
function get_all_dirty_from_scope($$scope) {
    if ($$scope.ctx.length > 32) {
        const dirty = [];
        const length = $$scope.ctx.length / 32;
        for (let i = 0; i < length; i++) {
            dirty[i] = -1;
        }
        return dirty;
    }
    return -1;
}
function exclude_internal_props(props) {
    const result = {};
    for (const k in props)
        if (k[0] !== '$')
            result[k] = props[k];
    return result;
}
function compute_rest_props(props, keys) {
    const rest = {};
    keys = new Set(keys);
    for (const k in props)
        if (!keys.has(k) && k[0] !== '$')
            rest[k] = props[k];
    return rest;
}
function compute_slots(slots) {
    const result = {};
    for (const key in slots) {
        result[key] = true;
    }
    return result;
}
function set_store_value(store, ret, value) {
    store.set(value);
    return ret;
}
function action_destroyer(action_result) {
    return action_result && is_function(action_result.destroy) ? action_result.destroy : noop;
}

const is_client = typeof window !== 'undefined';
let now = is_client
    ? () => window.performance.now()
    : () => Date.now();
let raf = is_client ? cb => requestAnimationFrame(cb) : noop;

const tasks = new Set();
function run_tasks(now) {
    tasks.forEach(task => {
        if (!task.c(now)) {
            tasks.delete(task);
            task.f();
        }
    });
    if (tasks.size !== 0)
        raf(run_tasks);
}
/**
 * Creates a new task that runs on each raf frame
 * until it returns a falsy value or is aborted
 */
function loop(callback) {
    let task;
    if (tasks.size === 0)
        raf(run_tasks);
    return {
        promise: new Promise(fulfill => {
            tasks.add(task = { c: callback, f: fulfill });
        }),
        abort() {
            tasks.delete(task);
        }
    };
}

// Track which nodes are claimed during hydration. Unclaimed nodes can then be removed from the DOM
// at the end of hydration without touching the remaining nodes.
let is_hydrating = false;
function start_hydrating() {
    is_hydrating = true;
}
function end_hydrating() {
    is_hydrating = false;
}
function upper_bound(low, high, key, value) {
    // Return first index of value larger than input value in the range [low, high)
    while (low < high) {
        const mid = low + ((high - low) >> 1);
        if (key(mid) <= value) {
            low = mid + 1;
        }
        else {
            high = mid;
        }
    }
    return low;
}
function init_hydrate(target) {
    if (target.hydrate_init)
        return;
    target.hydrate_init = true;
    // We know that all children have claim_order values since the unclaimed have been detached if target is not <head>
    let children = target.childNodes;
    // If target is <head>, there may be children without claim_order
    if (target.nodeName === 'HEAD') {
        const myChildren = [];
        for (let i = 0; i < children.length; i++) {
            const node = children[i];
            if (node.claim_order !== undefined) {
                myChildren.push(node);
            }
        }
        children = myChildren;
    }
    /*
    * Reorder claimed children optimally.
    * We can reorder claimed children optimally by finding the longest subsequence of
    * nodes that are already claimed in order and only moving the rest. The longest
    * subsequence subsequence of nodes that are claimed in order can be found by
    * computing the longest increasing subsequence of .claim_order values.
    *
    * This algorithm is optimal in generating the least amount of reorder operations
    * possible.
    *
    * Proof:
    * We know that, given a set of reordering operations, the nodes that do not move
    * always form an increasing subsequence, since they do not move among each other
    * meaning that they must be already ordered among each other. Thus, the maximal
    * set of nodes that do not move form a longest increasing subsequence.
    */
    // Compute longest increasing subsequence
    // m: subsequence length j => index k of smallest value that ends an increasing subsequence of length j
    const m = new Int32Array(children.length + 1);
    // Predecessor indices + 1
    const p = new Int32Array(children.length);
    m[0] = -1;
    let longest = 0;
    for (let i = 0; i < children.length; i++) {
        const current = children[i].claim_order;
        // Find the largest subsequence length such that it ends in a value less than our current value
        // upper_bound returns first greater value, so we subtract one
        // with fast path for when we are on the current longest subsequence
        const seqLen = ((longest > 0 && children[m[longest]].claim_order <= current) ? longest + 1 : upper_bound(1, longest, idx => children[m[idx]].claim_order, current)) - 1;
        p[i] = m[seqLen] + 1;
        const newLen = seqLen + 1;
        // We can guarantee that current is the smallest value. Otherwise, we would have generated a longer sequence.
        m[newLen] = i;
        longest = Math.max(newLen, longest);
    }
    // The longest increasing subsequence of nodes (initially reversed)
    const lis = [];
    // The rest of the nodes, nodes that will be moved
    const toMove = [];
    let last = children.length - 1;
    for (let cur = m[longest] + 1; cur != 0; cur = p[cur - 1]) {
        lis.push(children[cur - 1]);
        for (; last >= cur; last--) {
            toMove.push(children[last]);
        }
        last--;
    }
    for (; last >= 0; last--) {
        toMove.push(children[last]);
    }
    lis.reverse();
    // We sort the nodes being moved to guarantee that their insertion order matches the claim order
    toMove.sort((a, b) => a.claim_order - b.claim_order);
    // Finally, we move the nodes
    for (let i = 0, j = 0; i < toMove.length; i++) {
        while (j < lis.length && toMove[i].claim_order >= lis[j].claim_order) {
            j++;
        }
        const anchor = j < lis.length ? lis[j] : null;
        target.insertBefore(toMove[i], anchor);
    }
}
function append(target, node) {
    target.appendChild(node);
}
function get_root_for_style(node) {
    if (!node)
        return document;
    const root = node.getRootNode ? node.getRootNode() : node.ownerDocument;
    if (root && root.host) {
        return root;
    }
    return node.ownerDocument;
}
function append_empty_stylesheet(node) {
    const style_element = element('style');
    append_stylesheet(get_root_for_style(node), style_element);
    return style_element.sheet;
}
function append_stylesheet(node, style) {
    append(node.head || node, style);
}
function append_hydration(target, node) {
    if (is_hydrating) {
        init_hydrate(target);
        if ((target.actual_end_child === undefined) || ((target.actual_end_child !== null) && (target.actual_end_child.parentElement !== target))) {
            target.actual_end_child = target.firstChild;
        }
        // Skip nodes of undefined ordering
        while ((target.actual_end_child !== null) && (target.actual_end_child.claim_order === undefined)) {
            target.actual_end_child = target.actual_end_child.nextSibling;
        }
        if (node !== target.actual_end_child) {
            // We only insert if the ordering of this node should be modified or the parent node is not target
            if (node.claim_order !== undefined || node.parentNode !== target) {
                target.insertBefore(node, target.actual_end_child);
            }
        }
        else {
            target.actual_end_child = node.nextSibling;
        }
    }
    else if (node.parentNode !== target || node.nextSibling !== null) {
        target.appendChild(node);
    }
}
function insert(target, node, anchor) {
    target.insertBefore(node, anchor || null);
}
function insert_hydration(target, node, anchor) {
    if (is_hydrating && !anchor) {
        append_hydration(target, node);
    }
    else if (node.parentNode !== target || node.nextSibling != anchor) {
        target.insertBefore(node, anchor || null);
    }
}
function detach(node) {
    node.parentNode.removeChild(node);
}
function destroy_each(iterations, detaching) {
    for (let i = 0; i < iterations.length; i += 1) {
        if (iterations[i])
            iterations[i].d(detaching);
    }
}
function element(name) {
    return document.createElement(name);
}
function svg_element(name) {
    return document.createElementNS('http://www.w3.org/2000/svg', name);
}
function text(data) {
    return document.createTextNode(data);
}
function space() {
    return text(' ');
}
function empty() {
    return text('');
}
function listen(node, event, handler, options) {
    node.addEventListener(event, handler, options);
    return () => node.removeEventListener(event, handler, options);
}
function prevent_default(fn) {
    return function (event) {
        event.preventDefault();
        // @ts-ignore
        return fn.call(this, event);
    };
}
function stop_propagation(fn) {
    return function (event) {
        event.stopPropagation();
        // @ts-ignore
        return fn.call(this, event);
    };
}
function attr(node, attribute, value) {
    if (value == null)
        node.removeAttribute(attribute);
    else if (node.getAttribute(attribute) !== value)
        node.setAttribute(attribute, value);
}
function set_attributes(node, attributes) {
    // @ts-ignore
    const descriptors = Object.getOwnPropertyDescriptors(node.__proto__);
    for (const key in attributes) {
        if (attributes[key] == null) {
            node.removeAttribute(key);
        }
        else if (key === 'style') {
            node.style.cssText = attributes[key];
        }
        else if (key === '__value') {
            node.value = node[key] = attributes[key];
        }
        else if (descriptors[key] && descriptors[key].set) {
            node[key] = attributes[key];
        }
        else {
            attr(node, key, attributes[key]);
        }
    }
}
function get_binding_group_value(group, __value, checked) {
    const value = new Set();
    for (let i = 0; i < group.length; i += 1) {
        if (group[i].checked)
            value.add(group[i].__value);
    }
    if (!checked) {
        value.delete(__value);
    }
    return Array.from(value);
}
function children(element) {
    return Array.from(element.childNodes);
}
function init_claim_info(nodes) {
    if (nodes.claim_info === undefined) {
        nodes.claim_info = { last_index: 0, total_claimed: 0 };
    }
}
function claim_node(nodes, predicate, processNode, createNode, dontUpdateLastIndex = false) {
    // Try to find nodes in an order such that we lengthen the longest increasing subsequence
    init_claim_info(nodes);
    const resultNode = (() => {
        // We first try to find an element after the previous one
        for (let i = nodes.claim_info.last_index; i < nodes.length; i++) {
            const node = nodes[i];
            if (predicate(node)) {
                const replacement = processNode(node);
                if (replacement === undefined) {
                    nodes.splice(i, 1);
                }
                else {
                    nodes[i] = replacement;
                }
                if (!dontUpdateLastIndex) {
                    nodes.claim_info.last_index = i;
                }
                return node;
            }
        }
        // Otherwise, we try to find one before
        // We iterate in reverse so that we don't go too far back
        for (let i = nodes.claim_info.last_index - 1; i >= 0; i--) {
            const node = nodes[i];
            if (predicate(node)) {
                const replacement = processNode(node);
                if (replacement === undefined) {
                    nodes.splice(i, 1);
                }
                else {
                    nodes[i] = replacement;
                }
                if (!dontUpdateLastIndex) {
                    nodes.claim_info.last_index = i;
                }
                else if (replacement === undefined) {
                    // Since we spliced before the last_index, we decrease it
                    nodes.claim_info.last_index--;
                }
                return node;
            }
        }
        // If we can't find any matching node, we create a new one
        return createNode();
    })();
    resultNode.claim_order = nodes.claim_info.total_claimed;
    nodes.claim_info.total_claimed += 1;
    return resultNode;
}
function claim_element_base(nodes, name, attributes, create_element) {
    return claim_node(nodes, (node) => node.nodeName === name, (node) => {
        const remove = [];
        for (let j = 0; j < node.attributes.length; j++) {
            const attribute = node.attributes[j];
            if (!attributes[attribute.name]) {
                remove.push(attribute.name);
            }
        }
        remove.forEach(v => node.removeAttribute(v));
        return undefined;
    }, () => create_element(name));
}
function claim_element(nodes, name, attributes) {
    return claim_element_base(nodes, name, attributes, element);
}
function claim_svg_element(nodes, name, attributes) {
    return claim_element_base(nodes, name, attributes, svg_element);
}
function claim_text(nodes, data) {
    return claim_node(nodes, (node) => node.nodeType === 3, (node) => {
        const dataStr = '' + data;
        if (node.data.startsWith(dataStr)) {
            if (node.data.length !== dataStr.length) {
                return node.splitText(dataStr.length);
            }
        }
        else {
            node.data = dataStr;
        }
    }, () => text(data), true // Text nodes should not update last index since it is likely not worth it to eliminate an increasing subsequence of actual elements
    );
}
function claim_space(nodes) {
    return claim_text(nodes, ' ');
}
function find_comment(nodes, text, start) {
    for (let i = start; i < nodes.length; i += 1) {
        const node = nodes[i];
        if (node.nodeType === 8 /* comment node */ && node.textContent.trim() === text) {
            return i;
        }
    }
    return nodes.length;
}
function claim_html_tag(nodes, is_svg) {
    // find html opening tag
    const start_index = find_comment(nodes, 'HTML_TAG_START', 0);
    const end_index = find_comment(nodes, 'HTML_TAG_END', start_index);
    if (start_index === end_index) {
        return new HtmlTagHydration(undefined, is_svg);
    }
    init_claim_info(nodes);
    const html_tag_nodes = nodes.splice(start_index, end_index - start_index + 1);
    detach(html_tag_nodes[0]);
    detach(html_tag_nodes[html_tag_nodes.length - 1]);
    const claimed_nodes = html_tag_nodes.slice(1, html_tag_nodes.length - 1);
    for (const n of claimed_nodes) {
        n.claim_order = nodes.claim_info.total_claimed;
        nodes.claim_info.total_claimed += 1;
    }
    return new HtmlTagHydration(claimed_nodes, is_svg);
}
function set_data(text, data) {
    data = '' + data;
    if (text.wholeText !== data)
        text.data = data;
}
function set_input_value(input, value) {
    input.value = value == null ? '' : value;
}
function set_style(node, key, value, important) {
    if (value === null) {
        node.style.removeProperty(key);
    }
    else {
        node.style.setProperty(key, value, important ? 'important' : '');
    }
}
function select_option(select, value) {
    for (let i = 0; i < select.options.length; i += 1) {
        const option = select.options[i];
        if (option.__value === value) {
            option.selected = true;
            return;
        }
    }
    select.selectedIndex = -1; // no option should be selected
}
function select_options(select, value) {
    for (let i = 0; i < select.options.length; i += 1) {
        const option = select.options[i];
        option.selected = ~value.indexOf(option.__value);
    }
}
function select_value(select) {
    const selected_option = select.querySelector(':checked') || select.options[0];
    return selected_option && selected_option.__value;
}
function toggle_class(element, name, toggle) {
    element.classList[toggle ? 'add' : 'remove'](name);
}
function custom_event(type, detail, { bubbles = false, cancelable = false } = {}) {
    const e = document.createEvent('CustomEvent');
    e.initCustomEvent(type, bubbles, cancelable, detail);
    return e;
}
class HtmlTag {
    constructor(is_svg = false) {
        this.is_svg = false;
        this.is_svg = is_svg;
        this.e = this.n = null;
    }
    c(html) {
        this.h(html);
    }
    m(html, target, anchor = null) {
        if (!this.e) {
            if (this.is_svg)
                this.e = svg_element(target.nodeName);
            else
                this.e = element(target.nodeName);
            this.t = target;
            this.c(html);
        }
        this.i(anchor);
    }
    h(html) {
        this.e.innerHTML = html;
        this.n = Array.from(this.e.childNodes);
    }
    i(anchor) {
        for (let i = 0; i < this.n.length; i += 1) {
            insert(this.t, this.n[i], anchor);
        }
    }
    p(html) {
        this.d();
        this.h(html);
        this.i(this.a);
    }
    d() {
        this.n.forEach(detach);
    }
}
class HtmlTagHydration extends HtmlTag {
    constructor(claimed_nodes, is_svg = false) {
        super(is_svg);
        this.e = this.n = null;
        this.l = claimed_nodes;
    }
    c(html) {
        if (this.l) {
            this.n = this.l;
        }
        else {
            super.c(html);
        }
    }
    i(anchor) {
        for (let i = 0; i < this.n.length; i += 1) {
            insert_hydration(this.t, this.n[i], anchor);
        }
    }
}

// we need to store the information for multiple documents because a Svelte application could also contain iframes
// https://github.com/sveltejs/svelte/issues/3624
const managed_styles = new Map();
let active = 0;
// https://github.com/darkskyapp/string-hash/blob/master/index.js
function hash$2(str) {
    let hash = 5381;
    let i = str.length;
    while (i--)
        hash = ((hash << 5) - hash) ^ str.charCodeAt(i);
    return hash >>> 0;
}
function create_style_information(doc, node) {
    const info = { stylesheet: append_empty_stylesheet(node), rules: {} };
    managed_styles.set(doc, info);
    return info;
}
function create_rule(node, a, b, duration, delay, ease, fn, uid = 0) {
    const step = 16.666 / duration;
    let keyframes = '{\n';
    for (let p = 0; p <= 1; p += step) {
        const t = a + (b - a) * ease(p);
        keyframes += p * 100 + `%{${fn(t, 1 - t)}}\n`;
    }
    const rule = keyframes + `100% {${fn(b, 1 - b)}}\n}`;
    const name = `__svelte_${hash$2(rule)}_${uid}`;
    const doc = get_root_for_style(node);
    const { stylesheet, rules } = managed_styles.get(doc) || create_style_information(doc, node);
    if (!rules[name]) {
        rules[name] = true;
        stylesheet.insertRule(`@keyframes ${name} ${rule}`, stylesheet.cssRules.length);
    }
    const animation = node.style.animation || '';
    node.style.animation = `${animation ? `${animation}, ` : ''}${name} ${duration}ms linear ${delay}ms 1 both`;
    active += 1;
    return name;
}
function delete_rule(node, name) {
    const previous = (node.style.animation || '').split(', ');
    const next = previous.filter(name
        ? anim => anim.indexOf(name) < 0 // remove specific animation
        : anim => anim.indexOf('__svelte') === -1 // remove all Svelte animations
    );
    const deleted = previous.length - next.length;
    if (deleted) {
        node.style.animation = next.join(', ');
        active -= deleted;
        if (!active)
            clear_rules();
    }
}
function clear_rules() {
    raf(() => {
        if (active)
            return;
        managed_styles.forEach(info => {
            const { stylesheet } = info;
            let i = stylesheet.cssRules.length;
            while (i--)
                stylesheet.deleteRule(i);
            info.rules = {};
        });
        managed_styles.clear();
    });
}

function create_animation(node, from, fn, params) {
    if (!from)
        return noop;
    const to = node.getBoundingClientRect();
    if (from.left === to.left && from.right === to.right && from.top === to.top && from.bottom === to.bottom)
        return noop;
    const { delay = 0, duration = 300, easing = identity, 
    // @ts-ignore todo: should this be separated from destructuring? Or start/end added to public api and documentation?
    start: start_time = now() + delay, 
    // @ts-ignore todo:
    end = start_time + duration, tick = noop, css } = fn(node, { from, to }, params);
    let running = true;
    let started = false;
    let name;
    function start() {
        if (css) {
            name = create_rule(node, 0, 1, duration, delay, easing, css);
        }
        if (!delay) {
            started = true;
        }
    }
    function stop() {
        if (css)
            delete_rule(node, name);
        running = false;
    }
    loop(now => {
        if (!started && now >= start_time) {
            started = true;
        }
        if (started && now >= end) {
            tick(1, 0);
            stop();
        }
        if (!running) {
            return false;
        }
        if (started) {
            const p = now - start_time;
            const t = 0 + 1 * easing(p / duration);
            tick(t, 1 - t);
        }
        return true;
    });
    start();
    tick(0, 1);
    return stop;
}
function fix_position(node) {
    const style = getComputedStyle(node);
    if (style.position !== 'absolute' && style.position !== 'fixed') {
        const { width, height } = style;
        const a = node.getBoundingClientRect();
        node.style.position = 'absolute';
        node.style.width = width;
        node.style.height = height;
        add_transform(node, a);
    }
}
function add_transform(node, a) {
    const b = node.getBoundingClientRect();
    if (a.left !== b.left || a.top !== b.top) {
        const style = getComputedStyle(node);
        const transform = style.transform === 'none' ? '' : style.transform;
        node.style.transform = `${transform} translate(${a.left - b.left}px, ${a.top - b.top}px)`;
    }
}

let current_component;
function set_current_component(component) {
    current_component = component;
}
function get_current_component() {
    if (!current_component)
        throw new Error('Function called outside component initialization');
    return current_component;
}
function onMount(fn) {
    get_current_component().$$.on_mount.push(fn);
}
function onDestroy(fn) {
    get_current_component().$$.on_destroy.push(fn);
}
function createEventDispatcher() {
    const component = get_current_component();
    return (type, detail, { cancelable = false } = {}) => {
        const callbacks = component.$$.callbacks[type];
        if (callbacks) {
            // TODO are there situations where events could be dispatched
            // in a server (non-DOM) environment?
            const event = custom_event(type, detail, { cancelable });
            callbacks.slice().forEach(fn => {
                fn.call(component, event);
            });
            return !event.defaultPrevented;
        }
        return true;
    };
}
function setContext(key, context) {
    get_current_component().$$.context.set(key, context);
    return context;
}
function getContext(key) {
    return get_current_component().$$.context.get(key);
}
// TODO figure out if we still want to support
// shorthand events, or if we want to implement
// a real bubbling mechanism
function bubble(component, event) {
    const callbacks = component.$$.callbacks[event.type];
    if (callbacks) {
        // @ts-ignore
        callbacks.slice().forEach(fn => fn.call(this, event));
    }
}

const dirty_components = [];
const binding_callbacks = [];
const render_callbacks = [];
const flush_callbacks = [];
const resolved_promise = Promise.resolve();
let update_scheduled = false;
function schedule_update() {
    if (!update_scheduled) {
        update_scheduled = true;
        resolved_promise.then(flush);
    }
}
function tick() {
    schedule_update();
    return resolved_promise;
}
function add_render_callback(fn) {
    render_callbacks.push(fn);
}
function add_flush_callback(fn) {
    flush_callbacks.push(fn);
}
// flush() calls callbacks in this order:
// 1. All beforeUpdate callbacks, in order: parents before children
// 2. All bind:this callbacks, in reverse order: children before parents.
// 3. All afterUpdate callbacks, in order: parents before children. EXCEPT
//    for afterUpdates called during the initial onMount, which are called in
//    reverse order: children before parents.
// Since callbacks might update component values, which could trigger another
// call to flush(), the following steps guard against this:
// 1. During beforeUpdate, any updated components will be added to the
//    dirty_components array and will cause a reentrant call to flush(). Because
//    the flush index is kept outside the function, the reentrant call will pick
//    up where the earlier call left off and go through all dirty components. The
//    current_component value is saved and restored so that the reentrant call will
//    not interfere with the "parent" flush() call.
// 2. bind:this callbacks cannot trigger new flush() calls.
// 3. During afterUpdate, any updated components will NOT have their afterUpdate
//    callback called a second time; the seen_callbacks set, outside the flush()
//    function, guarantees this behavior.
const seen_callbacks = new Set();
let flushidx = 0; // Do *not* move this inside the flush() function
function flush() {
    const saved_component = current_component;
    do {
        // first, call beforeUpdate functions
        // and update components
        while (flushidx < dirty_components.length) {
            const component = dirty_components[flushidx];
            flushidx++;
            set_current_component(component);
            update(component.$$);
        }
        set_current_component(null);
        dirty_components.length = 0;
        flushidx = 0;
        while (binding_callbacks.length)
            binding_callbacks.pop()();
        // then, once components are updated, call
        // afterUpdate functions. This may cause
        // subsequent updates...
        for (let i = 0; i < render_callbacks.length; i += 1) {
            const callback = render_callbacks[i];
            if (!seen_callbacks.has(callback)) {
                // ...so guard against infinite loops
                seen_callbacks.add(callback);
                callback();
            }
        }
        render_callbacks.length = 0;
    } while (dirty_components.length);
    while (flush_callbacks.length) {
        flush_callbacks.pop()();
    }
    update_scheduled = false;
    seen_callbacks.clear();
    set_current_component(saved_component);
}
function update($$) {
    if ($$.fragment !== null) {
        $$.update();
        run_all($$.before_update);
        const dirty = $$.dirty;
        $$.dirty = [-1];
        $$.fragment && $$.fragment.p($$.ctx, dirty);
        $$.after_update.forEach(add_render_callback);
    }
}

let promise;
function wait() {
    if (!promise) {
        promise = Promise.resolve();
        promise.then(() => {
            promise = null;
        });
    }
    return promise;
}
function dispatch(node, direction, kind) {
    node.dispatchEvent(custom_event(`${direction ? 'intro' : 'outro'}${kind}`));
}
const outroing = new Set();
let outros;
function group_outros() {
    outros = {
        r: 0,
        c: [],
        p: outros // parent group
    };
}
function check_outros() {
    if (!outros.r) {
        run_all(outros.c);
    }
    outros = outros.p;
}
function transition_in(block, local) {
    if (block && block.i) {
        outroing.delete(block);
        block.i(local);
    }
}
function transition_out(block, local, detach, callback) {
    if (block && block.o) {
        if (outroing.has(block))
            return;
        outroing.add(block);
        outros.c.push(() => {
            outroing.delete(block);
            if (callback) {
                if (detach)
                    block.d(1);
                callback();
            }
        });
        block.o(local);
    }
}
const null_transition = { duration: 0 };
function create_in_transition(node, fn, params) {
    let config = fn(node, params);
    let running = false;
    let animation_name;
    let task;
    let uid = 0;
    function cleanup() {
        if (animation_name)
            delete_rule(node, animation_name);
    }
    function go() {
        const { delay = 0, duration = 300, easing = identity, tick = noop, css } = config || null_transition;
        if (css)
            animation_name = create_rule(node, 0, 1, duration, delay, easing, css, uid++);
        tick(0, 1);
        const start_time = now() + delay;
        const end_time = start_time + duration;
        if (task)
            task.abort();
        running = true;
        add_render_callback(() => dispatch(node, true, 'start'));
        task = loop(now => {
            if (running) {
                if (now >= end_time) {
                    tick(1, 0);
                    dispatch(node, true, 'end');
                    cleanup();
                    return running = false;
                }
                if (now >= start_time) {
                    const t = easing((now - start_time) / duration);
                    tick(t, 1 - t);
                }
            }
            return running;
        });
    }
    let started = false;
    return {
        start() {
            if (started)
                return;
            started = true;
            delete_rule(node);
            if (is_function(config)) {
                config = config();
                wait().then(go);
            }
            else {
                go();
            }
        },
        invalidate() {
            started = false;
        },
        end() {
            if (running) {
                cleanup();
                running = false;
            }
        }
    };
}
function create_out_transition(node, fn, params) {
    let config = fn(node, params);
    let running = true;
    let animation_name;
    const group = outros;
    group.r += 1;
    function go() {
        const { delay = 0, duration = 300, easing = identity, tick = noop, css } = config || null_transition;
        if (css)
            animation_name = create_rule(node, 1, 0, duration, delay, easing, css);
        const start_time = now() + delay;
        const end_time = start_time + duration;
        add_render_callback(() => dispatch(node, false, 'start'));
        loop(now => {
            if (running) {
                if (now >= end_time) {
                    tick(0, 1);
                    dispatch(node, false, 'end');
                    if (!--group.r) {
                        // this will result in `end()` being called,
                        // so we don't need to clean up here
                        run_all(group.c);
                    }
                    return false;
                }
                if (now >= start_time) {
                    const t = easing((now - start_time) / duration);
                    tick(1 - t, t);
                }
            }
            return running;
        });
    }
    if (is_function(config)) {
        wait().then(() => {
            // @ts-ignore
            config = config();
            go();
        });
    }
    else {
        go();
    }
    return {
        end(reset) {
            if (reset && config.tick) {
                config.tick(1, 0);
            }
            if (running) {
                if (animation_name)
                    delete_rule(node, animation_name);
                running = false;
            }
        }
    };
}
function create_bidirectional_transition(node, fn, params, intro) {
    let config = fn(node, params);
    let t = intro ? 0 : 1;
    let running_program = null;
    let pending_program = null;
    let animation_name = null;
    function clear_animation() {
        if (animation_name)
            delete_rule(node, animation_name);
    }
    function init(program, duration) {
        const d = (program.b - t);
        duration *= Math.abs(d);
        return {
            a: t,
            b: program.b,
            d,
            duration,
            start: program.start,
            end: program.start + duration,
            group: program.group
        };
    }
    function go(b) {
        const { delay = 0, duration = 300, easing = identity, tick = noop, css } = config || null_transition;
        const program = {
            start: now() + delay,
            b
        };
        if (!b) {
            // @ts-ignore todo: improve typings
            program.group = outros;
            outros.r += 1;
        }
        if (running_program || pending_program) {
            pending_program = program;
        }
        else {
            // if this is an intro, and there's a delay, we need to do
            // an initial tick and/or apply CSS animation immediately
            if (css) {
                clear_animation();
                animation_name = create_rule(node, t, b, duration, delay, easing, css);
            }
            if (b)
                tick(0, 1);
            running_program = init(program, duration);
            add_render_callback(() => dispatch(node, b, 'start'));
            loop(now => {
                if (pending_program && now > pending_program.start) {
                    running_program = init(pending_program, duration);
                    pending_program = null;
                    dispatch(node, running_program.b, 'start');
                    if (css) {
                        clear_animation();
                        animation_name = create_rule(node, t, running_program.b, running_program.duration, 0, easing, config.css);
                    }
                }
                if (running_program) {
                    if (now >= running_program.end) {
                        tick(t = running_program.b, 1 - t);
                        dispatch(node, running_program.b, 'end');
                        if (!pending_program) {
                            // we're done
                            if (running_program.b) {
                                // intro — we can tidy up immediately
                                clear_animation();
                            }
                            else {
                                // outro — needs to be coordinated
                                if (!--running_program.group.r)
                                    run_all(running_program.group.c);
                            }
                        }
                        running_program = null;
                    }
                    else if (now >= running_program.start) {
                        const p = now - running_program.start;
                        t = running_program.a + running_program.d * easing(p / running_program.duration);
                        tick(t, 1 - t);
                    }
                }
                return !!(running_program || pending_program);
            });
        }
    }
    return {
        run(b) {
            if (is_function(config)) {
                wait().then(() => {
                    // @ts-ignore
                    config = config();
                    go(b);
                });
            }
            else {
                go(b);
            }
        },
        end() {
            clear_animation();
            running_program = pending_program = null;
        }
    };
}

const globals = (typeof window !== 'undefined'
    ? window
    : typeof globalThis !== 'undefined'
        ? globalThis
        : global);
function outro_and_destroy_block(block, lookup) {
    transition_out(block, 1, 1, () => {
        lookup.delete(block.key);
    });
}
function fix_and_outro_and_destroy_block(block, lookup) {
    block.f();
    outro_and_destroy_block(block, lookup);
}
function update_keyed_each(old_blocks, dirty, get_key, dynamic, ctx, list, lookup, node, destroy, create_each_block, next, get_context) {
    let o = old_blocks.length;
    let n = list.length;
    let i = o;
    const old_indexes = {};
    while (i--)
        old_indexes[old_blocks[i].key] = i;
    const new_blocks = [];
    const new_lookup = new Map();
    const deltas = new Map();
    i = n;
    while (i--) {
        const child_ctx = get_context(ctx, list, i);
        const key = get_key(child_ctx);
        let block = lookup.get(key);
        if (!block) {
            block = create_each_block(key, child_ctx);
            block.c();
        }
        else if (dynamic) {
            block.p(child_ctx, dirty);
        }
        new_lookup.set(key, new_blocks[i] = block);
        if (key in old_indexes)
            deltas.set(key, Math.abs(i - old_indexes[key]));
    }
    const will_move = new Set();
    const did_move = new Set();
    function insert(block) {
        transition_in(block, 1);
        block.m(node, next);
        lookup.set(block.key, block);
        next = block.first;
        n--;
    }
    while (o && n) {
        const new_block = new_blocks[n - 1];
        const old_block = old_blocks[o - 1];
        const new_key = new_block.key;
        const old_key = old_block.key;
        if (new_block === old_block) {
            // do nothing
            next = new_block.first;
            o--;
            n--;
        }
        else if (!new_lookup.has(old_key)) {
            // remove old block
            destroy(old_block, lookup);
            o--;
        }
        else if (!lookup.has(new_key) || will_move.has(new_key)) {
            insert(new_block);
        }
        else if (did_move.has(old_key)) {
            o--;
        }
        else if (deltas.get(new_key) > deltas.get(old_key)) {
            did_move.add(new_key);
            insert(new_block);
        }
        else {
            will_move.add(old_key);
            o--;
        }
    }
    while (o--) {
        const old_block = old_blocks[o];
        if (!new_lookup.has(old_block.key))
            destroy(old_block, lookup);
    }
    while (n)
        insert(new_blocks[n - 1]);
    return new_blocks;
}

function get_spread_update(levels, updates) {
    const update = {};
    const to_null_out = {};
    const accounted_for = { $$scope: 1 };
    let i = levels.length;
    while (i--) {
        const o = levels[i];
        const n = updates[i];
        if (n) {
            for (const key in o) {
                if (!(key in n))
                    to_null_out[key] = 1;
            }
            for (const key in n) {
                if (!accounted_for[key]) {
                    update[key] = n[key];
                    accounted_for[key] = 1;
                }
            }
            levels[i] = n;
        }
        else {
            for (const key in o) {
                accounted_for[key] = 1;
            }
        }
    }
    for (const key in to_null_out) {
        if (!(key in update))
            update[key] = undefined;
    }
    return update;
}
function get_spread_object(spread_props) {
    return typeof spread_props === 'object' && spread_props !== null ? spread_props : {};
}

function bind(component, name, callback) {
    const index = component.$$.props[name];
    if (index !== undefined) {
        component.$$.bound[index] = callback;
        callback(component.$$.ctx[index]);
    }
}
function create_component(block) {
    block && block.c();
}
function claim_component(block, parent_nodes) {
    block && block.l(parent_nodes);
}
function mount_component(component, target, anchor, customElement) {
    const { fragment, on_mount, on_destroy, after_update } = component.$$;
    fragment && fragment.m(target, anchor);
    if (!customElement) {
        // onMount happens before the initial afterUpdate
        add_render_callback(() => {
            const new_on_destroy = on_mount.map(run).filter(is_function);
            if (on_destroy) {
                on_destroy.push(...new_on_destroy);
            }
            else {
                // Edge case - component was destroyed immediately,
                // most likely as a result of a binding initialising
                run_all(new_on_destroy);
            }
            component.$$.on_mount = [];
        });
    }
    after_update.forEach(add_render_callback);
}
function destroy_component(component, detaching) {
    const $$ = component.$$;
    if ($$.fragment !== null) {
        run_all($$.on_destroy);
        $$.fragment && $$.fragment.d(detaching);
        // TODO null out other refs, including component.$$ (but need to
        // preserve final state?)
        $$.on_destroy = $$.fragment = null;
        $$.ctx = [];
    }
}
function make_dirty(component, i) {
    if (component.$$.dirty[0] === -1) {
        dirty_components.push(component);
        schedule_update();
        component.$$.dirty.fill(0);
    }
    component.$$.dirty[(i / 31) | 0] |= (1 << (i % 31));
}
function init(component, options, instance, create_fragment, not_equal, props, append_styles, dirty = [-1]) {
    const parent_component = current_component;
    set_current_component(component);
    const $$ = component.$$ = {
        fragment: null,
        ctx: null,
        // state
        props,
        update: noop,
        not_equal,
        bound: blank_object(),
        // lifecycle
        on_mount: [],
        on_destroy: [],
        on_disconnect: [],
        before_update: [],
        after_update: [],
        context: new Map(options.context || (parent_component ? parent_component.$$.context : [])),
        // everything else
        callbacks: blank_object(),
        dirty,
        skip_bound: false,
        root: options.target || parent_component.$$.root
    };
    append_styles && append_styles($$.root);
    let ready = false;
    $$.ctx = instance
        ? instance(component, options.props || {}, (i, ret, ...rest) => {
            const value = rest.length ? rest[0] : ret;
            if ($$.ctx && not_equal($$.ctx[i], $$.ctx[i] = value)) {
                if (!$$.skip_bound && $$.bound[i])
                    $$.bound[i](value);
                if (ready)
                    make_dirty(component, i);
            }
            return ret;
        })
        : [];
    $$.update();
    ready = true;
    run_all($$.before_update);
    // `false` as a special case of no DOM component
    $$.fragment = create_fragment ? create_fragment($$.ctx) : false;
    if (options.target) {
        if (options.hydrate) {
            start_hydrating();
            const nodes = children(options.target);
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            $$.fragment && $$.fragment.l(nodes);
            nodes.forEach(detach);
        }
        else {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            $$.fragment && $$.fragment.c();
        }
        if (options.intro)
            transition_in(component.$$.fragment);
        mount_component(component, options.target, options.anchor, options.customElement);
        end_hydrating();
        flush();
    }
    set_current_component(parent_component);
}
/**
 * Base class for Svelte components. Used when dev=false.
 */
class SvelteComponent {
    $destroy() {
        destroy_component(this, 1);
        this.$destroy = noop;
    }
    $on(type, callback) {
        const callbacks = (this.$$.callbacks[type] || (this.$$.callbacks[type] = []));
        callbacks.push(callback);
        return () => {
            const index = callbacks.indexOf(callback);
            if (index !== -1)
                callbacks.splice(index, 1);
        };
    }
    $set($$props) {
        if (this.$$set && !is_empty($$props)) {
            this.$$.skip_bound = true;
            this.$$set($$props);
            this.$$.skip_bound = false;
        }
    }
}

/* src\Icons\Beaker.svelte generated by Svelte v3.48.0 */

function create_fragment$X(ctx) {
	let path;

	return {
		c() {
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			path = claim_svg_element(nodes, "path", {
				"stroke-linecap": true,
				"stroke-linejoin": true,
				"stroke-width": true,
				d: true
			});

			children(path).forEach(detach);
			this.h();
		},
		h() {
			attr(path, "stroke-linecap", "round");
			attr(path, "stroke-linejoin", "round");
			attr(path, "stroke-width", "2");
			attr(path, "d", "M19.428 15.428a2 2 0 00-1.022-.547l-2.387-.477a6 6 0 00-3.86.517l-.318.158a6 6 0 01-3.86.517L6.05 15.21a2 2 0 00-1.806.547M8 4h8l-1 1v5.172a2 2 0 00.586 1.414l5 5c1.26 1.26.367 3.414-1.415 3.414H4.828c-1.782 0-2.674-2.154-1.414-3.414l5-5A2 2 0 009 10.172V5L8 4z");
		},
		m(target, anchor) {
			insert_hydration(target, path, anchor);
		},
		p: noop,
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(path);
		}
	};
}

class Beaker extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, null, create_fragment$X, safe_not_equal, {});
	}
}

/* src\Icons\Detail.svelte generated by Svelte v3.48.0 */

function create_fragment$W(ctx) {
	let path;

	return {
		c() {
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			path = claim_svg_element(nodes, "path", {
				"stroke-linecap": true,
				"stroke-linejoin": true,
				"stroke-width": true,
				d: true
			});

			children(path).forEach(detach);
			this.h();
		},
		h() {
			attr(path, "stroke-linecap", "round");
			attr(path, "stroke-linejoin", "round");
			attr(path, "stroke-width", "2");
			attr(path, "d", "M7 8h10M7 12h4m1 8l-4-4H5a2 2 0 01-2-2V6a2 2 0 012-2h14a2 2 0 012 2v8a2 2 0 01-2 2h-3l-4 4z");
		},
		m(target, anchor) {
			insert_hydration(target, path, anchor);
		},
		p: noop,
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(path);
		}
	};
}

class Detail extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, null, create_fragment$W, safe_not_equal, {});
	}
}

/* src\Icons\AlertIcon.svelte generated by Svelte v3.48.0 */

function create_fragment$V(ctx) {
	let path;

	return {
		c() {
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			path = claim_svg_element(nodes, "path", {
				"fill-rule": true,
				d: true,
				"clip-rule": true
			});

			children(path).forEach(detach);
			this.h();
		},
		h() {
			attr(path, "fill-rule", "evenodd");
			attr(path, "d", "M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-7 4a1 1 0 11-2 0 1 1 0 012 0zm-1-9a1 1 0 00-1 1v4a1 1 0 102 0V6a1 1 0 00-1-1z");
			attr(path, "clip-rule", "evenodd");
		},
		m(target, anchor) {
			insert_hydration(target, path, anchor);
		},
		p: noop,
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(path);
		}
	};
}

class AlertIcon extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, null, create_fragment$V, safe_not_equal, {});
	}
}

/* src\Icons\Search.svelte generated by Svelte v3.48.0 */

function create_fragment$U(ctx) {
	let path;

	return {
		c() {
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			path = claim_svg_element(nodes, "path", {
				"stroke-linecap": true,
				"stroke-linejoin": true,
				d: true
			});

			children(path).forEach(detach);
			this.h();
		},
		h() {
			attr(path, "stroke-linecap", "round");
			attr(path, "stroke-linejoin", "round");
			attr(path, "d", "M21 21l-6-6m2-5a7 7 0 11-14 0 7 7 0 0114 0z");
		},
		m(target, anchor) {
			insert_hydration(target, path, anchor);
		},
		p: noop,
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(path);
		}
	};
}

class Search extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, null, create_fragment$U, safe_not_equal, {});
	}
}

/* src\Icons\Tick.svelte generated by Svelte v3.48.0 */

function create_fragment$T(ctx) {
	let path;

	return {
		c() {
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			path = claim_svg_element(nodes, "path", {
				"fill-rule": true,
				d: true,
				"clip-rule": true
			});

			children(path).forEach(detach);
			this.h();
		},
		h() {
			attr(path, "fill-rule", "evenodd");
			attr(path, "d", "M16.707 5.293a1 1 0 010 1.414l-8 8a1 1 0 01-1.414 0l-4-4a1 1 0 011.414-1.414L8 12.586l7.293-7.293a1 1 0 011.414 0z");
			attr(path, "clip-rule", "evenodd");
		},
		m(target, anchor) {
			insert_hydration(target, path, anchor);
		},
		p: noop,
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(path);
		}
	};
}

class Tick extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, null, create_fragment$T, safe_not_equal, {});
	}
}

/* src\Icons\Cross.svelte generated by Svelte v3.48.0 */

function create_fragment$S(ctx) {
	let path;

	return {
		c() {
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			path = claim_svg_element(nodes, "path", {
				"stroke-linecap": true,
				"stroke-linejoin": true,
				"stroke-width": true,
				d: true
			});

			children(path).forEach(detach);
			this.h();
		},
		h() {
			attr(path, "stroke-linecap", "round");
			attr(path, "stroke-linejoin", "round");
			attr(path, "stroke-width", "2");
			attr(path, "d", "M6 18L18 6M6 6l12 12");
		},
		m(target, anchor) {
			insert_hydration(target, path, anchor);
		},
		p: noop,
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(path);
		}
	};
}

class Cross extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, null, create_fragment$S, safe_not_equal, {});
	}
}

/* src\Icons\Warn.svelte generated by Svelte v3.48.0 */

function create_fragment$R(ctx) {
	let path;

	return {
		c() {
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			path = claim_svg_element(nodes, "path", {
				"fill-rule": true,
				d: true,
				"clip-rule": true
			});

			children(path).forEach(detach);
			this.h();
		},
		h() {
			attr(path, "fill-rule", "evenodd");
			attr(path, "d", "M8.257 3.099c.765-1.36 2.722-1.36 3.486 0l5.58 9.92c.75 1.334-.213 2.98-1.742 2.98H4.42c-1.53 0-2.493-1.646-1.743-2.98l5.58-9.92zM11 13a1 1 0 11-2 0 1 1 0 012 0zm-1-8a1 1 0 00-1 1v3a1 1 0 002 0V6a1 1 0 00-1-1z");
			attr(path, "clip-rule", "evenodd");
		},
		m(target, anchor) {
			insert_hydration(target, path, anchor);
		},
		p: noop,
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(path);
		}
	};
}

class Warn extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, null, create_fragment$R, safe_not_equal, {});
	}
}

/* src\Icons\Info.svelte generated by Svelte v3.48.0 */

function create_fragment$Q(ctx) {
	let path;

	return {
		c() {
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			path = claim_svg_element(nodes, "path", {
				"fill-rule": true,
				d: true,
				"clip-rule": true
			});

			children(path).forEach(detach);
			this.h();
		},
		h() {
			attr(path, "fill-rule", "evenodd");
			attr(path, "d", "M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-7-4a1 1 0 11-2 0 1 1 0 012 0zM9 9a1 1 0 000 2v3a1 1 0 001 1h1a1 1 0 100-2v-3a1 1 0 00-1-1H9z");
			attr(path, "clip-rule", "evenodd");
		},
		m(target, anchor) {
			insert_hydration(target, path, anchor);
		},
		p: noop,
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(path);
		}
	};
}

class Info extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, null, create_fragment$Q, safe_not_equal, {});
	}
}

/* src\Icons\Exclamation.svelte generated by Svelte v3.48.0 */

function create_fragment$P(ctx) {
	let path;

	return {
		c() {
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			path = claim_svg_element(nodes, "path", {
				"fill-rule": true,
				d: true,
				"clip-rule": true
			});

			children(path).forEach(detach);
			this.h();
		},
		h() {
			attr(path, "fill-rule", "evenodd");
			attr(path, "d", "M8.257 3.099c.765-1.36 2.722-1.36 3.486 0l5.58 9.92c.75 1.334-.213 2.98-1.742 2.98H4.42c-1.53 0-2.493-1.646-1.743-2.98l5.58-9.92zM11 13a1 1 0 11-2 0 1 1 0 012 0zm-1-8a1 1 0 00-1 1v3a1 1 0 002 0V6a1 1 0 00-1-1z");
			attr(path, "clip-rule", "evenodd");
		},
		m(target, anchor) {
			insert_hydration(target, path, anchor);
		},
		p: noop,
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(path);
		}
	};
}

class Exclamation extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, null, create_fragment$P, safe_not_equal, {});
	}
}

/* src\Icons\XCircle.svelte generated by Svelte v3.48.0 */

function create_fragment$O(ctx) {
	let path;

	return {
		c() {
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			path = claim_svg_element(nodes, "path", {
				"fill-rule": true,
				d: true,
				"clip-rule": true
			});

			children(path).forEach(detach);
			this.h();
		},
		h() {
			attr(path, "fill-rule", "evenodd");
			attr(path, "d", "M10 18a8 8 0 100-16 8 8 0 000 16zM8.707 7.293a1 1 0 00-1.414 1.414L8.586 10l-1.293 1.293a1 1 0 101.414 1.414L10 11.414l1.293 1.293a1 1 0 001.414-1.414L11.414 10l1.293-1.293a1 1 0 00-1.414-1.414L10 8.586 8.707 7.293z");
			attr(path, "clip-rule", "evenodd");
		},
		m(target, anchor) {
			insert_hydration(target, path, anchor);
		},
		p: noop,
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(path);
		}
	};
}

class XCircle extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, null, create_fragment$O, safe_not_equal, {});
	}
}

const iconLibrary = [
  {
    Name: "beaker",
    Component: Beaker
  },
  {
    Name: "detail",
    Component: Detail
  },
  {
    Name: "alert",
    Component: AlertIcon
  },
  {
    Name: "search",
    Component: Search
  },
  {
    Name: "tick",
    Component: Tick
  },
  {
    Name: "cross",
    Component: Cross
  },
  {
    Name: "warn",
    Component: Warn
  },
  {
    Name: "info",
    Component: Info
  },
  {
    Name: "exclamation",
    Component: Exclamation
  },
  {
    Name: "xcircle",
    Component: XCircle
  }
];

/* src\Icons\BaseSvg.svelte generated by Svelte v3.48.0 */

function create_if_block$t(ctx) {
	let svg;
	let switch_instance;
	let svg_class_value;
	let current;
	var switch_value = /*iconToRender*/ ctx[4];

	function switch_props(ctx) {
		return {};
	}

	if (switch_value) {
		switch_instance = new switch_value(switch_props());
	}

	return {
		c() {
			svg = svg_element("svg");
			if (switch_instance) create_component(switch_instance.$$.fragment);
			this.h();
		},
		l(nodes) {
			svg = claim_svg_element(nodes, "svg", {
				class: true,
				xmlns: true,
				fill: true,
				viewBox: true,
				stroke: true,
				"aria-hidden": true
			});

			var svg_nodes = children(svg);
			if (switch_instance) claim_component(switch_instance.$$.fragment, svg_nodes);
			svg_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(svg, "class", svg_class_value = "h-" + /*size*/ ctx[0] + " w-" + /*size*/ ctx[0]);
			attr(svg, "xmlns", "http://www.w3.org/2000/svg");
			attr(svg, "fill", /*fillColour*/ ctx[2]);
			attr(svg, "viewBox", /*viewBox*/ ctx[3]);
			attr(svg, "stroke", /*colour*/ ctx[1]);
			attr(svg, "aria-hidden", "true");
		},
		m(target, anchor) {
			insert_hydration(target, svg, anchor);

			if (switch_instance) {
				mount_component(switch_instance, svg, null);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (switch_value !== (switch_value = /*iconToRender*/ ctx[4])) {
				if (switch_instance) {
					group_outros();
					const old_component = switch_instance;

					transition_out(old_component.$$.fragment, 1, 0, () => {
						destroy_component(old_component, 1);
					});

					check_outros();
				}

				if (switch_value) {
					switch_instance = new switch_value(switch_props());
					create_component(switch_instance.$$.fragment);
					transition_in(switch_instance.$$.fragment, 1);
					mount_component(switch_instance, svg, null);
				} else {
					switch_instance = null;
				}
			}

			if (!current || dirty & /*size*/ 1 && svg_class_value !== (svg_class_value = "h-" + /*size*/ ctx[0] + " w-" + /*size*/ ctx[0])) {
				attr(svg, "class", svg_class_value);
			}

			if (!current || dirty & /*fillColour*/ 4) {
				attr(svg, "fill", /*fillColour*/ ctx[2]);
			}

			if (!current || dirty & /*viewBox*/ 8) {
				attr(svg, "viewBox", /*viewBox*/ ctx[3]);
			}

			if (!current || dirty & /*colour*/ 2) {
				attr(svg, "stroke", /*colour*/ ctx[1]);
			}
		},
		i(local) {
			if (current) return;
			if (switch_instance) transition_in(switch_instance.$$.fragment, local);
			current = true;
		},
		o(local) {
			if (switch_instance) transition_out(switch_instance.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(svg);
			if (switch_instance) destroy_component(switch_instance);
		}
	};
}

function create_fragment$N(ctx) {
	let if_block_anchor;
	let current;
	let if_block = /*iconToRender*/ ctx[4] && create_if_block$t(ctx);

	return {
		c() {
			if (if_block) if_block.c();
			if_block_anchor = empty();
		},
		l(nodes) {
			if (if_block) if_block.l(nodes);
			if_block_anchor = empty();
		},
		m(target, anchor) {
			if (if_block) if_block.m(target, anchor);
			insert_hydration(target, if_block_anchor, anchor);
			current = true;
		},
		p(ctx, [dirty]) {
			if (/*iconToRender*/ ctx[4]) if_block.p(ctx, dirty);
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			if (if_block) if_block.d(detaching);
			if (detaching) detach(if_block_anchor);
		}
	};
}

function instance$N($$self, $$props, $$invalidate) {
	let { size = 4 } = $$props;
	let { colour = "currentColor" } = $$props;
	let { fillColour = "none" } = $$props;
	let { viewBox = "0 0 24 24" } = $$props;
	let { iconName } = $$props;
	var iconToRender = iconLibrary.find(i => i.Name == iconName).Component;

	$$self.$$set = $$props => {
		if ('size' in $$props) $$invalidate(0, size = $$props.size);
		if ('colour' in $$props) $$invalidate(1, colour = $$props.colour);
		if ('fillColour' in $$props) $$invalidate(2, fillColour = $$props.fillColour);
		if ('viewBox' in $$props) $$invalidate(3, viewBox = $$props.viewBox);
		if ('iconName' in $$props) $$invalidate(5, iconName = $$props.iconName);
	};

	return [size, colour, fillColour, viewBox, iconToRender, iconName];
}

class BaseSvg extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$N, create_fragment$N, safe_not_equal, {
			size: 0,
			colour: 1,
			fillColour: 2,
			viewBox: 3,
			iconName: 5
		});
	}
}

/* src\Alerts\Alert.svelte generated by Svelte v3.48.0 */
const get_title_slot_changes = dirty => ({});
const get_title_slot_context = ctx => ({});

// (49:4) {#if showIcon}
function create_if_block_2$8(ctx) {
	let div;
	let basesvg;
	let div_class_value;
	let current;

	basesvg = new BaseSvg({
			props: {
				iconName: /*styles*/ ctx[1].iconName,
				size: 5,
				fillColour: "currentColor",
				viewBox: "0 0 20 20",
				colour: "none"
			}
		});

	return {
		c() {
			div = element("div");
			create_component(basesvg.$$.fragment);
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			claim_component(basesvg.$$.fragment, div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", div_class_value = "flex-shrink-0 text-" + /*styles*/ ctx[1].theme + "-400");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			mount_component(basesvg, div, null);
			current = true;
		},
		p(ctx, dirty) {
			const basesvg_changes = {};
			if (dirty & /*styles*/ 2) basesvg_changes.iconName = /*styles*/ ctx[1].iconName;
			basesvg.$set(basesvg_changes);

			if (!current || dirty & /*styles*/ 2 && div_class_value !== (div_class_value = "flex-shrink-0 text-" + /*styles*/ ctx[1].theme + "-400")) {
				attr(div, "class", div_class_value);
			}
		},
		i(local) {
			if (current) return;
			transition_in(basesvg.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(basesvg.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			destroy_component(basesvg);
		}
	};
}

// (62:6) {#if $$slots.title}
function create_if_block_1$d(ctx) {
	let h3;
	let h3_class_value;
	let current;
	const title_slot_template = /*#slots*/ ctx[5].title;
	const title_slot = create_slot(title_slot_template, ctx, /*$$scope*/ ctx[4], get_title_slot_context);

	return {
		c() {
			h3 = element("h3");
			if (title_slot) title_slot.c();
			this.h();
		},
		l(nodes) {
			h3 = claim_element(nodes, "H3", { class: true });
			var h3_nodes = children(h3);
			if (title_slot) title_slot.l(h3_nodes);
			h3_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(h3, "class", h3_class_value = "text-sm font-medium text-" + /*styles*/ ctx[1].theme + "-800");
		},
		m(target, anchor) {
			insert_hydration(target, h3, anchor);

			if (title_slot) {
				title_slot.m(h3, null);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (title_slot) {
				if (title_slot.p && (!current || dirty & /*$$scope*/ 16)) {
					update_slot_base(
						title_slot,
						title_slot_template,
						ctx,
						/*$$scope*/ ctx[4],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[4])
						: get_slot_changes(title_slot_template, /*$$scope*/ ctx[4], dirty, get_title_slot_changes),
						get_title_slot_context
					);
				}
			}

			if (!current || dirty & /*styles*/ 2 && h3_class_value !== (h3_class_value = "text-sm font-medium text-" + /*styles*/ ctx[1].theme + "-800")) {
				attr(h3, "class", h3_class_value);
			}
		},
		i(local) {
			if (current) return;
			transition_in(title_slot, local);
			current = true;
		},
		o(local) {
			transition_out(title_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(h3);
			if (title_slot) title_slot.d(detaching);
		}
	};
}

// (68:6) {#if $$slots.default}
function create_if_block$s(ctx) {
	let div;
	let div_class_value;
	let current;
	const default_slot_template = /*#slots*/ ctx[5].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[4], null);

	return {
		c() {
			div = element("div");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			if (default_slot) default_slot.l(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", div_class_value = "text-sm text-" + /*styles*/ ctx[1].theme + "-700");
			toggle_class(div, "mt-2", /*$$slots*/ ctx[2].title);
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);

			if (default_slot) {
				default_slot.m(div, null);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 16)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[4],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[4])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[4], dirty, null),
						null
					);
				}
			}

			if (!current || dirty & /*styles*/ 2 && div_class_value !== (div_class_value = "text-sm text-" + /*styles*/ ctx[1].theme + "-700")) {
				attr(div, "class", div_class_value);
			}

			if (dirty & /*styles, $$slots*/ 6) {
				toggle_class(div, "mt-2", /*$$slots*/ ctx[2].title);
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			if (default_slot) default_slot.d(detaching);
		}
	};
}

function create_fragment$M(ctx) {
	let div2;
	let div1;
	let t0;
	let div0;
	let t1;
	let div2_class_value;
	let current;
	let if_block0 = /*showIcon*/ ctx[0] && create_if_block_2$8(ctx);
	let if_block1 = /*$$slots*/ ctx[2].title && create_if_block_1$d(ctx);
	let if_block2 = /*$$slots*/ ctx[2].default && create_if_block$s(ctx);

	return {
		c() {
			div2 = element("div");
			div1 = element("div");
			if (if_block0) if_block0.c();
			t0 = space();
			div0 = element("div");
			if (if_block1) if_block1.c();
			t1 = space();
			if (if_block2) if_block2.c();
			this.h();
		},
		l(nodes) {
			div2 = claim_element(nodes, "DIV", { class: true, role: true });
			var div2_nodes = children(div2);
			div1 = claim_element(div2_nodes, "DIV", { class: true });
			var div1_nodes = children(div1);
			if (if_block0) if_block0.l(div1_nodes);
			t0 = claim_space(div1_nodes);
			div0 = claim_element(div1_nodes, "DIV", {});
			var div0_nodes = children(div0);
			if (if_block1) if_block1.l(div0_nodes);
			t1 = claim_space(div0_nodes);
			if (if_block2) if_block2.l(div0_nodes);
			div0_nodes.forEach(detach);
			div1_nodes.forEach(detach);
			div2_nodes.forEach(detach);
			this.h();
		},
		h() {
			toggle_class(div0, "ml-3", /*showIcon*/ ctx[0]);
			attr(div1, "class", "flex");
			attr(div2, "class", div2_class_value = "bg-" + /*styles*/ ctx[1].theme + "-50 w-full rounded-md p-4");
			attr(div2, "role", "alert");
		},
		m(target, anchor) {
			insert_hydration(target, div2, anchor);
			append_hydration(div2, div1);
			if (if_block0) if_block0.m(div1, null);
			append_hydration(div1, t0);
			append_hydration(div1, div0);
			if (if_block1) if_block1.m(div0, null);
			append_hydration(div0, t1);
			if (if_block2) if_block2.m(div0, null);
			current = true;
		},
		p(ctx, [dirty]) {
			if (/*showIcon*/ ctx[0]) {
				if (if_block0) {
					if_block0.p(ctx, dirty);

					if (dirty & /*showIcon*/ 1) {
						transition_in(if_block0, 1);
					}
				} else {
					if_block0 = create_if_block_2$8(ctx);
					if_block0.c();
					transition_in(if_block0, 1);
					if_block0.m(div1, t0);
				}
			} else if (if_block0) {
				group_outros();

				transition_out(if_block0, 1, 1, () => {
					if_block0 = null;
				});

				check_outros();
			}

			if (/*$$slots*/ ctx[2].title) {
				if (if_block1) {
					if_block1.p(ctx, dirty);

					if (dirty & /*$$slots*/ 4) {
						transition_in(if_block1, 1);
					}
				} else {
					if_block1 = create_if_block_1$d(ctx);
					if_block1.c();
					transition_in(if_block1, 1);
					if_block1.m(div0, t1);
				}
			} else if (if_block1) {
				group_outros();

				transition_out(if_block1, 1, 1, () => {
					if_block1 = null;
				});

				check_outros();
			}

			if (/*$$slots*/ ctx[2].default) {
				if (if_block2) {
					if_block2.p(ctx, dirty);

					if (dirty & /*$$slots*/ 4) {
						transition_in(if_block2, 1);
					}
				} else {
					if_block2 = create_if_block$s(ctx);
					if_block2.c();
					transition_in(if_block2, 1);
					if_block2.m(div0, null);
				}
			} else if (if_block2) {
				group_outros();

				transition_out(if_block2, 1, 1, () => {
					if_block2 = null;
				});

				check_outros();
			}

			if (dirty & /*showIcon*/ 1) {
				toggle_class(div0, "ml-3", /*showIcon*/ ctx[0]);
			}

			if (!current || dirty & /*styles*/ 2 && div2_class_value !== (div2_class_value = "bg-" + /*styles*/ ctx[1].theme + "-50 w-full rounded-md p-4")) {
				attr(div2, "class", div2_class_value);
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block0);
			transition_in(if_block1);
			transition_in(if_block2);
			current = true;
		},
		o(local) {
			transition_out(if_block0);
			transition_out(if_block1);
			transition_out(if_block2);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div2);
			if (if_block0) if_block0.d();
			if (if_block1) if_block1.d();
			if (if_block2) if_block2.d();
		}
	};
}

function instance$M($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	const $$slots = compute_slots(slots);
	let { kind = "info" } = $$props;
	let { showIcon = true } = $$props;
	let styles = { theme: "gray", iconName: "info" };

	switch (kind) {
		case "warn":
			styles.theme = "yellow";
			styles.iconName = "exclamation";
			break;
		case "error":
			styles.theme = "red";
			styles.iconName = "xcircle";
			break;
		case "success":
			styles.theme = "green";
			styles.iconName = "tick";
			break;
		case "info":
			styles.theme = "blue";
			styles.iconName = "info";
			break;
	}

	$$self.$$set = $$props => {
		if ('kind' in $$props) $$invalidate(3, kind = $$props.kind);
		if ('showIcon' in $$props) $$invalidate(0, showIcon = $$props.showIcon);
		if ('$$scope' in $$props) $$invalidate(4, $$scope = $$props.$$scope);
	};

	return [showIcon, styles, $$slots, kind, $$scope, slots];
}

class Alert extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$M, create_fragment$M, safe_not_equal, { kind: 3, showIcon: 0 });
	}
}

const subscriber_queue = [];
/**
 * Creates a `Readable` store that allows reading by subscription.
 * @param value initial value
 * @param {StartStopNotifier}start start and stop notifications for subscriptions
 */
function readable(value, start) {
    return {
        subscribe: writable(value, start).subscribe
    };
}
/**
 * Create a `Writable` store that allows both updating and reading by subscription.
 * @param {*=}value initial value
 * @param {StartStopNotifier=}start start and stop notifications for subscriptions
 */
function writable(value, start = noop) {
    let stop;
    const subscribers = new Set();
    function set(new_value) {
        if (safe_not_equal(value, new_value)) {
            value = new_value;
            if (stop) { // store is ready
                const run_queue = !subscriber_queue.length;
                for (const subscriber of subscribers) {
                    subscriber[1]();
                    subscriber_queue.push(subscriber, value);
                }
                if (run_queue) {
                    for (let i = 0; i < subscriber_queue.length; i += 2) {
                        subscriber_queue[i][0](subscriber_queue[i + 1]);
                    }
                    subscriber_queue.length = 0;
                }
            }
        }
    }
    function update(fn) {
        set(fn(value));
    }
    function subscribe(run, invalidate = noop) {
        const subscriber = [run, invalidate];
        subscribers.add(subscriber);
        if (subscribers.size === 1) {
            stop = start(set) || noop;
        }
        run(value);
        return () => {
            subscribers.delete(subscriber);
            if (subscribers.size === 0) {
                stop();
                stop = null;
            }
        };
    }
    return { set, update, subscribe };
}
function derived(stores, fn, initial_value) {
    const single = !Array.isArray(stores);
    const stores_array = single
        ? [stores]
        : stores;
    const auto = fn.length < 2;
    return readable(initial_value, (set) => {
        let inited = false;
        const values = [];
        let pending = 0;
        let cleanup = noop;
        const sync = () => {
            if (pending) {
                return;
            }
            cleanup();
            const result = fn(single ? values[0] : values, set);
            if (auto) {
                set(result);
            }
            else {
                cleanup = is_function(result) ? result : noop;
            }
        };
        const unsubscribers = stores_array.map((store, i) => subscribe(store, (value) => {
            values[i] = value;
            pending &= ~(1 << i);
            if (inited) {
                sync();
            }
        }, () => {
            pending |= (1 << i);
        }));
        inited = true;
        sync();
        return function stop() {
            run_all(unsubscribers);
            cleanup();
        };
    });
}

/* src\Accordion\Accordion.svelte generated by Svelte v3.48.0 */

function create_fragment$L(ctx) {
	let div;
	let current;
	const default_slot_template = /*#slots*/ ctx[3].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[2], null);

	return {
		c() {
			div = element("div");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			if (default_slot) default_slot.l(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", /*klass*/ ctx[0]);
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);

			if (default_slot) {
				default_slot.m(div, null);
			}

			current = true;
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 4)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[2],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[2])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[2], dirty, null),
						null
					);
				}
			}

			if (!current || dirty & /*klass*/ 1) {
				attr(div, "class", /*klass*/ ctx[0]);
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			if (default_slot) default_slot.d(detaching);
		}
	};
}

const ACCORDION_KEY = {};

function instance$L($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	let { allowMultiple = false } = $$props;
	let { klass = "" } = $$props;
	const startingValue = allowMultiple ? [] : null;
	const activeItems = writable(startingValue);
	const listItemRegister = writable(0);

	setContext(ACCORDION_KEY, {
		activeItems,
		listItemRegister,
		allowMultiple
	});

	$$self.$$set = $$props => {
		if ('allowMultiple' in $$props) $$invalidate(1, allowMultiple = $$props.allowMultiple);
		if ('klass' in $$props) $$invalidate(0, klass = $$props.klass);
		if ('$$scope' in $$props) $$invalidate(2, $$scope = $$props.$$scope);
	};

	return [klass, allowMultiple, $$scope, slots];
}

class Accordion extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$L, create_fragment$L, safe_not_equal, { allowMultiple: 1, klass: 0 });
	}
}

function cubicOut(t) {
    const f = t - 1.0;
    return f * f * f + 1.0;
}

function fade(node, { delay = 0, duration = 400, easing = identity } = {}) {
    const o = +getComputedStyle(node).opacity;
    return {
        delay,
        duration,
        easing,
        css: t => `opacity: ${t * o}`
    };
}
function fly(node, { delay = 0, duration = 400, easing = cubicOut, x = 0, y = 0, opacity = 0 } = {}) {
    const style = getComputedStyle(node);
    const target_opacity = +style.opacity;
    const transform = style.transform === 'none' ? '' : style.transform;
    const od = target_opacity * (1 - opacity);
    return {
        delay,
        duration,
        easing,
        css: (t, u) => `
			transform: ${transform} translate(${(1 - t) * x}px, ${(1 - t) * y}px);
			opacity: ${target_opacity - (od * u)}`
    };
}
function slide(node, { delay = 0, duration = 400, easing = cubicOut } = {}) {
    const style = getComputedStyle(node);
    const opacity = +style.opacity;
    const height = parseFloat(style.height);
    const padding_top = parseFloat(style.paddingTop);
    const padding_bottom = parseFloat(style.paddingBottom);
    const margin_top = parseFloat(style.marginTop);
    const margin_bottom = parseFloat(style.marginBottom);
    const border_top_width = parseFloat(style.borderTopWidth);
    const border_bottom_width = parseFloat(style.borderBottomWidth);
    return {
        delay,
        duration,
        easing,
        css: t => 'overflow: hidden;' +
            `opacity: ${Math.min(t * 20, 1) * opacity};` +
            `height: ${t * height}px;` +
            `padding-top: ${t * padding_top}px;` +
            `padding-bottom: ${t * padding_bottom}px;` +
            `margin-top: ${t * margin_top}px;` +
            `margin-bottom: ${t * margin_bottom}px;` +
            `border-top-width: ${t * border_top_width}px;` +
            `border-bottom-width: ${t * border_bottom_width}px;`
    };
}
function scale(node, { delay = 0, duration = 400, easing = cubicOut, start = 0, opacity = 0 } = {}) {
    const style = getComputedStyle(node);
    const target_opacity = +style.opacity;
    const transform = style.transform === 'none' ? '' : style.transform;
    const sd = 1 - start;
    const od = target_opacity * (1 - opacity);
    return {
        delay,
        duration,
        easing,
        css: (_t, u) => `
			transform: ${transform} scale(${1 - (sd * u)});
			opacity: ${target_opacity - (od * u)}
		`
    };
}

/* src\Accordion\AccordionItem.svelte generated by Svelte v3.48.0 */
const get_accordion_item_content_slot_changes = dirty => ({ isActive: dirty & /*isActive*/ 1 });
const get_accordion_item_content_slot_context = ctx => ({ isActive: /*isActive*/ ctx[0] });
const get_accordion_item_activation_slot_changes = dirty => ({ isActive: dirty & /*isActive*/ 1 });
const get_accordion_item_activation_slot_context = ctx => ({ isActive: /*isActive*/ ctx[0] });

// (57:2) {#if isActive}
function create_if_block$r(ctx) {
	let div;
	let div_transition;
	let current;
	const accordion_item_content_slot_template = /*#slots*/ ctx[7].accordion_item_content;
	const accordion_item_content_slot = create_slot(accordion_item_content_slot_template, ctx, /*$$scope*/ ctx[6], get_accordion_item_content_slot_context);

	return {
		c() {
			div = element("div");
			if (accordion_item_content_slot) accordion_item_content_slot.c();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", {});
			var div_nodes = children(div);
			if (accordion_item_content_slot) accordion_item_content_slot.l(div_nodes);
			div_nodes.forEach(detach);
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);

			if (accordion_item_content_slot) {
				accordion_item_content_slot.m(div, null);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (accordion_item_content_slot) {
				if (accordion_item_content_slot.p && (!current || dirty & /*$$scope, isActive*/ 65)) {
					update_slot_base(
						accordion_item_content_slot,
						accordion_item_content_slot_template,
						ctx,
						/*$$scope*/ ctx[6],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[6])
						: get_slot_changes(accordion_item_content_slot_template, /*$$scope*/ ctx[6], dirty, get_accordion_item_content_slot_changes),
						get_accordion_item_content_slot_context
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(accordion_item_content_slot, local);

			add_render_callback(() => {
				if (!div_transition) div_transition = create_bidirectional_transition(div, slide, {}, true);
				div_transition.run(1);
			});

			current = true;
		},
		o(local) {
			transition_out(accordion_item_content_slot, local);
			if (!div_transition) div_transition = create_bidirectional_transition(div, slide, {}, false);
			div_transition.run(0);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			if (accordion_item_content_slot) accordion_item_content_slot.d(detaching);
			if (detaching && div_transition) div_transition.end();
		}
	};
}

function create_fragment$K(ctx) {
	let t0;
	let div1;
	let div0;
	let t1;
	let current;
	let mounted;
	let dispose;
	let if_block0 = false ;
	const accordion_item_activation_slot_template = /*#slots*/ ctx[7].accordion_item_activation;
	const accordion_item_activation_slot = create_slot(accordion_item_activation_slot_template, ctx, /*$$scope*/ ctx[6], get_accordion_item_activation_slot_context);
	let if_block1 = /*isActive*/ ctx[0] && create_if_block$r(ctx);

	return {
		c() {
			t0 = space();
			div1 = element("div");
			div0 = element("div");
			if (accordion_item_activation_slot) accordion_item_activation_slot.c();
			t1 = space();
			if (if_block1) if_block1.c();
		},
		l(nodes) {
			t0 = claim_space(nodes);
			div1 = claim_element(nodes, "DIV", {});
			var div1_nodes = children(div1);
			div0 = claim_element(div1_nodes, "DIV", {});
			var div0_nodes = children(div0);
			if (accordion_item_activation_slot) accordion_item_activation_slot.l(div0_nodes);
			div0_nodes.forEach(detach);
			t1 = claim_space(div1_nodes);
			if (if_block1) if_block1.l(div1_nodes);
			div1_nodes.forEach(detach);
		},
		m(target, anchor) {
			insert_hydration(target, t0, anchor);
			insert_hydration(target, div1, anchor);
			append_hydration(div1, div0);

			if (accordion_item_activation_slot) {
				accordion_item_activation_slot.m(div0, null);
			}

			append_hydration(div1, t1);
			if (if_block1) if_block1.m(div1, null);
			current = true;

			if (!mounted) {
				dispose = listen(div0, "click", /*click_handler*/ ctx[8]);
				mounted = true;
			}
		},
		p(ctx, [dirty]) {

			if (accordion_item_activation_slot) {
				if (accordion_item_activation_slot.p && (!current || dirty & /*$$scope, isActive*/ 65)) {
					update_slot_base(
						accordion_item_activation_slot,
						accordion_item_activation_slot_template,
						ctx,
						/*$$scope*/ ctx[6],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[6])
						: get_slot_changes(accordion_item_activation_slot_template, /*$$scope*/ ctx[6], dirty, get_accordion_item_activation_slot_changes),
						get_accordion_item_activation_slot_context
					);
				}
			}

			if (/*isActive*/ ctx[0]) {
				if (if_block1) {
					if_block1.p(ctx, dirty);

					if (dirty & /*isActive*/ 1) {
						transition_in(if_block1, 1);
					}
				} else {
					if_block1 = create_if_block$r(ctx);
					if_block1.c();
					transition_in(if_block1, 1);
					if_block1.m(div1, null);
				}
			} else if (if_block1) {
				group_outros();

				transition_out(if_block1, 1, 1, () => {
					if_block1 = null;
				});

				check_outros();
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block0);
			transition_in(accordion_item_activation_slot, local);
			transition_in(if_block1);
			current = true;
		},
		o(local) {
			transition_out(if_block0);
			transition_out(accordion_item_activation_slot, local);
			transition_out(if_block1);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(t0);
			if (detaching) detach(div1);
			if (accordion_item_activation_slot) accordion_item_activation_slot.d(detaching);
			if (if_block1) if_block1.d();
			mounted = false;
			dispose();
		}
	};
}

function instance$K($$self, $$props, $$invalidate) {
	let isActive;
	let $activeItems;
	let $listItemRegister;
	let { $$slots: slots = {}, $$scope } = $$props;
	const { activeItems, listItemRegister, allowMultiple } = getContext(ACCORDION_KEY);
	component_subscribe($$self, activeItems, value => $$invalidate(5, $activeItems = value));
	component_subscribe($$self, listItemRegister, value => $$invalidate(9, $listItemRegister = value));
	const accordionItemId = $listItemRegister;
	set_store_value(listItemRegister, $listItemRegister++, $listItemRegister);
	let { open = false } = $$props;

	const handleItemClick = () => {
		if (allowMultiple) {
			if ($activeItems.includes(accordionItemId)) {
				set_store_value(activeItems, $activeItems = $activeItems.filter(i => i != accordionItemId), $activeItems);
			} else {
				set_store_value(activeItems, $activeItems = [...$activeItems, accordionItemId], $activeItems);
			}
		} else {
			set_store_value(activeItems, $activeItems = accordionItemId, $activeItems);
		}
	};

	if (open) {
		if (allowMultiple) {
			set_store_value(activeItems, $activeItems = [...$activeItems, accordionItemId], $activeItems);
		} else {
			set_store_value(activeItems, $activeItems = accordionItemId, $activeItems);
		}
	}

	const click_handler = () => handleItemClick();

	$$self.$$set = $$props => {
		if ('open' in $$props) $$invalidate(4, open = $$props.open);
		if ('$$scope' in $$props) $$invalidate(6, $$scope = $$props.$$scope);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*$activeItems*/ 32) {
			$$invalidate(0, isActive = allowMultiple && $activeItems.includes(accordionItemId) || !allowMultiple && $activeItems === accordionItemId);
		}
	};

	return [
		isActive,
		activeItems,
		listItemRegister,
		handleItemClick,
		open,
		$activeItems,
		$$scope,
		slots,
		click_handler
	];
}

class AccordionItem extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$K, create_fragment$K, safe_not_equal, { open: 4 });
	}
}

/* src\Badge\Badge.svelte generated by Svelte v3.48.0 */

function fallback_block$2(ctx) {
	let t;

	return {
		c() {
			t = text("Slot");
		},
		l(nodes) {
			t = claim_text(nodes, "Slot");
		},
		m(target, anchor) {
			insert_hydration(target, t, anchor);
		},
		d(detaching) {
			if (detaching) detach(t);
		}
	};
}

// (123:2) {#if dismissible}
function create_if_block$q(ctx) {
	let button;
	let span;
	let t0;
	let t1;
	let svg;
	let path;
	let button_class_value;
	let mounted;
	let dispose;

	return {
		c() {
			button = element("button");
			span = element("span");
			t0 = text("Remove option");
			t1 = space();
			svg = svg_element("svg");
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			button = claim_element(nodes, "BUTTON", { type: true, class: true });
			var button_nodes = children(button);
			span = claim_element(button_nodes, "SPAN", { class: true });
			var span_nodes = children(span);
			t0 = claim_text(span_nodes, "Remove option");
			span_nodes.forEach(detach);
			t1 = claim_space(button_nodes);

			svg = claim_svg_element(button_nodes, "svg", {
				class: true,
				stroke: true,
				fill: true,
				viewBox: true
			});

			var svg_nodes = children(svg);

			path = claim_svg_element(svg_nodes, "path", {
				"stroke-linecap": true,
				"stroke-width": true,
				d: true
			});

			children(path).forEach(detach);
			svg_nodes.forEach(detach);
			button_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(span, "class", "sr-only");
			attr(path, "stroke-linecap", "round");
			attr(path, "stroke-width", "1.5");
			attr(path, "d", "M1 1l6 6m0-6L1 7");
			attr(svg, "class", "");
			attr(svg, "stroke", "currentColor");
			attr(svg, "fill", "none");
			attr(svg, "viewBox", "0 0 8 8");
			toggle_class(svg, "h-2", /*size*/ ctx[0] === "small" || /*size*/ ctx[0] === "xsmall");
			toggle_class(svg, "w-2", /*size*/ ctx[0] === "small" || /*size*/ ctx[0] === "xsmall");
			toggle_class(svg, "h-3", /*size*/ ctx[0] === "large");
			toggle_class(svg, "w-3", /*size*/ ctx[0] === "large");
			attr(button, "type", "button");
			attr(button, "class", button_class_value = "" + (/*buttonText*/ ctx[4] + " focus:outline-none ml-1.5 inline-flex flex-shrink-0 items-center justify-center rounded-full hover:bg-red-200 hover:text-red-500 focus:bg-red-500 focus:text-white"));
			toggle_class(button, "h-4", /*size*/ ctx[0] === "small" || /*size*/ ctx[0] === "xsmall");
			toggle_class(button, "w-4", /*size*/ ctx[0] === "small" || /*size*/ ctx[0] === "xsmall");
			toggle_class(button, "h-5", /*size*/ ctx[0] === "large");
			toggle_class(button, "w-5", /*size*/ ctx[0] === "large");
		},
		m(target, anchor) {
			insert_hydration(target, button, anchor);
			append_hydration(button, span);
			append_hydration(span, t0);
			append_hydration(button, t1);
			append_hydration(button, svg);
			append_hydration(svg, path);

			if (!mounted) {
				dispose = listen(button, "click", /*handleClick*/ ctx[5]);
				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (dirty & /*size*/ 1) {
				toggle_class(svg, "h-2", /*size*/ ctx[0] === "small" || /*size*/ ctx[0] === "xsmall");
			}

			if (dirty & /*size*/ 1) {
				toggle_class(svg, "w-2", /*size*/ ctx[0] === "small" || /*size*/ ctx[0] === "xsmall");
			}

			if (dirty & /*size*/ 1) {
				toggle_class(svg, "h-3", /*size*/ ctx[0] === "large");
			}

			if (dirty & /*size*/ 1) {
				toggle_class(svg, "w-3", /*size*/ ctx[0] === "large");
			}

			if (dirty & /*buttonText*/ 16 && button_class_value !== (button_class_value = "" + (/*buttonText*/ ctx[4] + " focus:outline-none ml-1.5 inline-flex flex-shrink-0 items-center justify-center rounded-full hover:bg-red-200 hover:text-red-500 focus:bg-red-500 focus:text-white"))) {
				attr(button, "class", button_class_value);
			}

			if (dirty & /*buttonText, size*/ 17) {
				toggle_class(button, "h-4", /*size*/ ctx[0] === "small" || /*size*/ ctx[0] === "xsmall");
			}

			if (dirty & /*buttonText, size*/ 17) {
				toggle_class(button, "w-4", /*size*/ ctx[0] === "small" || /*size*/ ctx[0] === "xsmall");
			}

			if (dirty & /*buttonText, size*/ 17) {
				toggle_class(button, "h-5", /*size*/ ctx[0] === "large");
			}

			if (dirty & /*buttonText, size*/ 17) {
				toggle_class(button, "w-5", /*size*/ ctx[0] === "large");
			}
		},
		d(detaching) {
			if (detaching) detach(button);
			mounted = false;
			dispose();
		}
	};
}

function create_fragment$J(ctx) {
	let span;
	let t;
	let span_class_value;
	let current;
	const default_slot_template = /*#slots*/ ctx[8].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[7], null);
	const default_slot_or_fallback = default_slot || fallback_block$2();
	let if_block = /*dismissible*/ ctx[2] && create_if_block$q(ctx);

	return {
		c() {
			span = element("span");
			if (default_slot_or_fallback) default_slot_or_fallback.c();
			t = space();
			if (if_block) if_block.c();
			this.h();
		},
		l(nodes) {
			span = claim_element(nodes, "SPAN", { class: true });
			var span_nodes = children(span);
			if (default_slot_or_fallback) default_slot_or_fallback.l(span_nodes);
			t = claim_space(span_nodes);
			if (if_block) if_block.l(span_nodes);
			span_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(span, "class", span_class_value = /*classes*/ ctx[3].join(" "));
			toggle_class(span, "rounded-full", /*rounded*/ ctx[1]);
			toggle_class(span, "rounded", !/*rounded*/ ctx[1]);
		},
		m(target, anchor) {
			insert_hydration(target, span, anchor);

			if (default_slot_or_fallback) {
				default_slot_or_fallback.m(span, null);
			}

			append_hydration(span, t);
			if (if_block) if_block.m(span, null);
			current = true;
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 128)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[7],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[7])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[7], dirty, null),
						null
					);
				}
			}

			if (/*dismissible*/ ctx[2]) {
				if (if_block) {
					if_block.p(ctx, dirty);
				} else {
					if_block = create_if_block$q(ctx);
					if_block.c();
					if_block.m(span, null);
				}
			} else if (if_block) {
				if_block.d(1);
				if_block = null;
			}

			if (!current || dirty & /*classes*/ 8 && span_class_value !== (span_class_value = /*classes*/ ctx[3].join(" "))) {
				attr(span, "class", span_class_value);
			}

			if (dirty & /*classes, rounded*/ 10) {
				toggle_class(span, "rounded-full", /*rounded*/ ctx[1]);
			}

			if (dirty & /*classes, rounded*/ 10) {
				toggle_class(span, "rounded", !/*rounded*/ ctx[1]);
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot_or_fallback, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot_or_fallback, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(span);
			if (default_slot_or_fallback) default_slot_or_fallback.d(detaching);
			if (if_block) if_block.d();
		}
	};
}

const baseClass = "inline-flex rounded-full items-center font-medium";

function instance$J($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	let { kind = "gray" } = $$props;
	let { size = "small" } = $$props;
	let { rounded = true } = $$props;
	let { dismissible = false } = $$props;
	let classes = [];
	let buttonText = "text-indigo-400";

	// Tailwind badges
	// [large] inline-flex rounded-full items-center py-0.5 pl-2.5 pr-1 text-sm font-medium bg-indigo-100 text-indigo-700
	// [small] inline-flex rounded-full items-center py-0.5 pl-2 pr-0.5 text-xs font-medium bg-indigo-100 text-indigo-700
	// use update dependencies here
	const updateKind = kind => {
		$$invalidate(3, classes = [baseClass]);

		switch (size) {
			case "xsmall":
				classes.push("py-0.5 text-sm");
				if (dismissible) {
					classes.push("pl-3 pr-1");
				} else {
					classes.push("px-3");
				}
				break;
			case "small":
				classes.push("py-1 text-sm");
				if (dismissible) {
					classes.push("pl-3 pr-1");
				} else {
					classes.push("px-3");
				}
				break;
			case "large":
				classes.push("py-2");
				if (dismissible) {
					classes.push("pl-4 pr-2");
				} else {
					classes.push("px-4");
				}
				break;
		}

		switch (kind) {
			case "gray":
				classes.push("bg-gray-100 text-gray-800");
				$$invalidate(4, buttonText = "text-gray-400");
				break;
			case "pink":
				classes.push("bg-pink-100 text-pink-800");
				$$invalidate(4, buttonText = "text-pink-400");
				break;
			case "purple":
				classes.push("bg-purple-100 text-purple-800");
				$$invalidate(4, buttonText = "text-purple-400");
				break;
			case "yellow":
				classes.push("bg-yellow-100 text-yellow-800");
				$$invalidate(4, buttonText = "text-yellow-400");
				break;
			case "red":
				classes.push("bg-red-100 text-red-800");
				$$invalidate(4, buttonText = "text-red-400");
				break;
			case "green":
				classes.push("bg-green-100 text-green-800");
				$$invalidate(4, buttonText = "text-green-400");
				break;
			case "blue":
				classes.push("bg-blue-100 text-blue-800");
				$$invalidate(4, buttonText = "text-blue-400");
				break;
			case "indigo":
				classes.push("bg-indigo-100 text-indigo-800");
				$$invalidate(4, buttonText = "text-indigo-400");
		}
	};

	const dispatch = createEventDispatcher();

	const handleClick = () => {
		dispatch("dismissed");
	};

	$$self.$$set = $$props => {
		if ('kind' in $$props) $$invalidate(6, kind = $$props.kind);
		if ('size' in $$props) $$invalidate(0, size = $$props.size);
		if ('rounded' in $$props) $$invalidate(1, rounded = $$props.rounded);
		if ('dismissible' in $$props) $$invalidate(2, dismissible = $$props.dismissible);
		if ('$$scope' in $$props) $$invalidate(7, $$scope = $$props.$$scope);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*kind*/ 64) {
			updateKind(kind);
		}
	};

	return [
		size,
		rounded,
		dismissible,
		classes,
		buttonText,
		handleClick,
		kind,
		$$scope,
		slots
	];
}

class Badge extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$J, create_fragment$J, safe_not_equal, {
			kind: 6,
			size: 0,
			rounded: 1,
			dismissible: 2
		});
	}
}

/* src\Button\Button.svelte generated by Svelte v3.48.0 */

function create_else_block$6(ctx) {
	let button;
	let div;
	let t;
	let button_class_value;
	let button_disabled_value;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[11].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[10], null);
	const default_slot_or_fallback = default_slot || fallback_block_1();
	let if_block = /*loading*/ ctx[4] && create_if_block_1$c();

	let button_levels = [
		{
			class: button_class_value = /*classes*/ ctx[6].join(" ")
		},
		{ type: /*type*/ ctx[3] },
		{
			disabled: button_disabled_value = /*disabled*/ ctx[2] || /*loading*/ ctx[4]
		},
		/*$$restProps*/ ctx[7]
	];

	let button_data = {};

	for (let i = 0; i < button_levels.length; i += 1) {
		button_data = assign(button_data, button_levels[i]);
	}

	return {
		c() {
			button = element("button");
			div = element("div");
			if (default_slot_or_fallback) default_slot_or_fallback.c();
			t = space();
			if (if_block) if_block.c();
			this.h();
		},
		l(nodes) {
			button = claim_element(nodes, "BUTTON", { class: true, type: true });
			var button_nodes = children(button);
			div = claim_element(button_nodes, "DIV", { class: true });
			var div_nodes = children(div);
			if (default_slot_or_fallback) default_slot_or_fallback.l(div_nodes);
			div_nodes.forEach(detach);
			t = claim_space(button_nodes);
			if (if_block) if_block.l(button_nodes);
			button_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", "inline-flex items-center");
			toggle_class(div, "invisible", /*loading*/ ctx[4]);
			set_attributes(button, button_data);
			toggle_class(button, "w-full", /*full*/ ctx[1]);
			toggle_class(button, "cursor-not-allowed", /*disabled*/ ctx[2] || /*loading*/ ctx[4]);
			toggle_class(button, "rounded-full", /*rounded*/ ctx[0]);
			toggle_class(button, "rounded-md", !/*rounded*/ ctx[0]);
			toggle_class(button, "disabled", /*disabled*/ ctx[2]);
			toggle_class(button, "svelte-fwhzzf", true);
		},
		m(target, anchor) {
			insert_hydration(target, button, anchor);
			append_hydration(button, div);

			if (default_slot_or_fallback) {
				default_slot_or_fallback.m(div, null);
			}

			append_hydration(button, t);
			if (if_block) if_block.m(button, null);
			if (button.autofocus) button.focus();
			current = true;

			if (!mounted) {
				dispose = [
					listen(button, "click", /*click_handler_1*/ ctx[16]),
					listen(button, "mouseover", /*mouseover_handler_1*/ ctx[17]),
					listen(button, "mouseenter", /*mouseenter_handler_1*/ ctx[18]),
					listen(button, "mouseleave", /*mouseleave_handler_1*/ ctx[19])
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 1024)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[10],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[10])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[10], dirty, null),
						null
					);
				}
			}

			if (dirty & /*loading*/ 16) {
				toggle_class(div, "invisible", /*loading*/ ctx[4]);
			}

			if (/*loading*/ ctx[4]) {
				if (if_block) ; else {
					if_block = create_if_block_1$c();
					if_block.c();
					if_block.m(button, null);
				}
			} else if (if_block) {
				if_block.d(1);
				if_block = null;
			}

			set_attributes(button, button_data = get_spread_update(button_levels, [
				(!current || dirty & /*classes*/ 64 && button_class_value !== (button_class_value = /*classes*/ ctx[6].join(" "))) && { class: button_class_value },
				(!current || dirty & /*type*/ 8) && { type: /*type*/ ctx[3] },
				(!current || dirty & /*disabled, loading*/ 20 && button_disabled_value !== (button_disabled_value = /*disabled*/ ctx[2] || /*loading*/ ctx[4])) && { disabled: button_disabled_value },
				dirty & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7]
			]));

			toggle_class(button, "w-full", /*full*/ ctx[1]);
			toggle_class(button, "cursor-not-allowed", /*disabled*/ ctx[2] || /*loading*/ ctx[4]);
			toggle_class(button, "rounded-full", /*rounded*/ ctx[0]);
			toggle_class(button, "rounded-md", !/*rounded*/ ctx[0]);
			toggle_class(button, "disabled", /*disabled*/ ctx[2]);
			toggle_class(button, "svelte-fwhzzf", true);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot_or_fallback, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot_or_fallback, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(button);
			if (default_slot_or_fallback) default_slot_or_fallback.d(detaching);
			if (if_block) if_block.d();
			mounted = false;
			run_all(dispose);
		}
	};
}

// (116:0) {#if href}
function create_if_block$p(ctx) {
	let a;
	let div;
	let a_class_value;
	let a_disabled_value;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[11].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[10], null);
	const default_slot_or_fallback = default_slot || fallback_block$1();

	let a_levels = [
		{ href: /*href*/ ctx[5] },
		{
			class: a_class_value = /*classes*/ ctx[6].join(" ")
		},
		{
			disabled: a_disabled_value = /*disabled*/ ctx[2] || /*loading*/ ctx[4]
		},
		/*$$restProps*/ ctx[7]
	];

	let a_data = {};

	for (let i = 0; i < a_levels.length; i += 1) {
		a_data = assign(a_data, a_levels[i]);
	}

	return {
		c() {
			a = element("a");
			div = element("div");
			if (default_slot_or_fallback) default_slot_or_fallback.c();
			this.h();
		},
		l(nodes) {
			a = claim_element(nodes, "A", { href: true, class: true, disabled: true });
			var a_nodes = children(a);
			div = claim_element(a_nodes, "DIV", { class: true });
			var div_nodes = children(div);
			if (default_slot_or_fallback) default_slot_or_fallback.l(div_nodes);
			div_nodes.forEach(detach);
			a_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", "inline-flex items-center");
			toggle_class(div, "invisible", /*loading*/ ctx[4]);
			set_attributes(a, a_data);
			toggle_class(a, "w-full", /*full*/ ctx[1]);
			toggle_class(a, "cursor-not-allowed", /*disabled*/ ctx[2] || /*loading*/ ctx[4]);
			toggle_class(a, "rounded-full", /*rounded*/ ctx[0]);
			toggle_class(a, "rounded-md", !/*rounded*/ ctx[0]);
			toggle_class(a, "disabled", /*disabled*/ ctx[2]);
			toggle_class(a, "svelte-fwhzzf", true);
		},
		m(target, anchor) {
			insert_hydration(target, a, anchor);
			append_hydration(a, div);

			if (default_slot_or_fallback) {
				default_slot_or_fallback.m(div, null);
			}

			current = true;

			if (!mounted) {
				dispose = [
					listen(a, "click", /*click_handler*/ ctx[12]),
					listen(a, "mouseover", /*mouseover_handler*/ ctx[13]),
					listen(a, "mouseenter", /*mouseenter_handler*/ ctx[14]),
					listen(a, "mouseleave", /*mouseleave_handler*/ ctx[15])
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 1024)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[10],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[10])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[10], dirty, null),
						null
					);
				}
			}

			if (dirty & /*loading*/ 16) {
				toggle_class(div, "invisible", /*loading*/ ctx[4]);
			}

			set_attributes(a, a_data = get_spread_update(a_levels, [
				(!current || dirty & /*href*/ 32) && { href: /*href*/ ctx[5] },
				(!current || dirty & /*classes*/ 64 && a_class_value !== (a_class_value = /*classes*/ ctx[6].join(" "))) && { class: a_class_value },
				(!current || dirty & /*disabled, loading*/ 20 && a_disabled_value !== (a_disabled_value = /*disabled*/ ctx[2] || /*loading*/ ctx[4])) && { disabled: a_disabled_value },
				dirty & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7]
			]));

			toggle_class(a, "w-full", /*full*/ ctx[1]);
			toggle_class(a, "cursor-not-allowed", /*disabled*/ ctx[2] || /*loading*/ ctx[4]);
			toggle_class(a, "rounded-full", /*rounded*/ ctx[0]);
			toggle_class(a, "rounded-md", !/*rounded*/ ctx[0]);
			toggle_class(a, "disabled", /*disabled*/ ctx[2]);
			toggle_class(a, "svelte-fwhzzf", true);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot_or_fallback, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot_or_fallback, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(a);
			if (default_slot_or_fallback) default_slot_or_fallback.d(detaching);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (153:12) Slot
function fallback_block_1(ctx) {
	let t;

	return {
		c() {
			t = text("Slot");
		},
		l(nodes) {
			t = claim_text(nodes, "Slot");
		},
		m(target, anchor) {
			insert_hydration(target, t, anchor);
		},
		d(detaching) {
			if (detaching) detach(t);
		}
	};
}

// (156:4) {#if loading}
function create_if_block_1$c(ctx) {
	let svg;
	let circle;
	let path;

	return {
		c() {
			svg = svg_element("svg");
			circle = svg_element("circle");
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			svg = claim_svg_element(nodes, "svg", {
				class: true,
				xmlns: true,
				fill: true,
				viewBox: true
			});

			var svg_nodes = children(svg);

			circle = claim_svg_element(svg_nodes, "circle", {
				class: true,
				cx: true,
				cy: true,
				r: true,
				stroke: true,
				"stroke-width": true
			});

			children(circle).forEach(detach);
			path = claim_svg_element(svg_nodes, "path", { class: true, fill: true, d: true });
			children(path).forEach(detach);
			svg_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(circle, "class", "opacity-25");
			attr(circle, "cx", "12");
			attr(circle, "cy", "12");
			attr(circle, "r", "10");
			attr(circle, "stroke", "currentColor");
			attr(circle, "stroke-width", "4");
			attr(path, "class", "opacity-75");
			attr(path, "fill", "currentColor");
			attr(path, "d", "M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z");
			attr(svg, "class", "absolute h-5 w-5 animate-spin");
			attr(svg, "xmlns", "http://www.w3.org/2000/svg");
			attr(svg, "fill", "none");
			attr(svg, "viewBox", "0 0 24 24");
		},
		m(target, anchor) {
			insert_hydration(target, svg, anchor);
			append_hydration(svg, circle);
			append_hydration(svg, path);
		},
		d(detaching) {
			if (detaching) detach(svg);
		}
	};
}

// (133:12) Link Slot
function fallback_block$1(ctx) {
	let t;

	return {
		c() {
			t = text("Link Slot");
		},
		l(nodes) {
			t = claim_text(nodes, "Link Slot");
		},
		m(target, anchor) {
			insert_hydration(target, t, anchor);
		},
		d(detaching) {
			if (detaching) detach(t);
		}
	};
}

function create_fragment$I(ctx) {
	let current_block_type_index;
	let if_block;
	let if_block_anchor;
	let current;
	const if_block_creators = [create_if_block$p, create_else_block$6];
	const if_blocks = [];

	function select_block_type(ctx, dirty) {
		if (/*href*/ ctx[5]) return 0;
		return 1;
	}

	current_block_type_index = select_block_type(ctx);
	if_block = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);

	return {
		c() {
			if_block.c();
			if_block_anchor = empty();
		},
		l(nodes) {
			if_block.l(nodes);
			if_block_anchor = empty();
		},
		m(target, anchor) {
			if_blocks[current_block_type_index].m(target, anchor);
			insert_hydration(target, if_block_anchor, anchor);
			current = true;
		},
		p(ctx, [dirty]) {
			let previous_block_index = current_block_type_index;
			current_block_type_index = select_block_type(ctx);

			if (current_block_type_index === previous_block_index) {
				if_blocks[current_block_type_index].p(ctx, dirty);
			} else {
				group_outros();

				transition_out(if_blocks[previous_block_index], 1, 1, () => {
					if_blocks[previous_block_index] = null;
				});

				check_outros();
				if_block = if_blocks[current_block_type_index];

				if (!if_block) {
					if_block = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);
					if_block.c();
				} else {
					if_block.p(ctx, dirty);
				}

				transition_in(if_block, 1);
				if_block.m(if_block_anchor.parentNode, if_block_anchor);
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			if_blocks[current_block_type_index].d(detaching);
			if (detaching) detach(if_block_anchor);
		}
	};
}

function instance$I($$self, $$props, $$invalidate) {
	const omit_props_names = ["kind","rounded","full","disabled","size","type","loading","href"];
	let $$restProps = compute_rest_props($$props, omit_props_names);
	let { $$slots: slots = {}, $$scope } = $$props;
	let { kind = "primary" } = $$props;
	let { rounded = false } = $$props;
	let { full = false } = $$props;
	let { disabled = false } = $$props;
	let { size = "base" } = $$props;
	let { type = "button" } = $$props;
	let { loading = false } = $$props;

	let classes = [
		"inline-flex justify-center items-center font-medium focus:outline-none focus:ring-1"
	];

	const handleKinds = (kind, size) => {
		$$invalidate(6, classes = [
			"inline-flex justify-center items-center font-medium focus:outline-none focus:ring-1"
		]);

		switch (size) {
			case "xsmall":
				classes.push("px-3 py-0.5 text-sm");
				break;
			case "small":
				classes.push("px-3 py-1 text-sm");
				break;
			case "base":
				classes.push("px-4 py-2 text-sm");
				break;
			case "large":
				classes.push("px-4 py-2 text-base");
				break;
		}

		switch (kind) {
			case "primary":
				classes.push("bg-blue-500 text-white hover:bg-blue-700 focus:bg-blue-800 border border-transparent focus:ring-offset-2 focus:ring-offset-white focus:ring-blue-300");
				break;
			case "secondary":
				classes.push("bg-blue-100 hover:bg-blue-200 focus:bg-blue-100 border border-transparent text-blue-600 focus:ring-offset-2 focus:ring-offset-white focus:ring-blue-300");
				break;
			case "white":
				classes.push("bg-white text-gray-700 hover:bg-gray-50 border border-gray-300 focus:ring-offset-2 focus:ring-offset-white focus:ring-blue-300");
				break;
			case "danger":
				classes.push("w-full inline-flex justify-center rounded-md border border-transparent shadow-sm bg-red-600 text-white hover:bg-red-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-red-500");
				break;
			case "warning":
				classes.push("w-full inline-flex justify-center rounded-md border border-transparent shadow-sm bg-red-100 text-red-500 hover:bg-red-200 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-red-500");
				break;
			case "gray":
				classes.push("bg-gray-100 hover:bg-gray-200 focus:bg-gray-300 border border-transparent text-gray-800 focus:ring-offset-2 focus:ring-offset-white focus:ring-gray-300");
				break;
		}
	};

	let { href = null } = $$props;

	function click_handler(event) {
		bubble.call(this, $$self, event);
	}

	function mouseover_handler(event) {
		bubble.call(this, $$self, event);
	}

	function mouseenter_handler(event) {
		bubble.call(this, $$self, event);
	}

	function mouseleave_handler(event) {
		bubble.call(this, $$self, event);
	}

	function click_handler_1(event) {
		bubble.call(this, $$self, event);
	}

	function mouseover_handler_1(event) {
		bubble.call(this, $$self, event);
	}

	function mouseenter_handler_1(event) {
		bubble.call(this, $$self, event);
	}

	function mouseleave_handler_1(event) {
		bubble.call(this, $$self, event);
	}

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(7, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('kind' in $$new_props) $$invalidate(8, kind = $$new_props.kind);
		if ('rounded' in $$new_props) $$invalidate(0, rounded = $$new_props.rounded);
		if ('full' in $$new_props) $$invalidate(1, full = $$new_props.full);
		if ('disabled' in $$new_props) $$invalidate(2, disabled = $$new_props.disabled);
		if ('size' in $$new_props) $$invalidate(9, size = $$new_props.size);
		if ('type' in $$new_props) $$invalidate(3, type = $$new_props.type);
		if ('loading' in $$new_props) $$invalidate(4, loading = $$new_props.loading);
		if ('href' in $$new_props) $$invalidate(5, href = $$new_props.href);
		if ('$$scope' in $$new_props) $$invalidate(10, $$scope = $$new_props.$$scope);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*kind, size*/ 768) {
			handleKinds(kind, size);
		}
	};

	return [
		rounded,
		full,
		disabled,
		type,
		loading,
		href,
		classes,
		$$restProps,
		kind,
		size,
		$$scope,
		slots,
		click_handler,
		mouseover_handler,
		mouseenter_handler,
		mouseleave_handler,
		click_handler_1,
		mouseover_handler_1,
		mouseenter_handler_1,
		mouseleave_handler_1
	];
}

class Button extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$I, create_fragment$I, safe_not_equal, {
			kind: 8,
			rounded: 0,
			full: 1,
			disabled: 2,
			size: 9,
			type: 3,
			loading: 4,
			href: 5
		});
	}
}

/* src\Button\ButtonGroup.svelte generated by Svelte v3.48.0 */

function create_fragment$H(ctx) {
	let span;
	let current;
	const default_slot_template = /*#slots*/ ctx[1].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[0], null);

	return {
		c() {
			span = element("span");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			span = claim_element(nodes, "SPAN", { class: true });
			var span_nodes = children(span);
			if (default_slot) default_slot.l(span_nodes);
			span_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(span, "class", "relative z-0 inline-flex shadow-sm rounded-md button_group_hh");
		},
		m(target, anchor) {
			insert_hydration(target, span, anchor);

			if (default_slot) {
				default_slot.m(span, null);
			}

			current = true;
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 1)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[0],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[0])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[0], dirty, null),
						null
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(span);
			if (default_slot) default_slot.d(detaching);
		}
	};
}

function instance$H($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;

	$$self.$$set = $$props => {
		if ('$$scope' in $$props) $$invalidate(0, $$scope = $$props.$$scope);
	};

	return [$$scope, slots];
}

class ButtonGroup extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$H, create_fragment$H, safe_not_equal, {});
	}
}

/* src\Button\ButtonItem.svelte generated by Svelte v3.48.0 */

function create_fragment$G(ctx) {
	let button;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[1].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[0], null);

	return {
		c() {
			button = element("button");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			button = claim_element(nodes, "BUTTON", { type: true, class: true });
			var button_nodes = children(button);
			if (default_slot) default_slot.l(button_nodes);
			button_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(button, "type", "button");
			attr(button, "class", "-ml-px relative rounded-r-md inline-flex items-center px-4 py-2 border border-gray-300 bg-white text-sm font-medium text-gray-700 hover:bg-gray-50 focus:z-10 focus:outline-none focus:ring-1 focus:ring-indigo-500 focus:border-indigo-500 svelte-1qhr38y");
		},
		m(target, anchor) {
			insert_hydration(target, button, anchor);

			if (default_slot) {
				default_slot.m(button, null);
			}

			current = true;

			if (!mounted) {
				dispose = listen(button, "click", /*click_handler*/ ctx[2]);
				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 1)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[0],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[0])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[0], dirty, null),
						null
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(button);
			if (default_slot) default_slot.d(detaching);
			mounted = false;
			dispose();
		}
	};
}

function instance$G($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;

	function click_handler(event) {
		bubble.call(this, $$self, event);
	}

	$$self.$$set = $$props => {
		if ('$$scope' in $$props) $$invalidate(0, $$scope = $$props.$$scope);
	};

	return [$$scope, slots, click_handler];
}

class ButtonItem extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$G, create_fragment$G, safe_not_equal, {});
	}
}

/* src\Chips\Chip.svelte generated by Svelte v3.48.0 */

function create_else_block$5(ctx) {
	let t;

	return {
		c() {
			t = text(/*label*/ ctx[0]);
		},
		l(nodes) {
			t = claim_text(nodes, /*label*/ ctx[0]);
		},
		m(target, anchor) {
			insert_hydration(target, t, anchor);
		},
		p(ctx, dirty) {
			if (dirty & /*label*/ 1) set_data(t, /*label*/ ctx[0]);
		},
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(t);
		}
	};
}

// (38:2) {#if $$slots.default}
function create_if_block$o(ctx) {
	let current;
	const default_slot_template = /*#slots*/ ctx[6].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[8], null);

	return {
		c() {
			if (default_slot) default_slot.c();
		},
		l(nodes) {
			if (default_slot) default_slot.l(nodes);
		},
		m(target, anchor) {
			if (default_slot) {
				default_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 256)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[8],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[8])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[8], dirty, null),
						null
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (default_slot) default_slot.d(detaching);
		}
	};
}

// (37:0) <Button {kind} {rounded} {size} {disabled} on:click>
function create_default_slot$9(ctx) {
	let current_block_type_index;
	let if_block;
	let t;
	let svg;
	let path;
	let current;
	const if_block_creators = [create_if_block$o, create_else_block$5];
	const if_blocks = [];

	function select_block_type(ctx, dirty) {
		if (/*$$slots*/ ctx[5].default) return 0;
		return 1;
	}

	current_block_type_index = select_block_type(ctx);
	if_block = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);

	return {
		c() {
			if_block.c();
			t = space();
			svg = svg_element("svg");
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			if_block.l(nodes);
			t = claim_space(nodes);

			svg = claim_svg_element(nodes, "svg", {
				class: true,
				stroke: true,
				fill: true,
				viewBox: true
			});

			var svg_nodes = children(svg);

			path = claim_svg_element(svg_nodes, "path", {
				"stroke-linecap": true,
				"stroke-width": true,
				d: true
			});

			children(path).forEach(detach);
			svg_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(path, "stroke-linecap", "round");
			attr(path, "stroke-width", "1.5");
			attr(path, "d", "M1 1l6 6m0-6L1 7");
			attr(svg, "class", "h-2.5 w-2.5 ml-3");
			attr(svg, "stroke", "currentColor");
			attr(svg, "fill", "none");
			attr(svg, "viewBox", "0 0 8 8");
		},
		m(target, anchor) {
			if_blocks[current_block_type_index].m(target, anchor);
			insert_hydration(target, t, anchor);
			insert_hydration(target, svg, anchor);
			append_hydration(svg, path);
			current = true;
		},
		p(ctx, dirty) {
			let previous_block_index = current_block_type_index;
			current_block_type_index = select_block_type(ctx);

			if (current_block_type_index === previous_block_index) {
				if_blocks[current_block_type_index].p(ctx, dirty);
			} else {
				group_outros();

				transition_out(if_blocks[previous_block_index], 1, 1, () => {
					if_blocks[previous_block_index] = null;
				});

				check_outros();
				if_block = if_blocks[current_block_type_index];

				if (!if_block) {
					if_block = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);
					if_block.c();
				} else {
					if_block.p(ctx, dirty);
				}

				transition_in(if_block, 1);
				if_block.m(t.parentNode, t);
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			if_blocks[current_block_type_index].d(detaching);
			if (detaching) detach(t);
			if (detaching) detach(svg);
		}
	};
}

function create_fragment$F(ctx) {
	let button;
	let current;

	button = new Button({
			props: {
				kind: /*kind*/ ctx[1],
				rounded: /*rounded*/ ctx[2],
				size: /*size*/ ctx[3],
				disabled: /*disabled*/ ctx[4],
				$$slots: { default: [create_default_slot$9] },
				$$scope: { ctx }
			}
		});

	button.$on("click", /*click_handler*/ ctx[7]);

	return {
		c() {
			create_component(button.$$.fragment);
		},
		l(nodes) {
			claim_component(button.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(button, target, anchor);
			current = true;
		},
		p(ctx, [dirty]) {
			const button_changes = {};
			if (dirty & /*kind*/ 2) button_changes.kind = /*kind*/ ctx[1];
			if (dirty & /*rounded*/ 4) button_changes.rounded = /*rounded*/ ctx[2];
			if (dirty & /*size*/ 8) button_changes.size = /*size*/ ctx[3];
			if (dirty & /*disabled*/ 16) button_changes.disabled = /*disabled*/ ctx[4];

			if (dirty & /*$$scope, $$slots, label*/ 289) {
				button_changes.$$scope = { dirty, ctx };
			}

			button.$set(button_changes);
		},
		i(local) {
			if (current) return;
			transition_in(button.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(button.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(button, detaching);
		}
	};
}

function instance$F($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	const $$slots = compute_slots(slots);
	let { label } = $$props;
	let { kind = "secondary" } = $$props;
	let { rounded = false } = $$props;
	let { size = "base" } = $$props;
	let { disabled = false } = $$props;

	function click_handler(event) {
		bubble.call(this, $$self, event);
	}

	$$self.$$set = $$props => {
		if ('label' in $$props) $$invalidate(0, label = $$props.label);
		if ('kind' in $$props) $$invalidate(1, kind = $$props.kind);
		if ('rounded' in $$props) $$invalidate(2, rounded = $$props.rounded);
		if ('size' in $$props) $$invalidate(3, size = $$props.size);
		if ('disabled' in $$props) $$invalidate(4, disabled = $$props.disabled);
		if ('$$scope' in $$props) $$invalidate(8, $$scope = $$props.$$scope);
	};

	return [label, kind, rounded, size, disabled, $$slots, slots, click_handler, $$scope];
}

class Chip extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$F, create_fragment$F, safe_not_equal, {
			label: 0,
			kind: 1,
			rounded: 2,
			size: 3,
			disabled: 4
		});
	}
}

function flip$2(node, { from, to }, params = {}) {
    const style = getComputedStyle(node);
    const transform = style.transform === 'none' ? '' : style.transform;
    const [ox, oy] = style.transformOrigin.split(' ').map(parseFloat);
    const dx = (from.left + from.width * ox / to.width) - (to.left + ox);
    const dy = (from.top + from.height * oy / to.height) - (to.top + oy);
    const { delay = 0, duration = (d) => Math.sqrt(d) * 120, easing = cubicOut } = params;
    return {
        delay,
        duration: is_function(duration) ? duration(Math.sqrt(dx * dx + dy * dy)) : duration,
        easing,
        css: (t, u) => {
            const x = u * dx;
            const y = u * dy;
            const sx = t + u * from.width / to.width;
            const sy = t + u * from.height / to.height;
            return `transform: ${transform} translate(${x}px, ${y}px) scale(${sx}, ${sy});`;
        }
    };
}

/* src\Chips\ChipSet.svelte generated by Svelte v3.48.0 */

function get_each_context$9(ctx, list, i) {
	const child_ctx = ctx.slice();
	child_ctx[3] = list[i];
	return child_ctx;
}

// (18:0) {#if chipArray.length}
function create_if_block$n(ctx) {
	let div;
	let each_blocks = [];
	let each_1_lookup = new Map();
	let current;
	let each_value = /*chipArray*/ ctx[0];
	const get_key = ctx => /*chip*/ ctx[3];

	for (let i = 0; i < each_value.length; i += 1) {
		let child_ctx = get_each_context$9(ctx, each_value, i);
		let key = get_key(child_ctx);
		each_1_lookup.set(key, each_blocks[i] = create_each_block$9(key, child_ctx));
	}

	return {
		c() {
			div = element("div");

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].c();
			}

			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].l(div_nodes);
			}

			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", "flex flex-wrap");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].m(div, null);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (dirty & /*chipArray, handleClick*/ 3) {
				each_value = /*chipArray*/ ctx[0];
				group_outros();
				for (let i = 0; i < each_blocks.length; i += 1) each_blocks[i].r();
				each_blocks = update_keyed_each(each_blocks, dirty, get_key, 1, ctx, each_value, each_1_lookup, div, fix_and_outro_and_destroy_block, create_each_block$9, null, get_each_context$9);
				for (let i = 0; i < each_blocks.length; i += 1) each_blocks[i].a();
				check_outros();
			}
		},
		i(local) {
			if (current) return;

			for (let i = 0; i < each_value.length; i += 1) {
				transition_in(each_blocks[i]);
			}

			current = true;
		},
		o(local) {
			for (let i = 0; i < each_blocks.length; i += 1) {
				transition_out(each_blocks[i]);
			}

			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].d();
			}
		}
	};
}

// (20:4) {#each chipArray as chip (chip)}
function create_each_block$9(key_1, ctx) {
	let div;
	let chip;
	let t;
	let div_transition;
	let rect;
	let stop_animation = noop;
	let current;

	function click_handler() {
		return /*click_handler*/ ctx[2](/*chip*/ ctx[3]);
	}

	chip = new Chip({ props: { label: /*chip*/ ctx[3] } });
	chip.$on("click", click_handler);

	return {
		key: key_1,
		first: null,
		c() {
			div = element("div");
			create_component(chip.$$.fragment);
			t = space();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			claim_component(chip.$$.fragment, div_nodes);
			t = claim_space(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", "inline-block mx-2 my-2");
			this.first = div;
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			mount_component(chip, div, null);
			append_hydration(div, t);
			current = true;
		},
		p(new_ctx, dirty) {
			ctx = new_ctx;
			const chip_changes = {};
			if (dirty & /*chipArray*/ 1) chip_changes.label = /*chip*/ ctx[3];
			chip.$set(chip_changes);
		},
		r() {
			rect = div.getBoundingClientRect();
		},
		f() {
			fix_position(div);
			stop_animation();
			add_transform(div, rect);
		},
		a() {
			stop_animation();
			stop_animation = create_animation(div, rect, flip$2, { duration: 300 });
		},
		i(local) {
			if (current) return;
			transition_in(chip.$$.fragment, local);

			add_render_callback(() => {
				if (!div_transition) div_transition = create_bidirectional_transition(div, fly, { x: -20, duration: 300 }, true);
				div_transition.run(1);
			});

			current = true;
		},
		o(local) {
			transition_out(chip.$$.fragment, local);
			if (!div_transition) div_transition = create_bidirectional_transition(div, fly, { x: -20, duration: 300 }, false);
			div_transition.run(0);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			destroy_component(chip);
			if (detaching && div_transition) div_transition.end();
		}
	};
}

function create_fragment$E(ctx) {
	let if_block_anchor;
	let current;
	let if_block = /*chipArray*/ ctx[0].length && create_if_block$n(ctx);

	return {
		c() {
			if (if_block) if_block.c();
			if_block_anchor = empty();
		},
		l(nodes) {
			if (if_block) if_block.l(nodes);
			if_block_anchor = empty();
		},
		m(target, anchor) {
			if (if_block) if_block.m(target, anchor);
			insert_hydration(target, if_block_anchor, anchor);
			current = true;
		},
		p(ctx, [dirty]) {
			if (/*chipArray*/ ctx[0].length) {
				if (if_block) {
					if_block.p(ctx, dirty);

					if (dirty & /*chipArray*/ 1) {
						transition_in(if_block, 1);
					}
				} else {
					if_block = create_if_block$n(ctx);
					if_block.c();
					transition_in(if_block, 1);
					if_block.m(if_block_anchor.parentNode, if_block_anchor);
				}
			} else if (if_block) {
				group_outros();

				transition_out(if_block, 1, 1, () => {
					if_block = null;
				});

				check_outros();
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			if (if_block) if_block.d(detaching);
			if (detaching) detach(if_block_anchor);
		}
	};
}

function instance$E($$self, $$props, $$invalidate) {
	let { chipArray = [] } = $$props;

	const handleClick = chip => {
		$$invalidate(0, chipArray = chipArray.filter(c => c != chip));
	};

	const click_handler = chip => handleClick(chip);

	$$self.$$set = $$props => {
		if ('chipArray' in $$props) $$invalidate(0, chipArray = $$props.chipArray);
	};

	return [chipArray, handleClick, click_handler];
}

class ChipSet extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$E, create_fragment$E, safe_not_equal, { chipArray: 0 });
	}
}

/*! clipboard-copy. MIT License. Feross Aboukhadijeh <https://feross.org/opensource> */
/* global DOMException */

var clipboardCopy_1 = clipboardCopy;

function makeError () {
  return new DOMException('The request is not allowed', 'NotAllowedError')
}

async function copyClipboardApi (text) {
  // Use the Async Clipboard API when available. Requires a secure browsing
  // context (i.e. HTTPS)
  if (!navigator.clipboard) {
    throw makeError()
  }
  return navigator.clipboard.writeText(text)
}

async function copyExecCommand (text) {
  // Put the text to copy into a <span>
  const span = document.createElement('span');
  span.textContent = text;

  // Preserve consecutive spaces and newlines
  span.style.whiteSpace = 'pre';
  span.style.webkitUserSelect = 'auto';
  span.style.userSelect = 'all';

  // Add the <span> to the page
  document.body.appendChild(span);

  // Make a selection object representing the range of text selected by the user
  const selection = window.getSelection();
  const range = window.document.createRange();
  selection.removeAllRanges();
  range.selectNode(span);
  selection.addRange(range);

  // Copy text to the clipboard
  let success = false;
  try {
    success = window.document.execCommand('copy');
  } finally {
    // Cleanup
    selection.removeAllRanges();
    window.document.body.removeChild(span);
  }

  if (!success) throw makeError()
}

async function clipboardCopy (text) {
  try {
    await copyClipboardApi(text);
  } catch (err) {
    // ...Otherwise, use document.execCommand() fallback
    try {
      await copyExecCommand(text);
    } catch (err2) {
      throw (err2 || err || makeError())
    }
  }
}

var top = 'top';
var bottom = 'bottom';
var right = 'right';
var left = 'left';
var auto = 'auto';
var basePlacements = [top, bottom, right, left];
var start = 'start';
var end = 'end';
var clippingParents = 'clippingParents';
var viewport = 'viewport';
var popper = 'popper';
var reference = 'reference';
var variationPlacements = /*#__PURE__*/basePlacements.reduce(function (acc, placement) {
  return acc.concat([placement + "-" + start, placement + "-" + end]);
}, []);
var placements = /*#__PURE__*/[].concat(basePlacements, [auto]).reduce(function (acc, placement) {
  return acc.concat([placement, placement + "-" + start, placement + "-" + end]);
}, []); // modifiers that need to read the DOM

var beforeRead = 'beforeRead';
var read = 'read';
var afterRead = 'afterRead'; // pure-logic modifiers

var beforeMain = 'beforeMain';
var main = 'main';
var afterMain = 'afterMain'; // modifier with the purpose to write to the DOM (or write into a framework state)

var beforeWrite = 'beforeWrite';
var write = 'write';
var afterWrite = 'afterWrite';
var modifierPhases = [beforeRead, read, afterRead, beforeMain, main, afterMain, beforeWrite, write, afterWrite];

function getNodeName(element) {
  return element ? (element.nodeName || '').toLowerCase() : null;
}

function getWindow(node) {
  if (node == null) {
    return window;
  }

  if (node.toString() !== '[object Window]') {
    var ownerDocument = node.ownerDocument;
    return ownerDocument ? ownerDocument.defaultView || window : window;
  }

  return node;
}

function isElement(node) {
  var OwnElement = getWindow(node).Element;
  return node instanceof OwnElement || node instanceof Element;
}

function isHTMLElement(node) {
  var OwnElement = getWindow(node).HTMLElement;
  return node instanceof OwnElement || node instanceof HTMLElement;
}

function isShadowRoot(node) {
  // IE 11 has no ShadowRoot
  if (typeof ShadowRoot === 'undefined') {
    return false;
  }

  var OwnElement = getWindow(node).ShadowRoot;
  return node instanceof OwnElement || node instanceof ShadowRoot;
}

// and applies them to the HTMLElements such as popper and arrow

function applyStyles(_ref) {
  var state = _ref.state;
  Object.keys(state.elements).forEach(function (name) {
    var style = state.styles[name] || {};
    var attributes = state.attributes[name] || {};
    var element = state.elements[name]; // arrow is optional + virtual elements

    if (!isHTMLElement(element) || !getNodeName(element)) {
      return;
    } // Flow doesn't support to extend this property, but it's the most
    // effective way to apply styles to an HTMLElement
    // $FlowFixMe[cannot-write]


    Object.assign(element.style, style);
    Object.keys(attributes).forEach(function (name) {
      var value = attributes[name];

      if (value === false) {
        element.removeAttribute(name);
      } else {
        element.setAttribute(name, value === true ? '' : value);
      }
    });
  });
}

function effect$2(_ref2) {
  var state = _ref2.state;
  var initialStyles = {
    popper: {
      position: state.options.strategy,
      left: '0',
      top: '0',
      margin: '0'
    },
    arrow: {
      position: 'absolute'
    },
    reference: {}
  };
  Object.assign(state.elements.popper.style, initialStyles.popper);
  state.styles = initialStyles;

  if (state.elements.arrow) {
    Object.assign(state.elements.arrow.style, initialStyles.arrow);
  }

  return function () {
    Object.keys(state.elements).forEach(function (name) {
      var element = state.elements[name];
      var attributes = state.attributes[name] || {};
      var styleProperties = Object.keys(state.styles.hasOwnProperty(name) ? state.styles[name] : initialStyles[name]); // Set all values to an empty string to unset them

      var style = styleProperties.reduce(function (style, property) {
        style[property] = '';
        return style;
      }, {}); // arrow is optional + virtual elements

      if (!isHTMLElement(element) || !getNodeName(element)) {
        return;
      }

      Object.assign(element.style, style);
      Object.keys(attributes).forEach(function (attribute) {
        element.removeAttribute(attribute);
      });
    });
  };
} // eslint-disable-next-line import/no-unused-modules


var applyStyles$1 = {
  name: 'applyStyles',
  enabled: true,
  phase: 'write',
  fn: applyStyles,
  effect: effect$2,
  requires: ['computeStyles']
};

function getBasePlacement(placement) {
  return placement.split('-')[0];
}

var max = Math.max;
var min = Math.min;
var round = Math.round;

function getBoundingClientRect(element, includeScale) {
  if (includeScale === void 0) {
    includeScale = false;
  }

  var rect = element.getBoundingClientRect();
  var scaleX = 1;
  var scaleY = 1;

  if (isHTMLElement(element) && includeScale) {
    var offsetHeight = element.offsetHeight;
    var offsetWidth = element.offsetWidth; // Do not attempt to divide by 0, otherwise we get `Infinity` as scale
    // Fallback to 1 in case both values are `0`

    if (offsetWidth > 0) {
      scaleX = round(rect.width) / offsetWidth || 1;
    }

    if (offsetHeight > 0) {
      scaleY = round(rect.height) / offsetHeight || 1;
    }
  }

  return {
    width: rect.width / scaleX,
    height: rect.height / scaleY,
    top: rect.top / scaleY,
    right: rect.right / scaleX,
    bottom: rect.bottom / scaleY,
    left: rect.left / scaleX,
    x: rect.left / scaleX,
    y: rect.top / scaleY
  };
}

// means it doesn't take into account transforms.

function getLayoutRect(element) {
  var clientRect = getBoundingClientRect(element); // Use the clientRect sizes if it's not been transformed.
  // Fixes https://github.com/popperjs/popper-core/issues/1223

  var width = element.offsetWidth;
  var height = element.offsetHeight;

  if (Math.abs(clientRect.width - width) <= 1) {
    width = clientRect.width;
  }

  if (Math.abs(clientRect.height - height) <= 1) {
    height = clientRect.height;
  }

  return {
    x: element.offsetLeft,
    y: element.offsetTop,
    width: width,
    height: height
  };
}

function contains$1(parent, child) {
  var rootNode = child.getRootNode && child.getRootNode(); // First, attempt with faster native method

  if (parent.contains(child)) {
    return true;
  } // then fallback to custom implementation with Shadow DOM support
  else if (rootNode && isShadowRoot(rootNode)) {
      var next = child;

      do {
        if (next && parent.isSameNode(next)) {
          return true;
        } // $FlowFixMe[prop-missing]: need a better way to handle this...


        next = next.parentNode || next.host;
      } while (next);
    } // Give up, the result is false


  return false;
}

function getComputedStyle$1(element) {
  return getWindow(element).getComputedStyle(element);
}

function isTableElement(element) {
  return ['table', 'td', 'th'].indexOf(getNodeName(element)) >= 0;
}

function getDocumentElement(element) {
  // $FlowFixMe[incompatible-return]: assume body is always available
  return ((isElement(element) ? element.ownerDocument : // $FlowFixMe[prop-missing]
  element.document) || window.document).documentElement;
}

function getParentNode(element) {
  if (getNodeName(element) === 'html') {
    return element;
  }

  return (// this is a quicker (but less type safe) way to save quite some bytes from the bundle
    // $FlowFixMe[incompatible-return]
    // $FlowFixMe[prop-missing]
    element.assignedSlot || // step into the shadow DOM of the parent of a slotted node
    element.parentNode || ( // DOM Element detected
    isShadowRoot(element) ? element.host : null) || // ShadowRoot detected
    // $FlowFixMe[incompatible-call]: HTMLElement is a Node
    getDocumentElement(element) // fallback

  );
}

function getTrueOffsetParent(element) {
  if (!isHTMLElement(element) || // https://github.com/popperjs/popper-core/issues/837
  getComputedStyle$1(element).position === 'fixed') {
    return null;
  }

  return element.offsetParent;
} // `.offsetParent` reports `null` for fixed elements, while absolute elements
// return the containing block


function getContainingBlock(element) {
  var isFirefox = navigator.userAgent.toLowerCase().indexOf('firefox') !== -1;
  var isIE = navigator.userAgent.indexOf('Trident') !== -1;

  if (isIE && isHTMLElement(element)) {
    // In IE 9, 10 and 11 fixed elements containing block is always established by the viewport
    var elementCss = getComputedStyle$1(element);

    if (elementCss.position === 'fixed') {
      return null;
    }
  }

  var currentNode = getParentNode(element);

  if (isShadowRoot(currentNode)) {
    currentNode = currentNode.host;
  }

  while (isHTMLElement(currentNode) && ['html', 'body'].indexOf(getNodeName(currentNode)) < 0) {
    var css = getComputedStyle$1(currentNode); // This is non-exhaustive but covers the most common CSS properties that
    // create a containing block.
    // https://developer.mozilla.org/en-US/docs/Web/CSS/Containing_block#identifying_the_containing_block

    if (css.transform !== 'none' || css.perspective !== 'none' || css.contain === 'paint' || ['transform', 'perspective'].indexOf(css.willChange) !== -1 || isFirefox && css.willChange === 'filter' || isFirefox && css.filter && css.filter !== 'none') {
      return currentNode;
    } else {
      currentNode = currentNode.parentNode;
    }
  }

  return null;
} // Gets the closest ancestor positioned element. Handles some edge cases,
// such as table ancestors and cross browser bugs.


function getOffsetParent(element) {
  var window = getWindow(element);
  var offsetParent = getTrueOffsetParent(element);

  while (offsetParent && isTableElement(offsetParent) && getComputedStyle$1(offsetParent).position === 'static') {
    offsetParent = getTrueOffsetParent(offsetParent);
  }

  if (offsetParent && (getNodeName(offsetParent) === 'html' || getNodeName(offsetParent) === 'body' && getComputedStyle$1(offsetParent).position === 'static')) {
    return window;
  }

  return offsetParent || getContainingBlock(element) || window;
}

function getMainAxisFromPlacement(placement) {
  return ['top', 'bottom'].indexOf(placement) >= 0 ? 'x' : 'y';
}

function within(min$1, value, max$1) {
  return max(min$1, min(value, max$1));
}
function withinMaxClamp(min, value, max) {
  var v = within(min, value, max);
  return v > max ? max : v;
}

function getFreshSideObject() {
  return {
    top: 0,
    right: 0,
    bottom: 0,
    left: 0
  };
}

function mergePaddingObject(paddingObject) {
  return Object.assign({}, getFreshSideObject(), paddingObject);
}

function expandToHashMap(value, keys) {
  return keys.reduce(function (hashMap, key) {
    hashMap[key] = value;
    return hashMap;
  }, {});
}

var toPaddingObject = function toPaddingObject(padding, state) {
  padding = typeof padding === 'function' ? padding(Object.assign({}, state.rects, {
    placement: state.placement
  })) : padding;
  return mergePaddingObject(typeof padding !== 'number' ? padding : expandToHashMap(padding, basePlacements));
};

function arrow(_ref) {
  var _state$modifiersData$;

  var state = _ref.state,
      name = _ref.name,
      options = _ref.options;
  var arrowElement = state.elements.arrow;
  var popperOffsets = state.modifiersData.popperOffsets;
  var basePlacement = getBasePlacement(state.placement);
  var axis = getMainAxisFromPlacement(basePlacement);
  var isVertical = [left, right].indexOf(basePlacement) >= 0;
  var len = isVertical ? 'height' : 'width';

  if (!arrowElement || !popperOffsets) {
    return;
  }

  var paddingObject = toPaddingObject(options.padding, state);
  var arrowRect = getLayoutRect(arrowElement);
  var minProp = axis === 'y' ? top : left;
  var maxProp = axis === 'y' ? bottom : right;
  var endDiff = state.rects.reference[len] + state.rects.reference[axis] - popperOffsets[axis] - state.rects.popper[len];
  var startDiff = popperOffsets[axis] - state.rects.reference[axis];
  var arrowOffsetParent = getOffsetParent(arrowElement);
  var clientSize = arrowOffsetParent ? axis === 'y' ? arrowOffsetParent.clientHeight || 0 : arrowOffsetParent.clientWidth || 0 : 0;
  var centerToReference = endDiff / 2 - startDiff / 2; // Make sure the arrow doesn't overflow the popper if the center point is
  // outside of the popper bounds

  var min = paddingObject[minProp];
  var max = clientSize - arrowRect[len] - paddingObject[maxProp];
  var center = clientSize / 2 - arrowRect[len] / 2 + centerToReference;
  var offset = within(min, center, max); // Prevents breaking syntax highlighting...

  var axisProp = axis;
  state.modifiersData[name] = (_state$modifiersData$ = {}, _state$modifiersData$[axisProp] = offset, _state$modifiersData$.centerOffset = offset - center, _state$modifiersData$);
}

function effect$1(_ref2) {
  var state = _ref2.state,
      options = _ref2.options;
  var _options$element = options.element,
      arrowElement = _options$element === void 0 ? '[data-popper-arrow]' : _options$element;

  if (arrowElement == null) {
    return;
  } // CSS selector


  if (typeof arrowElement === 'string') {
    arrowElement = state.elements.popper.querySelector(arrowElement);

    if (!arrowElement) {
      return;
    }
  }

  if (process.env.NODE_ENV !== "production") {
    if (!isHTMLElement(arrowElement)) {
      console.error(['Popper: "arrow" element must be an HTMLElement (not an SVGElement).', 'To use an SVG arrow, wrap it in an HTMLElement that will be used as', 'the arrow.'].join(' '));
    }
  }

  if (!contains$1(state.elements.popper, arrowElement)) {
    if (process.env.NODE_ENV !== "production") {
      console.error(['Popper: "arrow" modifier\'s `element` must be a child of the popper', 'element.'].join(' '));
    }

    return;
  }

  state.elements.arrow = arrowElement;
} // eslint-disable-next-line import/no-unused-modules


var arrow$1 = {
  name: 'arrow',
  enabled: true,
  phase: 'main',
  fn: arrow,
  effect: effect$1,
  requires: ['popperOffsets'],
  requiresIfExists: ['preventOverflow']
};

function getVariation(placement) {
  return placement.split('-')[1];
}

var unsetSides = {
  top: 'auto',
  right: 'auto',
  bottom: 'auto',
  left: 'auto'
}; // Round the offsets to the nearest suitable subpixel based on the DPR.
// Zooming can change the DPR, but it seems to report a value that will
// cleanly divide the values into the appropriate subpixels.

function roundOffsetsByDPR(_ref) {
  var x = _ref.x,
      y = _ref.y;
  var win = window;
  var dpr = win.devicePixelRatio || 1;
  return {
    x: round(x * dpr) / dpr || 0,
    y: round(y * dpr) / dpr || 0
  };
}

function mapToStyles(_ref2) {
  var _Object$assign2;

  var popper = _ref2.popper,
      popperRect = _ref2.popperRect,
      placement = _ref2.placement,
      variation = _ref2.variation,
      offsets = _ref2.offsets,
      position = _ref2.position,
      gpuAcceleration = _ref2.gpuAcceleration,
      adaptive = _ref2.adaptive,
      roundOffsets = _ref2.roundOffsets,
      isFixed = _ref2.isFixed;
  var _offsets$x = offsets.x,
      x = _offsets$x === void 0 ? 0 : _offsets$x,
      _offsets$y = offsets.y,
      y = _offsets$y === void 0 ? 0 : _offsets$y;

  var _ref3 = typeof roundOffsets === 'function' ? roundOffsets({
    x: x,
    y: y
  }) : {
    x: x,
    y: y
  };

  x = _ref3.x;
  y = _ref3.y;
  var hasX = offsets.hasOwnProperty('x');
  var hasY = offsets.hasOwnProperty('y');
  var sideX = left;
  var sideY = top;
  var win = window;

  if (adaptive) {
    var offsetParent = getOffsetParent(popper);
    var heightProp = 'clientHeight';
    var widthProp = 'clientWidth';

    if (offsetParent === getWindow(popper)) {
      offsetParent = getDocumentElement(popper);

      if (getComputedStyle$1(offsetParent).position !== 'static' && position === 'absolute') {
        heightProp = 'scrollHeight';
        widthProp = 'scrollWidth';
      }
    } // $FlowFixMe[incompatible-cast]: force type refinement, we compare offsetParent with window above, but Flow doesn't detect it


    offsetParent = offsetParent;

    if (placement === top || (placement === left || placement === right) && variation === end) {
      sideY = bottom;
      var offsetY = isFixed && offsetParent === win && win.visualViewport ? win.visualViewport.height : // $FlowFixMe[prop-missing]
      offsetParent[heightProp];
      y -= offsetY - popperRect.height;
      y *= gpuAcceleration ? 1 : -1;
    }

    if (placement === left || (placement === top || placement === bottom) && variation === end) {
      sideX = right;
      var offsetX = isFixed && offsetParent === win && win.visualViewport ? win.visualViewport.width : // $FlowFixMe[prop-missing]
      offsetParent[widthProp];
      x -= offsetX - popperRect.width;
      x *= gpuAcceleration ? 1 : -1;
    }
  }

  var commonStyles = Object.assign({
    position: position
  }, adaptive && unsetSides);

  var _ref4 = roundOffsets === true ? roundOffsetsByDPR({
    x: x,
    y: y
  }) : {
    x: x,
    y: y
  };

  x = _ref4.x;
  y = _ref4.y;

  if (gpuAcceleration) {
    var _Object$assign;

    return Object.assign({}, commonStyles, (_Object$assign = {}, _Object$assign[sideY] = hasY ? '0' : '', _Object$assign[sideX] = hasX ? '0' : '', _Object$assign.transform = (win.devicePixelRatio || 1) <= 1 ? "translate(" + x + "px, " + y + "px)" : "translate3d(" + x + "px, " + y + "px, 0)", _Object$assign));
  }

  return Object.assign({}, commonStyles, (_Object$assign2 = {}, _Object$assign2[sideY] = hasY ? y + "px" : '', _Object$assign2[sideX] = hasX ? x + "px" : '', _Object$assign2.transform = '', _Object$assign2));
}

function computeStyles(_ref5) {
  var state = _ref5.state,
      options = _ref5.options;
  var _options$gpuAccelerat = options.gpuAcceleration,
      gpuAcceleration = _options$gpuAccelerat === void 0 ? true : _options$gpuAccelerat,
      _options$adaptive = options.adaptive,
      adaptive = _options$adaptive === void 0 ? true : _options$adaptive,
      _options$roundOffsets = options.roundOffsets,
      roundOffsets = _options$roundOffsets === void 0 ? true : _options$roundOffsets;

  if (process.env.NODE_ENV !== "production") {
    var transitionProperty = getComputedStyle$1(state.elements.popper).transitionProperty || '';

    if (adaptive && ['transform', 'top', 'right', 'bottom', 'left'].some(function (property) {
      return transitionProperty.indexOf(property) >= 0;
    })) {
      console.warn(['Popper: Detected CSS transitions on at least one of the following', 'CSS properties: "transform", "top", "right", "bottom", "left".', '\n\n', 'Disable the "computeStyles" modifier\'s `adaptive` option to allow', 'for smooth transitions, or remove these properties from the CSS', 'transition declaration on the popper element if only transitioning', 'opacity or background-color for example.', '\n\n', 'We recommend using the popper element as a wrapper around an inner', 'element that can have any CSS property transitioned for animations.'].join(' '));
    }
  }

  var commonStyles = {
    placement: getBasePlacement(state.placement),
    variation: getVariation(state.placement),
    popper: state.elements.popper,
    popperRect: state.rects.popper,
    gpuAcceleration: gpuAcceleration,
    isFixed: state.options.strategy === 'fixed'
  };

  if (state.modifiersData.popperOffsets != null) {
    state.styles.popper = Object.assign({}, state.styles.popper, mapToStyles(Object.assign({}, commonStyles, {
      offsets: state.modifiersData.popperOffsets,
      position: state.options.strategy,
      adaptive: adaptive,
      roundOffsets: roundOffsets
    })));
  }

  if (state.modifiersData.arrow != null) {
    state.styles.arrow = Object.assign({}, state.styles.arrow, mapToStyles(Object.assign({}, commonStyles, {
      offsets: state.modifiersData.arrow,
      position: 'absolute',
      adaptive: false,
      roundOffsets: roundOffsets
    })));
  }

  state.attributes.popper = Object.assign({}, state.attributes.popper, {
    'data-popper-placement': state.placement
  });
} // eslint-disable-next-line import/no-unused-modules


var computeStyles$1 = {
  name: 'computeStyles',
  enabled: true,
  phase: 'beforeWrite',
  fn: computeStyles,
  data: {}
};

var passive = {
  passive: true
};

function effect(_ref) {
  var state = _ref.state,
      instance = _ref.instance,
      options = _ref.options;
  var _options$scroll = options.scroll,
      scroll = _options$scroll === void 0 ? true : _options$scroll,
      _options$resize = options.resize,
      resize = _options$resize === void 0 ? true : _options$resize;
  var window = getWindow(state.elements.popper);
  var scrollParents = [].concat(state.scrollParents.reference, state.scrollParents.popper);

  if (scroll) {
    scrollParents.forEach(function (scrollParent) {
      scrollParent.addEventListener('scroll', instance.update, passive);
    });
  }

  if (resize) {
    window.addEventListener('resize', instance.update, passive);
  }

  return function () {
    if (scroll) {
      scrollParents.forEach(function (scrollParent) {
        scrollParent.removeEventListener('scroll', instance.update, passive);
      });
    }

    if (resize) {
      window.removeEventListener('resize', instance.update, passive);
    }
  };
} // eslint-disable-next-line import/no-unused-modules


var eventListeners = {
  name: 'eventListeners',
  enabled: true,
  phase: 'write',
  fn: function fn() {},
  effect: effect,
  data: {}
};

var hash$1 = {
  left: 'right',
  right: 'left',
  bottom: 'top',
  top: 'bottom'
};
function getOppositePlacement(placement) {
  return placement.replace(/left|right|bottom|top/g, function (matched) {
    return hash$1[matched];
  });
}

var hash = {
  start: 'end',
  end: 'start'
};
function getOppositeVariationPlacement(placement) {
  return placement.replace(/start|end/g, function (matched) {
    return hash[matched];
  });
}

function getWindowScroll(node) {
  var win = getWindow(node);
  var scrollLeft = win.pageXOffset;
  var scrollTop = win.pageYOffset;
  return {
    scrollLeft: scrollLeft,
    scrollTop: scrollTop
  };
}

function getWindowScrollBarX(element) {
  // If <html> has a CSS width greater than the viewport, then this will be
  // incorrect for RTL.
  // Popper 1 is broken in this case and never had a bug report so let's assume
  // it's not an issue. I don't think anyone ever specifies width on <html>
  // anyway.
  // Browsers where the left scrollbar doesn't cause an issue report `0` for
  // this (e.g. Edge 2019, IE11, Safari)
  return getBoundingClientRect(getDocumentElement(element)).left + getWindowScroll(element).scrollLeft;
}

function getViewportRect(element) {
  var win = getWindow(element);
  var html = getDocumentElement(element);
  var visualViewport = win.visualViewport;
  var width = html.clientWidth;
  var height = html.clientHeight;
  var x = 0;
  var y = 0; // NB: This isn't supported on iOS <= 12. If the keyboard is open, the popper
  // can be obscured underneath it.
  // Also, `html.clientHeight` adds the bottom bar height in Safari iOS, even
  // if it isn't open, so if this isn't available, the popper will be detected
  // to overflow the bottom of the screen too early.

  if (visualViewport) {
    width = visualViewport.width;
    height = visualViewport.height; // Uses Layout Viewport (like Chrome; Safari does not currently)
    // In Chrome, it returns a value very close to 0 (+/-) but contains rounding
    // errors due to floating point numbers, so we need to check precision.
    // Safari returns a number <= 0, usually < -1 when pinch-zoomed
    // Feature detection fails in mobile emulation mode in Chrome.
    // Math.abs(win.innerWidth / visualViewport.scale - visualViewport.width) <
    // 0.001
    // Fallback here: "Not Safari" userAgent

    if (!/^((?!chrome|android).)*safari/i.test(navigator.userAgent)) {
      x = visualViewport.offsetLeft;
      y = visualViewport.offsetTop;
    }
  }

  return {
    width: width,
    height: height,
    x: x + getWindowScrollBarX(element),
    y: y
  };
}

// of the `<html>` and `<body>` rect bounds if horizontally scrollable

function getDocumentRect(element) {
  var _element$ownerDocumen;

  var html = getDocumentElement(element);
  var winScroll = getWindowScroll(element);
  var body = (_element$ownerDocumen = element.ownerDocument) == null ? void 0 : _element$ownerDocumen.body;
  var width = max(html.scrollWidth, html.clientWidth, body ? body.scrollWidth : 0, body ? body.clientWidth : 0);
  var height = max(html.scrollHeight, html.clientHeight, body ? body.scrollHeight : 0, body ? body.clientHeight : 0);
  var x = -winScroll.scrollLeft + getWindowScrollBarX(element);
  var y = -winScroll.scrollTop;

  if (getComputedStyle$1(body || html).direction === 'rtl') {
    x += max(html.clientWidth, body ? body.clientWidth : 0) - width;
  }

  return {
    width: width,
    height: height,
    x: x,
    y: y
  };
}

function isScrollParent(element) {
  // Firefox wants us to check `-x` and `-y` variations as well
  var _getComputedStyle = getComputedStyle$1(element),
      overflow = _getComputedStyle.overflow,
      overflowX = _getComputedStyle.overflowX,
      overflowY = _getComputedStyle.overflowY;

  return /auto|scroll|overlay|hidden/.test(overflow + overflowY + overflowX);
}

function getScrollParent(node) {
  if (['html', 'body', '#document'].indexOf(getNodeName(node)) >= 0) {
    // $FlowFixMe[incompatible-return]: assume body is always available
    return node.ownerDocument.body;
  }

  if (isHTMLElement(node) && isScrollParent(node)) {
    return node;
  }

  return getScrollParent(getParentNode(node));
}

/*
given a DOM element, return the list of all scroll parents, up the list of ancesors
until we get to the top window object. This list is what we attach scroll listeners
to, because if any of these parent elements scroll, we'll need to re-calculate the
reference element's position.
*/

function listScrollParents(element, list) {
  var _element$ownerDocumen;

  if (list === void 0) {
    list = [];
  }

  var scrollParent = getScrollParent(element);
  var isBody = scrollParent === ((_element$ownerDocumen = element.ownerDocument) == null ? void 0 : _element$ownerDocumen.body);
  var win = getWindow(scrollParent);
  var target = isBody ? [win].concat(win.visualViewport || [], isScrollParent(scrollParent) ? scrollParent : []) : scrollParent;
  var updatedList = list.concat(target);
  return isBody ? updatedList : // $FlowFixMe[incompatible-call]: isBody tells us target will be an HTMLElement here
  updatedList.concat(listScrollParents(getParentNode(target)));
}

function rectToClientRect(rect) {
  return Object.assign({}, rect, {
    left: rect.x,
    top: rect.y,
    right: rect.x + rect.width,
    bottom: rect.y + rect.height
  });
}

function getInnerBoundingClientRect(element) {
  var rect = getBoundingClientRect(element);
  rect.top = rect.top + element.clientTop;
  rect.left = rect.left + element.clientLeft;
  rect.bottom = rect.top + element.clientHeight;
  rect.right = rect.left + element.clientWidth;
  rect.width = element.clientWidth;
  rect.height = element.clientHeight;
  rect.x = rect.left;
  rect.y = rect.top;
  return rect;
}

function getClientRectFromMixedType(element, clippingParent) {
  return clippingParent === viewport ? rectToClientRect(getViewportRect(element)) : isElement(clippingParent) ? getInnerBoundingClientRect(clippingParent) : rectToClientRect(getDocumentRect(getDocumentElement(element)));
} // A "clipping parent" is an overflowable container with the characteristic of
// clipping (or hiding) overflowing elements with a position different from
// `initial`


function getClippingParents(element) {
  var clippingParents = listScrollParents(getParentNode(element));
  var canEscapeClipping = ['absolute', 'fixed'].indexOf(getComputedStyle$1(element).position) >= 0;
  var clipperElement = canEscapeClipping && isHTMLElement(element) ? getOffsetParent(element) : element;

  if (!isElement(clipperElement)) {
    return [];
  } // $FlowFixMe[incompatible-return]: https://github.com/facebook/flow/issues/1414


  return clippingParents.filter(function (clippingParent) {
    return isElement(clippingParent) && contains$1(clippingParent, clipperElement) && getNodeName(clippingParent) !== 'body';
  });
} // Gets the maximum area that the element is visible in due to any number of
// clipping parents


function getClippingRect(element, boundary, rootBoundary) {
  var mainClippingParents = boundary === 'clippingParents' ? getClippingParents(element) : [].concat(boundary);
  var clippingParents = [].concat(mainClippingParents, [rootBoundary]);
  var firstClippingParent = clippingParents[0];
  var clippingRect = clippingParents.reduce(function (accRect, clippingParent) {
    var rect = getClientRectFromMixedType(element, clippingParent);
    accRect.top = max(rect.top, accRect.top);
    accRect.right = min(rect.right, accRect.right);
    accRect.bottom = min(rect.bottom, accRect.bottom);
    accRect.left = max(rect.left, accRect.left);
    return accRect;
  }, getClientRectFromMixedType(element, firstClippingParent));
  clippingRect.width = clippingRect.right - clippingRect.left;
  clippingRect.height = clippingRect.bottom - clippingRect.top;
  clippingRect.x = clippingRect.left;
  clippingRect.y = clippingRect.top;
  return clippingRect;
}

function computeOffsets(_ref) {
  var reference = _ref.reference,
      element = _ref.element,
      placement = _ref.placement;
  var basePlacement = placement ? getBasePlacement(placement) : null;
  var variation = placement ? getVariation(placement) : null;
  var commonX = reference.x + reference.width / 2 - element.width / 2;
  var commonY = reference.y + reference.height / 2 - element.height / 2;
  var offsets;

  switch (basePlacement) {
    case top:
      offsets = {
        x: commonX,
        y: reference.y - element.height
      };
      break;

    case bottom:
      offsets = {
        x: commonX,
        y: reference.y + reference.height
      };
      break;

    case right:
      offsets = {
        x: reference.x + reference.width,
        y: commonY
      };
      break;

    case left:
      offsets = {
        x: reference.x - element.width,
        y: commonY
      };
      break;

    default:
      offsets = {
        x: reference.x,
        y: reference.y
      };
  }

  var mainAxis = basePlacement ? getMainAxisFromPlacement(basePlacement) : null;

  if (mainAxis != null) {
    var len = mainAxis === 'y' ? 'height' : 'width';

    switch (variation) {
      case start:
        offsets[mainAxis] = offsets[mainAxis] - (reference[len] / 2 - element[len] / 2);
        break;

      case end:
        offsets[mainAxis] = offsets[mainAxis] + (reference[len] / 2 - element[len] / 2);
        break;
    }
  }

  return offsets;
}

function detectOverflow(state, options) {
  if (options === void 0) {
    options = {};
  }

  var _options = options,
      _options$placement = _options.placement,
      placement = _options$placement === void 0 ? state.placement : _options$placement,
      _options$boundary = _options.boundary,
      boundary = _options$boundary === void 0 ? clippingParents : _options$boundary,
      _options$rootBoundary = _options.rootBoundary,
      rootBoundary = _options$rootBoundary === void 0 ? viewport : _options$rootBoundary,
      _options$elementConte = _options.elementContext,
      elementContext = _options$elementConte === void 0 ? popper : _options$elementConte,
      _options$altBoundary = _options.altBoundary,
      altBoundary = _options$altBoundary === void 0 ? false : _options$altBoundary,
      _options$padding = _options.padding,
      padding = _options$padding === void 0 ? 0 : _options$padding;
  var paddingObject = mergePaddingObject(typeof padding !== 'number' ? padding : expandToHashMap(padding, basePlacements));
  var altContext = elementContext === popper ? reference : popper;
  var popperRect = state.rects.popper;
  var element = state.elements[altBoundary ? altContext : elementContext];
  var clippingClientRect = getClippingRect(isElement(element) ? element : element.contextElement || getDocumentElement(state.elements.popper), boundary, rootBoundary);
  var referenceClientRect = getBoundingClientRect(state.elements.reference);
  var popperOffsets = computeOffsets({
    reference: referenceClientRect,
    element: popperRect,
    strategy: 'absolute',
    placement: placement
  });
  var popperClientRect = rectToClientRect(Object.assign({}, popperRect, popperOffsets));
  var elementClientRect = elementContext === popper ? popperClientRect : referenceClientRect; // positive = overflowing the clipping rect
  // 0 or negative = within the clipping rect

  var overflowOffsets = {
    top: clippingClientRect.top - elementClientRect.top + paddingObject.top,
    bottom: elementClientRect.bottom - clippingClientRect.bottom + paddingObject.bottom,
    left: clippingClientRect.left - elementClientRect.left + paddingObject.left,
    right: elementClientRect.right - clippingClientRect.right + paddingObject.right
  };
  var offsetData = state.modifiersData.offset; // Offsets can be applied only to the popper element

  if (elementContext === popper && offsetData) {
    var offset = offsetData[placement];
    Object.keys(overflowOffsets).forEach(function (key) {
      var multiply = [right, bottom].indexOf(key) >= 0 ? 1 : -1;
      var axis = [top, bottom].indexOf(key) >= 0 ? 'y' : 'x';
      overflowOffsets[key] += offset[axis] * multiply;
    });
  }

  return overflowOffsets;
}

function computeAutoPlacement(state, options) {
  if (options === void 0) {
    options = {};
  }

  var _options = options,
      placement = _options.placement,
      boundary = _options.boundary,
      rootBoundary = _options.rootBoundary,
      padding = _options.padding,
      flipVariations = _options.flipVariations,
      _options$allowedAutoP = _options.allowedAutoPlacements,
      allowedAutoPlacements = _options$allowedAutoP === void 0 ? placements : _options$allowedAutoP;
  var variation = getVariation(placement);
  var placements$1 = variation ? flipVariations ? variationPlacements : variationPlacements.filter(function (placement) {
    return getVariation(placement) === variation;
  }) : basePlacements;
  var allowedPlacements = placements$1.filter(function (placement) {
    return allowedAutoPlacements.indexOf(placement) >= 0;
  });

  if (allowedPlacements.length === 0) {
    allowedPlacements = placements$1;

    if (process.env.NODE_ENV !== "production") {
      console.error(['Popper: The `allowedAutoPlacements` option did not allow any', 'placements. Ensure the `placement` option matches the variation', 'of the allowed placements.', 'For example, "auto" cannot be used to allow "bottom-start".', 'Use "auto-start" instead.'].join(' '));
    }
  } // $FlowFixMe[incompatible-type]: Flow seems to have problems with two array unions...


  var overflows = allowedPlacements.reduce(function (acc, placement) {
    acc[placement] = detectOverflow(state, {
      placement: placement,
      boundary: boundary,
      rootBoundary: rootBoundary,
      padding: padding
    })[getBasePlacement(placement)];
    return acc;
  }, {});
  return Object.keys(overflows).sort(function (a, b) {
    return overflows[a] - overflows[b];
  });
}

function getExpandedFallbackPlacements(placement) {
  if (getBasePlacement(placement) === auto) {
    return [];
  }

  var oppositePlacement = getOppositePlacement(placement);
  return [getOppositeVariationPlacement(placement), oppositePlacement, getOppositeVariationPlacement(oppositePlacement)];
}

function flip(_ref) {
  var state = _ref.state,
      options = _ref.options,
      name = _ref.name;

  if (state.modifiersData[name]._skip) {
    return;
  }

  var _options$mainAxis = options.mainAxis,
      checkMainAxis = _options$mainAxis === void 0 ? true : _options$mainAxis,
      _options$altAxis = options.altAxis,
      checkAltAxis = _options$altAxis === void 0 ? true : _options$altAxis,
      specifiedFallbackPlacements = options.fallbackPlacements,
      padding = options.padding,
      boundary = options.boundary,
      rootBoundary = options.rootBoundary,
      altBoundary = options.altBoundary,
      _options$flipVariatio = options.flipVariations,
      flipVariations = _options$flipVariatio === void 0 ? true : _options$flipVariatio,
      allowedAutoPlacements = options.allowedAutoPlacements;
  var preferredPlacement = state.options.placement;
  var basePlacement = getBasePlacement(preferredPlacement);
  var isBasePlacement = basePlacement === preferredPlacement;
  var fallbackPlacements = specifiedFallbackPlacements || (isBasePlacement || !flipVariations ? [getOppositePlacement(preferredPlacement)] : getExpandedFallbackPlacements(preferredPlacement));
  var placements = [preferredPlacement].concat(fallbackPlacements).reduce(function (acc, placement) {
    return acc.concat(getBasePlacement(placement) === auto ? computeAutoPlacement(state, {
      placement: placement,
      boundary: boundary,
      rootBoundary: rootBoundary,
      padding: padding,
      flipVariations: flipVariations,
      allowedAutoPlacements: allowedAutoPlacements
    }) : placement);
  }, []);
  var referenceRect = state.rects.reference;
  var popperRect = state.rects.popper;
  var checksMap = new Map();
  var makeFallbackChecks = true;
  var firstFittingPlacement = placements[0];

  for (var i = 0; i < placements.length; i++) {
    var placement = placements[i];

    var _basePlacement = getBasePlacement(placement);

    var isStartVariation = getVariation(placement) === start;
    var isVertical = [top, bottom].indexOf(_basePlacement) >= 0;
    var len = isVertical ? 'width' : 'height';
    var overflow = detectOverflow(state, {
      placement: placement,
      boundary: boundary,
      rootBoundary: rootBoundary,
      altBoundary: altBoundary,
      padding: padding
    });
    var mainVariationSide = isVertical ? isStartVariation ? right : left : isStartVariation ? bottom : top;

    if (referenceRect[len] > popperRect[len]) {
      mainVariationSide = getOppositePlacement(mainVariationSide);
    }

    var altVariationSide = getOppositePlacement(mainVariationSide);
    var checks = [];

    if (checkMainAxis) {
      checks.push(overflow[_basePlacement] <= 0);
    }

    if (checkAltAxis) {
      checks.push(overflow[mainVariationSide] <= 0, overflow[altVariationSide] <= 0);
    }

    if (checks.every(function (check) {
      return check;
    })) {
      firstFittingPlacement = placement;
      makeFallbackChecks = false;
      break;
    }

    checksMap.set(placement, checks);
  }

  if (makeFallbackChecks) {
    // `2` may be desired in some cases – research later
    var numberOfChecks = flipVariations ? 3 : 1;

    var _loop = function _loop(_i) {
      var fittingPlacement = placements.find(function (placement) {
        var checks = checksMap.get(placement);

        if (checks) {
          return checks.slice(0, _i).every(function (check) {
            return check;
          });
        }
      });

      if (fittingPlacement) {
        firstFittingPlacement = fittingPlacement;
        return "break";
      }
    };

    for (var _i = numberOfChecks; _i > 0; _i--) {
      var _ret = _loop(_i);

      if (_ret === "break") break;
    }
  }

  if (state.placement !== firstFittingPlacement) {
    state.modifiersData[name]._skip = true;
    state.placement = firstFittingPlacement;
    state.reset = true;
  }
} // eslint-disable-next-line import/no-unused-modules


var flip$1 = {
  name: 'flip',
  enabled: true,
  phase: 'main',
  fn: flip,
  requiresIfExists: ['offset'],
  data: {
    _skip: false
  }
};

function getSideOffsets(overflow, rect, preventedOffsets) {
  if (preventedOffsets === void 0) {
    preventedOffsets = {
      x: 0,
      y: 0
    };
  }

  return {
    top: overflow.top - rect.height - preventedOffsets.y,
    right: overflow.right - rect.width + preventedOffsets.x,
    bottom: overflow.bottom - rect.height + preventedOffsets.y,
    left: overflow.left - rect.width - preventedOffsets.x
  };
}

function isAnySideFullyClipped(overflow) {
  return [top, right, bottom, left].some(function (side) {
    return overflow[side] >= 0;
  });
}

function hide(_ref) {
  var state = _ref.state,
      name = _ref.name;
  var referenceRect = state.rects.reference;
  var popperRect = state.rects.popper;
  var preventedOffsets = state.modifiersData.preventOverflow;
  var referenceOverflow = detectOverflow(state, {
    elementContext: 'reference'
  });
  var popperAltOverflow = detectOverflow(state, {
    altBoundary: true
  });
  var referenceClippingOffsets = getSideOffsets(referenceOverflow, referenceRect);
  var popperEscapeOffsets = getSideOffsets(popperAltOverflow, popperRect, preventedOffsets);
  var isReferenceHidden = isAnySideFullyClipped(referenceClippingOffsets);
  var hasPopperEscaped = isAnySideFullyClipped(popperEscapeOffsets);
  state.modifiersData[name] = {
    referenceClippingOffsets: referenceClippingOffsets,
    popperEscapeOffsets: popperEscapeOffsets,
    isReferenceHidden: isReferenceHidden,
    hasPopperEscaped: hasPopperEscaped
  };
  state.attributes.popper = Object.assign({}, state.attributes.popper, {
    'data-popper-reference-hidden': isReferenceHidden,
    'data-popper-escaped': hasPopperEscaped
  });
} // eslint-disable-next-line import/no-unused-modules


var hide$1 = {
  name: 'hide',
  enabled: true,
  phase: 'main',
  requiresIfExists: ['preventOverflow'],
  fn: hide
};

function distanceAndSkiddingToXY(placement, rects, offset) {
  var basePlacement = getBasePlacement(placement);
  var invertDistance = [left, top].indexOf(basePlacement) >= 0 ? -1 : 1;

  var _ref = typeof offset === 'function' ? offset(Object.assign({}, rects, {
    placement: placement
  })) : offset,
      skidding = _ref[0],
      distance = _ref[1];

  skidding = skidding || 0;
  distance = (distance || 0) * invertDistance;
  return [left, right].indexOf(basePlacement) >= 0 ? {
    x: distance,
    y: skidding
  } : {
    x: skidding,
    y: distance
  };
}

function offset(_ref2) {
  var state = _ref2.state,
      options = _ref2.options,
      name = _ref2.name;
  var _options$offset = options.offset,
      offset = _options$offset === void 0 ? [0, 0] : _options$offset;
  var data = placements.reduce(function (acc, placement) {
    acc[placement] = distanceAndSkiddingToXY(placement, state.rects, offset);
    return acc;
  }, {});
  var _data$state$placement = data[state.placement],
      x = _data$state$placement.x,
      y = _data$state$placement.y;

  if (state.modifiersData.popperOffsets != null) {
    state.modifiersData.popperOffsets.x += x;
    state.modifiersData.popperOffsets.y += y;
  }

  state.modifiersData[name] = data;
} // eslint-disable-next-line import/no-unused-modules


var offset$1 = {
  name: 'offset',
  enabled: true,
  phase: 'main',
  requires: ['popperOffsets'],
  fn: offset
};

function popperOffsets(_ref) {
  var state = _ref.state,
      name = _ref.name;
  // Offsets are the actual position the popper needs to have to be
  // properly positioned near its reference element
  // This is the most basic placement, and will be adjusted by
  // the modifiers in the next step
  state.modifiersData[name] = computeOffsets({
    reference: state.rects.reference,
    element: state.rects.popper,
    strategy: 'absolute',
    placement: state.placement
  });
} // eslint-disable-next-line import/no-unused-modules


var popperOffsets$1 = {
  name: 'popperOffsets',
  enabled: true,
  phase: 'read',
  fn: popperOffsets,
  data: {}
};

function getAltAxis(axis) {
  return axis === 'x' ? 'y' : 'x';
}

function preventOverflow(_ref) {
  var state = _ref.state,
      options = _ref.options,
      name = _ref.name;
  var _options$mainAxis = options.mainAxis,
      checkMainAxis = _options$mainAxis === void 0 ? true : _options$mainAxis,
      _options$altAxis = options.altAxis,
      checkAltAxis = _options$altAxis === void 0 ? false : _options$altAxis,
      boundary = options.boundary,
      rootBoundary = options.rootBoundary,
      altBoundary = options.altBoundary,
      padding = options.padding,
      _options$tether = options.tether,
      tether = _options$tether === void 0 ? true : _options$tether,
      _options$tetherOffset = options.tetherOffset,
      tetherOffset = _options$tetherOffset === void 0 ? 0 : _options$tetherOffset;
  var overflow = detectOverflow(state, {
    boundary: boundary,
    rootBoundary: rootBoundary,
    padding: padding,
    altBoundary: altBoundary
  });
  var basePlacement = getBasePlacement(state.placement);
  var variation = getVariation(state.placement);
  var isBasePlacement = !variation;
  var mainAxis = getMainAxisFromPlacement(basePlacement);
  var altAxis = getAltAxis(mainAxis);
  var popperOffsets = state.modifiersData.popperOffsets;
  var referenceRect = state.rects.reference;
  var popperRect = state.rects.popper;
  var tetherOffsetValue = typeof tetherOffset === 'function' ? tetherOffset(Object.assign({}, state.rects, {
    placement: state.placement
  })) : tetherOffset;
  var normalizedTetherOffsetValue = typeof tetherOffsetValue === 'number' ? {
    mainAxis: tetherOffsetValue,
    altAxis: tetherOffsetValue
  } : Object.assign({
    mainAxis: 0,
    altAxis: 0
  }, tetherOffsetValue);
  var offsetModifierState = state.modifiersData.offset ? state.modifiersData.offset[state.placement] : null;
  var data = {
    x: 0,
    y: 0
  };

  if (!popperOffsets) {
    return;
  }

  if (checkMainAxis) {
    var _offsetModifierState$;

    var mainSide = mainAxis === 'y' ? top : left;
    var altSide = mainAxis === 'y' ? bottom : right;
    var len = mainAxis === 'y' ? 'height' : 'width';
    var offset = popperOffsets[mainAxis];
    var min$1 = offset + overflow[mainSide];
    var max$1 = offset - overflow[altSide];
    var additive = tether ? -popperRect[len] / 2 : 0;
    var minLen = variation === start ? referenceRect[len] : popperRect[len];
    var maxLen = variation === start ? -popperRect[len] : -referenceRect[len]; // We need to include the arrow in the calculation so the arrow doesn't go
    // outside the reference bounds

    var arrowElement = state.elements.arrow;
    var arrowRect = tether && arrowElement ? getLayoutRect(arrowElement) : {
      width: 0,
      height: 0
    };
    var arrowPaddingObject = state.modifiersData['arrow#persistent'] ? state.modifiersData['arrow#persistent'].padding : getFreshSideObject();
    var arrowPaddingMin = arrowPaddingObject[mainSide];
    var arrowPaddingMax = arrowPaddingObject[altSide]; // If the reference length is smaller than the arrow length, we don't want
    // to include its full size in the calculation. If the reference is small
    // and near the edge of a boundary, the popper can overflow even if the
    // reference is not overflowing as well (e.g. virtual elements with no
    // width or height)

    var arrowLen = within(0, referenceRect[len], arrowRect[len]);
    var minOffset = isBasePlacement ? referenceRect[len] / 2 - additive - arrowLen - arrowPaddingMin - normalizedTetherOffsetValue.mainAxis : minLen - arrowLen - arrowPaddingMin - normalizedTetherOffsetValue.mainAxis;
    var maxOffset = isBasePlacement ? -referenceRect[len] / 2 + additive + arrowLen + arrowPaddingMax + normalizedTetherOffsetValue.mainAxis : maxLen + arrowLen + arrowPaddingMax + normalizedTetherOffsetValue.mainAxis;
    var arrowOffsetParent = state.elements.arrow && getOffsetParent(state.elements.arrow);
    var clientOffset = arrowOffsetParent ? mainAxis === 'y' ? arrowOffsetParent.clientTop || 0 : arrowOffsetParent.clientLeft || 0 : 0;
    var offsetModifierValue = (_offsetModifierState$ = offsetModifierState == null ? void 0 : offsetModifierState[mainAxis]) != null ? _offsetModifierState$ : 0;
    var tetherMin = offset + minOffset - offsetModifierValue - clientOffset;
    var tetherMax = offset + maxOffset - offsetModifierValue;
    var preventedOffset = within(tether ? min(min$1, tetherMin) : min$1, offset, tether ? max(max$1, tetherMax) : max$1);
    popperOffsets[mainAxis] = preventedOffset;
    data[mainAxis] = preventedOffset - offset;
  }

  if (checkAltAxis) {
    var _offsetModifierState$2;

    var _mainSide = mainAxis === 'x' ? top : left;

    var _altSide = mainAxis === 'x' ? bottom : right;

    var _offset = popperOffsets[altAxis];

    var _len = altAxis === 'y' ? 'height' : 'width';

    var _min = _offset + overflow[_mainSide];

    var _max = _offset - overflow[_altSide];

    var isOriginSide = [top, left].indexOf(basePlacement) !== -1;

    var _offsetModifierValue = (_offsetModifierState$2 = offsetModifierState == null ? void 0 : offsetModifierState[altAxis]) != null ? _offsetModifierState$2 : 0;

    var _tetherMin = isOriginSide ? _min : _offset - referenceRect[_len] - popperRect[_len] - _offsetModifierValue + normalizedTetherOffsetValue.altAxis;

    var _tetherMax = isOriginSide ? _offset + referenceRect[_len] + popperRect[_len] - _offsetModifierValue - normalizedTetherOffsetValue.altAxis : _max;

    var _preventedOffset = tether && isOriginSide ? withinMaxClamp(_tetherMin, _offset, _tetherMax) : within(tether ? _tetherMin : _min, _offset, tether ? _tetherMax : _max);

    popperOffsets[altAxis] = _preventedOffset;
    data[altAxis] = _preventedOffset - _offset;
  }

  state.modifiersData[name] = data;
} // eslint-disable-next-line import/no-unused-modules


var preventOverflow$1 = {
  name: 'preventOverflow',
  enabled: true,
  phase: 'main',
  fn: preventOverflow,
  requiresIfExists: ['offset']
};

function getHTMLElementScroll(element) {
  return {
    scrollLeft: element.scrollLeft,
    scrollTop: element.scrollTop
  };
}

function getNodeScroll(node) {
  if (node === getWindow(node) || !isHTMLElement(node)) {
    return getWindowScroll(node);
  } else {
    return getHTMLElementScroll(node);
  }
}

function isElementScaled(element) {
  var rect = element.getBoundingClientRect();
  var scaleX = round(rect.width) / element.offsetWidth || 1;
  var scaleY = round(rect.height) / element.offsetHeight || 1;
  return scaleX !== 1 || scaleY !== 1;
} // Returns the composite rect of an element relative to its offsetParent.
// Composite means it takes into account transforms as well as layout.


function getCompositeRect(elementOrVirtualElement, offsetParent, isFixed) {
  if (isFixed === void 0) {
    isFixed = false;
  }

  var isOffsetParentAnElement = isHTMLElement(offsetParent);
  var offsetParentIsScaled = isHTMLElement(offsetParent) && isElementScaled(offsetParent);
  var documentElement = getDocumentElement(offsetParent);
  var rect = getBoundingClientRect(elementOrVirtualElement, offsetParentIsScaled);
  var scroll = {
    scrollLeft: 0,
    scrollTop: 0
  };
  var offsets = {
    x: 0,
    y: 0
  };

  if (isOffsetParentAnElement || !isOffsetParentAnElement && !isFixed) {
    if (getNodeName(offsetParent) !== 'body' || // https://github.com/popperjs/popper-core/issues/1078
    isScrollParent(documentElement)) {
      scroll = getNodeScroll(offsetParent);
    }

    if (isHTMLElement(offsetParent)) {
      offsets = getBoundingClientRect(offsetParent, true);
      offsets.x += offsetParent.clientLeft;
      offsets.y += offsetParent.clientTop;
    } else if (documentElement) {
      offsets.x = getWindowScrollBarX(documentElement);
    }
  }

  return {
    x: rect.left + scroll.scrollLeft - offsets.x,
    y: rect.top + scroll.scrollTop - offsets.y,
    width: rect.width,
    height: rect.height
  };
}

function order(modifiers) {
  var map = new Map();
  var visited = new Set();
  var result = [];
  modifiers.forEach(function (modifier) {
    map.set(modifier.name, modifier);
  }); // On visiting object, check for its dependencies and visit them recursively

  function sort(modifier) {
    visited.add(modifier.name);
    var requires = [].concat(modifier.requires || [], modifier.requiresIfExists || []);
    requires.forEach(function (dep) {
      if (!visited.has(dep)) {
        var depModifier = map.get(dep);

        if (depModifier) {
          sort(depModifier);
        }
      }
    });
    result.push(modifier);
  }

  modifiers.forEach(function (modifier) {
    if (!visited.has(modifier.name)) {
      // check for visited object
      sort(modifier);
    }
  });
  return result;
}

function orderModifiers(modifiers) {
  // order based on dependencies
  var orderedModifiers = order(modifiers); // order based on phase

  return modifierPhases.reduce(function (acc, phase) {
    return acc.concat(orderedModifiers.filter(function (modifier) {
      return modifier.phase === phase;
    }));
  }, []);
}

function debounce(fn) {
  var pending;
  return function () {
    if (!pending) {
      pending = new Promise(function (resolve) {
        Promise.resolve().then(function () {
          pending = undefined;
          resolve(fn());
        });
      });
    }

    return pending;
  };
}

function format(str) {
  for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    args[_key - 1] = arguments[_key];
  }

  return [].concat(args).reduce(function (p, c) {
    return p.replace(/%s/, c);
  }, str);
}

var INVALID_MODIFIER_ERROR = 'Popper: modifier "%s" provided an invalid %s property, expected %s but got %s';
var MISSING_DEPENDENCY_ERROR = 'Popper: modifier "%s" requires "%s", but "%s" modifier is not available';
var VALID_PROPERTIES = ['name', 'enabled', 'phase', 'fn', 'effect', 'requires', 'options'];
function validateModifiers(modifiers) {
  modifiers.forEach(function (modifier) {
    [].concat(Object.keys(modifier), VALID_PROPERTIES) // IE11-compatible replacement for `new Set(iterable)`
    .filter(function (value, index, self) {
      return self.indexOf(value) === index;
    }).forEach(function (key) {
      switch (key) {
        case 'name':
          if (typeof modifier.name !== 'string') {
            console.error(format(INVALID_MODIFIER_ERROR, String(modifier.name), '"name"', '"string"', "\"" + String(modifier.name) + "\""));
          }

          break;

        case 'enabled':
          if (typeof modifier.enabled !== 'boolean') {
            console.error(format(INVALID_MODIFIER_ERROR, modifier.name, '"enabled"', '"boolean"', "\"" + String(modifier.enabled) + "\""));
          }

          break;

        case 'phase':
          if (modifierPhases.indexOf(modifier.phase) < 0) {
            console.error(format(INVALID_MODIFIER_ERROR, modifier.name, '"phase"', "either " + modifierPhases.join(', '), "\"" + String(modifier.phase) + "\""));
          }

          break;

        case 'fn':
          if (typeof modifier.fn !== 'function') {
            console.error(format(INVALID_MODIFIER_ERROR, modifier.name, '"fn"', '"function"', "\"" + String(modifier.fn) + "\""));
          }

          break;

        case 'effect':
          if (modifier.effect != null && typeof modifier.effect !== 'function') {
            console.error(format(INVALID_MODIFIER_ERROR, modifier.name, '"effect"', '"function"', "\"" + String(modifier.fn) + "\""));
          }

          break;

        case 'requires':
          if (modifier.requires != null && !Array.isArray(modifier.requires)) {
            console.error(format(INVALID_MODIFIER_ERROR, modifier.name, '"requires"', '"array"', "\"" + String(modifier.requires) + "\""));
          }

          break;

        case 'requiresIfExists':
          if (!Array.isArray(modifier.requiresIfExists)) {
            console.error(format(INVALID_MODIFIER_ERROR, modifier.name, '"requiresIfExists"', '"array"', "\"" + String(modifier.requiresIfExists) + "\""));
          }

          break;

        case 'options':
        case 'data':
          break;

        default:
          console.error("PopperJS: an invalid property has been provided to the \"" + modifier.name + "\" modifier, valid properties are " + VALID_PROPERTIES.map(function (s) {
            return "\"" + s + "\"";
          }).join(', ') + "; but \"" + key + "\" was provided.");
      }

      modifier.requires && modifier.requires.forEach(function (requirement) {
        if (modifiers.find(function (mod) {
          return mod.name === requirement;
        }) == null) {
          console.error(format(MISSING_DEPENDENCY_ERROR, String(modifier.name), requirement, requirement));
        }
      });
    });
  });
}

function uniqueBy(arr, fn) {
  var identifiers = new Set();
  return arr.filter(function (item) {
    var identifier = fn(item);

    if (!identifiers.has(identifier)) {
      identifiers.add(identifier);
      return true;
    }
  });
}

function mergeByName(modifiers) {
  var merged = modifiers.reduce(function (merged, current) {
    var existing = merged[current.name];
    merged[current.name] = existing ? Object.assign({}, existing, current, {
      options: Object.assign({}, existing.options, current.options),
      data: Object.assign({}, existing.data, current.data)
    }) : current;
    return merged;
  }, {}); // IE11 does not support Object.values

  return Object.keys(merged).map(function (key) {
    return merged[key];
  });
}

var INVALID_ELEMENT_ERROR = 'Popper: Invalid reference or popper argument provided. They must be either a DOM element or virtual element.';
var INFINITE_LOOP_ERROR = 'Popper: An infinite loop in the modifiers cycle has been detected! The cycle has been interrupted to prevent a browser crash.';
var DEFAULT_OPTIONS = {
  placement: 'bottom',
  modifiers: [],
  strategy: 'absolute'
};

function areValidElements() {
  for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }

  return !args.some(function (element) {
    return !(element && typeof element.getBoundingClientRect === 'function');
  });
}

function popperGenerator(generatorOptions) {
  if (generatorOptions === void 0) {
    generatorOptions = {};
  }

  var _generatorOptions = generatorOptions,
      _generatorOptions$def = _generatorOptions.defaultModifiers,
      defaultModifiers = _generatorOptions$def === void 0 ? [] : _generatorOptions$def,
      _generatorOptions$def2 = _generatorOptions.defaultOptions,
      defaultOptions = _generatorOptions$def2 === void 0 ? DEFAULT_OPTIONS : _generatorOptions$def2;
  return function createPopper(reference, popper, options) {
    if (options === void 0) {
      options = defaultOptions;
    }

    var state = {
      placement: 'bottom',
      orderedModifiers: [],
      options: Object.assign({}, DEFAULT_OPTIONS, defaultOptions),
      modifiersData: {},
      elements: {
        reference: reference,
        popper: popper
      },
      attributes: {},
      styles: {}
    };
    var effectCleanupFns = [];
    var isDestroyed = false;
    var instance = {
      state: state,
      setOptions: function setOptions(setOptionsAction) {
        var options = typeof setOptionsAction === 'function' ? setOptionsAction(state.options) : setOptionsAction;
        cleanupModifierEffects();
        state.options = Object.assign({}, defaultOptions, state.options, options);
        state.scrollParents = {
          reference: isElement(reference) ? listScrollParents(reference) : reference.contextElement ? listScrollParents(reference.contextElement) : [],
          popper: listScrollParents(popper)
        }; // Orders the modifiers based on their dependencies and `phase`
        // properties

        var orderedModifiers = orderModifiers(mergeByName([].concat(defaultModifiers, state.options.modifiers))); // Strip out disabled modifiers

        state.orderedModifiers = orderedModifiers.filter(function (m) {
          return m.enabled;
        }); // Validate the provided modifiers so that the consumer will get warned
        // if one of the modifiers is invalid for any reason

        if (process.env.NODE_ENV !== "production") {
          var modifiers = uniqueBy([].concat(orderedModifiers, state.options.modifiers), function (_ref) {
            var name = _ref.name;
            return name;
          });
          validateModifiers(modifiers);

          if (getBasePlacement(state.options.placement) === auto) {
            var flipModifier = state.orderedModifiers.find(function (_ref2) {
              var name = _ref2.name;
              return name === 'flip';
            });

            if (!flipModifier) {
              console.error(['Popper: "auto" placements require the "flip" modifier be', 'present and enabled to work.'].join(' '));
            }
          }

          var _getComputedStyle = getComputedStyle$1(popper),
              marginTop = _getComputedStyle.marginTop,
              marginRight = _getComputedStyle.marginRight,
              marginBottom = _getComputedStyle.marginBottom,
              marginLeft = _getComputedStyle.marginLeft; // We no longer take into account `margins` on the popper, and it can
          // cause bugs with positioning, so we'll warn the consumer


          if ([marginTop, marginRight, marginBottom, marginLeft].some(function (margin) {
            return parseFloat(margin);
          })) {
            console.warn(['Popper: CSS "margin" styles cannot be used to apply padding', 'between the popper and its reference element or boundary.', 'To replicate margin, use the `offset` modifier, as well as', 'the `padding` option in the `preventOverflow` and `flip`', 'modifiers.'].join(' '));
          }
        }

        runModifierEffects();
        return instance.update();
      },
      // Sync update – it will always be executed, even if not necessary. This
      // is useful for low frequency updates where sync behavior simplifies the
      // logic.
      // For high frequency updates (e.g. `resize` and `scroll` events), always
      // prefer the async Popper#update method
      forceUpdate: function forceUpdate() {
        if (isDestroyed) {
          return;
        }

        var _state$elements = state.elements,
            reference = _state$elements.reference,
            popper = _state$elements.popper; // Don't proceed if `reference` or `popper` are not valid elements
        // anymore

        if (!areValidElements(reference, popper)) {
          if (process.env.NODE_ENV !== "production") {
            console.error(INVALID_ELEMENT_ERROR);
          }

          return;
        } // Store the reference and popper rects to be read by modifiers


        state.rects = {
          reference: getCompositeRect(reference, getOffsetParent(popper), state.options.strategy === 'fixed'),
          popper: getLayoutRect(popper)
        }; // Modifiers have the ability to reset the current update cycle. The
        // most common use case for this is the `flip` modifier changing the
        // placement, which then needs to re-run all the modifiers, because the
        // logic was previously ran for the previous placement and is therefore
        // stale/incorrect

        state.reset = false;
        state.placement = state.options.placement; // On each update cycle, the `modifiersData` property for each modifier
        // is filled with the initial data specified by the modifier. This means
        // it doesn't persist and is fresh on each update.
        // To ensure persistent data, use `${name}#persistent`

        state.orderedModifiers.forEach(function (modifier) {
          return state.modifiersData[modifier.name] = Object.assign({}, modifier.data);
        });
        var __debug_loops__ = 0;

        for (var index = 0; index < state.orderedModifiers.length; index++) {
          if (process.env.NODE_ENV !== "production") {
            __debug_loops__ += 1;

            if (__debug_loops__ > 100) {
              console.error(INFINITE_LOOP_ERROR);
              break;
            }
          }

          if (state.reset === true) {
            state.reset = false;
            index = -1;
            continue;
          }

          var _state$orderedModifie = state.orderedModifiers[index],
              fn = _state$orderedModifie.fn,
              _state$orderedModifie2 = _state$orderedModifie.options,
              _options = _state$orderedModifie2 === void 0 ? {} : _state$orderedModifie2,
              name = _state$orderedModifie.name;

          if (typeof fn === 'function') {
            state = fn({
              state: state,
              options: _options,
              name: name,
              instance: instance
            }) || state;
          }
        }
      },
      // Async and optimistically optimized update – it will not be executed if
      // not necessary (debounced to run at most once-per-tick)
      update: debounce(function () {
        return new Promise(function (resolve) {
          instance.forceUpdate();
          resolve(state);
        });
      }),
      destroy: function destroy() {
        cleanupModifierEffects();
        isDestroyed = true;
      }
    };

    if (!areValidElements(reference, popper)) {
      if (process.env.NODE_ENV !== "production") {
        console.error(INVALID_ELEMENT_ERROR);
      }

      return instance;
    }

    instance.setOptions(options).then(function (state) {
      if (!isDestroyed && options.onFirstUpdate) {
        options.onFirstUpdate(state);
      }
    }); // Modifiers have the ability to execute arbitrary code before the first
    // update cycle runs. They will be executed in the same order as the update
    // cycle. This is useful when a modifier adds some persistent data that
    // other modifiers need to use, but the modifier is run after the dependent
    // one.

    function runModifierEffects() {
      state.orderedModifiers.forEach(function (_ref3) {
        var name = _ref3.name,
            _ref3$options = _ref3.options,
            options = _ref3$options === void 0 ? {} : _ref3$options,
            effect = _ref3.effect;

        if (typeof effect === 'function') {
          var cleanupFn = effect({
            state: state,
            name: name,
            instance: instance,
            options: options
          });

          var noopFn = function noopFn() {};

          effectCleanupFns.push(cleanupFn || noopFn);
        }
      });
    }

    function cleanupModifierEffects() {
      effectCleanupFns.forEach(function (fn) {
        return fn();
      });
      effectCleanupFns = [];
    }

    return instance;
  };
}

var defaultModifiers = [eventListeners, popperOffsets$1, computeStyles$1, applyStyles$1, offset$1, flip$1, preventOverflow$1, arrow$1, hide$1];
var createPopper = /*#__PURE__*/popperGenerator({
  defaultModifiers: defaultModifiers
}); // eslint-disable-next-line import/no-unused-modules

/* src\ToolTips\Tip.svelte generated by Svelte v3.48.0 */

function create_fragment$D(ctx) {
	let div1;
	let div0;
	let t;
	let html_tag;

	return {
		c() {
			div1 = element("div");
			div0 = element("div");
			t = space();
			html_tag = new HtmlTagHydration(false);
			this.h();
		},
		l(nodes) {
			div1 = claim_element(nodes, "DIV", { class: true, role: true });
			var div1_nodes = children(div1);
			div0 = claim_element(div1_nodes, "DIV", { class: true, "data-popper-arrow": true });
			children(div0).forEach(detach);
			t = claim_space(div1_nodes);
			html_tag = claim_html_tag(div1_nodes, false);
			div1_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div0, "class", "arrow svelte-2b6uu7");
			attr(div0, "data-popper-arrow", "");
			html_tag.a = null;
			attr(div1, "class", "tooltip z-50 text-center svelte-2b6uu7");
			attr(div1, "role", "tooltip");
		},
		m(target, anchor) {
			insert_hydration(target, div1, anchor);
			append_hydration(div1, div0);
			append_hydration(div1, t);
			html_tag.m(/*text*/ ctx[1], div1);
			/*div1_binding*/ ctx[2](div1);
		},
		p(ctx, [dirty]) {
			if (dirty & /*text*/ 2) html_tag.p(/*text*/ ctx[1]);
		},
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(div1);
			/*div1_binding*/ ctx[2](null);
		}
	};
}

function instance$D($$self, $$props, $$invalidate) {
	let { tip } = $$props;
	let { text } = $$props;

	function div1_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			tip = $$value;
			$$invalidate(0, tip);
		});
	}

	$$self.$$set = $$props => {
		if ('tip' in $$props) $$invalidate(0, tip = $$props.tip);
		if ('text' in $$props) $$invalidate(1, text = $$props.text);
	};

	return [tip, text, div1_binding];
}

class Tip extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$D, create_fragment$D, safe_not_equal, { tip: 0, text: 1 });
	}
}

/* src\CopyClipBoard\ClipBoard.svelte generated by Svelte v3.48.0 */

function create_fragment$C(ctx) {
	let div2;
	let div0;
	let input;
	let t0;
	let button_1;
	let div1;
	let svg;
	let path0;
	let path1;
	let t1;
	let span;
	let t2;
	let mounted;
	let dispose;

	return {
		c() {
			div2 = element("div");
			div0 = element("div");
			input = element("input");
			t0 = space();
			button_1 = element("button");
			div1 = element("div");
			svg = svg_element("svg");
			path0 = svg_element("path");
			path1 = svg_element("path");
			t1 = space();
			span = element("span");
			t2 = text("Copy");
			this.h();
		},
		l(nodes) {
			div2 = claim_element(nodes, "DIV", { class: true });
			var div2_nodes = children(div2);
			div0 = claim_element(div2_nodes, "DIV", { class: true });
			var div0_nodes = children(div0);
			input = claim_element(div0_nodes, "INPUT", { type: true, class: true });
			div0_nodes.forEach(detach);
			t0 = claim_space(div2_nodes);
			button_1 = claim_element(div2_nodes, "BUTTON", { class: true });
			var button_1_nodes = children(button_1);
			div1 = claim_element(button_1_nodes, "DIV", { class: true });
			var div1_nodes = children(div1);

			svg = claim_svg_element(div1_nodes, "svg", {
				xmlns: true,
				class: true,
				viewBox: true,
				fill: true
			});

			var svg_nodes = children(svg);
			path0 = claim_svg_element(svg_nodes, "path", { d: true });
			children(path0).forEach(detach);
			path1 = claim_svg_element(svg_nodes, "path", { d: true });
			children(path1).forEach(detach);
			svg_nodes.forEach(detach);
			t1 = claim_space(div1_nodes);
			span = claim_element(div1_nodes, "SPAN", { class: true });
			var span_nodes = children(span);
			t2 = claim_text(span_nodes, "Copy");
			span_nodes.forEach(detach);
			div1_nodes.forEach(detach);
			button_1_nodes.forEach(detach);
			div2_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(input, "type", "text");
			input.disabled = true;
			input.value = /*value*/ ctx[0];
			attr(input, "class", "block w-full rounded-none rounded-l-md sm:text-sm border-gray-300");
			attr(div0, "class", "relative flex items-stretch flex-grow focus-within:z-10");
			attr(path0, "d", "M8 2a1 1 0 000 2h2a1 1 0 100-2H8z");
			attr(path1, "d", "M3 5a2 2 0 012-2 3 3 0 003 3h2a3 3 0 003-3 2 2 0 012 2v6h-4.586l1.293-1.293a1 1 0 00-1.414-1.414l-3 3a1 1 0 000 1.414l3 3a1 1 0 001.414-1.414L10.414 13H15v3a2 2 0 01-2 2H5a2 2 0 01-2-2V5zM15 11h2a1 1 0 110 2h-2v-2z");
			attr(svg, "xmlns", "http://www.w3.org/2000/svg");
			attr(svg, "class", "h-5 w-5 text-gray-400");
			attr(svg, "viewBox", "0 0 20 20");
			attr(svg, "fill", "currentColor");
			attr(span, "class", "text-gray-700");
			attr(div1, "class", "inline-flex items-center");
			attr(button_1, "class", "-ml-px relative inline-flex items-center space-x-2 px-4 py-2 border border-gray-300 text-sm font-medium rounded-r-md text-gray-700 bg-gray-50 hover:bg-gray-100 focus:outline-none focus:ring-1 focus:ring-blue-300 focus:border-blue-300");
			attr(div2, "class", "flex rounded-md shadow-sm");
		},
		m(target, anchor) {
			insert_hydration(target, div2, anchor);
			append_hydration(div2, div0);
			append_hydration(div0, input);
			append_hydration(div2, t0);
			append_hydration(div2, button_1);
			append_hydration(button_1, div1);
			append_hydration(div1, svg);
			append_hydration(svg, path0);
			append_hydration(svg, path1);
			append_hydration(div1, t1);
			append_hydration(div1, span);
			append_hydration(span, t2);
			/*button_1_binding*/ ctx[4](button_1);

			if (!mounted) {
				dispose = listen(button_1, "click", /*click_handler*/ ctx[3]);
				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (dirty & /*value*/ 1 && input.value !== /*value*/ ctx[0]) {
				input.value = /*value*/ ctx[0];
			}
		},
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(div2);
			/*button_1_binding*/ ctx[4](null);
			mounted = false;
			dispose();
		}
	};
}

function instance$C($$self, $$props, $$invalidate) {
	let { value } = $$props;
	let button;
	let tip;

	const onCopy = async () => {
		let popper;
		console.log(clipboardCopy_1);
		await clipboardCopy_1(value);

		let tipper = new Tip({
				target: document.body,
				props: { text: "Copied" }
			});

		// this will be the tip from the component instance;
		tip = tipper.$$.ctx[0];

		popper = createPopper(button, tip, {
			placement: "bottom",
			strategy: "fixed",
			modifiers: [
				{
					name: "offset",
					options: { offset: [0, 8] }
				}
			]
		});

		setTimeout(
			() => {
				popper.destroy();
				tipper.$destroy();
			},
			700
		);
	};

	const click_handler = () => onCopy();

	function button_1_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			button = $$value;
			$$invalidate(1, button);
		});
	}

	$$self.$$set = $$props => {
		if ('value' in $$props) $$invalidate(0, value = $$props.value);
	};

	return [value, button, onCopy, click_handler, button_1_binding];
}

class ClipBoard extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$C, create_fragment$C, safe_not_equal, { value: 0 });
	}
}

/* src\Pagination\Pagination.svelte generated by Svelte v3.48.0 */

function get_each_context$8(ctx, list, i) {
	const child_ctx = ctx.slice();
	child_ctx[10] = list[i];
	return child_ctx;
}

// (57:4) {#if current > 1}
function create_if_block_1$b(ctx) {
	let div;
	let svg;
	let path;
	let t;
	let mounted;
	let dispose;

	return {
		c() {
			div = element("div");
			svg = svg_element("svg");
			path = svg_element("path");
			t = text("\r\n        Previous");
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);

			svg = claim_svg_element(div_nodes, "svg", {
				class: true,
				xmlns: true,
				viewBox: true,
				fill: true,
				"aria-hidden": true
			});

			var svg_nodes = children(svg);

			path = claim_svg_element(svg_nodes, "path", {
				"fill-rule": true,
				d: true,
				"clip-rule": true
			});

			children(path).forEach(detach);
			svg_nodes.forEach(detach);
			t = claim_text(div_nodes, "\r\n        Previous");
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(path, "fill-rule", "evenodd");
			attr(path, "d", "M7.707 14.707a1 1 0 01-1.414 0l-4-4a1 1 0 010-1.414l4-4a1 1 0 011.414 1.414L5.414 9H17a1 1 0 110 2H5.414l2.293 2.293a1 1 0 010 1.414z");
			attr(path, "clip-rule", "evenodd");
			attr(svg, "class", "mr-3 h-5 w-5 text-gray-400");
			attr(svg, "xmlns", "http://www.w3.org/2000/svg");
			attr(svg, "viewBox", "0 0 20 20");
			attr(svg, "fill", "currentColor");
			attr(svg, "aria-hidden", "true");
			attr(div, "class", "border-t-2 border-transparent pt-4 pr-1 inline-flex items-center text-sm font-medium text-gray-500 hover:text-gray-700 hover:border-gray-300");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			append_hydration(div, svg);
			append_hydration(svg, path);
			append_hydration(div, t);

			if (!mounted) {
				dispose = listen(div, "click", /*click_handler*/ ctx[6]);
				mounted = true;
			}
		},
		p: noop,
		d(detaching) {
			if (detaching) detach(div);
			mounted = false;
			dispose();
		}
	};
}

// (81:4) {#each arrayPages as i}
function create_each_block$8(ctx) {
	let div;
	let t0_value = /*i*/ ctx[10] + "";
	let t0;
	let t1;
	let div_class_value;
	let mounted;
	let dispose;

	function click_handler_1() {
		return /*click_handler_1*/ ctx[7](/*i*/ ctx[10]);
	}

	return {
		c() {
			div = element("div");
			t0 = text(t0_value);
			t1 = space();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true, "aria-current": true });
			var div_nodes = children(div);
			t0 = claim_text(div_nodes, t0_value);
			t1 = claim_space(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", div_class_value = "border-t-2 pt-4 px-4 inline-flex items-center text-sm font-medium cursor-pointer " + (!isNaN(/*i*/ ctx[10]) && /*current*/ ctx[0] !== /*i*/ ctx[10]
			? 'hover:text-gray-700 hover:border-gray-300'
			: ''));

			attr(div, "aria-current", "page");
			toggle_class(div, "border-blue-500", /*current*/ ctx[0] === /*i*/ ctx[10]);
			toggle_class(div, "text-blue-500", /*current*/ ctx[0] === /*i*/ ctx[10]);
			toggle_class(div, "text-gray-500", /*current*/ ctx[0] !== /*i*/ ctx[10]);
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			append_hydration(div, t0);
			append_hydration(div, t1);

			if (!mounted) {
				dispose = listen(div, "click", click_handler_1);
				mounted = true;
			}
		},
		p(new_ctx, dirty) {
			ctx = new_ctx;
			if (dirty & /*arrayPages*/ 4 && t0_value !== (t0_value = /*i*/ ctx[10] + "")) set_data(t0, t0_value);

			if (dirty & /*arrayPages, current*/ 5 && div_class_value !== (div_class_value = "border-t-2 pt-4 px-4 inline-flex items-center text-sm font-medium cursor-pointer " + (!isNaN(/*i*/ ctx[10]) && /*current*/ ctx[0] !== /*i*/ ctx[10]
			? 'hover:text-gray-700 hover:border-gray-300'
			: ''))) {
				attr(div, "class", div_class_value);
			}

			if (dirty & /*arrayPages, current, current, arrayPages*/ 5) {
				toggle_class(div, "border-blue-500", /*current*/ ctx[0] === /*i*/ ctx[10]);
			}

			if (dirty & /*arrayPages, current, current, arrayPages*/ 5) {
				toggle_class(div, "text-blue-500", /*current*/ ctx[0] === /*i*/ ctx[10]);
			}

			if (dirty & /*arrayPages, current, current, arrayPages*/ 5) {
				toggle_class(div, "text-gray-500", /*current*/ ctx[0] !== /*i*/ ctx[10]);
			}
		},
		d(detaching) {
			if (detaching) detach(div);
			mounted = false;
			dispose();
		}
	};
}

// (100:4) {#if current < numPages}
function create_if_block$m(ctx) {
	let div;
	let t;
	let svg;
	let path;
	let mounted;
	let dispose;

	return {
		c() {
			div = element("div");
			t = text("Next\r\n        \r\n        ");
			svg = svg_element("svg");
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			t = claim_text(div_nodes, "Next\r\n        \r\n        ");

			svg = claim_svg_element(div_nodes, "svg", {
				class: true,
				xmlns: true,
				viewBox: true,
				fill: true,
				"aria-hidden": true
			});

			var svg_nodes = children(svg);

			path = claim_svg_element(svg_nodes, "path", {
				"fill-rule": true,
				d: true,
				"clip-rule": true
			});

			children(path).forEach(detach);
			svg_nodes.forEach(detach);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(path, "fill-rule", "evenodd");
			attr(path, "d", "M12.293 5.293a1 1 0 011.414 0l4 4a1 1 0 010 1.414l-4 4a1 1 0 01-1.414-1.414L14.586 11H3a1 1 0 110-2h11.586l-2.293-2.293a1 1 0 010-1.414z");
			attr(path, "clip-rule", "evenodd");
			attr(svg, "class", "ml-3 h-5 w-5 text-gray-400");
			attr(svg, "xmlns", "http://www.w3.org/2000/svg");
			attr(svg, "viewBox", "0 0 20 20");
			attr(svg, "fill", "currentColor");
			attr(svg, "aria-hidden", "true");
			attr(div, "class", "border-t-2 border-transparent pt-4 pl-1 inline-flex items-center text-sm font-medium text-gray-500 hover:text-gray-700 hover:border-gray-300");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			append_hydration(div, t);
			append_hydration(div, svg);
			append_hydration(svg, path);

			if (!mounted) {
				dispose = listen(div, "click", /*click_handler_2*/ ctx[8]);
				mounted = true;
			}
		},
		p: noop,
		d(detaching) {
			if (detaching) detach(div);
			mounted = false;
			dispose();
		}
	};
}

function create_fragment$B(ctx) {
	let nav;
	let div0;
	let t0;
	let div1;
	let t1;
	let div2;
	let if_block0 = /*current*/ ctx[0] > 1 && create_if_block_1$b(ctx);
	let each_value = /*arrayPages*/ ctx[2];
	let each_blocks = [];

	for (let i = 0; i < each_value.length; i += 1) {
		each_blocks[i] = create_each_block$8(get_each_context$8(ctx, each_value, i));
	}

	let if_block1 = /*current*/ ctx[0] < /*numPages*/ ctx[1] && create_if_block$m(ctx);

	return {
		c() {
			nav = element("nav");
			div0 = element("div");
			if (if_block0) if_block0.c();
			t0 = space();
			div1 = element("div");

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].c();
			}

			t1 = space();
			div2 = element("div");
			if (if_block1) if_block1.c();
			this.h();
		},
		l(nodes) {
			nav = claim_element(nodes, "NAV", { class: true });
			var nav_nodes = children(nav);
			div0 = claim_element(nav_nodes, "DIV", { class: true });
			var div0_nodes = children(div0);
			if (if_block0) if_block0.l(div0_nodes);
			div0_nodes.forEach(detach);
			t0 = claim_space(nav_nodes);
			div1 = claim_element(nav_nodes, "DIV", { class: true });
			var div1_nodes = children(div1);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].l(div1_nodes);
			}

			div1_nodes.forEach(detach);
			t1 = claim_space(nav_nodes);
			div2 = claim_element(nav_nodes, "DIV", { class: true });
			var div2_nodes = children(div2);
			if (if_block1) if_block1.l(div2_nodes);
			div2_nodes.forEach(detach);
			nav_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div0, "class", "-mt-px w-0 flex-1 flex");
			attr(div1, "class", "md:-mt-px md:flex");
			attr(div2, "class", "-mt-px w-0 flex-1 flex justify-end");
			attr(nav, "class", "border-t border-gray-200 px-4 flex items-center justify-between sm:px-0");
		},
		m(target, anchor) {
			insert_hydration(target, nav, anchor);
			append_hydration(nav, div0);
			if (if_block0) if_block0.m(div0, null);
			append_hydration(nav, t0);
			append_hydration(nav, div1);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].m(div1, null);
			}

			append_hydration(nav, t1);
			append_hydration(nav, div2);
			if (if_block1) if_block1.m(div2, null);
		},
		p(ctx, [dirty]) {
			if (/*current*/ ctx[0] > 1) {
				if (if_block0) {
					if_block0.p(ctx, dirty);
				} else {
					if_block0 = create_if_block_1$b(ctx);
					if_block0.c();
					if_block0.m(div0, null);
				}
			} else if (if_block0) {
				if_block0.d(1);
				if_block0 = null;
			}

			if (dirty & /*isNaN, arrayPages, current, setCurrent*/ 13) {
				each_value = /*arrayPages*/ ctx[2];
				let i;

				for (i = 0; i < each_value.length; i += 1) {
					const child_ctx = get_each_context$8(ctx, each_value, i);

					if (each_blocks[i]) {
						each_blocks[i].p(child_ctx, dirty);
					} else {
						each_blocks[i] = create_each_block$8(child_ctx);
						each_blocks[i].c();
						each_blocks[i].m(div1, null);
					}
				}

				for (; i < each_blocks.length; i += 1) {
					each_blocks[i].d(1);
				}

				each_blocks.length = each_value.length;
			}

			if (/*current*/ ctx[0] < /*numPages*/ ctx[1]) {
				if (if_block1) {
					if_block1.p(ctx, dirty);
				} else {
					if_block1 = create_if_block$m(ctx);
					if_block1.c();
					if_block1.m(div2, null);
				}
			} else if (if_block1) {
				if_block1.d(1);
				if_block1 = null;
			}
		},
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(nav);
			if (if_block0) if_block0.d();
			destroy_each(each_blocks, detaching);
			if (if_block1) if_block1.d();
		}
	};
}

function buildArr(c, n) {
	if (n <= 7) {
		return [...Array(n)].map((_, i) => i + 1);
	} else {
		if (c < 3 || c > n - 2) {
			return [1, 2, 3, "...", n - 2, n - 1, n];
		} else {
			return [1, "...", c - 1, c, c + 1, "...", n];
		}
	}
}

function instance$B($$self, $$props, $$invalidate) {
	let { current = 1 } = $$props;
	let { numItems } = $$props;
	let { perPage = 10 } = $$props;
	let numPages;
	let arrayPages = [];

	function setArrPages() {
		$$invalidate(2, arrayPages = buildArr(current, numPages));
	}

	function setCurrent(i) {
		if (isNaN(i)) return;
		$$invalidate(0, current = i);
	}

	const click_handler = () => setCurrent(current - 1);
	const click_handler_1 = i => setCurrent(i);
	const click_handler_2 = () => setCurrent(current + 1);

	$$self.$$set = $$props => {
		if ('current' in $$props) $$invalidate(0, current = $$props.current);
		if ('numItems' in $$props) $$invalidate(4, numItems = $$props.numItems);
		if ('perPage' in $$props) $$invalidate(5, perPage = $$props.perPage);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*numItems, perPage*/ 48) {
			$$invalidate(1, numPages = Math.ceil(numItems / perPage));
		}

		if ($$self.$$.dirty & /*numItems, perPage, current*/ 49) {
			if (numItems) {
				$$invalidate(1, numPages = Math.ceil(numItems / perPage));
				$$invalidate(0, current = current || 1);
			}
		}

		if ($$self.$$.dirty & /*numPages, perPage, current*/ 35) {
			setArrPages();
		}
	};

	return [
		current,
		numPages,
		arrayPages,
		setCurrent,
		numItems,
		perPage,
		click_handler,
		click_handler_1,
		click_handler_2
	];
}

class Pagination extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$B, create_fragment$B, safe_not_equal, { current: 0, numItems: 4, perPage: 5 });
	}
}

function createCommonjsModule(fn) {
  var module = { exports: {} };
	return fn(module, module.exports), module.exports;
}

var dist = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });
exports.useActions = exports.createActionList = void 0;
/**
 * A wrapper function that provides intellisense
 */
var createActionList = function (actions) {
    return actions;
};
exports.createActionList = createActionList;
/**
 * Takes in actions as a parameter and executes them all.
 * Also manages the update and destroy functions if present.
 */
var useActions = function (node, actions) {
    var actionReturns = [];
    if (actions) {
        actions.forEach(function (currentTuple) {
            var action = currentTuple[0];
            var params = currentTuple[1];
            actionReturns.push(action(node, params));
        });
    }
    return {
        update: function (actions) {
            actions.forEach(function (currentTuple, i) {
                var _a;
                var currentReturn = actionReturns[i];
                var params = currentTuple[1];
                if (!currentReturn)
                    return;
                if (typeof params !== 'undefined') {
                    (_a = currentReturn.update) === null || _a === void 0 ? void 0 : _a.call(currentReturn, params);
                }
            });
        },
        destroy: function () {
            actionReturns.forEach(function (currentReturn) {
                var _a;
                if (currentReturn)
                    (_a = currentReturn.destroy) === null || _a === void 0 ? void 0 : _a.call(currentReturn);
            });
        },
    };
};
exports.useActions = useActions;
});

/* src\Inputs\CheckBox.svelte generated by Svelte v3.48.0 */

function create_if_block$l(ctx) {
	let div;
	let label_1;
	let t0;
	let label_1_for_value;
	let t1;
	let if_block = /*hasError*/ ctx[1] && /*errorMessage*/ ctx[7] && create_if_block_1$a(ctx);

	return {
		c() {
			div = element("div");
			label_1 = element("label");
			t0 = text(/*label*/ ctx[4]);
			t1 = space();
			if (if_block) if_block.c();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			label_1 = claim_element(div_nodes, "LABEL", { for: true, class: true });
			var label_1_nodes = children(label_1);
			t0 = claim_text(label_1_nodes, /*label*/ ctx[4]);
			label_1_nodes.forEach(detach);
			t1 = claim_space(div_nodes);
			if (if_block) if_block.l(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(label_1, "for", label_1_for_value = /*id*/ ctx[3] ? /*id*/ ctx[3] : /*name*/ ctx[2]);
			attr(label_1, "class", "cursor-pointer font-medium text-gray-700 svelte-1o8a4i7");
			toggle_class(label_1, "error", /*hasError*/ ctx[1]);
			toggle_class(label_1, "cursor-not-allowed", /*disabled*/ ctx[6]);
			attr(div, "class", "ml-3 text-sm");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			append_hydration(div, label_1);
			append_hydration(label_1, t0);
			append_hydration(div, t1);
			if (if_block) if_block.m(div, null);
		},
		p(ctx, dirty) {
			if (dirty & /*label*/ 16) set_data(t0, /*label*/ ctx[4]);

			if (dirty & /*id, name*/ 12 && label_1_for_value !== (label_1_for_value = /*id*/ ctx[3] ? /*id*/ ctx[3] : /*name*/ ctx[2])) {
				attr(label_1, "for", label_1_for_value);
			}

			if (dirty & /*hasError*/ 2) {
				toggle_class(label_1, "error", /*hasError*/ ctx[1]);
			}

			if (dirty & /*disabled*/ 64) {
				toggle_class(label_1, "cursor-not-allowed", /*disabled*/ ctx[6]);
			}

			if (/*hasError*/ ctx[1] && /*errorMessage*/ ctx[7]) {
				if (if_block) {
					if_block.p(ctx, dirty);
				} else {
					if_block = create_if_block_1$a(ctx);
					if_block.c();
					if_block.m(div, null);
				}
			} else if (if_block) {
				if_block.d(1);
				if_block = null;
			}
		},
		d(detaching) {
			if (detaching) detach(div);
			if (if_block) if_block.d();
		}
	};
}

// (134:6) {#if hasError && errorMessage}
function create_if_block_1$a(ctx) {
	let p;
	let t;

	return {
		c() {
			p = element("p");
			t = text(/*errorMessage*/ ctx[7]);
			this.h();
		},
		l(nodes) {
			p = claim_element(nodes, "P", { class: true });
			var p_nodes = children(p);
			t = claim_text(p_nodes, /*errorMessage*/ ctx[7]);
			p_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(p, "class", "error svelte-1o8a4i7");
		},
		m(target, anchor) {
			insert_hydration(target, p, anchor);
			append_hydration(p, t);
		},
		p(ctx, dirty) {
			if (dirty & /*errorMessage*/ 128) set_data(t, /*errorMessage*/ ctx[7]);
		},
		d(detaching) {
			if (detaching) detach(p);
		}
	};
}

function create_fragment$A(ctx) {
	let div1;
	let div0;
	let input;
	let input_id_value;
	let input_class_value;
	let input_tabindex_value;
	let useActions_action;
	let t;
	let mounted;
	let dispose;

	let input_levels = [
		{
			id: input_id_value = /*id*/ ctx[3] ? /*id*/ ctx[3] : /*name*/ ctx[2]
		},
		{ name: /*name*/ ctx[2] },
		{ __value: /*value*/ ctx[5] },
		{ disabled: /*disabled*/ ctx[6] },
		{ type: "checkbox" },
		{
			class: input_class_value = "h-" + /*checkboxSize*/ ctx[9] + " w-" + /*checkboxSize*/ ctx[9] + " rounded border-gray-300 focus:border-blue-500 focus:ring-1 focus:ring-blue-500 " + (/*disabled*/ ctx[6]
			? 'cursor-not-allowed text-gray-400'
			: 'text-blue-500')
		},
		{ "aria-checked": /*checked*/ ctx[0] },
		{
			tabindex: input_tabindex_value = /*disabled*/ ctx[6] ? "-1" : "0"
		},
		/*$$restProps*/ ctx[10]
	];

	let input_data = {};

	for (let i = 0; i < input_levels.length; i += 1) {
		input_data = assign(input_data, input_levels[i]);
	}

	let if_block = /*label*/ ctx[4] && create_if_block$l(ctx);

	return {
		c() {
			div1 = element("div");
			div0 = element("div");
			input = element("input");
			t = space();
			if (if_block) if_block.c();
			this.h();
		},
		l(nodes) {
			div1 = claim_element(nodes, "DIV", { class: true });
			var div1_nodes = children(div1);
			div0 = claim_element(div1_nodes, "DIV", { class: true });
			var div0_nodes = children(div0);

			input = claim_element(div0_nodes, "INPUT", {
				id: true,
				name: true,
				type: true,
				class: true,
				"aria-checked": true,
				tabindex: true
			});

			div0_nodes.forEach(detach);
			t = claim_space(div1_nodes);
			if (if_block) if_block.l(div1_nodes);
			div1_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(input, input_data);
			toggle_class(input, "error", /*hasError*/ ctx[1]);
			toggle_class(input, "svelte-1o8a4i7", true);
			attr(div0, "class", "flex h-5 items-center");
			attr(div1, "class", "relative flex items-start");
		},
		m(target, anchor) {
			insert_hydration(target, div1, anchor);
			append_hydration(div1, div0);
			append_hydration(div0, input);
			if (input.autofocus) input.focus();
			input.checked = /*checked*/ ctx[0];
			append_hydration(div1, t);
			if (if_block) if_block.m(div1, null);

			if (!mounted) {
				dispose = [
					listen(input, "change", /*input_change_handler*/ ctx[15]),
					listen(input, "change", /*change_handler_1*/ ctx[16]),
					listen(input, "click", /*click_handler*/ ctx[13]),
					listen(input, "change", /*change_handler*/ ctx[14]),
					action_destroyer(useActions_action = dist.useActions.call(null, input, /*use*/ ctx[8]))
				];

				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			set_attributes(input, input_data = get_spread_update(input_levels, [
				dirty & /*id, name*/ 12 && input_id_value !== (input_id_value = /*id*/ ctx[3] ? /*id*/ ctx[3] : /*name*/ ctx[2]) && { id: input_id_value },
				dirty & /*name*/ 4 && { name: /*name*/ ctx[2] },
				dirty & /*value*/ 32 && { __value: /*value*/ ctx[5] },
				dirty & /*disabled*/ 64 && { disabled: /*disabled*/ ctx[6] },
				{ type: "checkbox" },
				dirty & /*checkboxSize, disabled*/ 576 && input_class_value !== (input_class_value = "h-" + /*checkboxSize*/ ctx[9] + " w-" + /*checkboxSize*/ ctx[9] + " rounded border-gray-300 focus:border-blue-500 focus:ring-1 focus:ring-blue-500 " + (/*disabled*/ ctx[6]
				? 'cursor-not-allowed text-gray-400'
				: 'text-blue-500')) && { class: input_class_value },
				dirty & /*checked*/ 1 && { "aria-checked": /*checked*/ ctx[0] },
				dirty & /*disabled*/ 64 && input_tabindex_value !== (input_tabindex_value = /*disabled*/ ctx[6] ? "-1" : "0") && { tabindex: input_tabindex_value },
				dirty & /*$$restProps*/ 1024 && /*$$restProps*/ ctx[10]
			]));

			if (dirty & /*checked*/ 1) {
				input.checked = /*checked*/ ctx[0];
			}

			if (useActions_action && is_function(useActions_action.update) && dirty & /*use*/ 256) useActions_action.update.call(null, /*use*/ ctx[8]);
			toggle_class(input, "error", /*hasError*/ ctx[1]);
			toggle_class(input, "svelte-1o8a4i7", true);

			if (/*label*/ ctx[4]) {
				if (if_block) {
					if_block.p(ctx, dirty);
				} else {
					if_block = create_if_block$l(ctx);
					if_block.c();
					if_block.m(div1, null);
				}
			} else if (if_block) {
				if_block.d(1);
				if_block = null;
			}
		},
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(div1);
			if (if_block) if_block.d();
			mounted = false;
			run_all(dispose);
		}
	};
}

function instance$A($$self, $$props, $$invalidate) {
	const omit_props_names = [
		"checked","name","id","group","label","value","size","disabled","hasError","errorMessage","use"
	];

	let $$restProps = compute_rest_props($$props, omit_props_names);
	let { checked = false } = $$props;
	let { name = "" } = $$props;
	let { id = "" } = $$props;
	let { group = [] } = $$props;
	let { label = "" } = $$props;
	let { value = "" } = $$props;
	let { size = "small" } = $$props;
	let { disabled = false } = $$props;
	let { hasError = false } = $$props;
	let { errorMessage = "" } = $$props;
	let checkboxSize;

	switch (size) {
		case "small":
			checkboxSize = 3;
			break;
		case "medium":
			checkboxSize = 3.5;
			break;
		case "large":
			checkboxSize = 4;
			break;
	}

	const updateGroup = checked => {
		const index = group.indexOf(value);

		if (checked) {
			if (index < 0) {
				group.push(value);
				$$invalidate(11, group);
			}
		} else {
			if (index >= 0) {
				group.splice(index, 1);
				$$invalidate(11, group);
			}
		}
	};

	const updateChekbox = group => {
		$$invalidate(0, checked = group.indexOf(value) >= 0);
	};

	let { use } = $$props;

	function click_handler(event) {
		bubble.call(this, $$self, event);
	}

	function change_handler(event) {
		bubble.call(this, $$self, event);
	}

	function input_change_handler() {
		checked = this.checked;
		$$invalidate(0, checked);
	}

	const change_handler_1 = () => $$invalidate(1, hasError = false);

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(10, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('checked' in $$new_props) $$invalidate(0, checked = $$new_props.checked);
		if ('name' in $$new_props) $$invalidate(2, name = $$new_props.name);
		if ('id' in $$new_props) $$invalidate(3, id = $$new_props.id);
		if ('group' in $$new_props) $$invalidate(11, group = $$new_props.group);
		if ('label' in $$new_props) $$invalidate(4, label = $$new_props.label);
		if ('value' in $$new_props) $$invalidate(5, value = $$new_props.value);
		if ('size' in $$new_props) $$invalidate(12, size = $$new_props.size);
		if ('disabled' in $$new_props) $$invalidate(6, disabled = $$new_props.disabled);
		if ('hasError' in $$new_props) $$invalidate(1, hasError = $$new_props.hasError);
		if ('errorMessage' in $$new_props) $$invalidate(7, errorMessage = $$new_props.errorMessage);
		if ('use' in $$new_props) $$invalidate(8, use = $$new_props.use);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*checked*/ 1) {
			updateGroup(checked);
		}

		if ($$self.$$.dirty & /*group*/ 2048) {
			updateChekbox(group);
		}
	};

	return [
		checked,
		hasError,
		name,
		id,
		label,
		value,
		disabled,
		errorMessage,
		use,
		checkboxSize,
		$$restProps,
		group,
		size,
		click_handler,
		change_handler,
		input_change_handler,
		change_handler_1
	];
}

class CheckBox extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$A, create_fragment$A, safe_not_equal, {
			checked: 0,
			name: 2,
			id: 3,
			group: 11,
			label: 4,
			value: 5,
			size: 12,
			disabled: 6,
			hasError: 1,
			errorMessage: 7,
			use: 8
		});
	}
}

/* src\Inputs\CheckBoxGroup.svelte generated by Svelte v3.48.0 */

function get_each_context$7(ctx, list, i) {
	const child_ctx = ctx.slice();
	child_ctx[7] = list[i];
	child_ctx[8] = list;
	child_ctx[9] = i;
	return child_ctx;
}

// (76:4) {#if checkbox.label}
function create_if_block$k(ctx) {
	let div;
	let label;
	let t0_value = /*checkbox*/ ctx[7].label + "";
	let t0;
	let label_for_value;
	let t1;
	let if_block = /*checkbox*/ ctx[7].hasError && /*checkbox*/ ctx[7].errorMessage && create_if_block_1$9(ctx);

	return {
		c() {
			div = element("div");
			label = element("label");
			t0 = text(t0_value);
			t1 = space();
			if (if_block) if_block.c();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			label = claim_element(div_nodes, "LABEL", { for: true, class: true });
			var label_nodes = children(label);
			t0 = claim_text(label_nodes, t0_value);
			label_nodes.forEach(detach);
			t1 = claim_space(div_nodes);
			if (if_block) if_block.l(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(label, "for", label_for_value = /*checkbox*/ ctx[7].name);
			attr(label, "class", "font-medium text-gray-700 svelte-sgm3x");
			toggle_class(label, "cursor-not-allowed", /*checkbox*/ ctx[7].disabled);
			toggle_class(label, "error", /*checkbox*/ ctx[7].hasError);
			attr(div, "class", "ml-3 text-sm");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			append_hydration(div, label);
			append_hydration(label, t0);
			append_hydration(div, t1);
			if (if_block) if_block.m(div, null);
		},
		p(ctx, dirty) {
			if (dirty & /*checkboxes*/ 1 && t0_value !== (t0_value = /*checkbox*/ ctx[7].label + "")) set_data(t0, t0_value);

			if (dirty & /*checkboxes*/ 1 && label_for_value !== (label_for_value = /*checkbox*/ ctx[7].name)) {
				attr(label, "for", label_for_value);
			}

			if (dirty & /*checkboxes*/ 1) {
				toggle_class(label, "cursor-not-allowed", /*checkbox*/ ctx[7].disabled);
			}

			if (dirty & /*checkboxes*/ 1) {
				toggle_class(label, "error", /*checkbox*/ ctx[7].hasError);
			}

			if (/*checkbox*/ ctx[7].hasError && /*checkbox*/ ctx[7].errorMessage) {
				if (if_block) {
					if_block.p(ctx, dirty);
				} else {
					if_block = create_if_block_1$9(ctx);
					if_block.c();
					if_block.m(div, null);
				}
			} else if (if_block) {
				if_block.d(1);
				if_block = null;
			}
		},
		d(detaching) {
			if (detaching) detach(div);
			if (if_block) if_block.d();
		}
	};
}

// (87:8) {#if checkbox.hasError && checkbox.errorMessage}
function create_if_block_1$9(ctx) {
	let p;
	let t_value = /*checkbox*/ ctx[7].errorMessage + "";
	let t;

	return {
		c() {
			p = element("p");
			t = text(t_value);
			this.h();
		},
		l(nodes) {
			p = claim_element(nodes, "P", { class: true });
			var p_nodes = children(p);
			t = claim_text(p_nodes, t_value);
			p_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(p, "class", "error svelte-sgm3x");
		},
		m(target, anchor) {
			insert_hydration(target, p, anchor);
			append_hydration(p, t);
		},
		p(ctx, dirty) {
			if (dirty & /*checkboxes*/ 1 && t_value !== (t_value = /*checkbox*/ ctx[7].errorMessage + "")) set_data(t, t_value);
		},
		d(detaching) {
			if (detaching) detach(p);
		}
	};
}

// (57:0) {#each checkboxes as checkbox}
function create_each_block$7(ctx) {
	let div1;
	let div0;
	let input;
	let input_value_value;
	let input_disabled_value;
	let input_id_value;
	let input_name_value;
	let input_class_value;
	let input_aria_checked_value;
	let div0_class_value;
	let t0;
	let t1;
	let mounted;
	let dispose;

	function change_handler() {
		return /*change_handler*/ ctx[6](/*checkbox*/ ctx[7], /*each_value*/ ctx[8], /*checkbox_index*/ ctx[9]);
	}

	let if_block = /*checkbox*/ ctx[7].label && create_if_block$k(ctx);

	return {
		c() {
			div1 = element("div");
			div0 = element("div");
			input = element("input");
			t0 = space();
			if (if_block) if_block.c();
			t1 = space();
			this.h();
		},
		l(nodes) {
			div1 = claim_element(nodes, "DIV", { class: true });
			var div1_nodes = children(div1);
			div0 = claim_element(div1_nodes, "DIV", { class: true });
			var div0_nodes = children(div0);

			input = claim_element(div0_nodes, "INPUT", {
				id: true,
				name: true,
				type: true,
				class: true,
				"aria-checked": true
			});

			div0_nodes.forEach(detach);
			t0 = claim_space(div1_nodes);
			if (if_block) if_block.l(div1_nodes);
			t1 = claim_space(div1_nodes);
			div1_nodes.forEach(detach);
			this.h();
		},
		h() {
			input.__value = input_value_value = /*checkbox*/ ctx[7].value;
			input.value = input.__value;
			input.disabled = input_disabled_value = /*checkbox*/ ctx[7].disabled;
			attr(input, "id", input_id_value = /*checkbox*/ ctx[7].name);
			attr(input, "name", input_name_value = /*checkbox*/ ctx[7].name);
			attr(input, "type", "checkbox");
			attr(input, "class", input_class_value = "h-" + /*checkboxSize*/ ctx[2] + " w-" + /*checkboxSize*/ ctx[2] + " border-gray-300 text-blue-500 rounded-md focus:border-blue-500 focus:ring-blue-500 focus:ring-1" + " svelte-sgm3x");
			attr(input, "aria-checked", input_aria_checked_value = /*checkbox*/ ctx[7].checked);
			/*$$binding_groups*/ ctx[5][0].push(input);
			toggle_class(input, "error", /*checkbox*/ ctx[7].hasError);
			attr(div0, "class", div0_class_value = "flex items-center h-" + (/*checkboxSize*/ ctx[2] + 2) + " svelte-sgm3x");
			attr(div1, "class", "relative flex items-start");
		},
		m(target, anchor) {
			insert_hydration(target, div1, anchor);
			append_hydration(div1, div0);
			append_hydration(div0, input);
			input.checked = ~/*group*/ ctx[1].indexOf(input.__value);
			append_hydration(div1, t0);
			if (if_block) if_block.m(div1, null);
			append_hydration(div1, t1);

			if (!mounted) {
				dispose = [
					listen(input, "change", /*input_change_handler*/ ctx[4]),
					listen(input, "change", change_handler)
				];

				mounted = true;
			}
		},
		p(new_ctx, dirty) {
			ctx = new_ctx;

			if (dirty & /*checkboxes*/ 1 && input_value_value !== (input_value_value = /*checkbox*/ ctx[7].value)) {
				input.__value = input_value_value;
				input.value = input.__value;
			}

			if (dirty & /*checkboxes*/ 1 && input_disabled_value !== (input_disabled_value = /*checkbox*/ ctx[7].disabled)) {
				input.disabled = input_disabled_value;
			}

			if (dirty & /*checkboxes*/ 1 && input_id_value !== (input_id_value = /*checkbox*/ ctx[7].name)) {
				attr(input, "id", input_id_value);
			}

			if (dirty & /*checkboxes*/ 1 && input_name_value !== (input_name_value = /*checkbox*/ ctx[7].name)) {
				attr(input, "name", input_name_value);
			}

			if (dirty & /*checkboxSize*/ 4 && input_class_value !== (input_class_value = "h-" + /*checkboxSize*/ ctx[2] + " w-" + /*checkboxSize*/ ctx[2] + " border-gray-300 text-blue-500 rounded-md focus:border-blue-500 focus:ring-blue-500 focus:ring-1" + " svelte-sgm3x")) {
				attr(input, "class", input_class_value);
			}

			if (dirty & /*checkboxes*/ 1 && input_aria_checked_value !== (input_aria_checked_value = /*checkbox*/ ctx[7].checked)) {
				attr(input, "aria-checked", input_aria_checked_value);
			}

			if (dirty & /*group*/ 2) {
				input.checked = ~/*group*/ ctx[1].indexOf(input.__value);
			}

			if (dirty & /*checkboxSize, checkboxes*/ 5) {
				toggle_class(input, "error", /*checkbox*/ ctx[7].hasError);
			}

			if (dirty & /*checkboxSize*/ 4 && div0_class_value !== (div0_class_value = "flex items-center h-" + (/*checkboxSize*/ ctx[2] + 2) + " svelte-sgm3x")) {
				attr(div0, "class", div0_class_value);
			}

			if (/*checkbox*/ ctx[7].label) {
				if (if_block) {
					if_block.p(ctx, dirty);
				} else {
					if_block = create_if_block$k(ctx);
					if_block.c();
					if_block.m(div1, t1);
				}
			} else if (if_block) {
				if_block.d(1);
				if_block = null;
			}
		},
		d(detaching) {
			if (detaching) detach(div1);
			/*$$binding_groups*/ ctx[5][0].splice(/*$$binding_groups*/ ctx[5][0].indexOf(input), 1);
			if (if_block) if_block.d();
			mounted = false;
			run_all(dispose);
		}
	};
}

function create_fragment$z(ctx) {
	let each_1_anchor;
	let each_value = /*checkboxes*/ ctx[0];
	let each_blocks = [];

	for (let i = 0; i < each_value.length; i += 1) {
		each_blocks[i] = create_each_block$7(get_each_context$7(ctx, each_value, i));
	}

	return {
		c() {
			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].c();
			}

			each_1_anchor = empty();
		},
		l(nodes) {
			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].l(nodes);
			}

			each_1_anchor = empty();
		},
		m(target, anchor) {
			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].m(target, anchor);
			}

			insert_hydration(target, each_1_anchor, anchor);
		},
		p(ctx, [dirty]) {
			if (dirty & /*checkboxes, checkboxSize, group*/ 7) {
				each_value = /*checkboxes*/ ctx[0];
				let i;

				for (i = 0; i < each_value.length; i += 1) {
					const child_ctx = get_each_context$7(ctx, each_value, i);

					if (each_blocks[i]) {
						each_blocks[i].p(child_ctx, dirty);
					} else {
						each_blocks[i] = create_each_block$7(child_ctx);
						each_blocks[i].c();
						each_blocks[i].m(each_1_anchor.parentNode, each_1_anchor);
					}
				}

				for (; i < each_blocks.length; i += 1) {
					each_blocks[i].d(1);
				}

				each_blocks.length = each_value.length;
			}
		},
		i: noop,
		o: noop,
		d(detaching) {
			destroy_each(each_blocks, detaching);
			if (detaching) detach(each_1_anchor);
		}
	};
}

function instance$z($$self, $$props, $$invalidate) {
	let { group = [] } = $$props;
	let { size = "small" } = $$props;
	let { checkboxes = [] } = $$props;
	let checkboxSize;

	switch (size) {
		case "small":
			checkboxSize = 3;
			break;
		case "medium":
			checkboxSize = 3.5;
			break;
		case "large":
			checkboxSize = 4;
			break;
	}

	const $$binding_groups = [[]];

	function input_change_handler() {
		group = get_binding_group_value($$binding_groups[0], this.__value, this.checked);
		($$invalidate(1, group), $$invalidate(0, checkboxes));
	}

	const change_handler = (checkbox, each_value, checkbox_index) => {
		$$invalidate(0, each_value[checkbox_index].checked = !checkbox.checked, checkboxes);
		$$invalidate(0, each_value[checkbox_index].hasError = false, checkboxes);
	};

	$$self.$$set = $$props => {
		if ('group' in $$props) $$invalidate(1, group = $$props.group);
		if ('size' in $$props) $$invalidate(3, size = $$props.size);
		if ('checkboxes' in $$props) $$invalidate(0, checkboxes = $$props.checkboxes);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*checkboxes*/ 1) {
			// to react to changes if you were to disable checkbox ect..
			{
				$$invalidate(1, group = checkboxes.filter(c => c.checked).map(c => c.value));
			}
		}
	};

	return [
		checkboxes,
		group,
		checkboxSize,
		size,
		input_change_handler,
		$$binding_groups,
		change_handler
	];
}

class CheckBoxGroup extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$z, create_fragment$z, safe_not_equal, { group: 1, size: 3, checkboxes: 0 });
	}
}

// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
const clickOutside = (node, action) => {

  function handleOutsideClick(e) {
      const targetElement = e.target;
      if (node && !node.contains(targetElement) ) {
        action();
      }
    }

  // wait a second to mount the dom node 
  setTimeout(() => { 
    window.addEventListener('click', handleOutsideClick);
  },300);

  return {
      destroy() {
        window.removeEventListener('click', handleOutsideClick);
      }
    };
  };

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function createPopperActions(initOptions) {
    var popperInstance = null;
    var referenceNode;
    var contentNode;
    var options = initOptions;
    var initPopper = function () {
        if (referenceNode && contentNode) {
            popperInstance = createPopper(referenceNode, contentNode, options);
        }
    };
    var deinitPopper = function () {
        if (popperInstance) {
            popperInstance.destroy();
            popperInstance = null;
        }
    };
    var referenceAction = function (node) {
        referenceNode = node;
        initPopper();
        return {
            destroy: function () {
                deinitPopper();
            },
        };
    };
    var contentAction = function (node, contentOptions) {
        contentNode = node;
        options = __assign(__assign({}, initOptions), contentOptions);
        initPopper();
        return {
            update: function (newContentOptions) {
                options = __assign(__assign({}, initOptions), newContentOptions);
                if (popperInstance && options) {
                    popperInstance.setOptions(options);
                }
            },
            destroy: function () {
                deinitPopper();
            },
        };
    };
    return [referenceAction, contentAction, function () { return popperInstance; }];
}

/* src\Inputs\Menu.svelte generated by Svelte v3.48.0 */
const get_menu_context_slot_changes = dirty => ({ open: dirty & /*open*/ 1 });
const get_menu_context_slot_context = ctx => ({ open: /*open*/ ctx[0] });
const get_menu_trigger_slot_changes = dirty => ({});
const get_menu_trigger_slot_context = ctx => ({});

// (85:30)         
function fallback_block(ctx) {
	let button_1;
	let svg;
	let path;

	return {
		c() {
			button_1 = element("button");
			svg = svg_element("svg");
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			button_1 = claim_element(nodes, "BUTTON", {
				class: true,
				id: true,
				"aria-haspopup": true,
				"aria-expanded": true
			});

			var button_1_nodes = children(button_1);

			svg = claim_svg_element(button_1_nodes, "svg", {
				class: true,
				xmlns: true,
				viewBox: true,
				fill: true,
				"aria-hidden": true
			});

			var svg_nodes = children(svg);
			path = claim_svg_element(svg_nodes, "path", { d: true });
			children(path).forEach(detach);
			svg_nodes.forEach(detach);
			button_1_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(path, "d", "M10 6a2 2 0 110-4 2 2 0 010 4zM10 12a2 2 0 110-4 2 2 0 010 4zM10 18a2 2 0 110-4 2 2 0 010 4z");
			attr(svg, "class", "h-5 w-5");
			attr(svg, "xmlns", "http://www.w3.org/2000/svg");
			attr(svg, "viewBox", "0 0 20 20");
			attr(svg, "fill", "currentColor");
			attr(svg, "aria-hidden", "true");
			attr(button_1, "class", "bg-gray-100 rounded-full flex items-center text-gray-400 hover:text-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-offset-gray-100 focus:ring-indigo-500");
			attr(button_1, "id", "options-menu");
			attr(button_1, "aria-haspopup", "true");
			attr(button_1, "aria-expanded", /*open*/ ctx[0]);
		},
		m(target, anchor) {
			insert_hydration(target, button_1, anchor);
			append_hydration(button_1, svg);
			append_hydration(svg, path);
		},
		p(ctx, dirty) {
			if (dirty & /*open*/ 1) {
				attr(button_1, "aria-expanded", /*open*/ ctx[0]);
			}
		},
		d(detaching) {
			if (detaching) detach(button_1);
		}
	};
}

// (108:2) {#if open}
function create_if_block$j(ctx) {
	let div1;
	let div0;
	let clickOutside_action;
	let div0_intro;
	let div0_outro;
	let popperContent_action;
	let current;
	let mounted;
	let dispose;
	const menu_context_slot_template = /*#slots*/ ctx[13].menu_context;
	const menu_context_slot = create_slot(menu_context_slot_template, ctx, /*$$scope*/ ctx[12], get_menu_context_slot_context);

	let div0_levels = [
		{
			class: "mt-2 rounded-md shadow-lg focus:outline-none"
		},
		{ tabindex: "-1" },
		/*$$props*/ ctx[9]
	];

	let div0_data = {};

	for (let i = 0; i < div0_levels.length; i += 1) {
		div0_data = assign(div0_data, div0_levels[i]);
	}

	return {
		c() {
			div1 = element("div");
			div0 = element("div");
			if (menu_context_slot) menu_context_slot.c();
			this.h();
		},
		l(nodes) {
			div1 = claim_element(nodes, "DIV", { class: true });
			var div1_nodes = children(div1);
			div0 = claim_element(div1_nodes, "DIV", { class: true, tabindex: true });
			var div0_nodes = children(div0);
			if (menu_context_slot) menu_context_slot.l(div0_nodes);
			div0_nodes.forEach(detach);
			div1_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(div0, div0_data);
			attr(div1, "class", "z-50");
		},
		m(target, anchor) {
			insert_hydration(target, div1, anchor);
			append_hydration(div1, div0);

			if (menu_context_slot) {
				menu_context_slot.m(div0, null);
			}

			/*div0_binding*/ ctx[16](div0);
			current = true;

			if (!mounted) {
				dispose = [
					listen(div0, "keydown", /*handleKeyPress*/ ctx[4]),
					action_destroyer(clickOutside_action = clickOutside.call(null, div0, /*clickOutside_function*/ ctx[17])),
					action_destroyer(popperContent_action = /*popperContent*/ ctx[8].call(null, div1, /*popperOptions*/ ctx[1]))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (menu_context_slot) {
				if (menu_context_slot.p && (!current || dirty & /*$$scope, open*/ 4097)) {
					update_slot_base(
						menu_context_slot,
						menu_context_slot_template,
						ctx,
						/*$$scope*/ ctx[12],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[12])
						: get_slot_changes(menu_context_slot_template, /*$$scope*/ ctx[12], dirty, get_menu_context_slot_changes),
						get_menu_context_slot_context
					);
				}
			}

			set_attributes(div0, div0_data = get_spread_update(div0_levels, [
				{
					class: "mt-2 rounded-md shadow-lg focus:outline-none"
				},
				{ tabindex: "-1" },
				dirty & /*$$props*/ 512 && /*$$props*/ ctx[9]
			]));

			if (popperContent_action && is_function(popperContent_action.update) && dirty & /*popperOptions*/ 2) popperContent_action.update.call(null, /*popperOptions*/ ctx[1]);
		},
		i(local) {
			if (current) return;
			transition_in(menu_context_slot, local);

			add_render_callback(() => {
				if (div0_outro) div0_outro.end(1);
				div0_intro = create_in_transition(div0, scale, { duration: 100, start: 0.95 });
				div0_intro.start();
			});

			current = true;
		},
		o(local) {
			transition_out(menu_context_slot, local);
			if (div0_intro) div0_intro.invalidate();
			div0_outro = create_out_transition(div0, scale, { duration: 75, start: 0.95 });
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div1);
			if (menu_context_slot) menu_context_slot.d(detaching);
			/*div0_binding*/ ctx[16](null);
			if (detaching && div0_outro) div0_outro.end();
			mounted = false;
			run_all(dispose);
		}
	};
}

function create_fragment$y(ctx) {
	let t0;
	let div;
	let span;
	let t1;
	let current;
	let mounted;
	let dispose;
	let if_block0 = false ;
	const menu_trigger_slot_template = /*#slots*/ ctx[13].menu_trigger;
	const menu_trigger_slot = create_slot(menu_trigger_slot_template, ctx, /*$$scope*/ ctx[12], get_menu_trigger_slot_context);
	const menu_trigger_slot_or_fallback = menu_trigger_slot || fallback_block(ctx);
	let if_block1 = /*open*/ ctx[0] && create_if_block$j(ctx);

	return {
		c() {
			t0 = space();
			div = element("div");
			span = element("span");
			if (menu_trigger_slot_or_fallback) menu_trigger_slot_or_fallback.c();
			t1 = space();
			if (if_block1) if_block1.c();
			this.h();
		},
		l(nodes) {
			t0 = claim_space(nodes);
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			span = claim_element(div_nodes, "SPAN", {});
			var span_nodes = children(span);
			if (menu_trigger_slot_or_fallback) menu_trigger_slot_or_fallback.l(span_nodes);
			span_nodes.forEach(detach);
			t1 = claim_space(div_nodes);
			if (if_block1) if_block1.l(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", "relative text-left");
		},
		m(target, anchor) {
			insert_hydration(target, t0, anchor);
			insert_hydration(target, div, anchor);
			append_hydration(div, span);

			if (menu_trigger_slot_or_fallback) {
				menu_trigger_slot_or_fallback.m(span, null);
			}

			/*span_binding*/ ctx[15](span);
			append_hydration(div, t1);
			if (if_block1) if_block1.m(div, null);
			current = true;

			if (!mounted) {
				dispose = [
					listen(span, "click", /*click_handler*/ ctx[14]),
					action_destroyer(/*popperRef*/ ctx[7].call(null, span))
				];

				mounted = true;
			}
		},
		p(ctx, [dirty]) {

			if (menu_trigger_slot) {
				if (menu_trigger_slot.p && (!current || dirty & /*$$scope*/ 4096)) {
					update_slot_base(
						menu_trigger_slot,
						menu_trigger_slot_template,
						ctx,
						/*$$scope*/ ctx[12],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[12])
						: get_slot_changes(menu_trigger_slot_template, /*$$scope*/ ctx[12], dirty, get_menu_trigger_slot_changes),
						get_menu_trigger_slot_context
					);
				}
			} else {
				if (menu_trigger_slot_or_fallback && menu_trigger_slot_or_fallback.p && (!current || dirty & /*open*/ 1)) {
					menu_trigger_slot_or_fallback.p(ctx, !current ? -1 : dirty);
				}
			}

			if (/*open*/ ctx[0]) {
				if (if_block1) {
					if_block1.p(ctx, dirty);

					if (dirty & /*open*/ 1) {
						transition_in(if_block1, 1);
					}
				} else {
					if_block1 = create_if_block$j(ctx);
					if_block1.c();
					transition_in(if_block1, 1);
					if_block1.m(div, null);
				}
			} else if (if_block1) {
				group_outros();

				transition_out(if_block1, 1, 1, () => {
					if_block1 = null;
				});

				check_outros();
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block0);
			transition_in(menu_trigger_slot_or_fallback, local);
			transition_in(if_block1);
			current = true;
		},
		o(local) {
			transition_out(if_block0);
			transition_out(menu_trigger_slot_or_fallback, local);
			transition_out(if_block1);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(t0);
			if (detaching) detach(div);
			if (menu_trigger_slot_or_fallback) menu_trigger_slot_or_fallback.d(detaching);
			/*span_binding*/ ctx[15](null);
			if (if_block1) if_block1.d();
			mounted = false;
			run_all(dispose);
		}
	};
}

function instance$y($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	let { open = false } = $$props;
	let { disabled = false } = $$props;
	let { menuWidth = "w-56" } = $$props;
	let menu;
	let button;

	const handleKeyPress = e => {
		const key = e.key;
		const nodes = menu.querySelectorAll("*");
		const tabbable = Array.from(nodes).filter(node => node.tabIndex >= 0);

		// only prevent default for the following key inputs;
		// so enter key still works ect...
		if (key === "ArrowDown" || key === "ArrowUp" || key === "Tab") {
			e.preventDefault();
		}

		if (key === "Escape" && open) {
			e.stopPropagation();
			$$invalidate(0, open = false);
			button.focus();
		}

		// Focus trapping
		if (key === "ArrowDown" || key === "ArrowUp") {
			let index = tabbable.indexOf(document.activeElement);
			if (tabbable.length - 1 === index && key === "ArrowDown") return;
			if (index === 0 && key === "ArrowUp") return;

			if (tabbable.length) {
				index += tabbable.length + (key === "ArrowUp" ? -1 : 1);
				index %= tabbable.length;
				tabbable[index].focus();
				e.preventDefault();
			}
		}
	};

	const closeModal = async () => {
		$$invalidate(0, open = false);
		await tick();
		button.focus();
	};

	const openMenu = async () => {
		if (disabled) return;
		$$invalidate(0, open = true);
		await tick();
		menu.focus();
	};

	const [popperRef, popperContent] = createPopperActions();

	let { popperOptions = {
		placement: "bottom-end",
		strategy: "fixed",
		modifiers: [
			{
				name: "offset",
				options: { offset: [0, 10] }
			}
		]
	} } = $$props;

	const click_handler = () => openMenu();

	function span_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			button = $$value;
			$$invalidate(3, button);
		});
	}

	function div0_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			menu = $$value;
			$$invalidate(2, menu);
		});
	}

	const clickOutside_function = () => closeModal();

	$$self.$$set = $$new_props => {
		$$invalidate(9, $$props = assign(assign({}, $$props), exclude_internal_props($$new_props)));
		if ('open' in $$new_props) $$invalidate(0, open = $$new_props.open);
		if ('disabled' in $$new_props) $$invalidate(10, disabled = $$new_props.disabled);
		if ('menuWidth' in $$new_props) $$invalidate(11, menuWidth = $$new_props.menuWidth);
		if ('popperOptions' in $$new_props) $$invalidate(1, popperOptions = $$new_props.popperOptions);
		if ('$$scope' in $$new_props) $$invalidate(12, $$scope = $$new_props.$$scope);
	};

	$$props = exclude_internal_props($$props);

	return [
		open,
		popperOptions,
		menu,
		button,
		handleKeyPress,
		closeModal,
		openMenu,
		popperRef,
		popperContent,
		$$props,
		disabled,
		menuWidth,
		$$scope,
		slots,
		click_handler,
		span_binding,
		div0_binding,
		clickOutside_function
	];
}

class Menu extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$y, create_fragment$y, safe_not_equal, {
			open: 0,
			disabled: 10,
			menuWidth: 11,
			popperOptions: 1
		});
	}
}

/* src\Inputs\RadioGroup.svelte generated by Svelte v3.48.0 */

function get_each_context$6(ctx, list, i) {
	const child_ctx = ctx.slice();
	child_ctx[7] = list[i];
	return child_ctx;
}

// (61:10) {#if option.helperText}
function create_if_block$i(ctx) {
	let span;
	let t_value = /*option*/ ctx[7].helperText + "";
	let t;

	return {
		c() {
			span = element("span");
			t = text(t_value);
			this.h();
		},
		l(nodes) {
			span = claim_element(nodes, "SPAN", { class: true });
			var span_nodes = children(span);
			t = claim_text(span_nodes, t_value);
			span_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(span, "class", "block text-sm");
			toggle_class(span, "text-blue-500", /*option*/ ctx[7].value == /*selectedOption*/ ctx[0]);
		},
		m(target, anchor) {
			insert_hydration(target, span, anchor);
			append_hydration(span, t);
		},
		p(ctx, dirty) {
			if (dirty & /*options*/ 2 && t_value !== (t_value = /*option*/ ctx[7].helperText + "")) set_data(t, t_value);

			if (dirty & /*options, selectedOption*/ 3) {
				toggle_class(span, "text-blue-500", /*option*/ ctx[7].value == /*selectedOption*/ ctx[0]);
			}
		},
		d(detaching) {
			if (detaching) detach(span);
		}
	};
}

// (27:4) {#each options as option}
function create_each_block$6(ctx) {
	let div1;
	let div0;
	let input;
	let input_id_value;
	let input_value_value;
	let input_disabled_value;
	let input_aria_checked_value;
	let input_tabindex_value;
	let t0;
	let label;
	let span;
	let t1_value = /*option*/ ctx[7].label + "";
	let t1;
	let t2;
	let label_for_value;
	let t3;
	let mounted;
	let dispose;

	let input_levels = [
		{ role: "radio" },
		{
			id: input_id_value = /*option*/ ctx[7].name
		},
		{ name: "privacy_setting" },
		{ type: "radio" },
		{
			__value: input_value_value = /*option*/ ctx[7].value
		},
		{
			disabled: input_disabled_value = /*option*/ ctx[7].disabled
		},
		{
			class: "h-4 w-4 cursor-pointer border-gray-300 text-blue-500 focus:ring-blue-500 rounded-md"
		},
		{
			"aria-checked": input_aria_checked_value = /*option*/ ctx[7].value == /*selectedOption*/ ctx[0]
		},
		{
			tabindex: input_tabindex_value = /*option*/ ctx[7].value == /*selectedOption*/ ctx[0]
			? 0
			: -1
		},
		/*$$restProps*/ ctx[3]
	];

	let input_data = {};

	for (let i = 0; i < input_levels.length; i += 1) {
		input_data = assign(input_data, input_levels[i]);
	}

	let if_block = /*option*/ ctx[7].helperText && create_if_block$i(ctx);

	return {
		c() {
			div1 = element("div");
			div0 = element("div");
			input = element("input");
			t0 = space();
			label = element("label");
			span = element("span");
			t1 = text(t1_value);
			t2 = space();
			if (if_block) if_block.c();
			t3 = space();
			this.h();
		},
		l(nodes) {
			div1 = claim_element(nodes, "DIV", { class: true });
			var div1_nodes = children(div1);
			div0 = claim_element(div1_nodes, "DIV", { class: true });
			var div0_nodes = children(div0);

			input = claim_element(div0_nodes, "INPUT", {
				role: true,
				id: true,
				name: true,
				type: true,
				class: true,
				"aria-checked": true,
				tabindex: true
			});

			div0_nodes.forEach(detach);
			t0 = claim_space(div1_nodes);
			label = claim_element(div1_nodes, "LABEL", { for: true, class: true });
			var label_nodes = children(label);
			span = claim_element(label_nodes, "SPAN", { class: true });
			var span_nodes = children(span);
			t1 = claim_text(span_nodes, t1_value);
			span_nodes.forEach(detach);
			t2 = claim_space(label_nodes);
			if (if_block) if_block.l(label_nodes);
			label_nodes.forEach(detach);
			t3 = claim_space(div1_nodes);
			div1_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(input, input_data);
			/*$$binding_groups*/ ctx[6][0].push(input);
			attr(div0, "class", "flex items-center h-5");
			attr(span, "class", "block text-sm font-medium");
			toggle_class(span, "text-gray-900", /*option*/ ctx[7].value == /*selectedOption*/ ctx[0]);
			attr(label, "for", label_for_value = /*option*/ ctx[7].name);
			attr(label, "class", "ml-3 flex flex-col cursor-pointer");
			toggle_class(label, "disabled", /*option*/ ctx[7].disabled);
			attr(div1, "class", "relative border p-4 flex rounded-md");
			toggle_class(div1, "border-blue-500", /*option*/ ctx[7].value == /*selectedOption*/ ctx[0]);
			toggle_class(div1, "z-10", /*option*/ ctx[7].value == /*selectedOption*/ ctx[0]);
		},
		m(target, anchor) {
			insert_hydration(target, div1, anchor);
			append_hydration(div1, div0);
			append_hydration(div0, input);
			if (input.autofocus) input.focus();
			input.checked = input.__value === /*selectedOption*/ ctx[0];
			append_hydration(div1, t0);
			append_hydration(div1, label);
			append_hydration(label, span);
			append_hydration(span, t1);
			append_hydration(label, t2);
			if (if_block) if_block.m(label, null);
			append_hydration(div1, t3);

			if (!mounted) {
				dispose = listen(input, "change", /*input_change_handler*/ ctx[5]);
				mounted = true;
			}
		},
		p(ctx, dirty) {
			set_attributes(input, input_data = get_spread_update(input_levels, [
				{ role: "radio" },
				dirty & /*options*/ 2 && input_id_value !== (input_id_value = /*option*/ ctx[7].name) && { id: input_id_value },
				{ name: "privacy_setting" },
				{ type: "radio" },
				dirty & /*options*/ 2 && input_value_value !== (input_value_value = /*option*/ ctx[7].value) && { __value: input_value_value },
				dirty & /*options*/ 2 && input_disabled_value !== (input_disabled_value = /*option*/ ctx[7].disabled) && { disabled: input_disabled_value },
				{
					class: "h-4 w-4 cursor-pointer border-gray-300 text-blue-500 focus:ring-blue-500 rounded-md"
				},
				dirty & /*options, selectedOption*/ 3 && input_aria_checked_value !== (input_aria_checked_value = /*option*/ ctx[7].value == /*selectedOption*/ ctx[0]) && { "aria-checked": input_aria_checked_value },
				dirty & /*options, selectedOption*/ 3 && input_tabindex_value !== (input_tabindex_value = /*option*/ ctx[7].value == /*selectedOption*/ ctx[0]
				? 0
				: -1) && { tabindex: input_tabindex_value },
				dirty & /*$$restProps*/ 8 && /*$$restProps*/ ctx[3]
			]));

			if (dirty & /*selectedOption*/ 1) {
				input.checked = input.__value === /*selectedOption*/ ctx[0];
			}

			if (dirty & /*options*/ 2 && t1_value !== (t1_value = /*option*/ ctx[7].label + "")) set_data(t1, t1_value);

			if (dirty & /*options, selectedOption*/ 3) {
				toggle_class(span, "text-gray-900", /*option*/ ctx[7].value == /*selectedOption*/ ctx[0]);
			}

			if (/*option*/ ctx[7].helperText) {
				if (if_block) {
					if_block.p(ctx, dirty);
				} else {
					if_block = create_if_block$i(ctx);
					if_block.c();
					if_block.m(label, null);
				}
			} else if (if_block) {
				if_block.d(1);
				if_block = null;
			}

			if (dirty & /*options*/ 2 && label_for_value !== (label_for_value = /*option*/ ctx[7].name)) {
				attr(label, "for", label_for_value);
			}

			if (dirty & /*options*/ 2) {
				toggle_class(label, "disabled", /*option*/ ctx[7].disabled);
			}

			if (dirty & /*options, selectedOption*/ 3) {
				toggle_class(div1, "border-blue-500", /*option*/ ctx[7].value == /*selectedOption*/ ctx[0]);
			}

			if (dirty & /*options, selectedOption*/ 3) {
				toggle_class(div1, "z-10", /*option*/ ctx[7].value == /*selectedOption*/ ctx[0]);
			}
		},
		d(detaching) {
			if (detaching) detach(div1);
			/*$$binding_groups*/ ctx[6][0].splice(/*$$binding_groups*/ ctx[6][0].indexOf(input), 1);
			if (if_block) if_block.d();
			mounted = false;
			dispose();
		}
	};
}

function create_fragment$x(ctx) {
	let fieldset;
	let div;
	let each_value = /*options*/ ctx[1];
	let each_blocks = [];

	for (let i = 0; i < each_value.length; i += 1) {
		each_blocks[i] = create_each_block$6(get_each_context$6(ctx, each_value, i));
	}

	return {
		c() {
			fieldset = element("fieldset");
			div = element("div");

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].c();
			}

			this.h();
		},
		l(nodes) {
			fieldset = claim_element(nodes, "FIELDSET", { class: true, role: true });
			var fieldset_nodes = children(fieldset);
			div = claim_element(fieldset_nodes, "DIV", { class: true });
			var div_nodes = children(div);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].l(div_nodes);
			}

			div_nodes.forEach(detach);
			fieldset_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", "bg-white rounded-md -space-y-px");
			attr(fieldset, "class", "inline-block");
			attr(fieldset, "role", "radiogroup");
			toggle_class(fieldset, "w-full", /*full*/ ctx[2]);
		},
		m(target, anchor) {
			insert_hydration(target, fieldset, anchor);
			append_hydration(fieldset, div);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].m(div, null);
			}
		},
		p(ctx, [dirty]) {
			if (dirty & /*options, selectedOption, $$restProps*/ 11) {
				each_value = /*options*/ ctx[1];
				let i;

				for (i = 0; i < each_value.length; i += 1) {
					const child_ctx = get_each_context$6(ctx, each_value, i);

					if (each_blocks[i]) {
						each_blocks[i].p(child_ctx, dirty);
					} else {
						each_blocks[i] = create_each_block$6(child_ctx);
						each_blocks[i].c();
						each_blocks[i].m(div, null);
					}
				}

				for (; i < each_blocks.length; i += 1) {
					each_blocks[i].d(1);
				}

				each_blocks.length = each_value.length;
			}

			if (dirty & /*full*/ 4) {
				toggle_class(fieldset, "w-full", /*full*/ ctx[2]);
			}
		},
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(fieldset);
			destroy_each(each_blocks, detaching);
		}
	};
}

function instance$x($$self, $$props, $$invalidate) {
	const omit_props_names = ["options","startIndex","selectedOption","full"];
	let $$restProps = compute_rest_props($$props, omit_props_names);
	let { options = [] } = $$props;
	let { startIndex = 0 } = $$props;

	let { selectedOption = startIndex
	? options[startIndex].value
	: options[0].value } = $$props;

	let { full = true } = $$props;
	const $$binding_groups = [[]];

	function input_change_handler() {
		selectedOption = this.__value;
		$$invalidate(0, selectedOption);
	}

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(3, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('options' in $$new_props) $$invalidate(1, options = $$new_props.options);
		if ('startIndex' in $$new_props) $$invalidate(4, startIndex = $$new_props.startIndex);
		if ('selectedOption' in $$new_props) $$invalidate(0, selectedOption = $$new_props.selectedOption);
		if ('full' in $$new_props) $$invalidate(2, full = $$new_props.full);
	};

	return [
		selectedOption,
		options,
		full,
		$$restProps,
		startIndex,
		input_change_handler,
		$$binding_groups
	];
}

class RadioGroup extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$x, create_fragment$x, safe_not_equal, {
			options: 1,
			startIndex: 4,
			selectedOption: 0,
			full: 2
		});
	}
}

/* src\Inputs\Select.svelte generated by Svelte v3.48.0 */

function get_each_context$5(ctx, list, i) {
	const child_ctx = ctx.slice();
	child_ctx[12] = list[i];
	child_ctx[14] = i;
	return child_ctx;
}

// (58:2) {#if label}
function create_if_block_1$8(ctx) {
	let label_1;
	let t;

	return {
		c() {
			label_1 = element("label");
			t = text(/*label*/ ctx[5]);
			this.h();
		},
		l(nodes) {
			label_1 = claim_element(nodes, "LABEL", { for: true, class: true });
			var label_1_nodes = children(label_1);
			t = claim_text(label_1_nodes, /*label*/ ctx[5]);
			label_1_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(label_1, "for", /*name*/ ctx[3]);
			attr(label_1, "class", "block text-sm font-medium text-gray-700");
		},
		m(target, anchor) {
			insert_hydration(target, label_1, anchor);
			append_hydration(label_1, t);
		},
		p(ctx, dirty) {
			if (dirty & /*label*/ 32) set_data(t, /*label*/ ctx[5]);

			if (dirty & /*name*/ 8) {
				attr(label_1, "for", /*name*/ ctx[3]);
			}
		},
		d(detaching) {
			if (detaching) detach(label_1);
		}
	};
}

// (76:4) {#if placeholder}
function create_if_block$h(ctx) {
	let option;
	let t;

	return {
		c() {
			option = element("option");
			t = text(/*placeholder*/ ctx[4]);
			this.h();
		},
		l(nodes) {
			option = claim_element(nodes, "OPTION", { class: true });
			var option_nodes = children(option);
			t = claim_text(option_nodes, /*placeholder*/ ctx[4]);
			option_nodes.forEach(detach);
			this.h();
		},
		h() {
			option.__value = "";
			option.value = option.__value;
			attr(option, "class", "text-gray-400");
		},
		m(target, anchor) {
			insert_hydration(target, option, anchor);
			append_hydration(option, t);
		},
		p(ctx, dirty) {
			if (dirty & /*placeholder*/ 16) set_data(t, /*placeholder*/ ctx[4]);
		},
		d(detaching) {
			if (detaching) detach(option);
		}
	};
}

// (79:4) {#each options as opt, i}
function create_each_block$5(ctx) {
	let option;
	let t_value = /*opt*/ ctx[12].label + "";
	let t;
	let option_value_value;
	let option_selected_value;

	return {
		c() {
			option = element("option");
			t = text(t_value);
			this.h();
		},
		l(nodes) {
			option = claim_element(nodes, "OPTION", { class: true });
			var option_nodes = children(option);
			t = claim_text(option_nodes, t_value);
			option_nodes.forEach(detach);
			this.h();
		},
		h() {
			option.__value = option_value_value = /*opt*/ ctx[12].value;
			option.value = option.__value;
			option.selected = option_selected_value = /*i*/ ctx[14] === /*selectedOption*/ ctx[2];
			attr(option, "class", "text-gray-900");
		},
		m(target, anchor) {
			insert_hydration(target, option, anchor);
			append_hydration(option, t);
		},
		p(ctx, dirty) {
			if (dirty & /*options*/ 2 && t_value !== (t_value = /*opt*/ ctx[12].label + "")) set_data(t, t_value);

			if (dirty & /*options*/ 2 && option_value_value !== (option_value_value = /*opt*/ ctx[12].value)) {
				option.__value = option_value_value;
				option.value = option.__value;
			}

			if (dirty & /*selectedOption*/ 4 && option_selected_value !== (option_selected_value = /*i*/ ctx[14] === /*selectedOption*/ ctx[2])) {
				option.selected = option_selected_value;
			}
		},
		d(detaching) {
			if (detaching) detach(option);
		}
	};
}

function create_fragment$w(ctx) {
	let div;
	let t;
	let select;
	let if_block1_anchor;
	let useActions_action;
	let mounted;
	let dispose;
	let if_block0 = /*label*/ ctx[5] && create_if_block_1$8(ctx);
	let if_block1 = /*placeholder*/ ctx[4] && create_if_block$h(ctx);
	let each_value = /*options*/ ctx[1];
	let each_blocks = [];

	for (let i = 0; i < each_value.length; i += 1) {
		each_blocks[i] = create_each_block$5(get_each_context$5(ctx, each_value, i));
	}

	let select_levels = [
		{ id: /*name*/ ctx[3] },
		{ name: /*name*/ ctx[3] },
		{
			class: "cursor-pointer mt-1 block pl-3 pr-10 py-2 text-base rounded-md border-gray-300 hover:border-blue-200 focus:outline-none focus:ring-1 focus:ring-blue-200 sm:text-sm"
		},
		/*$$restProps*/ ctx[9]
	];

	let select_data = {};

	for (let i = 0; i < select_levels.length; i += 1) {
		select_data = assign(select_data, select_levels[i]);
	}

	return {
		c() {
			div = element("div");
			if (if_block0) if_block0.c();
			t = space();
			select = element("select");
			if (if_block1) if_block1.c();
			if_block1_anchor = empty();

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].c();
			}

			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", {});
			var div_nodes = children(div);
			if (if_block0) if_block0.l(div_nodes);
			t = claim_space(div_nodes);
			select = claim_element(div_nodes, "SELECT", { id: true, name: true, class: true });
			var select_nodes = children(select);
			if (if_block1) if_block1.l(select_nodes);
			if_block1_anchor = empty();

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].l(select_nodes);
			}

			select_nodes.forEach(detach);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(select, select_data);
			if (/*value*/ ctx[0] === void 0) add_render_callback(() => /*select_change_handler*/ ctx[11].call(select));
			toggle_class(select, "w-full", /*full*/ ctx[6]);
			toggle_class(select, "invalid", /*hasError*/ ctx[7]);
			toggle_class(select, "text-gray-400", !/*value*/ ctx[0]);
			toggle_class(select, "svelte-1a9qnpq", true);
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			if (if_block0) if_block0.m(div, null);
			append_hydration(div, t);
			append_hydration(div, select);
			if (if_block1) if_block1.m(select, null);
			append_hydration(select, if_block1_anchor);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].m(select, null);
			}

			(select_data.multiple ? select_options : select_option)(select, select_data.value);
			if (select.autofocus) select.focus();
			select_option(select, /*value*/ ctx[0]);

			if (!mounted) {
				dispose = [
					listen(select, "change", /*change_handler*/ ctx[10]),
					listen(select, "change", /*select_change_handler*/ ctx[11]),
					action_destroyer(useActions_action = dist.useActions.call(null, select, /*use*/ ctx[8]))
				];

				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (/*label*/ ctx[5]) {
				if (if_block0) {
					if_block0.p(ctx, dirty);
				} else {
					if_block0 = create_if_block_1$8(ctx);
					if_block0.c();
					if_block0.m(div, t);
				}
			} else if (if_block0) {
				if_block0.d(1);
				if_block0 = null;
			}

			if (/*placeholder*/ ctx[4]) {
				if (if_block1) {
					if_block1.p(ctx, dirty);
				} else {
					if_block1 = create_if_block$h(ctx);
					if_block1.c();
					if_block1.m(select, if_block1_anchor);
				}
			} else if (if_block1) {
				if_block1.d(1);
				if_block1 = null;
			}

			if (dirty & /*options, selectedOption*/ 6) {
				each_value = /*options*/ ctx[1];
				let i;

				for (i = 0; i < each_value.length; i += 1) {
					const child_ctx = get_each_context$5(ctx, each_value, i);

					if (each_blocks[i]) {
						each_blocks[i].p(child_ctx, dirty);
					} else {
						each_blocks[i] = create_each_block$5(child_ctx);
						each_blocks[i].c();
						each_blocks[i].m(select, null);
					}
				}

				for (; i < each_blocks.length; i += 1) {
					each_blocks[i].d(1);
				}

				each_blocks.length = each_value.length;
			}

			set_attributes(select, select_data = get_spread_update(select_levels, [
				dirty & /*name*/ 8 && { id: /*name*/ ctx[3] },
				dirty & /*name*/ 8 && { name: /*name*/ ctx[3] },
				{
					class: "cursor-pointer mt-1 block pl-3 pr-10 py-2 text-base rounded-md border-gray-300 hover:border-blue-200 focus:outline-none focus:ring-1 focus:ring-blue-200 sm:text-sm"
				},
				dirty & /*$$restProps*/ 512 && /*$$restProps*/ ctx[9]
			]));

			if (dirty & /*name, $$restProps*/ 520 && 'value' in select_data) (select_data.multiple ? select_options : select_option)(select, select_data.value);

			if (dirty & /*value, options*/ 3) {
				select_option(select, /*value*/ ctx[0]);
			}

			if (useActions_action && is_function(useActions_action.update) && dirty & /*use*/ 256) useActions_action.update.call(null, /*use*/ ctx[8]);
			toggle_class(select, "w-full", /*full*/ ctx[6]);
			toggle_class(select, "invalid", /*hasError*/ ctx[7]);
			toggle_class(select, "text-gray-400", !/*value*/ ctx[0]);
			toggle_class(select, "svelte-1a9qnpq", true);
		},
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(div);
			if (if_block0) if_block0.d();
			if (if_block1) if_block1.d();
			destroy_each(each_blocks, detaching);
			mounted = false;
			run_all(dispose);
		}
	};
}

function instance$w($$self, $$props, $$invalidate) {
	const omit_props_names = [
		"options","selectedOption","value","name","placeholder","label","full","hasError","use"
	];

	let $$restProps = compute_rest_props($$props, omit_props_names);
	let { options } = $$props;
	let { selectedOption = null } = $$props;
	let { value = selectedOption ? options[selectedOption].value : "" } = $$props;
	let { name } = $$props;
	let { placeholder = "" } = $$props;
	let { label = "" } = $$props;
	let { full = false } = $$props;
	let { hasError = false } = $$props;
	let { use } = $$props;

	function change_handler(event) {
		bubble.call(this, $$self, event);
	}

	function select_change_handler() {
		value = select_value(this);
		$$invalidate(0, value);
		$$invalidate(1, options);
	}

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(9, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('options' in $$new_props) $$invalidate(1, options = $$new_props.options);
		if ('selectedOption' in $$new_props) $$invalidate(2, selectedOption = $$new_props.selectedOption);
		if ('value' in $$new_props) $$invalidate(0, value = $$new_props.value);
		if ('name' in $$new_props) $$invalidate(3, name = $$new_props.name);
		if ('placeholder' in $$new_props) $$invalidate(4, placeholder = $$new_props.placeholder);
		if ('label' in $$new_props) $$invalidate(5, label = $$new_props.label);
		if ('full' in $$new_props) $$invalidate(6, full = $$new_props.full);
		if ('hasError' in $$new_props) $$invalidate(7, hasError = $$new_props.hasError);
		if ('use' in $$new_props) $$invalidate(8, use = $$new_props.use);
	};

	return [
		value,
		options,
		selectedOption,
		name,
		placeholder,
		label,
		full,
		hasError,
		use,
		$$restProps,
		change_handler,
		select_change_handler
	];
}

class Select extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$w, create_fragment$w, safe_not_equal, {
			options: 1,
			selectedOption: 2,
			value: 0,
			name: 3,
			placeholder: 4,
			label: 5,
			full: 6,
			hasError: 7,
			use: 8
		});
	}
}

/* src\Inputs\SelectGrouped.svelte generated by Svelte v3.48.0 */

function get_each_context$4(ctx, list, i) {
	const child_ctx = ctx.slice();
	child_ctx[12] = list[i];
	return child_ctx;
}

function get_each_context_1(ctx, list, i) {
	const child_ctx = ctx.slice();
	child_ctx[15] = list[i];
	child_ctx[17] = i;
	return child_ctx;
}

// (60:2) {#if label}
function create_if_block_2$7(ctx) {
	let label_1;
	let t;

	return {
		c() {
			label_1 = element("label");
			t = text(/*label*/ ctx[5]);
			this.h();
		},
		l(nodes) {
			label_1 = claim_element(nodes, "LABEL", { for: true, class: true });
			var label_1_nodes = children(label_1);
			t = claim_text(label_1_nodes, /*label*/ ctx[5]);
			label_1_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(label_1, "for", /*name*/ ctx[3]);
			attr(label_1, "class", "block text-sm font-medium text-gray-700");
		},
		m(target, anchor) {
			insert_hydration(target, label_1, anchor);
			append_hydration(label_1, t);
		},
		p(ctx, dirty) {
			if (dirty & /*label*/ 32) set_data(t, /*label*/ ctx[5]);

			if (dirty & /*name*/ 8) {
				attr(label_1, "for", /*name*/ ctx[3]);
			}
		},
		d(detaching) {
			if (detaching) detach(label_1);
		}
	};
}

// (77:4) {#if placeholder}
function create_if_block_1$7(ctx) {
	let option;
	let t;

	return {
		c() {
			option = element("option");
			t = text(/*placeholder*/ ctx[4]);
			this.h();
		},
		l(nodes) {
			option = claim_element(nodes, "OPTION", { class: true });
			var option_nodes = children(option);
			t = claim_text(option_nodes, /*placeholder*/ ctx[4]);
			option_nodes.forEach(detach);
			this.h();
		},
		h() {
			option.__value = "";
			option.value = option.__value;
			attr(option, "class", "text-gray-400");
		},
		m(target, anchor) {
			insert_hydration(target, option, anchor);
			append_hydration(option, t);
		},
		p(ctx, dirty) {
			if (dirty & /*placeholder*/ 16) set_data(t, /*placeholder*/ ctx[4]);
		},
		d(detaching) {
			if (detaching) detach(option);
		}
	};
}

// (83:8) {#each group.options as option, i}
function create_each_block_1(ctx) {
	let option;
	let t0_value = /*option*/ ctx[15].label + "";
	let t0;
	let t1;
	let option_value_value;
	let option_selected_value;

	return {
		c() {
			option = element("option");
			t0 = text(t0_value);
			t1 = space();
			this.h();
		},
		l(nodes) {
			option = claim_element(nodes, "OPTION", { class: true });
			var option_nodes = children(option);
			t0 = claim_text(option_nodes, t0_value);
			t1 = claim_space(option_nodes);
			option_nodes.forEach(detach);
			this.h();
		},
		h() {
			option.__value = option_value_value = /*option*/ ctx[15].value;
			option.value = option.__value;
			option.selected = option_selected_value = /*i*/ ctx[17] === /*selectedOption*/ ctx[2];
			attr(option, "class", "text-gray-900");
		},
		m(target, anchor) {
			insert_hydration(target, option, anchor);
			append_hydration(option, t0);
			append_hydration(option, t1);
		},
		p(ctx, dirty) {
			if (dirty & /*optionGroup*/ 2 && t0_value !== (t0_value = /*option*/ ctx[15].label + "")) set_data(t0, t0_value);

			if (dirty & /*optionGroup*/ 2 && option_value_value !== (option_value_value = /*option*/ ctx[15].value)) {
				option.__value = option_value_value;
				option.value = option.__value;
			}

			if (dirty & /*selectedOption*/ 4 && option_selected_value !== (option_selected_value = /*i*/ ctx[17] === /*selectedOption*/ ctx[2])) {
				option.selected = option_selected_value;
			}
		},
		d(detaching) {
			if (detaching) detach(option);
		}
	};
}

// (81:4) {#each optionGroup as group}
function create_each_block$4(ctx) {
	let optgroup;
	let optgroup_label_value;
	let each_value_1 = /*group*/ ctx[12].options;
	let each_blocks = [];

	for (let i = 0; i < each_value_1.length; i += 1) {
		each_blocks[i] = create_each_block_1(get_each_context_1(ctx, each_value_1, i));
	}

	return {
		c() {
			optgroup = element("optgroup");

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].c();
			}

			this.h();
		},
		l(nodes) {
			optgroup = claim_element(nodes, "OPTGROUP", { label: true, class: true });
			var optgroup_nodes = children(optgroup);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].l(optgroup_nodes);
			}

			optgroup_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(optgroup, "label", optgroup_label_value = /*group*/ ctx[12].name);
			attr(optgroup, "class", "text-gray-400");
		},
		m(target, anchor) {
			insert_hydration(target, optgroup, anchor);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].m(optgroup, null);
			}
		},
		p(ctx, dirty) {
			if (dirty & /*optionGroup, selectedOption*/ 6) {
				each_value_1 = /*group*/ ctx[12].options;
				let i;

				for (i = 0; i < each_value_1.length; i += 1) {
					const child_ctx = get_each_context_1(ctx, each_value_1, i);

					if (each_blocks[i]) {
						each_blocks[i].p(child_ctx, dirty);
					} else {
						each_blocks[i] = create_each_block_1(child_ctx);
						each_blocks[i].c();
						each_blocks[i].m(optgroup, null);
					}
				}

				for (; i < each_blocks.length; i += 1) {
					each_blocks[i].d(1);
				}

				each_blocks.length = each_value_1.length;
			}

			if (dirty & /*optionGroup*/ 2 && optgroup_label_value !== (optgroup_label_value = /*group*/ ctx[12].name)) {
				attr(optgroup, "label", optgroup_label_value);
			}
		},
		d(detaching) {
			if (detaching) detach(optgroup);
			destroy_each(each_blocks, detaching);
		}
	};
}

// (96:2) {#if hasError}
function create_if_block$g(ctx) {
	let p;
	let t;
	let p_id_value;

	return {
		c() {
			p = element("p");
			t = text(/*errorMessage*/ ctx[8]);
			this.h();
		},
		l(nodes) {
			p = claim_element(nodes, "P", { class: true, id: true });
			var p_nodes = children(p);
			t = claim_text(p_nodes, /*errorMessage*/ ctx[8]);
			p_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(p, "class", "mt-1 text-sm text-red-600");
			attr(p, "id", p_id_value = "" + (/*name*/ ctx[3] + "-error"));
		},
		m(target, anchor) {
			insert_hydration(target, p, anchor);
			append_hydration(p, t);
		},
		p(ctx, dirty) {
			if (dirty & /*errorMessage*/ 256) set_data(t, /*errorMessage*/ ctx[8]);

			if (dirty & /*name*/ 8 && p_id_value !== (p_id_value = "" + (/*name*/ ctx[3] + "-error"))) {
				attr(p, "id", p_id_value);
			}
		},
		d(detaching) {
			if (detaching) detach(p);
		}
	};
}

function create_fragment$v(ctx) {
	let div;
	let t0;
	let select;
	let if_block1_anchor;
	let t1;
	let mounted;
	let dispose;
	let if_block0 = /*label*/ ctx[5] && create_if_block_2$7(ctx);
	let if_block1 = /*placeholder*/ ctx[4] && create_if_block_1$7(ctx);
	let each_value = /*optionGroup*/ ctx[1];
	let each_blocks = [];

	for (let i = 0; i < each_value.length; i += 1) {
		each_blocks[i] = create_each_block$4(get_each_context$4(ctx, each_value, i));
	}

	let select_levels = [
		{ id: /*name*/ ctx[3] },
		{ name: /*name*/ ctx[3] },
		{
			class: "cursor-pointer mt-1 block pl-3 pr-10 py-2 text-base rounded-md border-gray-300 hover:border-blue-200 focus:outline-none focus:ring-1 focus:ring-blue-200 sm:text-sm"
		},
		/*$$restProps*/ ctx[9]
	];

	let select_data = {};

	for (let i = 0; i < select_levels.length; i += 1) {
		select_data = assign(select_data, select_levels[i]);
	}

	let if_block2 = /*hasError*/ ctx[7] && create_if_block$g(ctx);

	return {
		c() {
			div = element("div");
			if (if_block0) if_block0.c();
			t0 = space();
			select = element("select");
			if (if_block1) if_block1.c();
			if_block1_anchor = empty();

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].c();
			}

			t1 = space();
			if (if_block2) if_block2.c();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", {});
			var div_nodes = children(div);
			if (if_block0) if_block0.l(div_nodes);
			t0 = claim_space(div_nodes);
			select = claim_element(div_nodes, "SELECT", { id: true, name: true, class: true });
			var select_nodes = children(select);
			if (if_block1) if_block1.l(select_nodes);
			if_block1_anchor = empty();

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].l(select_nodes);
			}

			select_nodes.forEach(detach);
			t1 = claim_space(div_nodes);
			if (if_block2) if_block2.l(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(select, select_data);
			if (/*value*/ ctx[0] === void 0) add_render_callback(() => /*select_change_handler*/ ctx[11].call(select));
			toggle_class(select, "w-full", /*full*/ ctx[6]);
			toggle_class(select, "invalid", /*hasError*/ ctx[7]);
			toggle_class(select, "text-gray-400", !/*value*/ ctx[0]);
			toggle_class(select, "svelte-1a9qnpq", true);
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			if (if_block0) if_block0.m(div, null);
			append_hydration(div, t0);
			append_hydration(div, select);
			if (if_block1) if_block1.m(select, null);
			append_hydration(select, if_block1_anchor);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].m(select, null);
			}

			(select_data.multiple ? select_options : select_option)(select, select_data.value);
			if (select.autofocus) select.focus();
			select_option(select, /*value*/ ctx[0]);
			append_hydration(div, t1);
			if (if_block2) if_block2.m(div, null);

			if (!mounted) {
				dispose = [
					listen(select, "change", /*change_handler*/ ctx[10]),
					listen(select, "change", /*select_change_handler*/ ctx[11])
				];

				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (/*label*/ ctx[5]) {
				if (if_block0) {
					if_block0.p(ctx, dirty);
				} else {
					if_block0 = create_if_block_2$7(ctx);
					if_block0.c();
					if_block0.m(div, t0);
				}
			} else if (if_block0) {
				if_block0.d(1);
				if_block0 = null;
			}

			if (/*placeholder*/ ctx[4]) {
				if (if_block1) {
					if_block1.p(ctx, dirty);
				} else {
					if_block1 = create_if_block_1$7(ctx);
					if_block1.c();
					if_block1.m(select, if_block1_anchor);
				}
			} else if (if_block1) {
				if_block1.d(1);
				if_block1 = null;
			}

			if (dirty & /*optionGroup, selectedOption*/ 6) {
				each_value = /*optionGroup*/ ctx[1];
				let i;

				for (i = 0; i < each_value.length; i += 1) {
					const child_ctx = get_each_context$4(ctx, each_value, i);

					if (each_blocks[i]) {
						each_blocks[i].p(child_ctx, dirty);
					} else {
						each_blocks[i] = create_each_block$4(child_ctx);
						each_blocks[i].c();
						each_blocks[i].m(select, null);
					}
				}

				for (; i < each_blocks.length; i += 1) {
					each_blocks[i].d(1);
				}

				each_blocks.length = each_value.length;
			}

			set_attributes(select, select_data = get_spread_update(select_levels, [
				dirty & /*name*/ 8 && { id: /*name*/ ctx[3] },
				dirty & /*name*/ 8 && { name: /*name*/ ctx[3] },
				{
					class: "cursor-pointer mt-1 block pl-3 pr-10 py-2 text-base rounded-md border-gray-300 hover:border-blue-200 focus:outline-none focus:ring-1 focus:ring-blue-200 sm:text-sm"
				},
				dirty & /*$$restProps*/ 512 && /*$$restProps*/ ctx[9]
			]));

			if (dirty & /*name, $$restProps*/ 520 && 'value' in select_data) (select_data.multiple ? select_options : select_option)(select, select_data.value);

			if (dirty & /*value, optionGroup*/ 3) {
				select_option(select, /*value*/ ctx[0]);
			}

			toggle_class(select, "w-full", /*full*/ ctx[6]);
			toggle_class(select, "invalid", /*hasError*/ ctx[7]);
			toggle_class(select, "text-gray-400", !/*value*/ ctx[0]);
			toggle_class(select, "svelte-1a9qnpq", true);

			if (/*hasError*/ ctx[7]) {
				if (if_block2) {
					if_block2.p(ctx, dirty);
				} else {
					if_block2 = create_if_block$g(ctx);
					if_block2.c();
					if_block2.m(div, null);
				}
			} else if (if_block2) {
				if_block2.d(1);
				if_block2 = null;
			}
		},
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(div);
			if (if_block0) if_block0.d();
			if (if_block1) if_block1.d();
			destroy_each(each_blocks, detaching);
			if (if_block2) if_block2.d();
			mounted = false;
			run_all(dispose);
		}
	};
}

function instance$v($$self, $$props, $$invalidate) {
	const omit_props_names = [
		"optionGroup","selectedOption","value","name","placeholder","label","full","hasError","errorMessage"
	];

	let $$restProps = compute_rest_props($$props, omit_props_names);
	let { optionGroup } = $$props;
	let { selectedOption = null } = $$props;
	let { value = selectedOption ? options[selectedOption].value : "" } = $$props;
	let { name } = $$props;
	let { placeholder = "" } = $$props;
	let { label = "" } = $$props;
	let { full = false } = $$props;
	let { hasError = false } = $$props;
	let { errorMessage = "" } = $$props;

	function change_handler(event) {
		bubble.call(this, $$self, event);
	}

	function select_change_handler() {
		value = select_value(this);
		$$invalidate(0, value);
		$$invalidate(1, optionGroup);
	}

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(9, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('optionGroup' in $$new_props) $$invalidate(1, optionGroup = $$new_props.optionGroup);
		if ('selectedOption' in $$new_props) $$invalidate(2, selectedOption = $$new_props.selectedOption);
		if ('value' in $$new_props) $$invalidate(0, value = $$new_props.value);
		if ('name' in $$new_props) $$invalidate(3, name = $$new_props.name);
		if ('placeholder' in $$new_props) $$invalidate(4, placeholder = $$new_props.placeholder);
		if ('label' in $$new_props) $$invalidate(5, label = $$new_props.label);
		if ('full' in $$new_props) $$invalidate(6, full = $$new_props.full);
		if ('hasError' in $$new_props) $$invalidate(7, hasError = $$new_props.hasError);
		if ('errorMessage' in $$new_props) $$invalidate(8, errorMessage = $$new_props.errorMessage);
	};

	return [
		value,
		optionGroup,
		selectedOption,
		name,
		placeholder,
		label,
		full,
		hasError,
		errorMessage,
		$$restProps,
		change_handler,
		select_change_handler
	];
}

class SelectGrouped extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$v, create_fragment$v, safe_not_equal, {
			optionGroup: 1,
			selectedOption: 2,
			value: 0,
			name: 3,
			placeholder: 4,
			label: 5,
			full: 6,
			hasError: 7,
			errorMessage: 8
		});
	}
}

/* src\Inputs\SelectMenu.svelte generated by Svelte v3.48.0 */

function get_each_context$3(ctx, list, i) {
	const child_ctx = ctx.slice();
	child_ctx[18] = list[i];
	child_ctx[20] = i;
	return child_ctx;
}

// (120:4) {#if open}
function create_if_block$f(ctx) {
	let div;
	let ul;
	let div_transition;
	let current;
	let mounted;
	let dispose;
	let each_value = /*options*/ ctx[1];
	let each_blocks = [];

	for (let i = 0; i < each_value.length; i += 1) {
		each_blocks[i] = create_each_block$3(get_each_context$3(ctx, each_value, i));
	}

	return {
		c() {
			div = element("div");
			ul = element("ul");

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].c();
			}

			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			ul = claim_element(div_nodes, "UL", { tabindex: true, class: true });
			var ul_nodes = children(ul);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].l(ul_nodes);
			}

			ul_nodes.forEach(detach);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(ul, "tabindex", "-1");
			attr(ul, "class", "max-h-56 rounded-md py-1 text-base leading-6 shadow-xs overflow-auto sm:text-sm sm:leading-5 focus:outline-none");
			attr(div, "class", "absolute mt-1 rounded-md bg-white shadow-lg z-50");
			toggle_class(div, "w-full", /*full*/ ctx[2]);
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			append_hydration(div, ul);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].m(ul, null);
			}

			/*ul_binding*/ ctx[15](ul);
			current = true;

			if (!mounted) {
				dispose = listen(ul, "keydown", /*handleListKeyInputs*/ ctx[9]);
				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (dirty & /*select, handleSelected, selectedOption, options*/ 1059) {
				each_value = /*options*/ ctx[1];
				let i;

				for (i = 0; i < each_value.length; i += 1) {
					const child_ctx = get_each_context$3(ctx, each_value, i);

					if (each_blocks[i]) {
						each_blocks[i].p(child_ctx, dirty);
					} else {
						each_blocks[i] = create_each_block$3(child_ctx);
						each_blocks[i].c();
						each_blocks[i].m(ul, null);
					}
				}

				for (; i < each_blocks.length; i += 1) {
					each_blocks[i].d(1);
				}

				each_blocks.length = each_value.length;
			}

			if (dirty & /*full*/ 4) {
				toggle_class(div, "w-full", /*full*/ ctx[2]);
			}
		},
		i(local) {
			if (current) return;

			add_render_callback(() => {
				if (!div_transition) div_transition = create_bidirectional_transition(div, fade, { duration: 300 }, true);
				div_transition.run(1);
			});

			current = true;
		},
		o(local) {
			if (!div_transition) div_transition = create_bidirectional_transition(div, fade, { duration: 300 }, false);
			div_transition.run(0);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			destroy_each(each_blocks, detaching);
			/*ul_binding*/ ctx[15](null);
			if (detaching && div_transition) div_transition.end();
			mounted = false;
			dispose();
		}
	};
}

// (132:10) {#each options as opt, i}
function create_each_block$3(ctx) {
	let li;
	let div;
	let span0;
	let t0_value = /*opt*/ ctx[18].label + "";
	let t0;
	let t1;
	let span1;
	let svg;
	let path;
	let t2;
	let mounted;
	let dispose;

	function mouseenter_handler() {
		return /*mouseenter_handler*/ ctx[13](/*i*/ ctx[20]);
	}

	function click_handler_1() {
		return /*click_handler_1*/ ctx[14](/*i*/ ctx[20]);
	}

	return {
		c() {
			li = element("li");
			div = element("div");
			span0 = element("span");
			t0 = text(t0_value);
			t1 = space();
			span1 = element("span");
			svg = svg_element("svg");
			path = svg_element("path");
			t2 = space();
			this.h();
		},
		l(nodes) {
			li = claim_element(nodes, "LI", {
				"data-currentlyselected": true,
				class: true
			});

			var li_nodes = children(li);
			div = claim_element(li_nodes, "DIV", { class: true });
			var div_nodes = children(div);
			span0 = claim_element(div_nodes, "SPAN", { class: true });
			var span0_nodes = children(span0);
			t0 = claim_text(span0_nodes, t0_value);
			span0_nodes.forEach(detach);
			div_nodes.forEach(detach);
			t1 = claim_space(li_nodes);
			span1 = claim_element(li_nodes, "SPAN", { class: true });
			var span1_nodes = children(span1);
			svg = claim_svg_element(span1_nodes, "svg", { class: true, fill: true, viewBox: true });
			var svg_nodes = children(svg);

			path = claim_svg_element(svg_nodes, "path", {
				"fill-rule": true,
				d: true,
				"clip-rule": true
			});

			children(path).forEach(detach);
			svg_nodes.forEach(detach);
			span1_nodes.forEach(detach);
			t2 = claim_space(li_nodes);
			li_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(span0, "class", "font-normal block truncate");
			attr(div, "class", "flex items-center space-x-3");
			attr(path, "fill-rule", "evenodd");
			attr(path, "d", "M16.707 5.293a1 1 0 010 1.414l-8 8a1 1 0 01-1.414 0l-4-4a1 1 0 011.414-1.414L8 12.586l7.293-7.293a1 1 0 011.414 0z");
			attr(path, "clip-rule", "evenodd");
			attr(svg, "class", "h-5 w-5");
			attr(svg, "fill", "currentColor");
			attr(svg, "viewBox", "0 0 20 20");
			attr(span1, "class", "absolute inset-y-0 right-0 flex items-center pr-2 svelte-cujxyj");
			toggle_class(span1, "icon-color", /*select*/ ctx[5] != /*i*/ ctx[20]);
			toggle_class(span1, "hidden", /*selectedOption*/ ctx[0] != /*i*/ ctx[20]);
			attr(li, "data-currentlyselected", "true");
			attr(li, "class", "text-gray-900 cursor-default select-none relative py-2 pl-4 pr-9 svelte-cujxyj");
			toggle_class(li, "highlight", /*select*/ ctx[5] == /*i*/ ctx[20]);
		},
		m(target, anchor) {
			insert_hydration(target, li, anchor);
			append_hydration(li, div);
			append_hydration(div, span0);
			append_hydration(span0, t0);
			append_hydration(li, t1);
			append_hydration(li, span1);
			append_hydration(span1, svg);
			append_hydration(svg, path);
			append_hydration(li, t2);

			if (!mounted) {
				dispose = [
					listen(li, "mouseenter", mouseenter_handler),
					listen(li, "click", click_handler_1)
				];

				mounted = true;
			}
		},
		p(new_ctx, dirty) {
			ctx = new_ctx;
			if (dirty & /*options*/ 2 && t0_value !== (t0_value = /*opt*/ ctx[18].label + "")) set_data(t0, t0_value);

			if (dirty & /*select*/ 32) {
				toggle_class(span1, "icon-color", /*select*/ ctx[5] != /*i*/ ctx[20]);
			}

			if (dirty & /*selectedOption*/ 1) {
				toggle_class(span1, "hidden", /*selectedOption*/ ctx[0] != /*i*/ ctx[20]);
			}

			if (dirty & /*select*/ 32) {
				toggle_class(li, "highlight", /*select*/ ctx[5] == /*i*/ ctx[20]);
			}
		},
		d(detaching) {
			if (detaching) detach(li);
			mounted = false;
			run_all(dispose);
		}
	};
}

function create_fragment$u(ctx) {
	let div2;
	let label_1;
	let t0;
	let t1;
	let div1;
	let span2;
	let button_1;
	let div0;
	let span0;
	let t2_value = /*options*/ ctx[1][/*selectedOption*/ ctx[0]].label + "";
	let t2;
	let t3;
	let span1;
	let svg;
	let path;
	let t4;
	let clickOutside_action;
	let current;
	let mounted;
	let dispose;
	let if_block = /*open*/ ctx[4] && create_if_block$f(ctx);

	return {
		c() {
			div2 = element("div");
			label_1 = element("label");
			t0 = text(/*label*/ ctx[3]);
			t1 = space();
			div1 = element("div");
			span2 = element("span");
			button_1 = element("button");
			div0 = element("div");
			span0 = element("span");
			t2 = text(t2_value);
			t3 = space();
			span1 = element("span");
			svg = svg_element("svg");
			path = svg_element("path");
			t4 = space();
			if (if_block) if_block.c();
			this.h();
		},
		l(nodes) {
			div2 = claim_element(nodes, "DIV", {});
			var div2_nodes = children(div2);
			label_1 = claim_element(div2_nodes, "LABEL", { for: true, class: true });
			var label_1_nodes = children(label_1);
			t0 = claim_text(label_1_nodes, /*label*/ ctx[3]);
			label_1_nodes.forEach(detach);
			t1 = claim_space(div2_nodes);
			div1 = claim_element(div2_nodes, "DIV", { class: true });
			var div1_nodes = children(div1);
			span2 = claim_element(div1_nodes, "SPAN", { class: true });
			var span2_nodes = children(span2);
			button_1 = claim_element(span2_nodes, "BUTTON", { class: true });
			var button_1_nodes = children(button_1);
			div0 = claim_element(button_1_nodes, "DIV", { class: true });
			var div0_nodes = children(div0);
			span0 = claim_element(div0_nodes, "SPAN", { class: true });
			var span0_nodes = children(span0);
			t2 = claim_text(span0_nodes, t2_value);
			span0_nodes.forEach(detach);
			div0_nodes.forEach(detach);
			t3 = claim_space(button_1_nodes);
			span1 = claim_element(button_1_nodes, "SPAN", { class: true });
			var span1_nodes = children(span1);
			svg = claim_svg_element(span1_nodes, "svg", { class: true, fill: true, viewBox: true });
			var svg_nodes = children(svg);

			path = claim_svg_element(svg_nodes, "path", {
				d: true,
				"clip-rule": true,
				"fill-rule": true
			});

			children(path).forEach(detach);
			svg_nodes.forEach(detach);
			span1_nodes.forEach(detach);
			button_1_nodes.forEach(detach);
			span2_nodes.forEach(detach);
			t4 = claim_space(div1_nodes);
			if (if_block) if_block.l(div1_nodes);
			div1_nodes.forEach(detach);
			div2_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(label_1, "for", "assigned-to-label");
			attr(label_1, "class", "block text-sm leading-5 font-medium text-gray-700");
			attr(span0, "class", "block truncate");
			attr(div0, "class", "flex items-center space-x-3");
			attr(path, "d", "M10 3a1 1 0 01.707.293l3 3a1 1 0 01-1.414 1.414L10 5.414 7.707 7.707a1 1 0 01-1.414-1.414l3-3A1 1 0 0110 3zm-3.707 9.293a1 1 0 011.414 0L10 14.586l2.293-2.293a1 1 0 011.414 1.414l-3 3a1 1 0 01-1.414 0l-3-3a1 1 0 010-1.414z");
			attr(path, "clip-rule", "evenodd");
			attr(path, "fill-rule", "evenodd");
			attr(svg, "class", "h-5 w-5 text-gray-400");
			attr(svg, "fill", "currentColor");
			attr(svg, "viewBox", "0 0 20 20");
			attr(span1, "class", "absolute inset-y-0 right-0 flex items-center pr-2 pointer-events-none");
			attr(button_1, "class", "cursor-default relative w-full rounded-md border border-gray-300 bg-white pl-3 pr-10 py-2 text-left focus:outline-none focus:ring-2 focus:ring-blue-100 transition ease-in-out duration-150 sm:text-sm sm:leading-5");
			attr(span2, "class", "inline-block rounded-md shadow-sm");
			toggle_class(span2, "w-full", /*full*/ ctx[2]);
			attr(div1, "class", "relative");
		},
		m(target, anchor) {
			insert_hydration(target, div2, anchor);
			append_hydration(div2, label_1);
			append_hydration(label_1, t0);
			append_hydration(div2, t1);
			append_hydration(div2, div1);
			append_hydration(div1, span2);
			append_hydration(span2, button_1);
			append_hydration(button_1, div0);
			append_hydration(div0, span0);
			append_hydration(span0, t2);
			append_hydration(button_1, t3);
			append_hydration(button_1, span1);
			append_hydration(span1, svg);
			append_hydration(svg, path);
			/*button_1_binding*/ ctx[11](button_1);
			append_hydration(div1, t4);
			if (if_block) if_block.m(div1, null);
			current = true;

			if (!mounted) {
				dispose = [
					listen(button_1, "click", /*click_handler*/ ctx[12]),
					action_destroyer(clickOutside_action = clickOutside.call(null, div1, /*clickOutside_function*/ ctx[16]))
				];

				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (!current || dirty & /*label*/ 8) set_data(t0, /*label*/ ctx[3]);
			if ((!current || dirty & /*options, selectedOption*/ 3) && t2_value !== (t2_value = /*options*/ ctx[1][/*selectedOption*/ ctx[0]].label + "")) set_data(t2, t2_value);

			if (dirty & /*full*/ 4) {
				toggle_class(span2, "w-full", /*full*/ ctx[2]);
			}

			if (/*open*/ ctx[4]) {
				if (if_block) {
					if_block.p(ctx, dirty);

					if (dirty & /*open*/ 16) {
						transition_in(if_block, 1);
					}
				} else {
					if_block = create_if_block$f(ctx);
					if_block.c();
					transition_in(if_block, 1);
					if_block.m(div1, null);
				}
			} else if (if_block) {
				group_outros();

				transition_out(if_block, 1, 1, () => {
					if_block = null;
				});

				check_outros();
			}

			if (clickOutside_action && is_function(clickOutside_action.update) && dirty & /*open*/ 16) clickOutside_action.update.call(null, /*clickOutside_function*/ ctx[16]);
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div2);
			/*button_1_binding*/ ctx[11](null);
			if (if_block) if_block.d();
			mounted = false;
			run_all(dispose);
		}
	};
}

function instance$u($$self, $$props, $$invalidate) {
	let { options = [] } = $$props;
	let { selectedOption = 0 } = $$props;
	let { full = false } = $$props;
	let { label = "" } = $$props;
	let open = false;
	let select = selectedOption ? selectedOption : 0;
	let listBox = null;
	let button;

	const handleClick = async () => {
		$$invalidate(4, open = true);
		$$invalidate(5, select = selectedOption);
		await tick();
		listBox.focus();
		const selectedLi = listBox.children[selectedOption];
		$$invalidate(6, listBox.scrollTop = selectedLi.offsetTop - 10, listBox);
	};

	const handleListKeyInputs = e => {
		e.preventDefault();

		switch (e.key) {
			case "ArrowUp":
				if (select == 0) return;
				$$invalidate(5, select--, select);
				listBox.children[select].scrollIntoView({ block: "nearest", behavior: "smooth" });
				break;
			case "ArrowDown":
				if (select >= options.length - 1) return;
				listBox.children[select + 1].scrollIntoView({ block: "nearest", behavior: "smooth" });
				$$invalidate(5, select++, select);
				break;
			case "Enter":
				handleSelected(select);
				break;
			case " ":
				handleSelected(select);
				break;
			case "Escape":
				handleClose();
				break;
			case "Tab":
				e.preventDefault();
				break;
		}
	};

	const handleClose = () => {
		$$invalidate(4, open = false);
		button.focus();
	};

	const handleSelected = selected => {
		$$invalidate(0, selectedOption = selected);
		handleClose();
	};

	function button_1_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			button = $$value;
			$$invalidate(7, button);
		});
	}

	const click_handler = () => handleClick();
	const mouseenter_handler = i => $$invalidate(5, select = i);
	const click_handler_1 = i => handleSelected(i);

	function ul_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			listBox = $$value;
			$$invalidate(6, listBox);
		});
	}

	const clickOutside_function = () => $$invalidate(4, open = false);

	$$self.$$set = $$props => {
		if ('options' in $$props) $$invalidate(1, options = $$props.options);
		if ('selectedOption' in $$props) $$invalidate(0, selectedOption = $$props.selectedOption);
		if ('full' in $$props) $$invalidate(2, full = $$props.full);
		if ('label' in $$props) $$invalidate(3, label = $$props.label);
	};

	return [
		selectedOption,
		options,
		full,
		label,
		open,
		select,
		listBox,
		button,
		handleClick,
		handleListKeyInputs,
		handleSelected,
		button_1_binding,
		click_handler,
		mouseenter_handler,
		click_handler_1,
		ul_binding,
		clickOutside_function
	];
}

class SelectMenu extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$u, create_fragment$u, safe_not_equal, {
			options: 1,
			selectedOption: 0,
			full: 2,
			label: 3
		});
	}
}

/* src\Inputs\Switch.svelte generated by Svelte v3.48.0 */

const get_label_slot_changes_1 = dirty => ({});
const get_label_slot_context_1 = ctx => ({});
const get_label_slot_changes = dirty => ({});
const get_label_slot_context = ctx => ({});

// (30:2) {#if labelPostion == "right"}
function create_if_block_2$6(ctx) {
	let button;
	let span0;
	let t0;
	let span1;
	let span1_class_value;
	let t1;
	let span2;
	let t2;
	let if_block_anchor;
	let current;
	let mounted;
	let dispose;
	let if_block = /*$$slots*/ ctx[3].label && create_if_block_3$4(ctx);

	return {
		c() {
			button = element("button");
			span0 = element("span");
			t0 = space();
			span1 = element("span");
			t1 = space();
			span2 = element("span");
			t2 = space();
			if (if_block) if_block.c();
			if_block_anchor = empty();
			this.h();
		},
		l(nodes) {
			button = claim_element(nodes, "BUTTON", {
				type: true,
				class: true,
				role: true,
				"aria-checked": true
			});

			var button_nodes = children(button);
			span0 = claim_element(button_nodes, "SPAN", { "aria-hidden": true, class: true });
			children(span0).forEach(detach);
			t0 = claim_space(button_nodes);
			span1 = claim_element(button_nodes, "SPAN", { "aria-hidden": true, class: true });
			children(span1).forEach(detach);
			t1 = claim_space(button_nodes);

			span2 = claim_element(button_nodes, "SPAN", {
				"aria-hidden": true,
				class: true,
				style: true
			});

			children(span2).forEach(detach);
			button_nodes.forEach(detach);
			t2 = claim_space(nodes);
			if (if_block) if_block.l(nodes);
			if_block_anchor = empty();
			this.h();
		},
		h() {
			attr(span0, "aria-hidden", "true");
			attr(span0, "class", "pointer-events-none absolute w-full h-full rounded-md");
			attr(span1, "aria-hidden", "true");

			attr(span1, "class", span1_class_value = "pointer-events-none absolute h-4 w-9 mx-auto rounded-full transition-colors ease-in-out duration-200 " + (/*value*/ ctx[0] && !/*disabled*/ ctx[1]
			? 'bg-blue-500 group-hover:bg-blue-700'
			: '') + " " + (!/*value*/ ctx[0] && !/*disabled*/ ctx[1]
			? 'bg-gray-200 group-hover:bg-gray-400'
			: '') + " " + (/*disabled*/ ctx[1]
			? 'bg-blue-100 group-hover:bg-blue-100'
			: '') + "");

			attr(span2, "aria-hidden", "true");
			attr(span2, "class", "pointer-events-none absolute left-0 inline-block h-5 w-5 border border-gray-200 rounded-full bg-white shadow transform ring-0 transition-transform ease-in-out duration-200");
			set_style(span2, "--tw-translate-x", /*value*/ ctx[0] ? '1.25rem' : 0);
			attr(button, "type", "button");
			attr(button, "class", "flex-shrink-0 group relative rounded-full inline-flex items-center justify-center h-5 w-10 cursor-pointer focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-300 svelte-8oatug");
			attr(button, "role", "switch");
			attr(button, "aria-checked", /*value*/ ctx[0]);
			button.disabled = /*disabled*/ ctx[1];
		},
		m(target, anchor) {
			insert_hydration(target, button, anchor);
			append_hydration(button, span0);
			append_hydration(button, t0);
			append_hydration(button, span1);
			append_hydration(button, t1);
			append_hydration(button, span2);
			insert_hydration(target, t2, anchor);
			if (if_block) if_block.m(target, anchor);
			insert_hydration(target, if_block_anchor, anchor);
			current = true;

			if (!mounted) {
				dispose = [
					listen(button, "click", stop_propagation(/*click_handler_2*/ ctx[9])),
					listen(button, "click", stop_propagation(/*click_handler*/ ctx[8]))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (!current || dirty & /*value, disabled*/ 3 && span1_class_value !== (span1_class_value = "pointer-events-none absolute h-4 w-9 mx-auto rounded-full transition-colors ease-in-out duration-200 " + (/*value*/ ctx[0] && !/*disabled*/ ctx[1]
			? 'bg-blue-500 group-hover:bg-blue-700'
			: '') + " " + (!/*value*/ ctx[0] && !/*disabled*/ ctx[1]
			? 'bg-gray-200 group-hover:bg-gray-400'
			: '') + " " + (/*disabled*/ ctx[1]
			? 'bg-blue-100 group-hover:bg-blue-100'
			: '') + "")) {
				attr(span1, "class", span1_class_value);
			}

			if (!current || dirty & /*value*/ 1) {
				set_style(span2, "--tw-translate-x", /*value*/ ctx[0] ? '1.25rem' : 0);
			}

			if (!current || dirty & /*value*/ 1) {
				attr(button, "aria-checked", /*value*/ ctx[0]);
			}

			if (!current || dirty & /*disabled*/ 2) {
				button.disabled = /*disabled*/ ctx[1];
			}

			if (/*$$slots*/ ctx[3].label) {
				if (if_block) {
					if_block.p(ctx, dirty);

					if (dirty & /*$$slots*/ 8) {
						transition_in(if_block, 1);
					}
				} else {
					if_block = create_if_block_3$4(ctx);
					if_block.c();
					transition_in(if_block, 1);
					if_block.m(if_block_anchor.parentNode, if_block_anchor);
				}
			} else if (if_block) {
				group_outros();

				transition_out(if_block, 1, 1, () => {
					if_block = null;
				});

				check_outros();
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(button);
			if (detaching) detach(t2);
			if (if_block) if_block.d(detaching);
			if (detaching) detach(if_block_anchor);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (58:4) {#if $$slots.label}
function create_if_block_3$4(ctx) {
	let current;
	const label_slot_template = /*#slots*/ ctx[6].label;
	const label_slot = create_slot(label_slot_template, ctx, /*$$scope*/ ctx[5], get_label_slot_context);

	return {
		c() {
			if (label_slot) label_slot.c();
		},
		l(nodes) {
			if (label_slot) label_slot.l(nodes);
		},
		m(target, anchor) {
			if (label_slot) {
				label_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (label_slot) {
				if (label_slot.p && (!current || dirty & /*$$scope*/ 32)) {
					update_slot_base(
						label_slot,
						label_slot_template,
						ctx,
						/*$$scope*/ ctx[5],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[5])
						: get_slot_changes(label_slot_template, /*$$scope*/ ctx[5], dirty, get_label_slot_changes),
						get_label_slot_context
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(label_slot, local);
			current = true;
		},
		o(local) {
			transition_out(label_slot, local);
			current = false;
		},
		d(detaching) {
			if (label_slot) label_slot.d(detaching);
		}
	};
}

// (63:2) {#if labelPostion == "left"}
function create_if_block$e(ctx) {
	let t0;
	let button;
	let span0;
	let t1;
	let span1;
	let span1_class_value;
	let t2;
	let span2;
	let current;
	let mounted;
	let dispose;
	let if_block = /*$$slots*/ ctx[3].label && create_if_block_1$6(ctx);

	return {
		c() {
			if (if_block) if_block.c();
			t0 = space();
			button = element("button");
			span0 = element("span");
			t1 = space();
			span1 = element("span");
			t2 = space();
			span2 = element("span");
			this.h();
		},
		l(nodes) {
			if (if_block) if_block.l(nodes);
			t0 = claim_space(nodes);

			button = claim_element(nodes, "BUTTON", {
				type: true,
				class: true,
				role: true,
				"aria-checked": true
			});

			var button_nodes = children(button);
			span0 = claim_element(button_nodes, "SPAN", { "aria-hidden": true, class: true });
			children(span0).forEach(detach);
			t1 = claim_space(button_nodes);
			span1 = claim_element(button_nodes, "SPAN", { "aria-hidden": true, class: true });
			children(span1).forEach(detach);
			t2 = claim_space(button_nodes);

			span2 = claim_element(button_nodes, "SPAN", {
				"aria-hidden": true,
				class: true,
				style: true
			});

			children(span2).forEach(detach);
			button_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(span0, "aria-hidden", "true");
			attr(span0, "class", "pointer-events-none absolute w-full h-full rounded-md");
			attr(span1, "aria-hidden", "true");

			attr(span1, "class", span1_class_value = "pointer-events-none absolute h-4 w-9 mx-auto rounded-full transition-colors ease-in-out duration-200 " + (/*value*/ ctx[0] && !/*disabled*/ ctx[1]
			? 'bg-blue-500 group-hover:bg-blue-700'
			: '') + " " + (!/*value*/ ctx[0] && !/*disabled*/ ctx[1]
			? 'bg-gray-200 group-hover:bg-gray-400'
			: '') + " " + (/*disabled*/ ctx[1]
			? 'bg-blue-100 group-hover:bg-blue-100'
			: '') + "");

			attr(span2, "aria-hidden", "true");
			attr(span2, "class", "pointer-events-none absolute left-0 inline-block h-5 w-5 border border-gray-200 rounded-full bg-white shadow transform ring-0 transition-transform ease-in-out duration-200");
			set_style(span2, "--tw-translate-x", /*value*/ ctx[0] ? '1.25rem' : 0);
			attr(button, "type", "button");
			attr(button, "class", "flex-shrink-0 group relative rounded-full inline-flex items-center justify-center h-5 w-10 cursor-pointer focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-300 svelte-8oatug");
			attr(button, "role", "switch");
			attr(button, "aria-checked", /*value*/ ctx[0]);
			button.disabled = /*disabled*/ ctx[1];
		},
		m(target, anchor) {
			if (if_block) if_block.m(target, anchor);
			insert_hydration(target, t0, anchor);
			insert_hydration(target, button, anchor);
			append_hydration(button, span0);
			append_hydration(button, t1);
			append_hydration(button, span1);
			append_hydration(button, t2);
			append_hydration(button, span2);
			current = true;

			if (!mounted) {
				dispose = [
					listen(button, "click", /*click_handler_3*/ ctx[10]),
					listen(button, "click", /*click_handler_1*/ ctx[7])
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (/*$$slots*/ ctx[3].label) {
				if (if_block) {
					if_block.p(ctx, dirty);

					if (dirty & /*$$slots*/ 8) {
						transition_in(if_block, 1);
					}
				} else {
					if_block = create_if_block_1$6(ctx);
					if_block.c();
					transition_in(if_block, 1);
					if_block.m(t0.parentNode, t0);
				}
			} else if (if_block) {
				group_outros();

				transition_out(if_block, 1, 1, () => {
					if_block = null;
				});

				check_outros();
			}

			if (!current || dirty & /*value, disabled*/ 3 && span1_class_value !== (span1_class_value = "pointer-events-none absolute h-4 w-9 mx-auto rounded-full transition-colors ease-in-out duration-200 " + (/*value*/ ctx[0] && !/*disabled*/ ctx[1]
			? 'bg-blue-500 group-hover:bg-blue-700'
			: '') + " " + (!/*value*/ ctx[0] && !/*disabled*/ ctx[1]
			? 'bg-gray-200 group-hover:bg-gray-400'
			: '') + " " + (/*disabled*/ ctx[1]
			? 'bg-blue-100 group-hover:bg-blue-100'
			: '') + "")) {
				attr(span1, "class", span1_class_value);
			}

			if (!current || dirty & /*value*/ 1) {
				set_style(span2, "--tw-translate-x", /*value*/ ctx[0] ? '1.25rem' : 0);
			}

			if (!current || dirty & /*value*/ 1) {
				attr(button, "aria-checked", /*value*/ ctx[0]);
			}

			if (!current || dirty & /*disabled*/ 2) {
				button.disabled = /*disabled*/ ctx[1];
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			if (if_block) if_block.d(detaching);
			if (detaching) detach(t0);
			if (detaching) detach(button);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (64:4) {#if $$slots.label}
function create_if_block_1$6(ctx) {
	let current;
	const label_slot_template = /*#slots*/ ctx[6].label;
	const label_slot = create_slot(label_slot_template, ctx, /*$$scope*/ ctx[5], get_label_slot_context_1);

	return {
		c() {
			if (label_slot) label_slot.c();
		},
		l(nodes) {
			if (label_slot) label_slot.l(nodes);
		},
		m(target, anchor) {
			if (label_slot) {
				label_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (label_slot) {
				if (label_slot.p && (!current || dirty & /*$$scope*/ 32)) {
					update_slot_base(
						label_slot,
						label_slot_template,
						ctx,
						/*$$scope*/ ctx[5],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[5])
						: get_slot_changes(label_slot_template, /*$$scope*/ ctx[5], dirty, get_label_slot_changes_1),
						get_label_slot_context_1
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(label_slot, local);
			current = true;
		},
		o(local) {
			transition_out(label_slot, local);
			current = false;
		},
		d(detaching) {
			if (label_slot) label_slot.d(detaching);
		}
	};
}

function create_fragment$t(ctx) {
	let div;
	let t;
	let current;
	let if_block0 = /*labelPostion*/ ctx[2] == "right" && create_if_block_2$6(ctx);
	let if_block1 = /*labelPostion*/ ctx[2] == "left" && create_if_block$e(ctx);

	return {
		c() {
			div = element("div");
			if (if_block0) if_block0.c();
			t = space();
			if (if_block1) if_block1.c();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			if (if_block0) if_block0.l(div_nodes);
			t = claim_space(div_nodes);
			if (if_block1) if_block1.l(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", "flex items-center");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			if (if_block0) if_block0.m(div, null);
			append_hydration(div, t);
			if (if_block1) if_block1.m(div, null);
			current = true;
		},
		p(ctx, [dirty]) {
			if (/*labelPostion*/ ctx[2] == "right") {
				if (if_block0) {
					if_block0.p(ctx, dirty);

					if (dirty & /*labelPostion*/ 4) {
						transition_in(if_block0, 1);
					}
				} else {
					if_block0 = create_if_block_2$6(ctx);
					if_block0.c();
					transition_in(if_block0, 1);
					if_block0.m(div, t);
				}
			} else if (if_block0) {
				group_outros();

				transition_out(if_block0, 1, 1, () => {
					if_block0 = null;
				});

				check_outros();
			}

			if (/*labelPostion*/ ctx[2] == "left") {
				if (if_block1) {
					if_block1.p(ctx, dirty);

					if (dirty & /*labelPostion*/ 4) {
						transition_in(if_block1, 1);
					}
				} else {
					if_block1 = create_if_block$e(ctx);
					if_block1.c();
					transition_in(if_block1, 1);
					if_block1.m(div, null);
				}
			} else if (if_block1) {
				group_outros();

				transition_out(if_block1, 1, 1, () => {
					if_block1 = null;
				});

				check_outros();
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block0);
			transition_in(if_block1);
			current = true;
		},
		o(local) {
			transition_out(if_block0);
			transition_out(if_block1);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			if (if_block0) if_block0.d();
			if (if_block1) if_block1.d();
		}
	};
}

function instance$t($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	const $$slots = compute_slots(slots);
	let { value = false } = $$props;
	let { disabled = false } = $$props;
	let { labelPostion = "right" } = $$props;
	let { name } = $$props;

	function click_handler_1(event) {
		bubble.call(this, $$self, event);
	}

	function click_handler(event) {
		bubble.call(this, $$self, event);
	}

	const click_handler_2 = () => $$invalidate(0, value = !value);
	const click_handler_3 = () => $$invalidate(0, value = !value);

	$$self.$$set = $$props => {
		if ('value' in $$props) $$invalidate(0, value = $$props.value);
		if ('disabled' in $$props) $$invalidate(1, disabled = $$props.disabled);
		if ('labelPostion' in $$props) $$invalidate(2, labelPostion = $$props.labelPostion);
		if ('name' in $$props) $$invalidate(4, name = $$props.name);
		if ('$$scope' in $$props) $$invalidate(5, $$scope = $$props.$$scope);
	};

	return [
		value,
		disabled,
		labelPostion,
		$$slots,
		name,
		$$scope,
		slots,
		click_handler_1,
		click_handler,
		click_handler_2,
		click_handler_3
	];
}

class Switch extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$t, create_fragment$t, safe_not_equal, {
			value: 0,
			disabled: 1,
			labelPostion: 2,
			name: 4
		});
	}
}

/* src\Inputs\TextArea.svelte generated by Svelte v3.48.0 */

function create_if_block$d(ctx) {
	let label_1;
	let t;

	return {
		c() {
			label_1 = element("label");
			t = text(/*label*/ ctx[1]);
			this.h();
		},
		l(nodes) {
			label_1 = claim_element(nodes, "LABEL", { for: true, class: true });
			var label_1_nodes = children(label_1);
			t = claim_text(label_1_nodes, /*label*/ ctx[1]);
			label_1_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(label_1, "for", /*name*/ ctx[2]);
			attr(label_1, "class", "block text-sm font-medium text-gray-700");
		},
		m(target, anchor) {
			insert_hydration(target, label_1, anchor);
			append_hydration(label_1, t);
		},
		p(ctx, dirty) {
			if (dirty & /*label*/ 2) set_data(t, /*label*/ ctx[1]);

			if (dirty & /*name*/ 4) {
				attr(label_1, "for", /*name*/ ctx[2]);
			}
		},
		d(detaching) {
			if (detaching) detach(label_1);
		}
	};
}

function create_fragment$s(ctx) {
	let div1;
	let t;
	let div0;
	let textarea;
	let useActions_action;
	let mounted;
	let dispose;
	let if_block = /*label*/ ctx[1] && create_if_block$d(ctx);

	let textarea_levels = [
		{ disabled: /*disabled*/ ctx[4] },
		{ type: "text" },
		{ name: /*name*/ ctx[2] },
		{ id: /*name*/ ctx[2] },
		{
			class: "border h-full text-sm border-gray-300 hover:border-blue-200 block focus:border-blue-500 focus:ring-1 focus:ring-blue-200 placeholder-gray-400 rounded-md text-gray-900"
		},
		{ placeholder: /*placeholder*/ ctx[5] },
		/*$$restProps*/ ctx[8]
	];

	let textarea_data = {};

	for (let i = 0; i < textarea_levels.length; i += 1) {
		textarea_data = assign(textarea_data, textarea_levels[i]);
	}

	return {
		c() {
			div1 = element("div");
			if (if_block) if_block.c();
			t = space();
			div0 = element("div");
			textarea = element("textarea");
			this.h();
		},
		l(nodes) {
			div1 = claim_element(nodes, "DIV", { class: true });
			var div1_nodes = children(div1);
			if (if_block) if_block.l(div1_nodes);
			t = claim_space(div1_nodes);
			div0 = claim_element(div1_nodes, "DIV", { class: true });
			var div0_nodes = children(div0);

			textarea = claim_element(div0_nodes, "TEXTAREA", {
				type: true,
				name: true,
				id: true,
				class: true,
				placeholder: true
			});

			children(textarea).forEach(detach);
			div0_nodes.forEach(detach);
			div1_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(textarea, textarea_data);
			toggle_class(textarea, "invalid", /*hasError*/ ctx[6]);
			toggle_class(textarea, "w-full", /*full*/ ctx[3]);
			toggle_class(textarea, "svelte-1jq1hsw", true);
			attr(div0, "class", "mt-1 relative inline-block h-full");
			toggle_class(div0, "w-full", /*full*/ ctx[3]);
			attr(div1, "class", "h-full");
		},
		m(target, anchor) {
			insert_hydration(target, div1, anchor);
			if (if_block) if_block.m(div1, null);
			append_hydration(div1, t);
			append_hydration(div1, div0);
			append_hydration(div0, textarea);
			if (textarea.autofocus) textarea.focus();
			set_input_value(textarea, /*value*/ ctx[0]);

			if (!mounted) {
				dispose = [
					listen(textarea, "input", /*textarea_input_handler*/ ctx[9]),
					action_destroyer(useActions_action = dist.useActions.call(null, textarea, /*use*/ ctx[7]))
				];

				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (/*label*/ ctx[1]) {
				if (if_block) {
					if_block.p(ctx, dirty);
				} else {
					if_block = create_if_block$d(ctx);
					if_block.c();
					if_block.m(div1, t);
				}
			} else if (if_block) {
				if_block.d(1);
				if_block = null;
			}

			set_attributes(textarea, textarea_data = get_spread_update(textarea_levels, [
				dirty & /*disabled*/ 16 && { disabled: /*disabled*/ ctx[4] },
				{ type: "text" },
				dirty & /*name*/ 4 && { name: /*name*/ ctx[2] },
				dirty & /*name*/ 4 && { id: /*name*/ ctx[2] },
				{
					class: "border h-full text-sm border-gray-300 hover:border-blue-200 block focus:border-blue-500 focus:ring-1 focus:ring-blue-200 placeholder-gray-400 rounded-md text-gray-900"
				},
				dirty & /*placeholder*/ 32 && { placeholder: /*placeholder*/ ctx[5] },
				dirty & /*$$restProps*/ 256 && /*$$restProps*/ ctx[8]
			]));

			if (dirty & /*value*/ 1) {
				set_input_value(textarea, /*value*/ ctx[0]);
			}

			if (useActions_action && is_function(useActions_action.update) && dirty & /*use*/ 128) useActions_action.update.call(null, /*use*/ ctx[7]);
			toggle_class(textarea, "invalid", /*hasError*/ ctx[6]);
			toggle_class(textarea, "w-full", /*full*/ ctx[3]);
			toggle_class(textarea, "svelte-1jq1hsw", true);

			if (dirty & /*full*/ 8) {
				toggle_class(div0, "w-full", /*full*/ ctx[3]);
			}
		},
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(div1);
			if (if_block) if_block.d();
			mounted = false;
			run_all(dispose);
		}
	};
}

function instance$s($$self, $$props, $$invalidate) {
	const omit_props_names = ["label","name","full","disabled","value","placeholder","hasError","use"];
	let $$restProps = compute_rest_props($$props, omit_props_names);
	let { label = "" } = $$props;
	let { name = "" } = $$props;
	let { full = false } = $$props;
	let { disabled = false } = $$props;
	let { value = "" } = $$props;
	let { placeholder = "" } = $$props;
	let { hasError = false } = $$props;
	let { use } = $$props;

	function textarea_input_handler() {
		value = this.value;
		$$invalidate(0, value);
	}

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(8, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('label' in $$new_props) $$invalidate(1, label = $$new_props.label);
		if ('name' in $$new_props) $$invalidate(2, name = $$new_props.name);
		if ('full' in $$new_props) $$invalidate(3, full = $$new_props.full);
		if ('disabled' in $$new_props) $$invalidate(4, disabled = $$new_props.disabled);
		if ('value' in $$new_props) $$invalidate(0, value = $$new_props.value);
		if ('placeholder' in $$new_props) $$invalidate(5, placeholder = $$new_props.placeholder);
		if ('hasError' in $$new_props) $$invalidate(6, hasError = $$new_props.hasError);
		if ('use' in $$new_props) $$invalidate(7, use = $$new_props.use);
	};

	return [
		value,
		label,
		name,
		full,
		disabled,
		placeholder,
		hasError,
		use,
		$$restProps,
		textarea_input_handler
	];
}

class TextArea extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$s, create_fragment$s, safe_not_equal, {
			label: 1,
			name: 2,
			full: 3,
			disabled: 4,
			value: 0,
			placeholder: 5,
			hasError: 6,
			use: 7
		});
	}
}

/* src\Inputs\TextInput.svelte generated by Svelte v3.48.0 */
const get_leading_slot_changes = dirty => ({});
const get_leading_slot_context = ctx => ({});
const get_trailing_slot_changes = dirty => ({});
const get_trailing_slot_context = ctx => ({});

// (64:2) {#if label}
function create_if_block_4$3(ctx) {
	let label_1;
	let t;

	return {
		c() {
			label_1 = element("label");
			t = text(/*label*/ ctx[2]);
			this.h();
		},
		l(nodes) {
			label_1 = claim_element(nodes, "LABEL", { for: true, class: true });
			var label_1_nodes = children(label_1);
			t = claim_text(label_1_nodes, /*label*/ ctx[2]);
			label_1_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(label_1, "for", /*name*/ ctx[3]);
			attr(label_1, "class", "block text-sm font-medium text-gray-700");
		},
		m(target, anchor) {
			insert_hydration(target, label_1, anchor);
			append_hydration(label_1, t);
		},
		p(ctx, dirty) {
			if (dirty & /*label*/ 4) set_data(t, /*label*/ ctx[2]);

			if (dirty & /*name*/ 8) {
				attr(label_1, "for", /*name*/ ctx[3]);
			}
		},
		d(detaching) {
			if (detaching) detach(label_1);
		}
	};
}

// (91:4) {#if !hasError && !isLoading && $$slots.trailing}
function create_if_block_3$3(ctx) {
	let current;
	const trailing_slot_template = /*#slots*/ ctx[15].trailing;
	const trailing_slot = create_slot(trailing_slot_template, ctx, /*$$scope*/ ctx[14], get_trailing_slot_context);

	return {
		c() {
			if (trailing_slot) trailing_slot.c();
		},
		l(nodes) {
			if (trailing_slot) trailing_slot.l(nodes);
		},
		m(target, anchor) {
			if (trailing_slot) {
				trailing_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (trailing_slot) {
				if (trailing_slot.p && (!current || dirty & /*$$scope*/ 16384)) {
					update_slot_base(
						trailing_slot,
						trailing_slot_template,
						ctx,
						/*$$scope*/ ctx[14],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[14])
						: get_slot_changes(trailing_slot_template, /*$$scope*/ ctx[14], dirty, get_trailing_slot_changes),
						get_trailing_slot_context
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(trailing_slot, local);
			current = true;
		},
		o(local) {
			transition_out(trailing_slot, local);
			current = false;
		},
		d(detaching) {
			if (trailing_slot) trailing_slot.d(detaching);
		}
	};
}

// (95:4) {#if $$slots.leading}
function create_if_block_2$5(ctx) {
	let current;
	const leading_slot_template = /*#slots*/ ctx[15].leading;
	const leading_slot = create_slot(leading_slot_template, ctx, /*$$scope*/ ctx[14], get_leading_slot_context);

	return {
		c() {
			if (leading_slot) leading_slot.c();
		},
		l(nodes) {
			if (leading_slot) leading_slot.l(nodes);
		},
		m(target, anchor) {
			if (leading_slot) {
				leading_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (leading_slot) {
				if (leading_slot.p && (!current || dirty & /*$$scope*/ 16384)) {
					update_slot_base(
						leading_slot,
						leading_slot_template,
						ctx,
						/*$$scope*/ ctx[14],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[14])
						: get_slot_changes(leading_slot_template, /*$$scope*/ ctx[14], dirty, get_leading_slot_changes),
						get_leading_slot_context
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(leading_slot, local);
			current = true;
		},
		o(local) {
			transition_out(leading_slot, local);
			current = false;
		},
		d(detaching) {
			if (leading_slot) leading_slot.d(detaching);
		}
	};
}

// (99:4) {#if isLoading}
function create_if_block_1$5(ctx) {
	let div;
	let svg;
	let circle;
	let path;

	return {
		c() {
			div = element("div");
			svg = svg_element("svg");
			circle = svg_element("circle");
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);

			svg = claim_svg_element(div_nodes, "svg", {
				class: true,
				xmlns: true,
				fill: true,
				viewBox: true
			});

			var svg_nodes = children(svg);

			circle = claim_svg_element(svg_nodes, "circle", {
				class: true,
				cx: true,
				cy: true,
				r: true,
				stroke: true,
				"stroke-width": true
			});

			children(circle).forEach(detach);
			path = claim_svg_element(svg_nodes, "path", { class: true, fill: true, d: true });
			children(path).forEach(detach);
			svg_nodes.forEach(detach);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(circle, "class", "opacity-25");
			attr(circle, "cx", "12");
			attr(circle, "cy", "12");
			attr(circle, "r", "10");
			attr(circle, "stroke", "currentColor");
			attr(circle, "stroke-width", "4");
			attr(path, "class", "opacity-75");
			attr(path, "fill", "currentColor");
			attr(path, "d", "M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z");
			attr(svg, "class", "absolute h-5 w-5 animate-spin");
			attr(svg, "xmlns", "http://www.w3.org/2000/svg");
			attr(svg, "fill", "none");
			attr(svg, "viewBox", "0 0 24 24");
			attr(div, "class", "pointer-events-none absolute inset-y-0 right-5 flex items-center pr-1");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			append_hydration(div, svg);
			append_hydration(svg, circle);
			append_hydration(svg, path);
		},
		d(detaching) {
			if (detaching) detach(div);
		}
	};
}

// (126:4) {#if hasError}
function create_if_block$c(ctx) {
	let div;
	let svg;
	let path;

	return {
		c() {
			div = element("div");
			svg = svg_element("svg");
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);

			svg = claim_svg_element(div_nodes, "svg", {
				xmlns: true,
				class: true,
				viewBox: true,
				fill: true
			});

			var svg_nodes = children(svg);

			path = claim_svg_element(svg_nodes, "path", {
				"fill-rule": true,
				d: true,
				"clip-rule": true
			});

			children(path).forEach(detach);
			svg_nodes.forEach(detach);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(path, "fill-rule", "evenodd");
			attr(path, "d", "M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-7 4a1 1 0 11-2 0 1 1 0 012 0zm-1-9a1 1 0 00-1 1v4a1 1 0 102 0V6a1 1 0 00-1-1z");
			attr(path, "clip-rule", "evenodd");
			attr(svg, "xmlns", "http://www.w3.org/2000/svg");
			attr(svg, "class", "h-5 w-5 text-red-500");
			attr(svg, "viewBox", "0 0 20 20");
			attr(svg, "fill", "currentColor");
			attr(div, "class", "pointer-events-none absolute inset-y-0 right-0 flex items-center pr-1 text-red-500");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			append_hydration(div, svg);
			append_hydration(svg, path);
		},
		d(detaching) {
			if (detaching) detach(div);
		}
	};
}

function create_fragment$r(ctx) {
	let div1;
	let t0;
	let div0;
	let input_1;
	let input_1_class_value;
	let useActions_action;
	let t1;
	let t2;
	let t3;
	let t4;
	let current;
	let mounted;
	let dispose;
	let if_block0 = /*label*/ ctx[2] && create_if_block_4$3(ctx);

	let input_1_levels = [
		{ disabled: /*disabled*/ ctx[5] },
		{ type: "text" },
		{ name: /*name*/ ctx[3] },
		{ id: /*name*/ ctx[3] },
		{
			class: input_1_class_value = "block rounded-md border-gray-300 placeholder-gray-400 hover:border-blue-200 " + /*textSize*/ ctx[10] + " text-gray-900"
		},
		{ placeholder: /*placeholder*/ ctx[6] },
		/*$$restProps*/ ctx[11]
	];

	let input_1_data = {};

	for (let i = 0; i < input_1_levels.length; i += 1) {
		input_1_data = assign(input_1_data, input_1_levels[i]);
	}

	let if_block1 = !/*hasError*/ ctx[7] && !/*isLoading*/ ctx[8] && /*$$slots*/ ctx[12].trailing && create_if_block_3$3(ctx);
	let if_block2 = /*$$slots*/ ctx[12].leading && create_if_block_2$5(ctx);
	let if_block3 = /*isLoading*/ ctx[8] && create_if_block_1$5();
	let if_block4 = /*hasError*/ ctx[7] && create_if_block$c();

	return {
		c() {
			div1 = element("div");
			if (if_block0) if_block0.c();
			t0 = space();
			div0 = element("div");
			input_1 = element("input");
			t1 = space();
			if (if_block1) if_block1.c();
			t2 = space();
			if (if_block2) if_block2.c();
			t3 = space();
			if (if_block3) if_block3.c();
			t4 = space();
			if (if_block4) if_block4.c();
			this.h();
		},
		l(nodes) {
			div1 = claim_element(nodes, "DIV", {});
			var div1_nodes = children(div1);
			if (if_block0) if_block0.l(div1_nodes);
			t0 = claim_space(div1_nodes);
			div0 = claim_element(div1_nodes, "DIV", { class: true });
			var div0_nodes = children(div0);

			input_1 = claim_element(div0_nodes, "INPUT", {
				type: true,
				name: true,
				id: true,
				class: true,
				placeholder: true
			});

			t1 = claim_space(div0_nodes);
			if (if_block1) if_block1.l(div0_nodes);
			t2 = claim_space(div0_nodes);
			if (if_block2) if_block2.l(div0_nodes);
			t3 = claim_space(div0_nodes);
			if (if_block3) if_block3.l(div0_nodes);
			t4 = claim_space(div0_nodes);
			if (if_block4) if_block4.l(div0_nodes);
			div0_nodes.forEach(detach);
			div1_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(input_1, input_1_data);
			toggle_class(input_1, "invalid", /*hasError*/ ctx[7]);
			toggle_class(input_1, "w-full", /*full*/ ctx[4]);
			toggle_class(input_1, "leading", /*$$slots*/ ctx[12].leading);
			toggle_class(input_1, "loading", /*isLoading*/ ctx[8]);
			toggle_class(input_1, "svelte-6y4x3a", true);
			attr(div0, "class", "relative inline-block");
			toggle_class(div0, "w-full", /*full*/ ctx[4]);
			toggle_class(div1, "w-full", /*full*/ ctx[4]);
		},
		m(target, anchor) {
			insert_hydration(target, div1, anchor);
			if (if_block0) if_block0.m(div1, null);
			append_hydration(div1, t0);
			append_hydration(div1, div0);
			append_hydration(div0, input_1);
			if (input_1.autofocus) input_1.focus();
			/*input_1_binding*/ ctx[20](input_1);
			set_input_value(input_1, /*value*/ ctx[0]);
			append_hydration(div0, t1);
			if (if_block1) if_block1.m(div0, null);
			append_hydration(div0, t2);
			if (if_block2) if_block2.m(div0, null);
			append_hydration(div0, t3);
			if (if_block3) if_block3.m(div0, null);
			append_hydration(div0, t4);
			if (if_block4) if_block4.m(div0, null);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = dist.useActions.call(null, input_1, /*use*/ ctx[9])),
					listen(input_1, "focus", /*focus_handler*/ ctx[16]),
					listen(input_1, "focusout", /*focusout_handler*/ ctx[17]),
					listen(input_1, "keydown", /*keydown_handler*/ ctx[18]),
					listen(input_1, "keyup", /*keyup_handler*/ ctx[19]),
					listen(input_1, "input", /*input_1_input_handler*/ ctx[21])
				];

				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (/*label*/ ctx[2]) {
				if (if_block0) {
					if_block0.p(ctx, dirty);
				} else {
					if_block0 = create_if_block_4$3(ctx);
					if_block0.c();
					if_block0.m(div1, t0);
				}
			} else if (if_block0) {
				if_block0.d(1);
				if_block0 = null;
			}

			set_attributes(input_1, input_1_data = get_spread_update(input_1_levels, [
				(!current || dirty & /*disabled*/ 32) && { disabled: /*disabled*/ ctx[5] },
				{ type: "text" },
				(!current || dirty & /*name*/ 8) && { name: /*name*/ ctx[3] },
				(!current || dirty & /*name*/ 8) && { id: /*name*/ ctx[3] },
				(!current || dirty & /*textSize*/ 1024 && input_1_class_value !== (input_1_class_value = "block rounded-md border-gray-300 placeholder-gray-400 hover:border-blue-200 " + /*textSize*/ ctx[10] + " text-gray-900")) && { class: input_1_class_value },
				(!current || dirty & /*placeholder*/ 64) && { placeholder: /*placeholder*/ ctx[6] },
				dirty & /*$$restProps*/ 2048 && /*$$restProps*/ ctx[11]
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty & /*use*/ 512) useActions_action.update.call(null, /*use*/ ctx[9]);

			if (dirty & /*value*/ 1 && input_1.value !== /*value*/ ctx[0]) {
				set_input_value(input_1, /*value*/ ctx[0]);
			}

			toggle_class(input_1, "invalid", /*hasError*/ ctx[7]);
			toggle_class(input_1, "w-full", /*full*/ ctx[4]);
			toggle_class(input_1, "leading", /*$$slots*/ ctx[12].leading);
			toggle_class(input_1, "loading", /*isLoading*/ ctx[8]);
			toggle_class(input_1, "svelte-6y4x3a", true);

			if (!/*hasError*/ ctx[7] && !/*isLoading*/ ctx[8] && /*$$slots*/ ctx[12].trailing) {
				if (if_block1) {
					if_block1.p(ctx, dirty);

					if (dirty & /*hasError, isLoading, $$slots*/ 4480) {
						transition_in(if_block1, 1);
					}
				} else {
					if_block1 = create_if_block_3$3(ctx);
					if_block1.c();
					transition_in(if_block1, 1);
					if_block1.m(div0, t2);
				}
			} else if (if_block1) {
				group_outros();

				transition_out(if_block1, 1, 1, () => {
					if_block1 = null;
				});

				check_outros();
			}

			if (/*$$slots*/ ctx[12].leading) {
				if (if_block2) {
					if_block2.p(ctx, dirty);

					if (dirty & /*$$slots*/ 4096) {
						transition_in(if_block2, 1);
					}
				} else {
					if_block2 = create_if_block_2$5(ctx);
					if_block2.c();
					transition_in(if_block2, 1);
					if_block2.m(div0, t3);
				}
			} else if (if_block2) {
				group_outros();

				transition_out(if_block2, 1, 1, () => {
					if_block2 = null;
				});

				check_outros();
			}

			if (/*isLoading*/ ctx[8]) {
				if (if_block3) ; else {
					if_block3 = create_if_block_1$5();
					if_block3.c();
					if_block3.m(div0, t4);
				}
			} else if (if_block3) {
				if_block3.d(1);
				if_block3 = null;
			}

			if (/*hasError*/ ctx[7]) {
				if (if_block4) ; else {
					if_block4 = create_if_block$c();
					if_block4.c();
					if_block4.m(div0, null);
				}
			} else if (if_block4) {
				if_block4.d(1);
				if_block4 = null;
			}

			if (dirty & /*full*/ 16) {
				toggle_class(div0, "w-full", /*full*/ ctx[4]);
			}

			if (dirty & /*full*/ 16) {
				toggle_class(div1, "w-full", /*full*/ ctx[4]);
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block1);
			transition_in(if_block2);
			current = true;
		},
		o(local) {
			transition_out(if_block1);
			transition_out(if_block2);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div1);
			if (if_block0) if_block0.d();
			/*input_1_binding*/ ctx[20](null);
			if (if_block1) if_block1.d();
			if (if_block2) if_block2.d();
			if (if_block3) if_block3.d();
			if (if_block4) if_block4.d();
			mounted = false;
			run_all(dispose);
		}
	};
}

function instance$r($$self, $$props, $$invalidate) {
	const omit_props_names = [
		"label","name","full","disabled","value","placeholder","hasError","isLoading","size","input","use"
	];

	let $$restProps = compute_rest_props($$props, omit_props_names);
	let { $$slots: slots = {}, $$scope } = $$props;
	const $$slots = compute_slots(slots);
	let { label = "" } = $$props;
	let { name = "" } = $$props;
	let { full = false } = $$props;
	let { disabled = false } = $$props;
	let { value = "" } = $$props;
	let { placeholder = "" } = $$props;
	let { hasError = false } = $$props;
	let { isLoading = false } = $$props;
	let { size = "medium" } = $$props;
	let textSize;

	switch (size) {
		case "small":
			textSize = "text-xs";
			break;
		case "medium":
			textSize = "text-sm";
			break;
		case "large":
			textSize = "text-md";
			break;
	}

	let { input = null } = $$props;
	let { use } = $$props;

	function focus_handler(event) {
		bubble.call(this, $$self, event);
	}

	function focusout_handler(event) {
		bubble.call(this, $$self, event);
	}

	function keydown_handler(event) {
		bubble.call(this, $$self, event);
	}

	function keyup_handler(event) {
		bubble.call(this, $$self, event);
	}

	function input_1_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			input = $$value;
			$$invalidate(1, input);
		});
	}

	function input_1_input_handler() {
		value = this.value;
		$$invalidate(0, value);
	}

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(11, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('label' in $$new_props) $$invalidate(2, label = $$new_props.label);
		if ('name' in $$new_props) $$invalidate(3, name = $$new_props.name);
		if ('full' in $$new_props) $$invalidate(4, full = $$new_props.full);
		if ('disabled' in $$new_props) $$invalidate(5, disabled = $$new_props.disabled);
		if ('value' in $$new_props) $$invalidate(0, value = $$new_props.value);
		if ('placeholder' in $$new_props) $$invalidate(6, placeholder = $$new_props.placeholder);
		if ('hasError' in $$new_props) $$invalidate(7, hasError = $$new_props.hasError);
		if ('isLoading' in $$new_props) $$invalidate(8, isLoading = $$new_props.isLoading);
		if ('size' in $$new_props) $$invalidate(13, size = $$new_props.size);
		if ('input' in $$new_props) $$invalidate(1, input = $$new_props.input);
		if ('use' in $$new_props) $$invalidate(9, use = $$new_props.use);
		if ('$$scope' in $$new_props) $$invalidate(14, $$scope = $$new_props.$$scope);
	};

	return [
		value,
		input,
		label,
		name,
		full,
		disabled,
		placeholder,
		hasError,
		isLoading,
		use,
		textSize,
		$$restProps,
		$$slots,
		size,
		$$scope,
		slots,
		focus_handler,
		focusout_handler,
		keydown_handler,
		keyup_handler,
		input_1_binding,
		input_1_input_handler
	];
}

class TextInput extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$r, create_fragment$r, safe_not_equal, {
			label: 2,
			name: 3,
			full: 4,
			disabled: 5,
			value: 0,
			placeholder: 6,
			hasError: 7,
			isLoading: 8,
			size: 13,
			input: 1,
			use: 9
		});
	}
}

/* src\Inputs\AutoComplete.svelte generated by Svelte v3.48.0 */

function get_each_context$2(ctx, list, i) {
	const child_ctx = ctx.slice();
	child_ctx[33] = list[i];
	child_ctx[35] = i;
	return child_ctx;
}

const get_list_item_slot_changes = dirty => ({
	item: dirty[0] & /*filteredList*/ 4096,
	highlight: dirty[0] & /*select*/ 512
});

const get_list_item_slot_context = ctx => ({
	item: /*opt*/ ctx[33],
	highlight: /*select*/ ctx[9] === /*i*/ ctx[35]
});

// (170:2) {#if open}
function create_if_block$b(ctx) {
	let div;
	let t;
	let clickOutside_action;
	let div_transition;
	let current;
	let mounted;
	let dispose;
	let if_block0 = create_if_block_2$4(ctx);
	let if_block1 = /*filteredList*/ ctx[12].length == 0 && !/*isSearching*/ ctx[7] && create_if_block_1$4();

	return {
		c() {
			div = element("div");
			if (if_block0) if_block0.c();
			t = space();
			if (if_block1) if_block1.c();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			if (if_block0) if_block0.l(div_nodes);
			t = claim_space(div_nodes);
			if (if_block1) if_block1.l(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", "absolute mt-1 rounded-md bg-white shadow-lg w-full");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			if (if_block0) if_block0.m(div, null);
			append_hydration(div, t);
			if (if_block1) if_block1.m(div, null);
			current = true;

			if (!mounted) {
				dispose = action_destroyer(clickOutside_action = clickOutside.call(null, div, /*clickOutside_function*/ ctx[27]));
				mounted = true;
			}
		},
		p(ctx, dirty) {
			if_block0.p(ctx, dirty);

			if (/*filteredList*/ ctx[12].length == 0 && !/*isSearching*/ ctx[7]) {
				if (if_block1) ; else {
					if_block1 = create_if_block_1$4();
					if_block1.c();
					if_block1.m(div, null);
				}
			} else if (if_block1) {
				if_block1.d(1);
				if_block1 = null;
			}

			if (clickOutside_action && is_function(clickOutside_action.update) && dirty[0] & /*open*/ 256) clickOutside_action.update.call(null, /*clickOutside_function*/ ctx[27]);
		},
		i(local) {
			if (current) return;
			transition_in(if_block0);

			add_render_callback(() => {
				if (!div_transition) div_transition = create_bidirectional_transition(div, fade, { duration: 300 }, true);
				div_transition.run(1);
			});

			current = true;
		},
		o(local) {
			transition_out(if_block0);
			if (!div_transition) div_transition = create_bidirectional_transition(div, fade, { duration: 300 }, false);
			div_transition.run(0);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			if (if_block0) if_block0.d();
			if (if_block1) if_block1.d();
			if (detaching && div_transition) div_transition.end();
			mounted = false;
			dispose();
		}
	};
}

// (176:6) {#if true}
function create_if_block_2$4(ctx) {
	let ul;
	let current;
	let mounted;
	let dispose;
	let each_value = /*filteredList*/ ctx[12];
	let each_blocks = [];

	for (let i = 0; i < each_value.length; i += 1) {
		each_blocks[i] = create_each_block$2(get_each_context$2(ctx, each_value, i));
	}

	const out = i => transition_out(each_blocks[i], 1, 1, () => {
		each_blocks[i] = null;
	});

	return {
		c() {
			ul = element("ul");

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].c();
			}

			this.h();
		},
		l(nodes) {
			ul = claim_element(nodes, "UL", { id: true, tabindex: true, class: true });
			var ul_nodes = children(ul);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].l(ul_nodes);
			}

			ul_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(ul, "id", "listbox");
			attr(ul, "tabindex", "-1");
			attr(ul, "class", "max-h-56 rounded-md py-1 text-base leading-6 shadow-xs overflow-auto sm:text-sm sm:leading-5 focus:outline-none");
		},
		m(target, anchor) {
			insert_hydration(target, ul, anchor);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].m(ul, null);
			}

			/*ul_binding*/ ctx[26](ul);
			current = true;

			if (!mounted) {
				dispose = listen(ul, "keydown", /*handleListKeyInputs*/ ctx[13]);
				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (dirty[0] & /*select, handleSelected, filteredList, $$scope*/ 545280) {
				each_value = /*filteredList*/ ctx[12];
				let i;

				for (i = 0; i < each_value.length; i += 1) {
					const child_ctx = get_each_context$2(ctx, each_value, i);

					if (each_blocks[i]) {
						each_blocks[i].p(child_ctx, dirty);
						transition_in(each_blocks[i], 1);
					} else {
						each_blocks[i] = create_each_block$2(child_ctx);
						each_blocks[i].c();
						transition_in(each_blocks[i], 1);
						each_blocks[i].m(ul, null);
					}
				}

				group_outros();

				for (i = each_value.length; i < each_blocks.length; i += 1) {
					out(i);
				}

				check_outros();
			}
		},
		i(local) {
			if (current) return;

			for (let i = 0; i < each_value.length; i += 1) {
				transition_in(each_blocks[i]);
			}

			current = true;
		},
		o(local) {
			each_blocks = each_blocks.filter(Boolean);

			for (let i = 0; i < each_blocks.length; i += 1) {
				transition_out(each_blocks[i]);
			}

			current = false;
		},
		d(detaching) {
			if (detaching) detach(ul);
			destroy_each(each_blocks, detaching);
			/*ul_binding*/ ctx[26](null);
			mounted = false;
			dispose();
		}
	};
}

// (184:10) {#each filteredList as opt, i}
function create_each_block$2(ctx) {
	let li;
	let t;
	let current;
	let mounted;
	let dispose;
	const list_item_slot_template = /*#slots*/ ctx[20].list_item;
	const list_item_slot = create_slot(list_item_slot_template, ctx, /*$$scope*/ ctx[19], get_list_item_slot_context);

	function mouseenter_handler() {
		return /*mouseenter_handler*/ ctx[24](/*i*/ ctx[35]);
	}

	function click_handler() {
		return /*click_handler*/ ctx[25](/*i*/ ctx[35], /*opt*/ ctx[33]);
	}

	return {
		c() {
			li = element("li");
			if (list_item_slot) list_item_slot.c();
			t = space();
			this.h();
		},
		l(nodes) {
			li = claim_element(nodes, "LI", { id: true, role: true, class: true });
			var li_nodes = children(li);
			if (list_item_slot) list_item_slot.l(li_nodes);
			t = claim_space(li_nodes);
			li_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(li, "id", `result-item-${/*i*/ ctx[35]}`);
			attr(li, "role", "option");
			attr(li, "class", "text-gray-900 cursor-default select-none relative py-2 pl-4 pr-9");
		},
		m(target, anchor) {
			insert_hydration(target, li, anchor);

			if (list_item_slot) {
				list_item_slot.m(li, null);
			}

			append_hydration(li, t);
			current = true;

			if (!mounted) {
				dispose = [
					listen(li, "mouseenter", mouseenter_handler),
					listen(li, "click", click_handler)
				];

				mounted = true;
			}
		},
		p(new_ctx, dirty) {
			ctx = new_ctx;

			if (list_item_slot) {
				if (list_item_slot.p && (!current || dirty[0] & /*$$scope, filteredList, select*/ 528896)) {
					update_slot_base(
						list_item_slot,
						list_item_slot_template,
						ctx,
						/*$$scope*/ ctx[19],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[19])
						: get_slot_changes(list_item_slot_template, /*$$scope*/ ctx[19], dirty, get_list_item_slot_changes),
						get_list_item_slot_context
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(list_item_slot, local);
			current = true;
		},
		o(local) {
			transition_out(list_item_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(li);
			if (list_item_slot) list_item_slot.d(detaching);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (197:6) {#if filteredList.length == 0 && !isSearching}
function create_if_block_1$4(ctx) {
	let div;
	let t;

	return {
		c() {
			div = element("div");
			t = text("No Results found");
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", {});
			var div_nodes = children(div);
			t = claim_text(div_nodes, "No Results found");
			div_nodes.forEach(detach);
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			append_hydration(div, t);
		},
		d(detaching) {
			if (detaching) detach(div);
		}
	};
}

function create_fragment$q(ctx) {
	let div;
	let textinput;
	let updating_value;
	let updating_input;
	let t;
	let current;

	function textinput_value_binding(value) {
		/*textinput_value_binding*/ ctx[21](value);
	}

	function textinput_input_binding(value) {
		/*textinput_input_binding*/ ctx[22](value);
	}

	let textinput_props = {
		name: /*name*/ ctx[2],
		label: /*label*/ ctx[4],
		full: true,
		hasError: /*hasError*/ ctx[1],
		placeholder: /*placeholder*/ ctx[3],
		disabled: /*disabled*/ ctx[6],
		isLoading: /*isSearching*/ ctx[7] && !/*hasError*/ ctx[1],
		errorMessage: /*errorMessage*/ ctx[5],
		"aria-activedescendant": /*open*/ ctx[8]
		? `aria-activedescendant-${/*select*/ ctx[9]}`
		: "",
		"aria-autocomplete": "list",
		"aria-controls": "listbox",
		autocomplete: "off"
	};

	if (/*value*/ ctx[0] !== void 0) {
		textinput_props.value = /*value*/ ctx[0];
	}

	if (/*input*/ ctx[11] !== void 0) {
		textinput_props.input = /*input*/ ctx[11];
	}

	textinput = new TextInput({ props: textinput_props });
	binding_callbacks.push(() => bind(textinput, 'value', textinput_value_binding));
	binding_callbacks.push(() => bind(textinput, 'input', textinput_input_binding));
	textinput.$on("focus", /*focus_handler*/ ctx[23]);
	textinput.$on("keydown", /*handleListKeyInputs*/ ctx[13]);
	let if_block = /*open*/ ctx[8] && create_if_block$b(ctx);

	return {
		c() {
			div = element("div");
			create_component(textinput.$$.fragment);
			t = space();
			if (if_block) if_block.c();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", {
				class: true,
				role: true,
				"aria-expanded": true,
				"aria-haspopup": true,
				"aria-owns": true
			});

			var div_nodes = children(div);
			claim_component(textinput.$$.fragment, div_nodes);
			t = claim_space(div_nodes);
			if (if_block) if_block.l(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", "mt-1 relative inline-block w-full");
			attr(div, "role", "combobox");
			attr(div, "aria-expanded", /*open*/ ctx[8]);
			attr(div, "aria-haspopup", "listbox");
			attr(div, "aria-owns", /*name*/ ctx[2]);
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			mount_component(textinput, div, null);
			append_hydration(div, t);
			if (if_block) if_block.m(div, null);
			current = true;
		},
		p(ctx, dirty) {
			const textinput_changes = {};
			if (dirty[0] & /*name*/ 4) textinput_changes.name = /*name*/ ctx[2];
			if (dirty[0] & /*label*/ 16) textinput_changes.label = /*label*/ ctx[4];
			if (dirty[0] & /*hasError*/ 2) textinput_changes.hasError = /*hasError*/ ctx[1];
			if (dirty[0] & /*placeholder*/ 8) textinput_changes.placeholder = /*placeholder*/ ctx[3];
			if (dirty[0] & /*disabled*/ 64) textinput_changes.disabled = /*disabled*/ ctx[6];
			if (dirty[0] & /*isSearching, hasError*/ 130) textinput_changes.isLoading = /*isSearching*/ ctx[7] && !/*hasError*/ ctx[1];
			if (dirty[0] & /*errorMessage*/ 32) textinput_changes.errorMessage = /*errorMessage*/ ctx[5];

			if (dirty[0] & /*open, select*/ 768) textinput_changes["aria-activedescendant"] = /*open*/ ctx[8]
			? `aria-activedescendant-${/*select*/ ctx[9]}`
			: "";

			if (!updating_value && dirty[0] & /*value*/ 1) {
				updating_value = true;
				textinput_changes.value = /*value*/ ctx[0];
				add_flush_callback(() => updating_value = false);
			}

			if (!updating_input && dirty[0] & /*input*/ 2048) {
				updating_input = true;
				textinput_changes.input = /*input*/ ctx[11];
				add_flush_callback(() => updating_input = false);
			}

			textinput.$set(textinput_changes);

			if (/*open*/ ctx[8]) {
				if (if_block) {
					if_block.p(ctx, dirty);

					if (dirty[0] & /*open*/ 256) {
						transition_in(if_block, 1);
					}
				} else {
					if_block = create_if_block$b(ctx);
					if_block.c();
					transition_in(if_block, 1);
					if_block.m(div, null);
				}
			} else if (if_block) {
				group_outros();

				transition_out(if_block, 1, 1, () => {
					if_block = null;
				});

				check_outros();
			}

			if (!current || dirty[0] & /*open*/ 256) {
				attr(div, "aria-expanded", /*open*/ ctx[8]);
			}

			if (!current || dirty[0] & /*name*/ 4) {
				attr(div, "aria-owns", /*name*/ ctx[2]);
			}
		},
		i(local) {
			if (current) return;
			transition_in(textinput.$$.fragment, local);
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(textinput.$$.fragment, local);
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			destroy_component(textinput);
			if (if_block) if_block.d();
		}
	};
}

function instance$q($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	const dispatch = createEventDispatcher();
	let isSearching = false;
	let { searchFunction } = $$props;
	let { isAsync = false } = $$props;
	let { valueKey } = $$props;
	let { value = "" } = $$props;
	let selectedOption = 0;
	let open = false;
	let select = selectedOption ? selectedOption : 0;
	let listBox = null;
	let input;
	let filteredList = [];

	const handleListKeyInputs = e => {
		$$invalidate(8, open = true);

		switch (e.key) {
			case "ArrowUp":
				if (select == 0) return;
				$$invalidate(9, select--, select);
				listBox.children[select].scrollIntoView({ block: "nearest", behavior: "smooth" });
				break;
			case "ArrowDown":
				if (select >= listBox.children.length - 1) return;
				listBox.children[select + 1].scrollIntoView({ block: "nearest", behavior: "smooth" });
				$$invalidate(9, select++, select);
				break;
			case "Enter":
				handleSelected(select, filteredList[select]);
				break;
			case "Escape":
				handleClose();
				break;
		}
	};

	const handleClose = () => {
		$$invalidate(8, open = false);
	};

	const itemSelected = item => {
		dispatch("Selected", item);
	};

	const handleSelected = async (selected, selectedValue) => {
		$$invalidate(1, hasError = false);
		selectedOption = selected;
		$$invalidate(0, value = selectedValue[valueKey]);
		itemSelected(selectedValue);
		handleClose();
	};

	const handleSearching = searchQuery => {
		if (isAsync && input == document.activeElement) {
			(async () => {
				$$invalidate(7, isSearching = true);
				$$invalidate(12, filteredList = await searchFunction(searchQuery));
				$$invalidate(7, isSearching = false);
			})();
		} else {
			$$invalidate(12, filteredList = searchFunction(searchQuery));
		}
	};

	const handleFocus = () => {
		handleSearching(value);
		$$invalidate(8, open = true);
	};

	let { name = "" } = $$props;
	let { placeholder = "" } = $$props;
	let { hasError = false } = $$props;
	let { label = "" } = $$props;
	let { errorMessage = "" } = $$props;
	let { disabled = false } = $$props;

	function textinput_value_binding(value$1) {
		value = value$1;
		$$invalidate(0, value);
	}

	function textinput_input_binding(value) {
		input = value;
		$$invalidate(11, input);
	}

	const focus_handler = () => handleFocus();
	const mouseenter_handler = i => $$invalidate(9, select = i);
	const click_handler = (i, opt) => handleSelected(i, opt);

	function ul_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			listBox = $$value;
			$$invalidate(10, listBox);
		});
	}

	const clickOutside_function = () => $$invalidate(8, open = false);

	$$self.$$set = $$props => {
		if ('searchFunction' in $$props) $$invalidate(16, searchFunction = $$props.searchFunction);
		if ('isAsync' in $$props) $$invalidate(17, isAsync = $$props.isAsync);
		if ('valueKey' in $$props) $$invalidate(18, valueKey = $$props.valueKey);
		if ('value' in $$props) $$invalidate(0, value = $$props.value);
		if ('name' in $$props) $$invalidate(2, name = $$props.name);
		if ('placeholder' in $$props) $$invalidate(3, placeholder = $$props.placeholder);
		if ('hasError' in $$props) $$invalidate(1, hasError = $$props.hasError);
		if ('label' in $$props) $$invalidate(4, label = $$props.label);
		if ('errorMessage' in $$props) $$invalidate(5, errorMessage = $$props.errorMessage);
		if ('disabled' in $$props) $$invalidate(6, disabled = $$props.disabled);
		if ('$$scope' in $$props) $$invalidate(19, $$scope = $$props.$$scope);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty[0] & /*searchFunction, value*/ 65537) {
			if (searchFunction) {
				handleSearching(value);
			}
		}
	};

	return [
		value,
		hasError,
		name,
		placeholder,
		label,
		errorMessage,
		disabled,
		isSearching,
		open,
		select,
		listBox,
		input,
		filteredList,
		handleListKeyInputs,
		handleSelected,
		handleFocus,
		searchFunction,
		isAsync,
		valueKey,
		$$scope,
		slots,
		textinput_value_binding,
		textinput_input_binding,
		focus_handler,
		mouseenter_handler,
		click_handler,
		ul_binding,
		clickOutside_function
	];
}

class AutoComplete extends SvelteComponent {
	constructor(options) {
		super();

		init(
			this,
			options,
			instance$q,
			create_fragment$q,
			safe_not_equal,
			{
				searchFunction: 16,
				isAsync: 17,
				valueKey: 18,
				value: 0,
				name: 2,
				placeholder: 3,
				hasError: 1,
				label: 4,
				errorMessage: 5,
				disabled: 6
			},
			null,
			[-1, -1]
		);
	}
}

/* src\List\List.svelte generated by Svelte v3.48.0 */

function create_fragment$p(ctx) {
	let ul;
	let clickOutside_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[5].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[4], null);

	return {
		c() {
			ul = element("ul");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			ul = claim_element(nodes, "UL", { tabindex: true, class: true });
			var ul_nodes = children(ul);
			if (default_slot) default_slot.l(ul_nodes);
			ul_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(ul, "tabindex", "-1");
			attr(ul, "class", "focus:outline-none");
		},
		m(target, anchor) {
			insert_hydration(target, ul, anchor);

			if (default_slot) {
				default_slot.m(ul, null);
			}

			/*ul_binding*/ ctx[6](ul);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(clickOutside_action = clickOutside.call(null, ul, /*clickOutside_function*/ ctx[7])),
					listen(ul, "blur", /*blur_handler*/ ctx[8]),
					listen(ul, "keydown", /*handleListKeyInputs*/ ctx[3])
				];

				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 16)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[4],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[4])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[4], dirty, null),
						null
					);
				}
			}

			if (clickOutside_action && is_function(clickOutside_action.update) && dirty & /*$selectedListItem*/ 2) clickOutside_action.update.call(null, /*clickOutside_function*/ ctx[7]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(ul);
			if (default_slot) default_slot.d(detaching);
			/*ul_binding*/ ctx[6](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

const LIST_KEY = {};

function instance$p($$self, $$props, $$invalidate) {
	let $selectedListItem;
	let { $$slots: slots = {}, $$scope } = $$props;
	const listitems = [];
	const selectedListItem = writable(null);
	component_subscribe($$self, selectedListItem, value => $$invalidate(1, $selectedListItem = value));
	let index = -1;
	let list;

	setContext(LIST_KEY, {
		registerItem: () => {
			index++;
			listitems.push(index);
			return index;
		},
		selectListItem: tab => {
			selectedListItem.set(tab);
		},
		selectedListItem,
		listitems
	});

	const handleListKeyInputs = e => {
		switch (e.key) {
			case "ArrowUp":
				if ($selectedListItem == 0) {
					set_store_value(selectedListItem, $selectedListItem = listitems.length - 1, $selectedListItem);
					return;
				}
				set_store_value(selectedListItem, $selectedListItem--, $selectedListItem);
				break;
			case "ArrowDown":
				if ($selectedListItem == listitems.length - 1) {
					set_store_value(selectedListItem, $selectedListItem = 0, $selectedListItem);
					return;
				}
				set_store_value(selectedListItem, $selectedListItem++, $selectedListItem);
				break;
			case "Escape":
				list.blur();
				break;
		}
	};

	function ul_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			list = $$value;
			$$invalidate(0, list);
		});
	}

	const clickOutside_function = () => set_store_value(selectedListItem, $selectedListItem = null, $selectedListItem);
	const blur_handler = () => set_store_value(selectedListItem, $selectedListItem = null, $selectedListItem);

	$$self.$$set = $$props => {
		if ('$$scope' in $$props) $$invalidate(4, $$scope = $$props.$$scope);
	};

	return [
		list,
		$selectedListItem,
		selectedListItem,
		handleListKeyInputs,
		$$scope,
		slots,
		ul_binding,
		clickOutside_function,
		blur_handler
	];
}

class List extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$p, create_fragment$p, safe_not_equal, {});
	}
}

/* src\List\ListItem.svelte generated by Svelte v3.48.0 */

function create_fragment$o(ctx) {
	let li;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[7].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[6], null);

	return {
		c() {
			li = element("li");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			li = claim_element(nodes, "LI", { class: true });
			var li_nodes = children(li);
			if (default_slot) default_slot.l(li_nodes);
			li_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(li, "class", /*CustomClass*/ ctx[0]);
			toggle_class(li, "bg-gray-200", /*$selectedListItem*/ ctx[2] == /*itemId*/ ctx[5]);
		},
		m(target, anchor) {
			insert_hydration(target, li, anchor);

			if (default_slot) {
				default_slot.m(li, null);
			}

			/*li_binding*/ ctx[9](li);
			current = true;

			if (!mounted) {
				dispose = [
					listen(li, "click", /*click_handler_1*/ ctx[10]),
					listen(li, "click", /*click_handler*/ ctx[8])
				];

				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 64)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[6],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[6])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[6], dirty, null),
						null
					);
				}
			}

			if (!current || dirty & /*CustomClass*/ 1) {
				attr(li, "class", /*CustomClass*/ ctx[0]);
			}

			if (dirty & /*CustomClass, $selectedListItem, itemId*/ 37) {
				toggle_class(li, "bg-gray-200", /*$selectedListItem*/ ctx[2] == /*itemId*/ ctx[5]);
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(li);
			if (default_slot) default_slot.d(detaching);
			/*li_binding*/ ctx[9](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

function instance$o($$self, $$props, $$invalidate) {
	let $selectedListItem;
	let { $$slots: slots = {}, $$scope } = $$props;
	let { CustomClass = "" } = $$props;
	const { selectListItem, registerItem, selectedListItem } = getContext(LIST_KEY);
	component_subscribe($$self, selectedListItem, value => $$invalidate(2, $selectedListItem = value));
	let listItem;
	const itemId = registerItem();

	selectedListItem.subscribe(c => {
		if (c == itemId) {
			listItem.focus();
		}
	});

	function click_handler(event) {
		bubble.call(this, $$self, event);
	}

	function li_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			listItem = $$value;
			$$invalidate(1, listItem);
		});
	}

	const click_handler_1 = () => selectListItem(itemId);

	$$self.$$set = $$props => {
		if ('CustomClass' in $$props) $$invalidate(0, CustomClass = $$props.CustomClass);
		if ('$$scope' in $$props) $$invalidate(6, $$scope = $$props.$$scope);
	};

	return [
		CustomClass,
		listItem,
		$selectedListItem,
		selectListItem,
		selectedListItem,
		itemId,
		$$scope,
		slots,
		click_handler,
		li_binding,
		click_handler_1
	];
}

class ListItem extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$o, create_fragment$o, safe_not_equal, { CustomClass: 0 });
	}
}

/* src\Loader\LinearProgress.svelte generated by Svelte v3.48.0 */

function create_else_block$4(ctx) {
	let div;
	let div_class_value;

	return {
		c() {
			div = element("div");
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true, style: true });
			children(div).forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", div_class_value = "h-full relative " + /*kind*/ ctx[2] + " svelte-vxwdgo");
			set_style(div, "width", /*progress*/ ctx[0] + "%");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
		},
		p(ctx, dirty) {
			if (dirty & /*kind*/ 4 && div_class_value !== (div_class_value = "h-full relative " + /*kind*/ ctx[2] + " svelte-vxwdgo")) {
				attr(div, "class", div_class_value);
			}

			if (dirty & /*progress*/ 1) {
				set_style(div, "width", /*progress*/ ctx[0] + "%");
			}
		},
		d(detaching) {
			if (detaching) detach(div);
		}
	};
}

// (43:2) {#if continuous}
function create_if_block$a(ctx) {
	let div;
	let div_class_value;

	return {
		c() {
			div = element("div");
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			children(div).forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", div_class_value = "h-full relative loader " + /*kind*/ ctx[2] + " svelte-vxwdgo");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
		},
		p(ctx, dirty) {
			if (dirty & /*kind*/ 4 && div_class_value !== (div_class_value = "h-full relative loader " + /*kind*/ ctx[2] + " svelte-vxwdgo")) {
				attr(div, "class", div_class_value);
			}
		},
		d(detaching) {
			if (detaching) detach(div);
		}
	};
}

function create_fragment$n(ctx) {
	let div1;
	let div0;
	let t;
	let div1_class_value;

	function select_block_type(ctx, dirty) {
		if (/*continuous*/ ctx[1]) return create_if_block$a;
		return create_else_block$4;
	}

	let current_block_type = select_block_type(ctx);
	let if_block = current_block_type(ctx);

	return {
		c() {
			div1 = element("div");
			div0 = element("div");
			t = space();
			if_block.c();
			this.h();
		},
		l(nodes) {
			div1 = claim_element(nodes, "DIV", { class: true });
			var div1_nodes = children(div1);
			div0 = claim_element(div1_nodes, "DIV", { class: true });
			children(div0).forEach(detach);
			t = claim_space(div1_nodes);
			if_block.l(div1_nodes);
			div1_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div0, "class", "w-full h-full bg-gray-200 absolute");
			attr(div1, "class", div1_class_value = "" + (/*height*/ ctx[3] + " relative max-w-xl rounded-full overflow-hidden" + " svelte-vxwdgo"));
		},
		m(target, anchor) {
			insert_hydration(target, div1, anchor);
			append_hydration(div1, div0);
			append_hydration(div1, t);
			if_block.m(div1, null);
		},
		p(ctx, [dirty]) {
			if (current_block_type === (current_block_type = select_block_type(ctx)) && if_block) {
				if_block.p(ctx, dirty);
			} else {
				if_block.d(1);
				if_block = current_block_type(ctx);

				if (if_block) {
					if_block.c();
					if_block.m(div1, null);
				}
			}

			if (dirty & /*height*/ 8 && div1_class_value !== (div1_class_value = "" + (/*height*/ ctx[3] + " relative max-w-xl rounded-full overflow-hidden" + " svelte-vxwdgo"))) {
				attr(div1, "class", div1_class_value);
			}
		},
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(div1);
			if_block.d();
		}
	};
}

function instance$n($$self, $$props, $$invalidate) {
	let { progress = null } = $$props;
	let { continuous = false } = $$props;
	let { size = "small" } = $$props;
	let { kind = "dark" } = $$props;
	let height;

	switch (size) {
		case "small":
			height = "h-2";
			break;
		case "medium":
			height = "h-3";
			break;
		case "large":
			height = "h-4";
			break;
	}

	$$self.$$set = $$props => {
		if ('progress' in $$props) $$invalidate(0, progress = $$props.progress);
		if ('continuous' in $$props) $$invalidate(1, continuous = $$props.continuous);
		if ('size' in $$props) $$invalidate(4, size = $$props.size);
		if ('kind' in $$props) $$invalidate(2, kind = $$props.kind);
	};

	return [progress, continuous, kind, height, size];
}

class LinearProgress extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$n, create_fragment$n, safe_not_equal, {
			progress: 0,
			continuous: 1,
			size: 4,
			kind: 2
		});
	}
}

var State;
(function (State) {
    State[State["Open"] = 0] = "Open";
    State[State["Closed"] = 1] = "Closed";
})(State || (State = {}));
const OPEN_CLOSED_CONTEXT_NAME = "headlessui-open-closed-context";
function hasOpenClosed() {
    return useOpenClosed() !== undefined;
}
function useOpenClosed() {
    return getContext(OPEN_CLOSED_CONTEXT_NAME);
}
function useOpenClosedProvider(value) {
    setContext(OPEN_CLOSED_CONTEXT_NAME, value);
}

function match(value, lookup, ...args) {
    if (value in lookup) {
        let returnValue = lookup[value];
        return typeof returnValue === "function"
            ? returnValue(...args)
            : returnValue;
    }
    let error = new Error(`Tried to handle "${value}" but there is no handler defined. Only defined handlers are: ${Object.keys(lookup)
        .map((key) => `"${key}"`)
        .join(", ")}.`);
    if (Error.captureStackTrace)
        Error.captureStackTrace(error, match);
    throw error;
}

let id$1 = 0;
function generateId() {
    return ++id$1;
}
function useId() {
    return generateId();
}

let interactables = new Set();
let originals = new Map();
function inert(element) {
    element.setAttribute("aria-hidden", "true");
    // @ts-expect-error `inert` does not exist on HTMLElement (yet!)
    element.inert = true;
}
function restore(element) {
    let original = originals.get(element);
    if (!original)
        return;
    if (original["aria-hidden"] === null)
        element.removeAttribute("aria-hidden");
    else
        element.setAttribute("aria-hidden", original["aria-hidden"]);
    // @ts-expect-error `inert` does not exist on HTMLElement (yet!)
    element.inert = original.inert;
}
function useInertOthers(container, enabled = true) {
    if (!enabled)
        return;
    if (!container)
        return;
    let element = container;
    // Mark myself as an interactable element
    interactables.add(element);
    // Restore elements that now contain an interactable child
    for (let original of originals.keys()) {
        if (original.contains(element)) {
            restore(original);
            originals.delete(original);
        }
    }
    // Collect direct children of the body
    document.querySelectorAll("body > *").forEach((child) => {
        if (!(child instanceof HTMLElement))
            return; // Skip non-HTMLElements
        // Skip the interactables, and the parents of the interactables
        for (let interactable of interactables) {
            if (child.contains(interactable))
                return;
        }
        // Keep track of the elements
        if (interactables.size === 1) {
            originals.set(child, {
                "aria-hidden": child.getAttribute("aria-hidden"),
                // @ts-expect-error `inert` does not exist on HTMLElement (yet!)
                inert: child.inert,
            });
            // Mutate the element
            inert(child);
        }
    });
    return () => {
        // Inert is disabled on the current element
        interactables.delete(element);
        // We still have interactable elements, therefore this one and its parent
        // will become inert as well.
        if (interactables.size > 0) {
            // Collect direct children of the body
            document.querySelectorAll("body > *").forEach((child) => {
                if (!(child instanceof HTMLElement))
                    return; // Skip non-HTMLElements
                // Skip already inert parents
                if (originals.has(child))
                    return;
                // Skip the interactables, and the parents of the interactables
                for (let interactable of interactables) {
                    if (child.contains(interactable))
                        return;
                }
                originals.set(child, {
                    "aria-hidden": child.getAttribute("aria-hidden"),
                    // @ts-expect-error `inert` does not exist on HTMLElement (yet!)
                    inert: child.inert,
                });
                // Mutate the element
                inert(child);
            });
        }
        else {
            for (let element of originals.keys()) {
                // Restore
                restore(element);
                // Cleanup
                originals.delete(element);
            }
        }
    };
}

function contains(containers, element) {
    for (let container of containers) {
        if (container.contains(element))
            return true;
    }
    return false;
}

// TODO: This must already exist somewhere, right? 🤔
// Ref: https://www.w3.org/TR/uievents-key/#named-key-attribute-values
var Keys;
(function (Keys) {
    Keys["Space"] = " ";
    Keys["Enter"] = "Enter";
    Keys["Escape"] = "Escape";
    Keys["Backspace"] = "Backspace";
    Keys["Delete"] = "Delete";
    Keys["ArrowLeft"] = "ArrowLeft";
    Keys["ArrowUp"] = "ArrowUp";
    Keys["ArrowRight"] = "ArrowRight";
    Keys["ArrowDown"] = "ArrowDown";
    Keys["Home"] = "Home";
    Keys["End"] = "End";
    Keys["PageUp"] = "PageUp";
    Keys["PageDown"] = "PageDown";
    Keys["Tab"] = "Tab";
})(Keys || (Keys = {}));

// Credit:
//  - https://stackoverflow.com/a/30753870
let focusableSelector = [
    "[contentEditable=true]",
    "[tabindex]",
    "a[href]",
    "area[href]",
    "button:not([disabled])",
    "iframe",
    "input:not([disabled])",
    "select:not([disabled])",
    "textarea:not([disabled])",
]
    .map(process.env.NODE_ENV === "test"
    ? // TODO: Remove this once JSDOM fixes the issue where an element that is
        // "hidden" can be the document.activeElement, because this is not possible
        // in real browsers.
        (selector) => `${selector}:not([tabindex='-1']):not([style*='display: none'])`
    : (selector) => `${selector}:not([tabindex='-1'])`)
    .join(",");
var Focus$1;
(function (Focus) {
    /** Focus the first non-disabled element */
    Focus[Focus["First"] = 1] = "First";
    /** Focus the previous non-disabled element */
    Focus[Focus["Previous"] = 2] = "Previous";
    /** Focus the next non-disabled element */
    Focus[Focus["Next"] = 4] = "Next";
    /** Focus the last non-disabled element */
    Focus[Focus["Last"] = 8] = "Last";
    /** Wrap tab around */
    Focus[Focus["WrapAround"] = 16] = "WrapAround";
    /** Prevent scrolling the focusable elements into view */
    Focus[Focus["NoScroll"] = 32] = "NoScroll";
})(Focus$1 || (Focus$1 = {}));
var FocusResult;
(function (FocusResult) {
    FocusResult[FocusResult["Error"] = 0] = "Error";
    FocusResult[FocusResult["Overflow"] = 1] = "Overflow";
    FocusResult[FocusResult["Success"] = 2] = "Success";
    FocusResult[FocusResult["Underflow"] = 3] = "Underflow";
})(FocusResult || (FocusResult = {}));
var Direction;
(function (Direction) {
    Direction[Direction["Previous"] = -1] = "Previous";
    Direction[Direction["Next"] = 1] = "Next";
})(Direction || (Direction = {}));
function getFocusableElements(container = document.body) {
    if (container == null)
        return [];
    return Array.from(container.querySelectorAll(focusableSelector));
}
var FocusableMode;
(function (FocusableMode) {
    /** The element itself must be focusable. */
    FocusableMode[FocusableMode["Strict"] = 0] = "Strict";
    /** The element should be inside of a focusable element. */
    FocusableMode[FocusableMode["Loose"] = 1] = "Loose";
})(FocusableMode || (FocusableMode = {}));
function focusElement(element) {
    element?.focus({ preventScroll: true });
}
function focusIn(container, focus) {
    let elements = Array.isArray(container)
        ? container
        : getFocusableElements(container);
    let active = document.activeElement;
    let direction = (() => {
        if (focus & (Focus$1.First | Focus$1.Next))
            return Direction.Next;
        if (focus & (Focus$1.Previous | Focus$1.Last))
            return Direction.Previous;
        throw new Error("Missing Focus.First, Focus.Previous, Focus.Next or Focus.Last");
    })();
    let startIndex = (() => {
        if (focus & Focus$1.First)
            return 0;
        if (focus & Focus$1.Previous)
            return Math.max(0, elements.indexOf(active)) - 1;
        if (focus & Focus$1.Next)
            return Math.max(0, elements.indexOf(active)) + 1;
        if (focus & Focus$1.Last)
            return elements.length - 1;
        throw new Error("Missing Focus.First, Focus.Previous, Focus.Next or Focus.Last");
    })();
    let focusOptions = focus & Focus$1.NoScroll ? { preventScroll: true } : {};
    let offset = 0;
    let total = elements.length;
    let next = undefined;
    do {
        // Guard against infinite loops
        if (offset >= total || offset + total <= 0)
            return FocusResult.Error;
        let nextIdx = startIndex + offset;
        if (focus & Focus$1.WrapAround) {
            nextIdx = (nextIdx + total) % total;
        }
        else {
            if (nextIdx < 0)
                return FocusResult.Underflow;
            if (nextIdx >= total)
                return FocusResult.Overflow;
        }
        next = elements[nextIdx];
        // Try the focus the next element, might not work if it is "hidden" to the user.
        next?.focus(focusOptions);
        // Try the next one in line
        offset += direction;
    } while (next !== document.activeElement);
    // This is a little weird, but let me try and explain: There are a few scenario's
    // in chrome for example where a focused `<a>` tag does not get the default focus
    // styles and sometimes they do. This highly depends on whether you started by
    // clicking or by using your keyboard. When you programmatically add focus `anchor.focus()`
    // then the active element (document.activeElement) is this anchor, which is expected.
    // However in that case the default focus styles are not applied *unless* you
    // also add this tabindex.
    if (!next.hasAttribute("tabindex"))
        next.setAttribute("tabindex", "0");
    return FocusResult.Success;
}

/* node_modules\svelte-headlessui-combobox-temporary\components\focus-trap\FocusTrap.svelte generated by Svelte v3.48.0 */

const { window: window_1$1 } = globals;

function create_fragment$m(ctx) {
	let mounted;
	let dispose;

	return {
		c: noop,
		l: noop,
		m(target, anchor) {
			if (!mounted) {
				dispose = [
					listen(window_1$1, "keydown", /*handleWindowKeyDown*/ ctx[0]),
					listen(window_1$1, "focus", /*handleWindowFocus*/ ctx[1], true)
				];

				mounted = true;
			}
		},
		p: noop,
		i: noop,
		o: noop,
		d(detaching) {
			mounted = false;
			run_all(dispose);
		}
	};
}

function instance$m($$self, $$props, $$invalidate) {
	let { containers } = $$props;
	let { enabled = true } = $$props;
	let { options = {} } = $$props;

	let restoreElement = typeof window !== "undefined"
	? document.activeElement
	: null;

	let previousActiveElement = null;

	async function handleFocus() {
		if (!enabled) return;
		if (containers.size !== 1) return;
		let { initialFocus } = options;
		await tick();
		let activeElement = document.activeElement;

		if (initialFocus) {
			if (initialFocus === activeElement) {
				return; // Initial focus ref is already the active element
			}
		} else if (contains(containers, activeElement)) {
			return; // Already focused within Dialog
		}

		restoreElement = activeElement;

		// Try to focus the initialFocus ref
		if (initialFocus) {
			focusElement(initialFocus);
		} else {
			let couldFocus = false;

			for (let container of containers) {
				let result = focusIn(container, Focus$1.First);

				if (result === FocusResult.Success) {
					couldFocus = true;
					break;
				}
			}

			if (!couldFocus) console.warn("There are no focusable elements inside the <FocusTrap />");
		}

		previousActiveElement = document.activeElement;
	}

	// Restore when `enabled` becomes false
	function restore() {
		focusElement(restoreElement);
		restoreElement = null;
		previousActiveElement = null;
	}

	// Handle initial focus
	onMount(handleFocus);

	// When this component is being destroyed, focusElement is called
	// before handleWindowFocus is removed, so in the svelte port we add this
	// to ignore the handler.
	let destroying = false;

	onDestroy(() => {
		destroying = true;
		restore();
	});

	// Handle Tab & Shift+Tab keyboard events
	function handleWindowKeyDown(event) {
		if (!enabled) return;
		if (event.key !== Keys.Tab) return;
		if (!document.activeElement) return;
		if (containers.size !== 1) return;
		event.preventDefault();

		for (let element of containers) {
			let result = focusIn(element, (event.shiftKey ? Focus$1.Previous : Focus$1.Next) | Focus$1.WrapAround);

			if (result === FocusResult.Success) {
				previousActiveElement = document.activeElement;
				break;
			}
		}
	}

	// Prevent programmatically escaping
	function handleWindowFocus(event) {
		if (event.target === window.document.body) {
			// Workaround for a SvelteKit issue: https://github.com/sveltejs/kit/issues/3501
			return;
		}

		if (!enabled) return;
		if (containers.size !== 1) return;
		if (destroying) return;
		let previous = previousActiveElement;
		if (!previous) return;
		let toElement = event.target;

		if (toElement && toElement instanceof HTMLElement) {
			if (!contains(containers, toElement)) {
				event.preventDefault();
				event.stopPropagation();
				focusElement(previous);
			} else {
				previousActiveElement = toElement;
				focusElement(toElement);
			}
		} else {
			focusElement(previousActiveElement);
		}
	}

	$$self.$$set = $$props => {
		if ('containers' in $$props) $$invalidate(2, containers = $$props.containers);
		if ('enabled' in $$props) $$invalidate(3, enabled = $$props.enabled);
		if ('options' in $$props) $$invalidate(4, options = $$props.options);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*enabled, containers*/ 12) {
			enabled && containers ? handleFocus() : restore();
		}
	};

	return [handleWindowKeyDown, handleWindowFocus, containers, enabled, options];
}

class FocusTrap extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$m, create_fragment$m, safe_not_equal, { containers: 2, enabled: 3, options: 4 });
	}
}

/* node_modules\svelte-headlessui-combobox-temporary\internal\StackContextProvider.svelte generated by Svelte v3.48.0 */

function create_fragment$l(ctx) {
	let current;
	const default_slot_template = /*#slots*/ ctx[4].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[3], null);

	return {
		c() {
			if (default_slot) default_slot.c();
		},
		l(nodes) {
			if (default_slot) default_slot.l(nodes);
		},
		m(target, anchor) {
			if (default_slot) {
				default_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 8)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[3],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[3])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[3], dirty, null),
						null
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (default_slot) default_slot.d(detaching);
		}
	};
}

var StackMessage;

(function (StackMessage) {
	StackMessage[StackMessage["Add"] = 0] = "Add";
	StackMessage[StackMessage["Remove"] = 1] = "Remove";
})(StackMessage || (StackMessage = {}));

const STACK_CONTEXT_NAME = "headlessui-stack-context";

function instance$l($$self, $$props, $$invalidate) {
	let _cleanup;
	let { $$slots: slots = {}, $$scope } = $$props;
	let { onUpdate } = $$props;
	let { element } = $$props;

	function notify(...args) {
		// Notify our layer
		onUpdate?.(...args);

		// Notify the parent
		parentUpdate?.(...args);
	}

	let parentUpdate = getContext(STACK_CONTEXT_NAME);
	setContext(STACK_CONTEXT_NAME, notify);

	onDestroy(() => {
		if (_cleanup) {
			_cleanup();
		}
	});

	$$self.$$set = $$props => {
		if ('onUpdate' in $$props) $$invalidate(0, onUpdate = $$props.onUpdate);
		if ('element' in $$props) $$invalidate(1, element = $$props.element);
		if ('$$scope' in $$props) $$invalidate(3, $$scope = $$props.$$scope);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*_cleanup, element*/ 6) {
			$$invalidate(2, _cleanup = (() => {
				if (_cleanup) {
					_cleanup();
				}

				if (!element) return null;
				let savedElement = element;
				notify(StackMessage.Add, savedElement);
				return () => notify(StackMessage.Remove, savedElement);
			})());
		}
	};

	return [onUpdate, element, _cleanup, $$scope, slots];
}

class StackContextProvider extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$l, create_fragment$l, safe_not_equal, { onUpdate: 0, element: 1 });
	}
}

/* node_modules\svelte-headlessui-combobox-temporary\components\description\DescriptionProvider.svelte generated by Svelte v3.48.0 */
const get_default_slot_changes$5 = dirty => ({ describedby: dirty & /*$contextStore*/ 1 });

const get_default_slot_context$5 = ctx => ({
	describedby: /*$contextStore*/ ctx[0].descriptionIds
});

function create_fragment$k(ctx) {
	let current;
	const default_slot_template = /*#slots*/ ctx[6].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[5], get_default_slot_context$5);

	return {
		c() {
			if (default_slot) default_slot.c();
		},
		l(nodes) {
			if (default_slot) default_slot.l(nodes);
		},
		m(target, anchor) {
			if (default_slot) {
				default_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope, $contextStore*/ 33)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[5],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[5])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[5], dirty, get_default_slot_changes$5),
						get_default_slot_context$5
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (default_slot) default_slot.d(detaching);
		}
	};
}

const DESCRIPTION_CONTEXT_NAME = "headlessui-description-context";

function instance$k($$self, $$props, $$invalidate) {
	const omit_props_names = ["name","slotProps"];
	let $$restProps = compute_rest_props($$props, omit_props_names);
	let $contextStore;
	let { $$slots: slots = {}, $$scope } = $$props;
	let { name } = $$props;
	let { slotProps = {} } = $$props;
	let descriptionIds = [];

	let contextStore = writable({
		name,
		slotProps,
		props: $$restProps,
		register
	});

	component_subscribe($$self, contextStore, value => $$invalidate(0, $contextStore = value));
	setContext(DESCRIPTION_CONTEXT_NAME, contextStore);

	function register(value) {
		$$invalidate(4, descriptionIds = [...descriptionIds, value]);

		return () => {
			$$invalidate(4, descriptionIds = descriptionIds.filter(descriptionId => descriptionId !== value));
		};
	}

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(8, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('name' in $$new_props) $$invalidate(2, name = $$new_props.name);
		if ('slotProps' in $$new_props) $$invalidate(3, slotProps = $$new_props.slotProps);
		if ('$$scope' in $$new_props) $$invalidate(5, $$scope = $$new_props.$$scope);
	};

	$$self.$$.update = () => {
		contextStore.set({
			name,
			slotProps,
			props: $$restProps,
			register,
			descriptionIds: descriptionIds.length > 0
			? descriptionIds.join(" ")
			: undefined
		});
	};

	return [$contextStore, contextStore, name, slotProps, descriptionIds, $$scope, slots];
}

class DescriptionProvider extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$k, create_fragment$k, safe_not_equal, { name: 2, slotProps: 3 });
	}
}

/* node_modules\svelte-headlessui-combobox-temporary\internal\ForcePortalRootContext.svelte generated by Svelte v3.48.0 */

function create_fragment$j(ctx) {
	let current;
	const default_slot_template = /*#slots*/ ctx[2].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[1], null);

	return {
		c() {
			if (default_slot) default_slot.c();
		},
		l(nodes) {
			if (default_slot) default_slot.l(nodes);
		},
		m(target, anchor) {
			if (default_slot) {
				default_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 2)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[1],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[1])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[1], dirty, null),
						null
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (default_slot) default_slot.d(detaching);
		}
	};
}

const FORCE_PORTAL_ROOT_CONTEXT_NAME = "headlessui-force-portal-root-context";

function usePortalRoot() {
	return getContext(FORCE_PORTAL_ROOT_CONTEXT_NAME);
}

function instance$j($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	let { force } = $$props;
	setContext(FORCE_PORTAL_ROOT_CONTEXT_NAME, writable(force));

	$$self.$$set = $$props => {
		if ('force' in $$props) $$invalidate(0, force = $$props.force);
		if ('$$scope' in $$props) $$invalidate(1, $$scope = $$props.$$scope);
	};

	return [force, $$scope, slots];
}

class ForcePortalRootContext extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$j, create_fragment$j, safe_not_equal, { force: 0 });
	}
}

/* node_modules\svelte-headlessui-combobox-temporary\components\portal\PortalGroup.svelte generated by Svelte v3.48.0 */

function create_fragment$i(ctx) {
	let current;
	const default_slot_template = /*#slots*/ ctx[2].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[1], null);

	return {
		c() {
			if (default_slot) default_slot.c();
		},
		l(nodes) {
			if (default_slot) default_slot.l(nodes);
		},
		m(target, anchor) {
			if (default_slot) {
				default_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 2)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[1],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[1])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[1], dirty, null),
						null
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (default_slot) default_slot.d(detaching);
		}
	};
}

const PORTAL_GROUP_CONTEXT_NAME = "headlessui-portal-group-context";

function usePortalGroupContext() {
	return getContext(PORTAL_GROUP_CONTEXT_NAME);
}

function instance$i($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	let { target } = $$props;
	let targetStore = writable(target);
	setContext(PORTAL_GROUP_CONTEXT_NAME, targetStore);

	$$self.$$set = $$props => {
		if ('target' in $$props) $$invalidate(0, target = $$props.target);
		if ('$$scope' in $$props) $$invalidate(1, $$scope = $$props.$$scope);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*target*/ 1) {
			targetStore.set(target);
		}
	};

	return [target, $$scope, slots];
}

class PortalGroup extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$i, create_fragment$i, safe_not_equal, { target: 0 });
	}
}

function portal(element, target) {
    if (target) {
        target.append(element);
    }
    return {
        update(newTarget) {
            target = newTarget;
            newTarget.append(element);
        },
        destroy() {
            // Need to detach ourselves--we can't rely on Svelte always detaching
            // us since we moved in the component tree.
            if (target?.contains(element)) {
                target.removeChild(element);
            }
            if (target && target.childNodes.length <= 0) {
                target.parentElement?.removeChild(target);
            }
        },
    };
}

/* node_modules\svelte-headlessui-combobox-temporary\components\portal\Portal.svelte generated by Svelte v3.48.0 */

function create_fragment$h(ctx) {
	let div;
	let portal_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[6].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[5], null);

	return {
		c() {
			div = element("div");
			if (default_slot) default_slot.c();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", {});
			var div_nodes = children(div);
			if (default_slot) default_slot.l(div_nodes);
			div_nodes.forEach(detach);
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);

			if (default_slot) {
				default_slot.m(div, null);
			}

			current = true;

			if (!mounted) {
				dispose = action_destroyer(portal_action = portal.call(null, div, /*target*/ ctx[0]));
				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 32)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[5],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[5])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[5], dirty, null),
						null
					);
				}
			}

			if (portal_action && is_function(portal_action.update) && dirty & /*target*/ 1) portal_action.update.call(null, /*target*/ ctx[0]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			if (default_slot) default_slot.d(detaching);
			mounted = false;
			dispose();
		}
	};
}

function instance$h($$self, $$props, $$invalidate) {
	let target;
	let $groupTarget;
	let $forceInRoot;
	let { $$slots: slots = {}, $$scope } = $$props;
	let forceInRoot = usePortalRoot();
	component_subscribe($$self, forceInRoot, value => $$invalidate(4, $forceInRoot = value));
	let groupTarget = usePortalGroupContext();
	component_subscribe($$self, groupTarget, value => $$invalidate(3, $groupTarget = value));

	$$self.$$set = $$props => {
		if ('$$scope' in $$props) $$invalidate(5, $$scope = $$props.$$scope);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*$forceInRoot, $groupTarget*/ 24) {
			$$invalidate(0, target = (() => {
				// Group context is used, but still null
				if (!(forceInRoot && $forceInRoot) && groupTarget !== undefined && $groupTarget !== null) return $groupTarget;

				// No group context is used, let's create a default portal root
				if (typeof window === "undefined") return null;

				let existingRoot = document.getElementById("headlessui-portal-root");
				if (existingRoot) return existingRoot;
				let root = document.createElement("div");
				root.setAttribute("id", "headlessui-portal-root");

				// During initial render, the "portal" might be constructed before
				// the root component has even attached, causing the portal to not work.
				// This is a workaround for this issue--it can't guarantee the portal is
				// **always** last, but it should catch the normal cases.
				tick().then(() => {
					if (root !== document.body.lastChild) {
						document.body.appendChild(root);
					}
				});

				return document.body.appendChild(root);
			})());
		}
	};

	return [target, forceInRoot, groupTarget, $groupTarget, $forceInRoot, $$scope, slots];
}

class Portal extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$h, create_fragment$h, safe_not_equal, {});
	}
}

const MODIFIER_DIVIDER = "!";
const modifierRegex = new RegExp(`^[^${MODIFIER_DIVIDER}]+(?:${MODIFIER_DIVIDER}(?:preventDefault|stopPropagation|passive|nonpassive|capture|once|self))+$`);
function forwardEventsBuilder(component, except = []) {
    // This is our pseudo $on function. It is defined on component mount.
    let $on;
    // This is a list of events bound before mount.
    let events = [];
    // And we override the $on function to forward all bound events.
    component.$on = (fullEventType, callback) => {
        let eventType = fullEventType;
        let destructor = () => { };
        for (let exception of except) {
            if (typeof exception === "string" && exception === eventType) {
                // Bail out of the event forwarding and run the normal Svelte $on() code
                const callbacks = component.$$.callbacks[eventType] ||
                    (component.$$.callbacks[eventType] = []);
                callbacks.push(callback);
                return () => {
                    const index = callbacks.indexOf(callback);
                    if (index !== -1)
                        callbacks.splice(index, 1);
                };
            }
            if (typeof exception === "object" && exception["name"] === eventType) {
                let oldCallback = callback;
                callback = (...props) => {
                    if (!(typeof exception === "object" && exception["shouldExclude"]())) {
                        oldCallback(...props);
                    }
                };
            }
        }
        if ($on) {
            // The event was bound programmatically.
            destructor = $on(eventType, callback);
        }
        else {
            // The event was bound before mount by Svelte.
            events.push([eventType, callback]);
        }
        return () => {
            destructor();
        };
    };
    function forward(e) {
        // Internally bubble the event up from Svelte components.
        bubble(component, e);
    }
    return (node) => {
        const destructors = [];
        const forwardDestructors = {};
        // This function is responsible for listening and forwarding
        // all bound events.
        $on = (fullEventType, callback) => {
            let eventType = fullEventType;
            let handler = callback;
            // DOM addEventListener options argument.
            let options = false;
            const modifierMatch = eventType.match(modifierRegex);
            if (modifierMatch) {
                // Parse the event modifiers.
                // Supported modifiers:
                // - preventDefault
                // - stopPropagation
                // - passive
                // - nonpassive
                // - capture
                // - once
                const parts = eventType.split(MODIFIER_DIVIDER);
                eventType = parts[0];
                const eventOptions = Object.fromEntries(parts.slice(1).map((mod) => [mod, true]));
                if (eventOptions.passive) {
                    options = options || {};
                    options.passive = true;
                }
                if (eventOptions.nonpassive) {
                    options = options || {};
                    options.passive = false;
                }
                if (eventOptions.capture) {
                    options = options || {};
                    options.capture = true;
                }
                if (eventOptions.once) {
                    options = options || {};
                    options.once = true;
                }
                if (eventOptions.preventDefault) {
                    handler = prevent_default(handler);
                }
                if (eventOptions.stopPropagation) {
                    handler = stop_propagation(handler);
                }
            }
            // Listen for the event directly, with the given options.
            const off = listen(node, eventType, handler, options);
            const destructor = () => {
                off();
                const idx = destructors.indexOf(destructor);
                if (idx > -1) {
                    destructors.splice(idx, 1);
                }
            };
            destructors.push(destructor);
            // Forward the event from Svelte.
            if (!(eventType in forwardDestructors)) {
                forwardDestructors[eventType] = listen(node, eventType, forward);
            }
            return destructor;
        };
        for (let i = 0; i < events.length; i++) {
            // Listen to all the events added before mount.
            $on(events[i][0], events[i][1]);
        }
        return {
            destroy: () => {
                // Remove all event listeners.
                for (let i = 0; i < destructors.length; i++) {
                    destructors[i]();
                }
                // Remove all event forwarders.
                for (let entry of Object.entries(forwardDestructors)) {
                    entry[1]();
                }
            },
        };
    };
}

const components = [
    "a",
    "address",
    "article",
    "aside",
    "b",
    "bdi",
    "bdo",
    "blockquote",
    "button",
    "cite",
    "code",
    "data",
    "datalist",
    "dd",
    "dl",
    "dt",
    "div",
    "em",
    "footer",
    "form",
    "h1",
    "h2",
    "h3",
    "h4",
    "h5",
    "h6",
    "header",
    "i",
    "input",
    "label",
    "li",
    "main",
    "nav",
    "ol",
    "p",
    "section",
    "span",
    "strong",
    "ul",
];
function isValidElement(element) {
    return !(typeof element === "string" && !components.includes(element));
}

function useActions(node, actions) {
    let actionReturns = [];
    if (actions) {
        for (let i = 0; i < actions.length; i++) {
            const actionEntry = actions[i];
            const action = Array.isArray(actionEntry) ? actionEntry[0] : actionEntry;
            if (Array.isArray(actionEntry) && actionEntry.length > 1) {
                actionReturns.push(action(node, actionEntry[1]));
            }
            else {
                actionReturns.push(action(node));
            }
        }
    }
    return {
        update(actions) {
            if (((actions && actions.length) || 0) != actionReturns.length) {
                throw new Error("You must not change the length of an actions array.");
            }
            if (actions) {
                for (let i = 0; i < actions.length; i++) {
                    const returnEntry = actionReturns[i];
                    if (returnEntry && returnEntry.update) {
                        const actionEntry = actions[i];
                        if (Array.isArray(actionEntry) && actionEntry.length > 1) {
                            returnEntry.update(actionEntry[1]);
                        }
                        else {
                            returnEntry.update();
                        }
                    }
                }
            }
        },
        destroy() {
            for (let i = 0; i < actionReturns.length; i++) {
                const returnEntry = actionReturns[i];
                if (returnEntry && returnEntry.destroy) {
                    returnEntry.destroy();
                }
            }
        },
    };
}

/// <reference types="svelte2tsx/svelte-jsx" />
// Can't figure out how to import from Render.svelte, so this must be moved here instead.
var Features$1;
(function (Features) {
    /** No features at all */
    Features[Features["None"] = 0] = "None";
    /**
     * When used, this will allow us to use one of the render strategies.
     *
     * **The render strategies are:**
     *    - **Unmount**   _(Will unmount the component.)_
     *    - **Hidden**    _(Will hide the component using the [hidden] attribute.)_
     */
    Features[Features["RenderStrategy"] = 1] = "RenderStrategy";
    /**
     * When used, this will allow the user of our component to be in control. This can be used when
     * you want to transition based on some state.
     */
    Features[Features["Static"] = 2] = "Static";
})(Features$1 || (Features$1 = {}));

/* node_modules\svelte-headlessui-combobox-temporary\utils\Render.svelte generated by Svelte v3.48.0 */

function create_if_block$9(ctx) {
	let current_block_type_index;
	let if_block;
	let if_block_anchor;
	let current;

	const if_block_creators = [
		create_if_block_1$3,
		create_if_block_2$3,
		create_if_block_3$2,
		create_if_block_4$2,
		create_if_block_5$2,
		create_if_block_6$1,
		create_if_block_7$1,
		create_if_block_8,
		create_if_block_9,
		create_if_block_10,
		create_if_block_11,
		create_if_block_12,
		create_if_block_13,
		create_if_block_14,
		create_if_block_15,
		create_if_block_16,
		create_if_block_17,
		create_if_block_18,
		create_if_block_19,
		create_if_block_20,
		create_if_block_21,
		create_if_block_22,
		create_if_block_23,
		create_if_block_24,
		create_if_block_25,
		create_if_block_26,
		create_if_block_27,
		create_if_block_28,
		create_if_block_29,
		create_if_block_30,
		create_if_block_31,
		create_if_block_32,
		create_if_block_33,
		create_if_block_34,
		create_if_block_35,
		create_if_block_36,
		create_if_block_37,
		create_if_block_38,
		create_if_block_39,
		create_else_block$3
	];

	const if_blocks = [];

	function select_block_type(ctx, dirty) {
		if (/*as*/ ctx[1] === "a") return 0;
		if (/*as*/ ctx[1] === "address") return 1;
		if (/*as*/ ctx[1] === "article") return 2;
		if (/*as*/ ctx[1] === "aside") return 3;
		if (/*as*/ ctx[1] === "b") return 4;
		if (/*as*/ ctx[1] === "bdi") return 5;
		if (/*as*/ ctx[1] === "bdo") return 6;
		if (/*as*/ ctx[1] === "blockquote") return 7;
		if (/*as*/ ctx[1] === "button") return 8;
		if (/*as*/ ctx[1] === "cite") return 9;
		if (/*as*/ ctx[1] === "code") return 10;
		if (/*as*/ ctx[1] === "data") return 11;
		if (/*as*/ ctx[1] === "datalist") return 12;
		if (/*as*/ ctx[1] === "dd") return 13;
		if (/*as*/ ctx[1] === "dl") return 14;
		if (/*as*/ ctx[1] === "dt") return 15;
		if (/*as*/ ctx[1] === "div") return 16;
		if (/*as*/ ctx[1] === "em") return 17;
		if (/*as*/ ctx[1] === "footer") return 18;
		if (/*as*/ ctx[1] === "form") return 19;
		if (/*as*/ ctx[1] === "h1") return 20;
		if (/*as*/ ctx[1] === "h2") return 21;
		if (/*as*/ ctx[1] === "h3") return 22;
		if (/*as*/ ctx[1] === "h4") return 23;
		if (/*as*/ ctx[1] === "h5") return 24;
		if (/*as*/ ctx[1] === "h6") return 25;
		if (/*as*/ ctx[1] === "header") return 26;
		if (/*as*/ ctx[1] === "i") return 27;
		if (/*as*/ ctx[1] === "input") return 28;
		if (/*as*/ ctx[1] === "label") return 29;
		if (/*as*/ ctx[1] === "li") return 30;
		if (/*as*/ ctx[1] === "main") return 31;
		if (/*as*/ ctx[1] === "nav") return 32;
		if (/*as*/ ctx[1] === "ol") return 33;
		if (/*as*/ ctx[1] === "p") return 34;
		if (/*as*/ ctx[1] === "section") return 35;
		if (/*as*/ ctx[1] === "span") return 36;
		if (/*as*/ ctx[1] === "strong") return 37;
		if (/*as*/ ctx[1] === "ul") return 38;
		return 39;
	}

	current_block_type_index = select_block_type(ctx);
	if_block = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);

	return {
		c() {
			if_block.c();
			if_block_anchor = empty();
		},
		l(nodes) {
			if_block.l(nodes);
			if_block_anchor = empty();
		},
		m(target, anchor) {
			if_blocks[current_block_type_index].m(target, anchor);
			insert_hydration(target, if_block_anchor, anchor);
			current = true;
		},
		p(ctx, dirty) {
			let previous_block_index = current_block_type_index;
			current_block_type_index = select_block_type(ctx);

			if (current_block_type_index === previous_block_index) {
				if_blocks[current_block_type_index].p(ctx, dirty);
			} else {
				group_outros();

				transition_out(if_blocks[previous_block_index], 1, 1, () => {
					if_blocks[previous_block_index] = null;
				});

				check_outros();
				if_block = if_blocks[current_block_type_index];

				if (!if_block) {
					if_block = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);
					if_block.c();
				} else {
					if_block.p(ctx, dirty);
				}

				transition_in(if_block, 1);
				if_block.m(if_block_anchor.parentNode, if_block_anchor);
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			if_blocks[current_block_type_index].d(detaching);
			if (detaching) detach(if_block_anchor);
		}
	};
}

// (498:2) {:else}
function create_else_block$3(ctx) {
	let switch_instance;
	let updating_el;
	let switch_instance_anchor;
	let current;

	const switch_instance_spread_levels = [
		{
			use: [.../*use*/ ctx[2], /*forwardEvents*/ ctx[6]]
		},
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{ hidden: /*hidden*/ ctx[4] || undefined }
	];

	function switch_instance_el_binding(value) {
		/*switch_instance_el_binding*/ ctx[59](value);
	}

	var switch_value = /*as*/ ctx[1];

	function switch_props(ctx) {
		let switch_instance_props = {
			$$slots: { default: [create_default_slot$8] },
			$$scope: { ctx }
		};

		for (let i = 0; i < switch_instance_spread_levels.length; i += 1) {
			switch_instance_props = assign(switch_instance_props, switch_instance_spread_levels[i]);
		}

		if (/*el*/ ctx[0] !== void 0) {
			switch_instance_props.el = /*el*/ ctx[0];
		}

		return { props: switch_instance_props };
	}

	if (switch_value) {
		switch_instance = new switch_value(switch_props(ctx));
		binding_callbacks.push(() => bind(switch_instance, 'el', switch_instance_el_binding));
	}

	return {
		c() {
			if (switch_instance) create_component(switch_instance.$$.fragment);
			switch_instance_anchor = empty();
		},
		l(nodes) {
			if (switch_instance) claim_component(switch_instance.$$.fragment, nodes);
			switch_instance_anchor = empty();
		},
		m(target, anchor) {
			if (switch_instance) {
				mount_component(switch_instance, target, anchor);
			}

			insert_hydration(target, switch_instance_anchor, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const switch_instance_changes = (dirty[0] & /*use, forwardEvents, $$restProps, propsWeControl, hidden*/ 220)
			? get_spread_update(switch_instance_spread_levels, [
					dirty[0] & /*use, forwardEvents*/ 68 && {
						use: [.../*use*/ ctx[2], /*forwardEvents*/ ctx[6]]
					},
					dirty[0] & /*$$restProps*/ 128 && get_spread_object(/*$$restProps*/ ctx[7]),
					dirty[0] & /*propsWeControl*/ 8 && get_spread_object(/*propsWeControl*/ ctx[3]),
					dirty[0] & /*hidden*/ 16 && { hidden: /*hidden*/ ctx[4] || undefined }
				])
			: {};

			if (dirty[1] & /*$$scope*/ 536870912) {
				switch_instance_changes.$$scope = { dirty, ctx };
			}

			if (!updating_el && dirty[0] & /*el*/ 1) {
				updating_el = true;
				switch_instance_changes.el = /*el*/ ctx[0];
				add_flush_callback(() => updating_el = false);
			}

			if (switch_value !== (switch_value = /*as*/ ctx[1])) {
				if (switch_instance) {
					group_outros();
					const old_component = switch_instance;

					transition_out(old_component.$$.fragment, 1, 0, () => {
						destroy_component(old_component, 1);
					});

					check_outros();
				}

				if (switch_value) {
					switch_instance = new switch_value(switch_props(ctx));
					binding_callbacks.push(() => bind(switch_instance, 'el', switch_instance_el_binding));
					create_component(switch_instance.$$.fragment);
					transition_in(switch_instance.$$.fragment, 1);
					mount_component(switch_instance, switch_instance_anchor.parentNode, switch_instance_anchor);
				} else {
					switch_instance = null;
				}
			} else if (switch_value) {
				switch_instance.$set(switch_instance_changes);
			}
		},
		i(local) {
			if (current) return;
			if (switch_instance) transition_in(switch_instance.$$.fragment, local);
			current = true;
		},
		o(local) {
			if (switch_instance) transition_out(switch_instance.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(switch_instance_anchor);
			if (switch_instance) destroy_component(switch_instance, detaching);
		}
	};
}

// (487:24) 
function create_if_block_39(ctx) {
	let ul;
	let ul_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let ul_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: ul_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let ul_data = {};

	for (let i = 0; i < ul_levels.length; i += 1) {
		ul_data = assign(ul_data, ul_levels[i]);
	}

	return {
		c() {
			ul = element("ul");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			ul = claim_element(nodes, "UL", {});
			var ul_nodes = children(ul);
			if (default_slot) default_slot.l(ul_nodes);
			ul_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(ul, ul_data);
		},
		m(target, anchor) {
			insert_hydration(target, ul, anchor);

			if (default_slot) {
				default_slot.m(ul, null);
			}

			/*ul_binding*/ ctx[58](ul);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, ul, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, ul))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(ul, ul_data = get_spread_update(ul_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && ul_hidden_value !== (ul_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: ul_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(ul);
			if (default_slot) default_slot.d(detaching);
			/*ul_binding*/ ctx[58](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (476:28) 
function create_if_block_38(ctx) {
	let strong;
	let strong_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let strong_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: strong_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let strong_data = {};

	for (let i = 0; i < strong_levels.length; i += 1) {
		strong_data = assign(strong_data, strong_levels[i]);
	}

	return {
		c() {
			strong = element("strong");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			strong = claim_element(nodes, "STRONG", {});
			var strong_nodes = children(strong);
			if (default_slot) default_slot.l(strong_nodes);
			strong_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(strong, strong_data);
		},
		m(target, anchor) {
			insert_hydration(target, strong, anchor);

			if (default_slot) {
				default_slot.m(strong, null);
			}

			/*strong_binding*/ ctx[57](strong);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, strong, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, strong))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(strong, strong_data = get_spread_update(strong_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && strong_hidden_value !== (strong_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: strong_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(strong);
			if (default_slot) default_slot.d(detaching);
			/*strong_binding*/ ctx[57](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (465:26) 
function create_if_block_37(ctx) {
	let span;
	let span_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let span_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: span_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let span_data = {};

	for (let i = 0; i < span_levels.length; i += 1) {
		span_data = assign(span_data, span_levels[i]);
	}

	return {
		c() {
			span = element("span");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			span = claim_element(nodes, "SPAN", {});
			var span_nodes = children(span);
			if (default_slot) default_slot.l(span_nodes);
			span_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(span, span_data);
		},
		m(target, anchor) {
			insert_hydration(target, span, anchor);

			if (default_slot) {
				default_slot.m(span, null);
			}

			/*span_binding*/ ctx[56](span);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, span, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, span))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(span, span_data = get_spread_update(span_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && span_hidden_value !== (span_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: span_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(span);
			if (default_slot) default_slot.d(detaching);
			/*span_binding*/ ctx[56](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (454:29) 
function create_if_block_36(ctx) {
	let section;
	let section_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let section_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: section_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let section_data = {};

	for (let i = 0; i < section_levels.length; i += 1) {
		section_data = assign(section_data, section_levels[i]);
	}

	return {
		c() {
			section = element("section");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			section = claim_element(nodes, "SECTION", {});
			var section_nodes = children(section);
			if (default_slot) default_slot.l(section_nodes);
			section_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(section, section_data);
		},
		m(target, anchor) {
			insert_hydration(target, section, anchor);

			if (default_slot) {
				default_slot.m(section, null);
			}

			/*section_binding*/ ctx[55](section);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, section, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, section))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(section, section_data = get_spread_update(section_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && section_hidden_value !== (section_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: section_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(section);
			if (default_slot) default_slot.d(detaching);
			/*section_binding*/ ctx[55](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (443:23) 
function create_if_block_35(ctx) {
	let p;
	let p_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let p_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: p_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let p_data = {};

	for (let i = 0; i < p_levels.length; i += 1) {
		p_data = assign(p_data, p_levels[i]);
	}

	return {
		c() {
			p = element("p");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			p = claim_element(nodes, "P", {});
			var p_nodes = children(p);
			if (default_slot) default_slot.l(p_nodes);
			p_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(p, p_data);
		},
		m(target, anchor) {
			insert_hydration(target, p, anchor);

			if (default_slot) {
				default_slot.m(p, null);
			}

			/*p_binding*/ ctx[54](p);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, p, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, p))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(p, p_data = get_spread_update(p_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && p_hidden_value !== (p_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: p_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(p);
			if (default_slot) default_slot.d(detaching);
			/*p_binding*/ ctx[54](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (432:24) 
function create_if_block_34(ctx) {
	let ol;
	let ol_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let ol_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: ol_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let ol_data = {};

	for (let i = 0; i < ol_levels.length; i += 1) {
		ol_data = assign(ol_data, ol_levels[i]);
	}

	return {
		c() {
			ol = element("ol");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			ol = claim_element(nodes, "OL", {});
			var ol_nodes = children(ol);
			if (default_slot) default_slot.l(ol_nodes);
			ol_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(ol, ol_data);
		},
		m(target, anchor) {
			insert_hydration(target, ol, anchor);

			if (default_slot) {
				default_slot.m(ol, null);
			}

			/*ol_binding*/ ctx[53](ol);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, ol, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, ol))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(ol, ol_data = get_spread_update(ol_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && ol_hidden_value !== (ol_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: ol_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(ol);
			if (default_slot) default_slot.d(detaching);
			/*ol_binding*/ ctx[53](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (421:25) 
function create_if_block_33(ctx) {
	let nav;
	let nav_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let nav_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: nav_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let nav_data = {};

	for (let i = 0; i < nav_levels.length; i += 1) {
		nav_data = assign(nav_data, nav_levels[i]);
	}

	return {
		c() {
			nav = element("nav");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			nav = claim_element(nodes, "NAV", {});
			var nav_nodes = children(nav);
			if (default_slot) default_slot.l(nav_nodes);
			nav_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(nav, nav_data);
		},
		m(target, anchor) {
			insert_hydration(target, nav, anchor);

			if (default_slot) {
				default_slot.m(nav, null);
			}

			/*nav_binding*/ ctx[52](nav);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, nav, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, nav))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(nav, nav_data = get_spread_update(nav_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && nav_hidden_value !== (nav_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: nav_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(nav);
			if (default_slot) default_slot.d(detaching);
			/*nav_binding*/ ctx[52](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (410:26) 
function create_if_block_32(ctx) {
	let main;
	let main_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let main_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: main_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let main_data = {};

	for (let i = 0; i < main_levels.length; i += 1) {
		main_data = assign(main_data, main_levels[i]);
	}

	return {
		c() {
			main = element("main");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			main = claim_element(nodes, "MAIN", {});
			var main_nodes = children(main);
			if (default_slot) default_slot.l(main_nodes);
			main_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(main, main_data);
		},
		m(target, anchor) {
			insert_hydration(target, main, anchor);

			if (default_slot) {
				default_slot.m(main, null);
			}

			/*main_binding*/ ctx[51](main);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, main, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, main))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(main, main_data = get_spread_update(main_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && main_hidden_value !== (main_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: main_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(main);
			if (default_slot) default_slot.d(detaching);
			/*main_binding*/ ctx[51](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (399:24) 
function create_if_block_31(ctx) {
	let li;
	let li_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let li_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: li_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let li_data = {};

	for (let i = 0; i < li_levels.length; i += 1) {
		li_data = assign(li_data, li_levels[i]);
	}

	return {
		c() {
			li = element("li");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			li = claim_element(nodes, "LI", {});
			var li_nodes = children(li);
			if (default_slot) default_slot.l(li_nodes);
			li_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(li, li_data);
		},
		m(target, anchor) {
			insert_hydration(target, li, anchor);

			if (default_slot) {
				default_slot.m(li, null);
			}

			/*li_binding*/ ctx[50](li);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, li, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, li))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(li, li_data = get_spread_update(li_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && li_hidden_value !== (li_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: li_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(li);
			if (default_slot) default_slot.d(detaching);
			/*li_binding*/ ctx[50](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (387:27) 
function create_if_block_30(ctx) {
	let label;
	let label_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let label_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: label_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let label_data = {};

	for (let i = 0; i < label_levels.length; i += 1) {
		label_data = assign(label_data, label_levels[i]);
	}

	return {
		c() {
			label = element("label");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			label = claim_element(nodes, "LABEL", {});
			var label_nodes = children(label);
			if (default_slot) default_slot.l(label_nodes);
			label_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(label, label_data);
		},
		m(target, anchor) {
			insert_hydration(target, label, anchor);

			if (default_slot) {
				default_slot.m(label, null);
			}

			/*label_binding*/ ctx[49](label);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, label, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, label))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(label, label_data = get_spread_update(label_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && label_hidden_value !== (label_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: label_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(label);
			if (default_slot) default_slot.d(detaching);
			/*label_binding*/ ctx[49](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (378:27) 
function create_if_block_29(ctx) {
	let input;
	let input_hidden_value;
	let useActions_action;
	let mounted;
	let dispose;

	let input_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: input_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let input_data = {};

	for (let i = 0; i < input_levels.length; i += 1) {
		input_data = assign(input_data, input_levels[i]);
	}

	return {
		c() {
			input = element("input");
			this.h();
		},
		l(nodes) {
			input = claim_element(nodes, "INPUT", {});
			this.h();
		},
		h() {
			set_attributes(input, input_data);
		},
		m(target, anchor) {
			insert_hydration(target, input, anchor);
			if (input.autofocus) input.focus();
			/*input_binding*/ ctx[48](input);

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, input, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, input))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			set_attributes(input, input_data = get_spread_update(input_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				dirty[0] & /*hidden*/ 16 && input_hidden_value !== (input_hidden_value = /*hidden*/ ctx[4] || undefined) && { hidden: input_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(input);
			/*input_binding*/ ctx[48](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (367:23) 
function create_if_block_28(ctx) {
	let i;
	let i_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let i_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: i_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let i_data = {};

	for (let i = 0; i < i_levels.length; i += 1) {
		i_data = assign(i_data, i_levels[i]);
	}

	return {
		c() {
			i = element("i");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			i = claim_element(nodes, "I", {});
			var i_nodes = children(i);
			if (default_slot) default_slot.l(i_nodes);
			i_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(i, i_data);
		},
		m(target, anchor) {
			insert_hydration(target, i, anchor);

			if (default_slot) {
				default_slot.m(i, null);
			}

			/*i_binding*/ ctx[47](i);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, i, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, i))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(i, i_data = get_spread_update(i_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && i_hidden_value !== (i_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: i_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(i);
			if (default_slot) default_slot.d(detaching);
			/*i_binding*/ ctx[47](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (356:28) 
function create_if_block_27(ctx) {
	let header;
	let header_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let header_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: header_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let header_data = {};

	for (let i = 0; i < header_levels.length; i += 1) {
		header_data = assign(header_data, header_levels[i]);
	}

	return {
		c() {
			header = element("header");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			header = claim_element(nodes, "HEADER", {});
			var header_nodes = children(header);
			if (default_slot) default_slot.l(header_nodes);
			header_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(header, header_data);
		},
		m(target, anchor) {
			insert_hydration(target, header, anchor);

			if (default_slot) {
				default_slot.m(header, null);
			}

			/*header_binding*/ ctx[46](header);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, header, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, header))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(header, header_data = get_spread_update(header_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && header_hidden_value !== (header_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: header_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(header);
			if (default_slot) default_slot.d(detaching);
			/*header_binding*/ ctx[46](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (345:24) 
function create_if_block_26(ctx) {
	let h6;
	let h6_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let h6_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: h6_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let h6_data = {};

	for (let i = 0; i < h6_levels.length; i += 1) {
		h6_data = assign(h6_data, h6_levels[i]);
	}

	return {
		c() {
			h6 = element("h6");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			h6 = claim_element(nodes, "H6", {});
			var h6_nodes = children(h6);
			if (default_slot) default_slot.l(h6_nodes);
			h6_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(h6, h6_data);
		},
		m(target, anchor) {
			insert_hydration(target, h6, anchor);

			if (default_slot) {
				default_slot.m(h6, null);
			}

			/*h6_binding*/ ctx[45](h6);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, h6, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, h6))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(h6, h6_data = get_spread_update(h6_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && h6_hidden_value !== (h6_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: h6_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(h6);
			if (default_slot) default_slot.d(detaching);
			/*h6_binding*/ ctx[45](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (334:24) 
function create_if_block_25(ctx) {
	let h5;
	let h5_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let h5_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: h5_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let h5_data = {};

	for (let i = 0; i < h5_levels.length; i += 1) {
		h5_data = assign(h5_data, h5_levels[i]);
	}

	return {
		c() {
			h5 = element("h5");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			h5 = claim_element(nodes, "H5", {});
			var h5_nodes = children(h5);
			if (default_slot) default_slot.l(h5_nodes);
			h5_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(h5, h5_data);
		},
		m(target, anchor) {
			insert_hydration(target, h5, anchor);

			if (default_slot) {
				default_slot.m(h5, null);
			}

			/*h5_binding*/ ctx[44](h5);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, h5, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, h5))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(h5, h5_data = get_spread_update(h5_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && h5_hidden_value !== (h5_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: h5_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(h5);
			if (default_slot) default_slot.d(detaching);
			/*h5_binding*/ ctx[44](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (323:24) 
function create_if_block_24(ctx) {
	let h4;
	let h4_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let h4_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: h4_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let h4_data = {};

	for (let i = 0; i < h4_levels.length; i += 1) {
		h4_data = assign(h4_data, h4_levels[i]);
	}

	return {
		c() {
			h4 = element("h4");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			h4 = claim_element(nodes, "H4", {});
			var h4_nodes = children(h4);
			if (default_slot) default_slot.l(h4_nodes);
			h4_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(h4, h4_data);
		},
		m(target, anchor) {
			insert_hydration(target, h4, anchor);

			if (default_slot) {
				default_slot.m(h4, null);
			}

			/*h4_binding*/ ctx[43](h4);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, h4, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, h4))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(h4, h4_data = get_spread_update(h4_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && h4_hidden_value !== (h4_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: h4_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(h4);
			if (default_slot) default_slot.d(detaching);
			/*h4_binding*/ ctx[43](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (312:24) 
function create_if_block_23(ctx) {
	let h3;
	let h3_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let h3_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: h3_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let h3_data = {};

	for (let i = 0; i < h3_levels.length; i += 1) {
		h3_data = assign(h3_data, h3_levels[i]);
	}

	return {
		c() {
			h3 = element("h3");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			h3 = claim_element(nodes, "H3", {});
			var h3_nodes = children(h3);
			if (default_slot) default_slot.l(h3_nodes);
			h3_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(h3, h3_data);
		},
		m(target, anchor) {
			insert_hydration(target, h3, anchor);

			if (default_slot) {
				default_slot.m(h3, null);
			}

			/*h3_binding*/ ctx[42](h3);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, h3, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, h3))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(h3, h3_data = get_spread_update(h3_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && h3_hidden_value !== (h3_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: h3_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(h3);
			if (default_slot) default_slot.d(detaching);
			/*h3_binding*/ ctx[42](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (301:24) 
function create_if_block_22(ctx) {
	let h2;
	let h2_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let h2_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: h2_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let h2_data = {};

	for (let i = 0; i < h2_levels.length; i += 1) {
		h2_data = assign(h2_data, h2_levels[i]);
	}

	return {
		c() {
			h2 = element("h2");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			h2 = claim_element(nodes, "H2", {});
			var h2_nodes = children(h2);
			if (default_slot) default_slot.l(h2_nodes);
			h2_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(h2, h2_data);
		},
		m(target, anchor) {
			insert_hydration(target, h2, anchor);

			if (default_slot) {
				default_slot.m(h2, null);
			}

			/*h2_binding*/ ctx[41](h2);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, h2, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, h2))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(h2, h2_data = get_spread_update(h2_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && h2_hidden_value !== (h2_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: h2_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(h2);
			if (default_slot) default_slot.d(detaching);
			/*h2_binding*/ ctx[41](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (290:24) 
function create_if_block_21(ctx) {
	let h1;
	let h1_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let h1_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: h1_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let h1_data = {};

	for (let i = 0; i < h1_levels.length; i += 1) {
		h1_data = assign(h1_data, h1_levels[i]);
	}

	return {
		c() {
			h1 = element("h1");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			h1 = claim_element(nodes, "H1", {});
			var h1_nodes = children(h1);
			if (default_slot) default_slot.l(h1_nodes);
			h1_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(h1, h1_data);
		},
		m(target, anchor) {
			insert_hydration(target, h1, anchor);

			if (default_slot) {
				default_slot.m(h1, null);
			}

			/*h1_binding*/ ctx[40](h1);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, h1, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, h1))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(h1, h1_data = get_spread_update(h1_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && h1_hidden_value !== (h1_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: h1_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(h1);
			if (default_slot) default_slot.d(detaching);
			/*h1_binding*/ ctx[40](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (279:26) 
function create_if_block_20(ctx) {
	let form;
	let form_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let form_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: form_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let form_data = {};

	for (let i = 0; i < form_levels.length; i += 1) {
		form_data = assign(form_data, form_levels[i]);
	}

	return {
		c() {
			form = element("form");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			form = claim_element(nodes, "FORM", {});
			var form_nodes = children(form);
			if (default_slot) default_slot.l(form_nodes);
			form_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(form, form_data);
		},
		m(target, anchor) {
			insert_hydration(target, form, anchor);

			if (default_slot) {
				default_slot.m(form, null);
			}

			/*form_binding*/ ctx[39](form);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, form, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, form))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(form, form_data = get_spread_update(form_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && form_hidden_value !== (form_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: form_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(form);
			if (default_slot) default_slot.d(detaching);
			/*form_binding*/ ctx[39](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (268:28) 
function create_if_block_19(ctx) {
	let footer;
	let footer_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let footer_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: footer_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let footer_data = {};

	for (let i = 0; i < footer_levels.length; i += 1) {
		footer_data = assign(footer_data, footer_levels[i]);
	}

	return {
		c() {
			footer = element("footer");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			footer = claim_element(nodes, "FOOTER", {});
			var footer_nodes = children(footer);
			if (default_slot) default_slot.l(footer_nodes);
			footer_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(footer, footer_data);
		},
		m(target, anchor) {
			insert_hydration(target, footer, anchor);

			if (default_slot) {
				default_slot.m(footer, null);
			}

			/*footer_binding*/ ctx[38](footer);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, footer, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, footer))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(footer, footer_data = get_spread_update(footer_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && footer_hidden_value !== (footer_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: footer_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(footer);
			if (default_slot) default_slot.d(detaching);
			/*footer_binding*/ ctx[38](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (257:24) 
function create_if_block_18(ctx) {
	let em;
	let em_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let em_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: em_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let em_data = {};

	for (let i = 0; i < em_levels.length; i += 1) {
		em_data = assign(em_data, em_levels[i]);
	}

	return {
		c() {
			em = element("em");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			em = claim_element(nodes, "EM", {});
			var em_nodes = children(em);
			if (default_slot) default_slot.l(em_nodes);
			em_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(em, em_data);
		},
		m(target, anchor) {
			insert_hydration(target, em, anchor);

			if (default_slot) {
				default_slot.m(em, null);
			}

			/*em_binding*/ ctx[37](em);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, em, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, em))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(em, em_data = get_spread_update(em_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && em_hidden_value !== (em_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: em_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(em);
			if (default_slot) default_slot.d(detaching);
			/*em_binding*/ ctx[37](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (246:25) 
function create_if_block_17(ctx) {
	let div;
	let div_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let div_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: div_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let div_data = {};

	for (let i = 0; i < div_levels.length; i += 1) {
		div_data = assign(div_data, div_levels[i]);
	}

	return {
		c() {
			div = element("div");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", {});
			var div_nodes = children(div);
			if (default_slot) default_slot.l(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(div, div_data);
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);

			if (default_slot) {
				default_slot.m(div, null);
			}

			/*div_binding*/ ctx[36](div);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, div, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, div))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(div, div_data = get_spread_update(div_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && div_hidden_value !== (div_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: div_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			if (default_slot) default_slot.d(detaching);
			/*div_binding*/ ctx[36](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (235:24) 
function create_if_block_16(ctx) {
	let dt;
	let dt_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let dt_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: dt_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let dt_data = {};

	for (let i = 0; i < dt_levels.length; i += 1) {
		dt_data = assign(dt_data, dt_levels[i]);
	}

	return {
		c() {
			dt = element("dt");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			dt = claim_element(nodes, "DT", {});
			var dt_nodes = children(dt);
			if (default_slot) default_slot.l(dt_nodes);
			dt_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(dt, dt_data);
		},
		m(target, anchor) {
			insert_hydration(target, dt, anchor);

			if (default_slot) {
				default_slot.m(dt, null);
			}

			/*dt_binding*/ ctx[35](dt);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, dt, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, dt))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(dt, dt_data = get_spread_update(dt_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && dt_hidden_value !== (dt_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: dt_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(dt);
			if (default_slot) default_slot.d(detaching);
			/*dt_binding*/ ctx[35](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (224:24) 
function create_if_block_15(ctx) {
	let dl;
	let dl_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let dl_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: dl_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let dl_data = {};

	for (let i = 0; i < dl_levels.length; i += 1) {
		dl_data = assign(dl_data, dl_levels[i]);
	}

	return {
		c() {
			dl = element("dl");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			dl = claim_element(nodes, "DL", {});
			var dl_nodes = children(dl);
			if (default_slot) default_slot.l(dl_nodes);
			dl_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(dl, dl_data);
		},
		m(target, anchor) {
			insert_hydration(target, dl, anchor);

			if (default_slot) {
				default_slot.m(dl, null);
			}

			/*dl_binding*/ ctx[34](dl);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, dl, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, dl))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(dl, dl_data = get_spread_update(dl_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && dl_hidden_value !== (dl_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: dl_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(dl);
			if (default_slot) default_slot.d(detaching);
			/*dl_binding*/ ctx[34](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (213:24) 
function create_if_block_14(ctx) {
	let dd;
	let dd_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let dd_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: dd_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let dd_data = {};

	for (let i = 0; i < dd_levels.length; i += 1) {
		dd_data = assign(dd_data, dd_levels[i]);
	}

	return {
		c() {
			dd = element("dd");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			dd = claim_element(nodes, "DD", {});
			var dd_nodes = children(dd);
			if (default_slot) default_slot.l(dd_nodes);
			dd_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(dd, dd_data);
		},
		m(target, anchor) {
			insert_hydration(target, dd, anchor);

			if (default_slot) {
				default_slot.m(dd, null);
			}

			/*dd_binding*/ ctx[33](dd);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, dd, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, dd))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(dd, dd_data = get_spread_update(dd_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && dd_hidden_value !== (dd_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: dd_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(dd);
			if (default_slot) default_slot.d(detaching);
			/*dd_binding*/ ctx[33](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (202:30) 
function create_if_block_13(ctx) {
	let datalist;
	let datalist_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let datalist_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: datalist_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let datalist_data = {};

	for (let i = 0; i < datalist_levels.length; i += 1) {
		datalist_data = assign(datalist_data, datalist_levels[i]);
	}

	return {
		c() {
			datalist = element("datalist");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			datalist = claim_element(nodes, "DATALIST", {});
			var datalist_nodes = children(datalist);
			if (default_slot) default_slot.l(datalist_nodes);
			datalist_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(datalist, datalist_data);
		},
		m(target, anchor) {
			insert_hydration(target, datalist, anchor);

			if (default_slot) {
				default_slot.m(datalist, null);
			}

			/*datalist_binding*/ ctx[32](datalist);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, datalist, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, datalist))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(datalist, datalist_data = get_spread_update(datalist_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && datalist_hidden_value !== (datalist_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: datalist_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(datalist);
			if (default_slot) default_slot.d(detaching);
			/*datalist_binding*/ ctx[32](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (191:26) 
function create_if_block_12(ctx) {
	let data;
	let data_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let data_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: data_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let data_data = {};

	for (let i = 0; i < data_levels.length; i += 1) {
		data_data = assign(data_data, data_levels[i]);
	}

	return {
		c() {
			data = element("data");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			data = claim_element(nodes, "DATA", {});
			var data_nodes = children(data);
			if (default_slot) default_slot.l(data_nodes);
			data_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(data, data_data);
		},
		m(target, anchor) {
			insert_hydration(target, data, anchor);

			if (default_slot) {
				default_slot.m(data, null);
			}

			/*data_binding*/ ctx[31](data);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, data, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, data))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(data, data_data = get_spread_update(data_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && data_hidden_value !== (data_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: data_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(data);
			if (default_slot) default_slot.d(detaching);
			/*data_binding*/ ctx[31](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (180:26) 
function create_if_block_11(ctx) {
	let code;
	let code_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let code_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: code_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let code_data = {};

	for (let i = 0; i < code_levels.length; i += 1) {
		code_data = assign(code_data, code_levels[i]);
	}

	return {
		c() {
			code = element("code");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			code = claim_element(nodes, "CODE", {});
			var code_nodes = children(code);
			if (default_slot) default_slot.l(code_nodes);
			code_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(code, code_data);
		},
		m(target, anchor) {
			insert_hydration(target, code, anchor);

			if (default_slot) {
				default_slot.m(code, null);
			}

			/*code_binding*/ ctx[30](code);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, code, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, code))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(code, code_data = get_spread_update(code_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && code_hidden_value !== (code_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: code_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(code);
			if (default_slot) default_slot.d(detaching);
			/*code_binding*/ ctx[30](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (169:26) 
function create_if_block_10(ctx) {
	let cite;
	let cite_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let cite_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: cite_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let cite_data = {};

	for (let i = 0; i < cite_levels.length; i += 1) {
		cite_data = assign(cite_data, cite_levels[i]);
	}

	return {
		c() {
			cite = element("cite");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			cite = claim_element(nodes, "CITE", {});
			var cite_nodes = children(cite);
			if (default_slot) default_slot.l(cite_nodes);
			cite_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(cite, cite_data);
		},
		m(target, anchor) {
			insert_hydration(target, cite, anchor);

			if (default_slot) {
				default_slot.m(cite, null);
			}

			/*cite_binding*/ ctx[29](cite);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, cite, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, cite))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(cite, cite_data = get_spread_update(cite_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && cite_hidden_value !== (cite_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: cite_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(cite);
			if (default_slot) default_slot.d(detaching);
			/*cite_binding*/ ctx[29](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (158:28) 
function create_if_block_9(ctx) {
	let button;
	let button_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let button_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: button_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let button_data = {};

	for (let i = 0; i < button_levels.length; i += 1) {
		button_data = assign(button_data, button_levels[i]);
	}

	return {
		c() {
			button = element("button");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			button = claim_element(nodes, "BUTTON", {});
			var button_nodes = children(button);
			if (default_slot) default_slot.l(button_nodes);
			button_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(button, button_data);
		},
		m(target, anchor) {
			insert_hydration(target, button, anchor);

			if (default_slot) {
				default_slot.m(button, null);
			}

			if (button.autofocus) button.focus();
			/*button_binding*/ ctx[28](button);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, button, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, button))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(button, button_data = get_spread_update(button_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && button_hidden_value !== (button_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: button_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(button);
			if (default_slot) default_slot.d(detaching);
			/*button_binding*/ ctx[28](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (147:32) 
function create_if_block_8(ctx) {
	let blockquote;
	let blockquote_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let blockquote_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: blockquote_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let blockquote_data = {};

	for (let i = 0; i < blockquote_levels.length; i += 1) {
		blockquote_data = assign(blockquote_data, blockquote_levels[i]);
	}

	return {
		c() {
			blockquote = element("blockquote");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			blockquote = claim_element(nodes, "BLOCKQUOTE", {});
			var blockquote_nodes = children(blockquote);
			if (default_slot) default_slot.l(blockquote_nodes);
			blockquote_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(blockquote, blockquote_data);
		},
		m(target, anchor) {
			insert_hydration(target, blockquote, anchor);

			if (default_slot) {
				default_slot.m(blockquote, null);
			}

			/*blockquote_binding*/ ctx[27](blockquote);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, blockquote, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, blockquote))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(blockquote, blockquote_data = get_spread_update(blockquote_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && blockquote_hidden_value !== (blockquote_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: blockquote_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(blockquote);
			if (default_slot) default_slot.d(detaching);
			/*blockquote_binding*/ ctx[27](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (136:25) 
function create_if_block_7$1(ctx) {
	let bdo;
	let bdo_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let bdo_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: bdo_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let bdo_data = {};

	for (let i = 0; i < bdo_levels.length; i += 1) {
		bdo_data = assign(bdo_data, bdo_levels[i]);
	}

	return {
		c() {
			bdo = element("bdo");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			bdo = claim_element(nodes, "BDO", {});
			var bdo_nodes = children(bdo);
			if (default_slot) default_slot.l(bdo_nodes);
			bdo_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(bdo, bdo_data);
		},
		m(target, anchor) {
			insert_hydration(target, bdo, anchor);

			if (default_slot) {
				default_slot.m(bdo, null);
			}

			/*bdo_binding*/ ctx[26](bdo);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, bdo, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, bdo))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(bdo, bdo_data = get_spread_update(bdo_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && bdo_hidden_value !== (bdo_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: bdo_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(bdo);
			if (default_slot) default_slot.d(detaching);
			/*bdo_binding*/ ctx[26](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (125:25) 
function create_if_block_6$1(ctx) {
	let bdi;
	let bdi_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let bdi_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: bdi_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let bdi_data = {};

	for (let i = 0; i < bdi_levels.length; i += 1) {
		bdi_data = assign(bdi_data, bdi_levels[i]);
	}

	return {
		c() {
			bdi = element("bdi");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			bdi = claim_element(nodes, "BDI", {});
			var bdi_nodes = children(bdi);
			if (default_slot) default_slot.l(bdi_nodes);
			bdi_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(bdi, bdi_data);
		},
		m(target, anchor) {
			insert_hydration(target, bdi, anchor);

			if (default_slot) {
				default_slot.m(bdi, null);
			}

			/*bdi_binding*/ ctx[25](bdi);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, bdi, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, bdi))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(bdi, bdi_data = get_spread_update(bdi_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && bdi_hidden_value !== (bdi_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: bdi_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(bdi);
			if (default_slot) default_slot.d(detaching);
			/*bdi_binding*/ ctx[25](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (114:23) 
function create_if_block_5$2(ctx) {
	let b;
	let b_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let b_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: b_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let b_data = {};

	for (let i = 0; i < b_levels.length; i += 1) {
		b_data = assign(b_data, b_levels[i]);
	}

	return {
		c() {
			b = element("b");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			b = claim_element(nodes, "B", {});
			var b_nodes = children(b);
			if (default_slot) default_slot.l(b_nodes);
			b_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(b, b_data);
		},
		m(target, anchor) {
			insert_hydration(target, b, anchor);

			if (default_slot) {
				default_slot.m(b, null);
			}

			/*b_binding*/ ctx[24](b);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, b, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, b))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(b, b_data = get_spread_update(b_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && b_hidden_value !== (b_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: b_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(b);
			if (default_slot) default_slot.d(detaching);
			/*b_binding*/ ctx[24](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (103:27) 
function create_if_block_4$2(ctx) {
	let aside;
	let aside_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let aside_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: aside_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let aside_data = {};

	for (let i = 0; i < aside_levels.length; i += 1) {
		aside_data = assign(aside_data, aside_levels[i]);
	}

	return {
		c() {
			aside = element("aside");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			aside = claim_element(nodes, "ASIDE", {});
			var aside_nodes = children(aside);
			if (default_slot) default_slot.l(aside_nodes);
			aside_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(aside, aside_data);
		},
		m(target, anchor) {
			insert_hydration(target, aside, anchor);

			if (default_slot) {
				default_slot.m(aside, null);
			}

			/*aside_binding*/ ctx[23](aside);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, aside, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, aside))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(aside, aside_data = get_spread_update(aside_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && aside_hidden_value !== (aside_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: aside_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(aside);
			if (default_slot) default_slot.d(detaching);
			/*aside_binding*/ ctx[23](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (92:29) 
function create_if_block_3$2(ctx) {
	let article;
	let article_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let article_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: article_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let article_data = {};

	for (let i = 0; i < article_levels.length; i += 1) {
		article_data = assign(article_data, article_levels[i]);
	}

	return {
		c() {
			article = element("article");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			article = claim_element(nodes, "ARTICLE", {});
			var article_nodes = children(article);
			if (default_slot) default_slot.l(article_nodes);
			article_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(article, article_data);
		},
		m(target, anchor) {
			insert_hydration(target, article, anchor);

			if (default_slot) {
				default_slot.m(article, null);
			}

			/*article_binding*/ ctx[22](article);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, article, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, article))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(article, article_data = get_spread_update(article_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && article_hidden_value !== (article_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: article_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(article);
			if (default_slot) default_slot.d(detaching);
			/*article_binding*/ ctx[22](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (81:29) 
function create_if_block_2$3(ctx) {
	let address;
	let address_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let address_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: address_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let address_data = {};

	for (let i = 0; i < address_levels.length; i += 1) {
		address_data = assign(address_data, address_levels[i]);
	}

	return {
		c() {
			address = element("address");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			address = claim_element(nodes, "ADDRESS", {});
			var address_nodes = children(address);
			if (default_slot) default_slot.l(address_nodes);
			address_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(address, address_data);
		},
		m(target, anchor) {
			insert_hydration(target, address, anchor);

			if (default_slot) {
				default_slot.m(address, null);
			}

			/*address_binding*/ ctx[21](address);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, address, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, address))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(address, address_data = get_spread_update(address_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && address_hidden_value !== (address_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: address_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(address);
			if (default_slot) default_slot.d(detaching);
			/*address_binding*/ ctx[21](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (69:2) {#if as === "a"}
function create_if_block_1$3(ctx) {
	let a;
	let a_hidden_value;
	let useActions_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	let a_levels = [
		/*$$restProps*/ ctx[7],
		/*propsWeControl*/ ctx[3],
		{
			hidden: a_hidden_value = /*hidden*/ ctx[4] || undefined
		}
	];

	let a_data = {};

	for (let i = 0; i < a_levels.length; i += 1) {
		a_data = assign(a_data, a_levels[i]);
	}

	return {
		c() {
			a = element("a");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			a = claim_element(nodes, "A", {});
			var a_nodes = children(a);
			if (default_slot) default_slot.l(a_nodes);
			a_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(a, a_data);
		},
		m(target, anchor) {
			insert_hydration(target, a, anchor);

			if (default_slot) {
				default_slot.m(a, null);
			}

			/*a_binding*/ ctx[20](a);
			current = true;

			if (!mounted) {
				dispose = [
					action_destroyer(useActions_action = useActions.call(null, a, /*use*/ ctx[2])),
					action_destroyer(/*forwardEvents*/ ctx[6].call(null, a))
				];

				mounted = true;
			}
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}

			set_attributes(a, a_data = get_spread_update(a_levels, [
				dirty[0] & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7],
				dirty[0] & /*propsWeControl*/ 8 && /*propsWeControl*/ ctx[3],
				(!current || dirty[0] & /*hidden*/ 16 && a_hidden_value !== (a_hidden_value = /*hidden*/ ctx[4] || undefined)) && { hidden: a_hidden_value }
			]));

			if (useActions_action && is_function(useActions_action.update) && dirty[0] & /*use*/ 4) useActions_action.update.call(null, /*use*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(a);
			if (default_slot) default_slot.d(detaching);
			/*a_binding*/ ctx[20](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

// (499:4) <svelte:component        this={as}        bind:el        use={[...use, forwardEvents]}        {...$$restProps}        {...propsWeControl}        hidden={hidden || undefined}      >
function create_default_slot$8(ctx) {
	let current;
	const default_slot_template = /*#slots*/ ctx[19].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[60], null);

	return {
		c() {
			if (default_slot) default_slot.c();
		},
		l(nodes) {
			if (default_slot) default_slot.l(nodes);
		},
		m(target, anchor) {
			if (default_slot) {
				default_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[1] & /*$$scope*/ 536870912)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[60],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[60])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[60], dirty, null),
						null
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (default_slot) default_slot.d(detaching);
		}
	};
}

function create_fragment$g(ctx) {
	let if_block_anchor;
	let current;
	let if_block = /*show*/ ctx[5] && create_if_block$9(ctx);

	return {
		c() {
			if (if_block) if_block.c();
			if_block_anchor = empty();
		},
		l(nodes) {
			if (if_block) if_block.l(nodes);
			if_block_anchor = empty();
		},
		m(target, anchor) {
			if (if_block) if_block.m(target, anchor);
			insert_hydration(target, if_block_anchor, anchor);
			current = true;
		},
		p(ctx, dirty) {
			if (/*show*/ ctx[5]) {
				if (if_block) {
					if_block.p(ctx, dirty);

					if (dirty[0] & /*show*/ 32) {
						transition_in(if_block, 1);
					}
				} else {
					if_block = create_if_block$9(ctx);
					if_block.c();
					transition_in(if_block, 1);
					if_block.m(if_block_anchor.parentNode, if_block_anchor);
				}
			} else if (if_block) {
				group_outros();

				transition_out(if_block, 1, 1, () => {
					if_block = null;
				});

				check_outros();
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			if (if_block) if_block.d(detaching);
			if (detaching) detach(if_block_anchor);
		}
	};
}

var RenderStrategy;

(function (RenderStrategy) {
	RenderStrategy[RenderStrategy["Unmount"] = 0] = "Unmount";
	RenderStrategy[RenderStrategy["Hidden"] = 1] = "Hidden";
})(RenderStrategy || (RenderStrategy = {}));

function instance$g($$self, $$props, $$invalidate) {
	let computedClass;
	let computedStyle;
	let show;
	let hidden;
	let propsWeControl;

	const omit_props_names = [
		"name","as","slotProps","elementName","el","use","visible","features","unmount","static","class","style"
	];

	let $$restProps = compute_rest_props($$props, omit_props_names);
	let { $$slots: slots = {}, $$scope } = $$props;
	const forwardEvents = forwardEventsBuilder(get_current_component());
	let { name } = $$props;
	let { as } = $$props;
	let { slotProps } = $$props;
	let { elementName = null } = $$props;
	let { el = null } = $$props;
	let { use = [] } = $$props;
	let { visible = true } = $$props;
	let { features = Features$1.None } = $$props;
	let { unmount = true } = $$props;
	let { static: static_ = false } = $$props;
	let { class: classProp = undefined } = $$props;
	let { style = undefined } = $$props;

	if (!as) {
		throw new Error(`<${name}> did not provide an \`as\` value to <Render>`);
	}

	if (!isValidElement(as)) {
		throw new Error(`<${name}> has an invalid or unsupported \`as\` prop: ${as}`);
	}

	function a_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function address_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function article_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function aside_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function b_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function bdi_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function bdo_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function blockquote_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function button_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function cite_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function code_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function data_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function datalist_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function dd_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function dl_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function dt_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function div_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function em_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function footer_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function form_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function h1_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function h2_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function h3_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function h4_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function h5_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function h6_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function header_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function i_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function input_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function label_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function li_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function main_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function nav_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function ol_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function p_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function section_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function span_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function strong_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function ul_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			el = $$value;
			$$invalidate(0, el);
		});
	}

	function switch_instance_el_binding(value) {
		el = value;
		$$invalidate(0, el);
	}

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(7, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('name' in $$new_props) $$invalidate(8, name = $$new_props.name);
		if ('as' in $$new_props) $$invalidate(1, as = $$new_props.as);
		if ('slotProps' in $$new_props) $$invalidate(9, slotProps = $$new_props.slotProps);
		if ('elementName' in $$new_props) $$invalidate(10, elementName = $$new_props.elementName);
		if ('el' in $$new_props) $$invalidate(0, el = $$new_props.el);
		if ('use' in $$new_props) $$invalidate(2, use = $$new_props.use);
		if ('visible' in $$new_props) $$invalidate(11, visible = $$new_props.visible);
		if ('features' in $$new_props) $$invalidate(12, features = $$new_props.features);
		if ('unmount' in $$new_props) $$invalidate(13, unmount = $$new_props.unmount);
		if ('static' in $$new_props) $$invalidate(14, static_ = $$new_props.static);
		if ('class' in $$new_props) $$invalidate(15, classProp = $$new_props.class);
		if ('style' in $$new_props) $$invalidate(16, style = $$new_props.style);
		if ('$$scope' in $$new_props) $$invalidate(60, $$scope = $$new_props.$$scope);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty[0] & /*classProp, slotProps*/ 33280) {
			$$invalidate(18, computedClass = typeof classProp === "function"
			? classProp(slotProps)
			: classProp);
		}

		if ($$self.$$.dirty[0] & /*style, slotProps*/ 66048) {
			$$invalidate(17, computedStyle = typeof style === "function" ? style(slotProps) : style);
		}

		if ($$self.$$.dirty[0] & /*visible, features, static_, unmount*/ 30720) {
			$$invalidate(5, show = visible || features & Features$1.Static && static_ || !(features & Features$1.RenderStrategy && unmount));
		}

		if ($$self.$$.dirty[0] & /*visible, features, static_, unmount*/ 30720) {
			$$invalidate(4, hidden = !visible && !(features & Features$1.Static && static_) && features & Features$1.RenderStrategy && !unmount);
		}

		if ($$self.$$.dirty[0] & /*elementName, computedClass, computedStyle, hidden*/ 394256) {
			$$invalidate(3, propsWeControl = {
				name: elementName || undefined,
				class: computedClass,
				style: `${computedStyle ?? ""}${hidden ? " display: none" : ""}` || undefined
			});
		}

		if ($$self.$$.dirty[0] & /*propsWeControl*/ 8) {
			if (propsWeControl.style === undefined) {
				delete propsWeControl.style;
			}
		}

		if ($$self.$$.dirty[0] & /*propsWeControl*/ 8) {
			if (propsWeControl.name === undefined) {
				delete propsWeControl.name;
			}
		}
	};

	return [
		el,
		as,
		use,
		propsWeControl,
		hidden,
		show,
		forwardEvents,
		$$restProps,
		name,
		slotProps,
		elementName,
		visible,
		features,
		unmount,
		static_,
		classProp,
		style,
		computedStyle,
		computedClass,
		slots,
		a_binding,
		address_binding,
		article_binding,
		aside_binding,
		b_binding,
		bdi_binding,
		bdo_binding,
		blockquote_binding,
		button_binding,
		cite_binding,
		code_binding,
		data_binding,
		datalist_binding,
		dd_binding,
		dl_binding,
		dt_binding,
		div_binding,
		em_binding,
		footer_binding,
		form_binding,
		h1_binding,
		h2_binding,
		h3_binding,
		h4_binding,
		h5_binding,
		h6_binding,
		header_binding,
		i_binding,
		input_binding,
		label_binding,
		li_binding,
		main_binding,
		nav_binding,
		ol_binding,
		p_binding,
		section_binding,
		span_binding,
		strong_binding,
		ul_binding,
		switch_instance_el_binding,
		$$scope
	];
}

class Render extends SvelteComponent {
	constructor(options) {
		super();

		init(
			this,
			options,
			instance$g,
			create_fragment$g,
			safe_not_equal,
			{
				name: 8,
				as: 1,
				slotProps: 9,
				elementName: 10,
				el: 0,
				use: 2,
				visible: 11,
				features: 12,
				unmount: 13,
				static: 14,
				class: 15,
				style: 16
			},
			null,
			[-1, -1]
		);
	}
}

/* node_modules\svelte-headlessui-combobox-temporary\components\dialog\Dialog.svelte generated by Svelte v3.48.0 */

const { window: window_1 } = globals;
const get_default_slot_spread_changes$1 = dirty => dirty & /*slotProps*/ 64;
const get_default_slot_changes$4 = dirty => ({});
const get_default_slot_context$4 = ctx => ({ .../*slotProps*/ ctx[6] });

// (221:12) <Render                {...{ ...$$restProps, ...propsWeControl }}                {as}                {slotProps}                use={[...use, forwardEvents]}                name={"Dialog"}                bind:el={internalDialogRef}                aria-describedby={describedby}                on:click={handleClick}                {visible}                features={Features.RenderStrategy | Features.Static}              >
function create_default_slot_6(ctx) {
	let current;
	const default_slot_template = /*#slots*/ ctx[24].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[27], get_default_slot_context$4);

	return {
		c() {
			if (default_slot) default_slot.c();
		},
		l(nodes) {
			if (default_slot) default_slot.l(nodes);
		},
		m(target, anchor) {
			if (default_slot) {
				default_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope, slotProps*/ 134217792)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[27],
						get_default_slot_spread_changes$1(dirty) || !current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[27])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[27], dirty, get_default_slot_changes$4),
						get_default_slot_context$4
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (default_slot) default_slot.d(detaching);
		}
	};
}

// (216:10) <DescriptionProvider              name={"DialogDescription"}              {slotProps}              let:describedby            >
function create_default_slot_5(ctx) {
	let render;
	let updating_el;
	let current;

	const render_spread_levels = [
		{
			.../*$$restProps*/ ctx[14],
			.../*propsWeControl*/ ctx[7]
		},
		{ as: /*as*/ ctx[0] },
		{ slotProps: /*slotProps*/ ctx[6] },
		{
			use: [.../*use*/ ctx[1], /*forwardEvents*/ ctx[9]]
		},
		{ name: "Dialog" },
		{
			"aria-describedby": /*describedby*/ ctx[30]
		},
		{ visible: /*visible*/ ctx[8] },
		{
			features: Features$1.RenderStrategy | Features$1.Static
		}
	];

	function render_el_binding(value) {
		/*render_el_binding*/ ctx[25](value);
	}

	let render_props = {
		$$slots: { default: [create_default_slot_6] },
		$$scope: { ctx }
	};

	for (let i = 0; i < render_spread_levels.length; i += 1) {
		render_props = assign(render_props, render_spread_levels[i]);
	}

	if (/*internalDialogRef*/ ctx[3] !== void 0) {
		render_props.el = /*internalDialogRef*/ ctx[3];
	}

	render = new Render({ props: render_props });
	binding_callbacks.push(() => bind(render, 'el', render_el_binding));
	render.$on("click", handleClick);

	return {
		c() {
			create_component(render.$$.fragment);
		},
		l(nodes) {
			claim_component(render.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(render, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const render_changes = (dirty & /*$$restProps, propsWeControl, as, slotProps, use, forwardEvents, describedby, visible, Features*/ 1073759171)
			? get_spread_update(render_spread_levels, [
					dirty & /*$$restProps, propsWeControl*/ 16512 && {
						.../*$$restProps*/ ctx[14],
						.../*propsWeControl*/ ctx[7]
					},
					dirty & /*as*/ 1 && { as: /*as*/ ctx[0] },
					dirty & /*slotProps*/ 64 && { slotProps: /*slotProps*/ ctx[6] },
					dirty & /*use, forwardEvents*/ 514 && {
						use: [.../*use*/ ctx[1], /*forwardEvents*/ ctx[9]]
					},
					render_spread_levels[4],
					dirty & /*describedby*/ 1073741824 && {
						"aria-describedby": /*describedby*/ ctx[30]
					},
					dirty & /*visible*/ 256 && { visible: /*visible*/ ctx[8] },
					dirty & /*Features*/ 0 && {
						features: Features$1.RenderStrategy | Features$1.Static
					}
				])
			: {};

			if (dirty & /*$$scope, slotProps*/ 134217792) {
				render_changes.$$scope = { dirty, ctx };
			}

			if (!updating_el && dirty & /*internalDialogRef*/ 8) {
				updating_el = true;
				render_changes.el = /*internalDialogRef*/ ctx[3];
				add_flush_callback(() => updating_el = false);
			}

			render.$set(render_changes);
		},
		i(local) {
			if (current) return;
			transition_in(render.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(render.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(render, detaching);
		}
	};
}

// (215:8) <ForcePortalRootContext force={false}>
function create_default_slot_4(ctx) {
	let descriptionprovider;
	let current;

	descriptionprovider = new DescriptionProvider({
			props: {
				name: "DialogDescription",
				slotProps: /*slotProps*/ ctx[6],
				$$slots: {
					default: [
						create_default_slot_5,
						({ describedby }) => ({ 30: describedby }),
						({ describedby }) => describedby ? 1073741824 : 0
					]
				},
				$$scope: { ctx }
			}
		});

	return {
		c() {
			create_component(descriptionprovider.$$.fragment);
		},
		l(nodes) {
			claim_component(descriptionprovider.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(descriptionprovider, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const descriptionprovider_changes = {};
			if (dirty & /*slotProps*/ 64) descriptionprovider_changes.slotProps = /*slotProps*/ ctx[6];

			if (dirty & /*$$scope, $$restProps, propsWeControl, as, slotProps, use, describedby, visible, internalDialogRef*/ 1207976395) {
				descriptionprovider_changes.$$scope = { dirty, ctx };
			}

			descriptionprovider.$set(descriptionprovider_changes);
		},
		i(local) {
			if (current) return;
			transition_in(descriptionprovider.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(descriptionprovider.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(descriptionprovider, detaching);
		}
	};
}

// (214:6) <PortalGroup target={internalDialogRef}>
function create_default_slot_3$2(ctx) {
	let forceportalrootcontext;
	let current;

	forceportalrootcontext = new ForcePortalRootContext({
			props: {
				force: false,
				$$slots: { default: [create_default_slot_4] },
				$$scope: { ctx }
			}
		});

	return {
		c() {
			create_component(forceportalrootcontext.$$.fragment);
		},
		l(nodes) {
			claim_component(forceportalrootcontext.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(forceportalrootcontext, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const forceportalrootcontext_changes = {};

			if (dirty & /*$$scope, slotProps, $$restProps, propsWeControl, as, use, visible, internalDialogRef*/ 134234571) {
				forceportalrootcontext_changes.$$scope = { dirty, ctx };
			}

			forceportalrootcontext.$set(forceportalrootcontext_changes);
		},
		i(local) {
			if (current) return;
			transition_in(forceportalrootcontext.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(forceportalrootcontext.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(forceportalrootcontext, detaching);
		}
	};
}

// (213:4) <Portal>
function create_default_slot_2$2(ctx) {
	let portalgroup;
	let current;

	portalgroup = new PortalGroup({
			props: {
				target: /*internalDialogRef*/ ctx[3],
				$$slots: { default: [create_default_slot_3$2] },
				$$scope: { ctx }
			}
		});

	return {
		c() {
			create_component(portalgroup.$$.fragment);
		},
		l(nodes) {
			claim_component(portalgroup.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(portalgroup, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const portalgroup_changes = {};
			if (dirty & /*internalDialogRef*/ 8) portalgroup_changes.target = /*internalDialogRef*/ ctx[3];

			if (dirty & /*$$scope, slotProps, $$restProps, propsWeControl, as, use, visible, internalDialogRef*/ 134234571) {
				portalgroup_changes.$$scope = { dirty, ctx };
			}

			portalgroup.$set(portalgroup_changes);
		},
		i(local) {
			if (current) return;
			transition_in(portalgroup.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(portalgroup.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(portalgroup, detaching);
		}
	};
}

// (212:2) <ForcePortalRootContext force={true}>
function create_default_slot_1$3(ctx) {
	let portal;
	let current;

	portal = new Portal({
			props: {
				$$slots: { default: [create_default_slot_2$2] },
				$$scope: { ctx }
			}
		});

	return {
		c() {
			create_component(portal.$$.fragment);
		},
		l(nodes) {
			claim_component(portal.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(portal, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const portal_changes = {};

			if (dirty & /*$$scope, internalDialogRef, slotProps, $$restProps, propsWeControl, as, use, visible*/ 134234571) {
				portal_changes.$$scope = { dirty, ctx };
			}

			portal.$set(portal_changes);
		},
		i(local) {
			if (current) return;
			transition_in(portal.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(portal.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(portal, detaching);
		}
	};
}

// (198:0) <StackContextProvider    element={internalDialogRef}    onUpdate={(message, element) => {      return match(message, {        [StackMessage.Add]() {          containers = new Set([...containers, element]);        },        [StackMessage.Remove]() {          containers.delete(element);          containers = new Set([...containers]);        },      });    }}  >
function create_default_slot$7(ctx) {
	let forceportalrootcontext;
	let current;

	forceportalrootcontext = new ForcePortalRootContext({
			props: {
				force: true,
				$$slots: { default: [create_default_slot_1$3] },
				$$scope: { ctx }
			}
		});

	return {
		c() {
			create_component(forceportalrootcontext.$$.fragment);
		},
		l(nodes) {
			claim_component(forceportalrootcontext.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(forceportalrootcontext, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const forceportalrootcontext_changes = {};

			if (dirty & /*$$scope, internalDialogRef, slotProps, $$restProps, propsWeControl, as, use, visible*/ 134234571) {
				forceportalrootcontext_changes.$$scope = { dirty, ctx };
			}

			forceportalrootcontext.$set(forceportalrootcontext_changes);
		},
		i(local) {
			if (current) return;
			transition_in(forceportalrootcontext.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(forceportalrootcontext.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(forceportalrootcontext, detaching);
		}
	};
}

function create_fragment$f(ctx) {
	let focustrap;
	let t;
	let stackcontextprovider;
	let current;
	let mounted;
	let dispose;

	focustrap = new FocusTrap({
			props: {
				containers: /*containers*/ ctx[5],
				enabled: /*enabled*/ ctx[4],
				options: { initialFocus: /*initialFocus*/ ctx[2] }
			}
		});

	stackcontextprovider = new StackContextProvider({
			props: {
				element: /*internalDialogRef*/ ctx[3],
				onUpdate: /*func*/ ctx[26],
				$$slots: { default: [create_default_slot$7] },
				$$scope: { ctx }
			}
		});

	return {
		c() {
			create_component(focustrap.$$.fragment);
			t = space();
			create_component(stackcontextprovider.$$.fragment);
		},
		l(nodes) {
			claim_component(focustrap.$$.fragment, nodes);
			t = claim_space(nodes);
			claim_component(stackcontextprovider.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(focustrap, target, anchor);
			insert_hydration(target, t, anchor);
			mount_component(stackcontextprovider, target, anchor);
			current = true;

			if (!mounted) {
				dispose = [
					listen(window_1, "mousedown", /*handleWindowMousedown*/ ctx[12]),
					listen(window_1, "keydown", /*handleWindowKeydown*/ ctx[13])
				];

				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			const focustrap_changes = {};
			if (dirty & /*containers*/ 32) focustrap_changes.containers = /*containers*/ ctx[5];
			if (dirty & /*enabled*/ 16) focustrap_changes.enabled = /*enabled*/ ctx[4];
			if (dirty & /*initialFocus*/ 4) focustrap_changes.options = { initialFocus: /*initialFocus*/ ctx[2] };
			focustrap.$set(focustrap_changes);
			const stackcontextprovider_changes = {};
			if (dirty & /*internalDialogRef*/ 8) stackcontextprovider_changes.element = /*internalDialogRef*/ ctx[3];
			if (dirty & /*containers*/ 32) stackcontextprovider_changes.onUpdate = /*func*/ ctx[26];

			if (dirty & /*$$scope, internalDialogRef, slotProps, $$restProps, propsWeControl, as, use, visible*/ 134234571) {
				stackcontextprovider_changes.$$scope = { dirty, ctx };
			}

			stackcontextprovider.$set(stackcontextprovider_changes);
		},
		i(local) {
			if (current) return;
			transition_in(focustrap.$$.fragment, local);
			transition_in(stackcontextprovider.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(focustrap.$$.fragment, local);
			transition_out(stackcontextprovider.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(focustrap, detaching);
			if (detaching) detach(t);
			destroy_component(stackcontextprovider, detaching);
			mounted = false;
			run_all(dispose);
		}
	};
}

var DialogStates;

(function (DialogStates) {
	DialogStates[DialogStates["Open"] = 0] = "Open";
	DialogStates[DialogStates["Closed"] = 1] = "Closed";
})(DialogStates || (DialogStates = {}));

const DIALOG_CONTEXT_NAME = "headlessui-dialog-context";

function useDialogContext(component) {
	let context = getContext(DIALOG_CONTEXT_NAME);

	if (context === undefined) {
		throw new Error(`<${component} /> is missing a parent <Dialog /> component.`);
	}

	return context;
}

function handleClick(e) {
	let event = e;
	event.stopPropagation();
}

function instance$f($$self, $$props, $$invalidate) {
	let dialogState;
	let visible;
	let enabled;
	let _cleanup;
	let _cleanupScrollLock;
	let _cleanupClose;
	let propsWeControl;
	let slotProps;
	const omit_props_names = ["as","use","open","initialFocus"];
	let $$restProps = compute_rest_props($$props, omit_props_names);
	let $api;
	let $openClosedState;
	let { $$slots: slots = {}, $$scope } = $$props;
	let { as = "div" } = $$props;
	let { use = [] } = $$props;
	let { open = undefined } = $$props;
	let { initialFocus = null } = $$props;

	/***** Events *****/
	const forwardEvents = forwardEventsBuilder(get_current_component(), ["close"]);

	const dispatch = createEventDispatcher();

	/***** Component *****/
	let containers = new Set();

	let openClosedState = useOpenClosed();
	component_subscribe($$self, openClosedState, value => $$invalidate(23, $openClosedState = value));
	let internalDialogRef = null;
	const id = `headlessui-dialog-${useId()}`;

	onDestroy(() => {
		if (_cleanup) {
			_cleanup();
		}
	});

	let titleId;

	let api = writable({
		titleId,
		dialogState,
		setTitleId(id) {
			if (titleId === id) return;
			$$invalidate(16, titleId = id);
		},
		close() {
			dispatch("close", false);
		}
	});

	component_subscribe($$self, api, value => $$invalidate(22, $api = value));
	setContext(DIALOG_CONTEXT_NAME, api);

	// Handle outside click
	async function handleWindowMousedown(event) {
		let target = event.target;
		if (dialogState !== DialogStates.Open) return;
		if (containers.size !== 1) return;
		if (contains(containers, target)) return;
		$api.close();
		await tick();
		target?.focus();
	}

	// Handle `Escape` to close
	function handleWindowKeydown(event) {
		if (event.key !== Keys.Escape) return;
		if (dialogState !== DialogStates.Open) return;
		if (containers.size > 1) return; // 1 is myself, otherwise other elements in the Stack
		event.preventDefault();
		event.stopPropagation();
		$api.close();
	}

	let mounted = false;
	onMount(() => $$invalidate(17, mounted = true));

	onDestroy(() => {
		if (_cleanupScrollLock) {
			_cleanupScrollLock();
		}
	});

	onDestroy(() => {
		if (_cleanupClose) {
			_cleanupClose();
		}
	});

	function render_el_binding(value) {
		internalDialogRef = value;
		$$invalidate(3, internalDialogRef);
	}

	const func = (message, element) => {
		return match(message, {
			[StackMessage.Add]() {
				$$invalidate(5, containers = new Set([...containers, element]));
			},
			[StackMessage.Remove]() {
				containers.delete(element);
				$$invalidate(5, containers = new Set([...containers]));
			}
		});
	};

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(14, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('as' in $$new_props) $$invalidate(0, as = $$new_props.as);
		if ('use' in $$new_props) $$invalidate(1, use = $$new_props.use);
		if ('open' in $$new_props) $$invalidate(15, open = $$new_props.open);
		if ('initialFocus' in $$new_props) $$invalidate(2, initialFocus = $$new_props.initialFocus);
		if ('$$scope' in $$new_props) $$invalidate(27, $$scope = $$new_props.$$scope);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*open, $openClosedState*/ 8421376) {
			{
				$$invalidate(15, open = open === undefined && openClosedState !== undefined
				? match($openClosedState, {
						[State.Open]: true,
						[State.Closed]: false
					})
				: open);

				// Validations
				let hasOpen = open !== undefined || openClosedState !== undefined;

				if (!hasOpen) {
					throw new Error(`You forgot to provide an \`open\` prop to the \`Dialog\` component.`);
				}

				if (typeof open !== "boolean") {
					throw new Error(`You provided an \`open\` prop to the \`Dialog\`, but the value is not a boolean. Received: ${open}`);
				}
			}
		}

		if ($$self.$$.dirty & /*open*/ 32768) {
			$$invalidate(18, dialogState = open ? DialogStates.Open : DialogStates.Closed);
		}

		if ($$self.$$.dirty & /*$openClosedState, dialogState*/ 8650752) {
			$$invalidate(8, visible = openClosedState !== undefined
			? $openClosedState === State.Open
			: dialogState === DialogStates.Open);
		}

		if ($$self.$$.dirty & /*dialogState*/ 262144) {
			$$invalidate(4, enabled = dialogState === DialogStates.Open);
		}

		if ($$self.$$.dirty & /*_cleanup, internalDialogRef, enabled*/ 2097176) {
			$$invalidate(21, _cleanup = (() => {
				if (_cleanup) {
					_cleanup();
				}

				return useInertOthers(internalDialogRef, enabled);
			})());
		}

		if ($$self.$$.dirty & /*titleId, dialogState*/ 327680) {
			api.update(obj => {
				return { ...obj, titleId, dialogState };
			});
		}

		if ($$self.$$.dirty & /*_cleanupScrollLock, dialogState, mounted*/ 1441792) {
			$$invalidate(20, _cleanupScrollLock = (() => {
				if (_cleanupScrollLock) {
					_cleanupScrollLock();
				}

				if (dialogState !== DialogStates.Open) return;
				if (!mounted) return;
				let overflow = document.documentElement.style.overflow;
				let paddingRight = document.documentElement.style.paddingRight;
				let scrollbarWidth = window.innerWidth - document.documentElement.clientWidth;
				document.documentElement.style.overflow = "hidden";
				document.documentElement.style.paddingRight = `${scrollbarWidth}px`;

				return () => {
					document.documentElement.style.overflow = overflow;
					document.documentElement.style.paddingRight = paddingRight;
				};
			})());
		}

		if ($$self.$$.dirty & /*_cleanupClose, dialogState, internalDialogRef, $api*/ 4980744) {
			$$invalidate(19, _cleanupClose = (() => {
				if (_cleanupClose) {
					_cleanupClose();
				}

				if (dialogState !== DialogStates.Open) return;
				let container = internalDialogRef;
				if (!container) return;

				let observer = new IntersectionObserver(entries => {
						for (let entry of entries) {
							if (entry.boundingClientRect.x === 0 && entry.boundingClientRect.y === 0 && entry.boundingClientRect.width === 0 && entry.boundingClientRect.height === 0) {
								$api.close();
							}
						}
					});

				observer.observe(container);
				return () => observer.disconnect();
			})());
		}

		if ($$self.$$.dirty & /*dialogState, titleId*/ 327680) {
			$$invalidate(7, propsWeControl = {
				id,
				role: "dialog",
				"aria-modal": dialogState === DialogStates.Open ? true : undefined,
				"aria-labelledby": titleId
			});
		}

		if ($$self.$$.dirty & /*open*/ 32768) {
			$$invalidate(6, slotProps = { open });
		}
	};

	return [
		as,
		use,
		initialFocus,
		internalDialogRef,
		enabled,
		containers,
		slotProps,
		propsWeControl,
		visible,
		forwardEvents,
		openClosedState,
		api,
		handleWindowMousedown,
		handleWindowKeydown,
		$$restProps,
		open,
		titleId,
		mounted,
		dialogState,
		_cleanupClose,
		_cleanupScrollLock,
		_cleanup,
		$api,
		$openClosedState,
		slots,
		render_el_binding,
		func,
		$$scope
	];
}

class Dialog extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$f, create_fragment$f, safe_not_equal, { as: 0, use: 1, open: 15, initialFocus: 2 });
	}
}

/* node_modules\svelte-headlessui-combobox-temporary\components\dialog\DialogOverlay.svelte generated by Svelte v3.48.0 */
const get_default_slot_spread_changes = dirty => dirty & /*slotProps*/ 4;
const get_default_slot_changes$3 = dirty => ({});
const get_default_slot_context$3 = ctx => ({ .../*slotProps*/ ctx[2] });

// (31:0) <Render    {...{ ...$$restProps, ...propsWeControl }}    {as}    {slotProps}    use={[...use, forwardEvents]}    name={"DialogOverlay"}    on:click={handleClick}  >
function create_default_slot$6(ctx) {
	let current;
	const default_slot_template = /*#slots*/ ctx[9].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[10], get_default_slot_context$3);

	return {
		c() {
			if (default_slot) default_slot.c();
		},
		l(nodes) {
			if (default_slot) default_slot.l(nodes);
		},
		m(target, anchor) {
			if (default_slot) {
				default_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope, slotProps*/ 1028)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[10],
						get_default_slot_spread_changes(dirty) || !current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[10])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[10], dirty, get_default_slot_changes$3),
						get_default_slot_context$3
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (default_slot) default_slot.d(detaching);
		}
	};
}

function create_fragment$e(ctx) {
	let render;
	let current;

	const render_spread_levels = [
		{
			.../*$$restProps*/ ctx[7],
			.../*propsWeControl*/ ctx[3]
		},
		{ as: /*as*/ ctx[0] },
		{ slotProps: /*slotProps*/ ctx[2] },
		{
			use: [.../*use*/ ctx[1], /*forwardEvents*/ ctx[4]]
		},
		{ name: "DialogOverlay" }
	];

	let render_props = {
		$$slots: { default: [create_default_slot$6] },
		$$scope: { ctx }
	};

	for (let i = 0; i < render_spread_levels.length; i += 1) {
		render_props = assign(render_props, render_spread_levels[i]);
	}

	render = new Render({ props: render_props });
	render.$on("click", /*handleClick*/ ctx[6]);

	return {
		c() {
			create_component(render.$$.fragment);
		},
		l(nodes) {
			claim_component(render.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(render, target, anchor);
			current = true;
		},
		p(ctx, [dirty]) {
			const render_changes = (dirty & /*$$restProps, propsWeControl, as, slotProps, use, forwardEvents*/ 159)
			? get_spread_update(render_spread_levels, [
					dirty & /*$$restProps, propsWeControl*/ 136 && {
						.../*$$restProps*/ ctx[7],
						.../*propsWeControl*/ ctx[3]
					},
					dirty & /*as*/ 1 && { as: /*as*/ ctx[0] },
					dirty & /*slotProps*/ 4 && { slotProps: /*slotProps*/ ctx[2] },
					dirty & /*use, forwardEvents*/ 18 && {
						use: [.../*use*/ ctx[1], /*forwardEvents*/ ctx[4]]
					},
					render_spread_levels[4]
				])
			: {};

			if (dirty & /*$$scope, slotProps*/ 1028) {
				render_changes.$$scope = { dirty, ctx };
			}

			render.$set(render_changes);
		},
		i(local) {
			if (current) return;
			transition_in(render.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(render.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(render, detaching);
		}
	};
}

function instance$e($$self, $$props, $$invalidate) {
	let propsWeControl;
	let slotProps;
	const omit_props_names = ["as","use"];
	let $$restProps = compute_rest_props($$props, omit_props_names);
	let $api;
	let { $$slots: slots = {}, $$scope } = $$props;
	let { as = "div" } = $$props;
	let { use = [] } = $$props;

	/***** Events *****/
	const forwardEvents = forwardEventsBuilder(get_current_component());

	/***** Component *****/
	let api = useDialogContext("DialogOverlay");

	component_subscribe($$self, api, value => $$invalidate(8, $api = value));
	let id = `headlessui-dialog-overlay-${useId()}`;

	function handleClick(e) {
		let event = e;
		if (event.target !== event.currentTarget) return;
		event.preventDefault();
		event.stopPropagation();
		$api.close();
	}

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(7, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('as' in $$new_props) $$invalidate(0, as = $$new_props.as);
		if ('use' in $$new_props) $$invalidate(1, use = $$new_props.use);
		if ('$$scope' in $$new_props) $$invalidate(10, $$scope = $$new_props.$$scope);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*$api*/ 256) {
			$$invalidate(2, slotProps = {
				open: $api.dialogState === DialogStates.Open
			});
		}
	};

	$$invalidate(3, propsWeControl = { id, "aria-hidden": true });

	return [
		as,
		use,
		slotProps,
		propsWeControl,
		forwardEvents,
		api,
		handleClick,
		$$restProps,
		$api,
		slots,
		$$scope
	];
}

class DialogOverlay extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$e, create_fragment$e, safe_not_equal, { as: 0, use: 1 });
	}
}

/* node_modules\svelte-headlessui-combobox-temporary\components\disclosure\Disclosure.svelte generated by Svelte v3.48.0 */

var DisclosureStates;

(function (DisclosureStates) {
	DisclosureStates[DisclosureStates["Open"] = 0] = "Open";
	DisclosureStates[DisclosureStates["Closed"] = 1] = "Closed";
})(DisclosureStates || (DisclosureStates = {}));

var Focus;
(function (Focus) {
    /** Focus the first non-disabled item. */
    Focus[Focus["First"] = 0] = "First";
    /** Focus the previous non-disabled item. */
    Focus[Focus["Previous"] = 1] = "Previous";
    /** Focus the next non-disabled item. */
    Focus[Focus["Next"] = 2] = "Next";
    /** Focus the last non-disabled item. */
    Focus[Focus["Last"] = 3] = "Last";
    /** Focus a specific item based on the `id` of the item. */
    Focus[Focus["Specific"] = 4] = "Specific";
    /** Focus no items at all. */
    Focus[Focus["Nothing"] = 5] = "Nothing";
})(Focus || (Focus = {}));

/* node_modules\svelte-headlessui-combobox-temporary\internal\Hidden.svelte generated by Svelte v3.48.0 */

var Features;

(function (Features) {
	// The default, no features.
	Features[Features["None"] = 1] = "None";

	// Whether the element should be focusable or not.
	Features[Features["Focusable"] = 2] = "Focusable";

	// Whether it should be completely hidden, even to assistive technologies.
	Features[Features["Hidden"] = 4] = "Hidden";
})(Features || (Features = {}));

/* node_modules\svelte-headlessui-combobox-temporary\components\listbox\Listbox.svelte generated by Svelte v3.48.0 */

var ListboxStates;

(function (ListboxStates) {
	ListboxStates[ListboxStates["Open"] = 0] = "Open";
	ListboxStates[ListboxStates["Closed"] = 1] = "Closed";
})(ListboxStates || (ListboxStates = {}));

/* node_modules\svelte-headlessui-combobox-temporary\components\menu\Menu.svelte generated by Svelte v3.48.0 */

var MenuStates;

(function (MenuStates) {
	MenuStates[MenuStates["Open"] = 0] = "Open";
	MenuStates[MenuStates["Closed"] = 1] = "Closed";
})(MenuStates || (MenuStates = {}));

/* node_modules\svelte-headlessui-combobox-temporary\components\popover\Popover.svelte generated by Svelte v3.48.0 */

var PopoverStates;

(function (PopoverStates) {
	PopoverStates[PopoverStates["Open"] = 0] = "Open";
	PopoverStates[PopoverStates["Closed"] = 1] = "Closed";
})(PopoverStates || (PopoverStates = {}));

function once(cb) {
    let state = { called: false };
    return (...args) => {
        if (state.called)
            return;
        state.called = true;
        return cb(...args);
    };
}

function disposables() {
    let disposables = [];
    let api = {
        requestAnimationFrame(...args) {
            let raf = requestAnimationFrame(...args);
            api.add(() => cancelAnimationFrame(raf));
        },
        nextFrame(...args) {
            api.requestAnimationFrame(() => {
                api.requestAnimationFrame(...args);
            });
        },
        setTimeout(...args) {
            let timer = setTimeout(...args);
            api.add(() => clearTimeout(timer));
        },
        add(cb) {
            disposables.push(cb);
        },
        dispose() {
            for (let dispose of disposables.splice(0)) {
                dispose();
            }
        },
    };
    return api;
}

function addClasses(node, ...classes) {
    node && classes.length > 0 && node.classList.add(...classes);
}
function removeClasses(node, ...classes) {
    node && classes.length > 0 && node.classList.remove(...classes);
}
var Reason;
(function (Reason) {
    Reason["Finished"] = "finished";
    Reason["Cancelled"] = "cancelled";
})(Reason || (Reason = {}));
function waitForTransition(node, done) {
    let d = disposables();
    if (!node)
        return d.dispose;
    // Safari returns a comma separated list of values, so let's sort them and take the highest value.
    let { transitionDuration, transitionDelay } = getComputedStyle(node);
    let [durationMs, delaysMs] = [transitionDuration, transitionDelay].map((value) => {
        let [resolvedValue = 0] = value
            .split(",")
            // Remove falsy we can't work with
            .filter(Boolean)
            // Values are returned as `0.3s` or `75ms`
            .map((v) => (v.includes("ms") ? parseFloat(v) : parseFloat(v) * 1000))
            .sort((a, z) => z - a);
        return resolvedValue;
    });
    // Waiting for the transition to end. We could use the `transitionend` event, however when no
    // actual transition/duration is defined then the `transitionend` event is not fired.
    //
    // TODO: Downside is, when you slow down transitions via devtools this timeout is still using the
    // full 100% speed instead of the 25% or 10%.
    if (durationMs !== 0) {
        d.setTimeout(() => {
            done(Reason.Finished);
        }, durationMs + delaysMs);
    }
    else {
        // No transition is happening, so we should cleanup already. Otherwise we have to wait until we
        // get disposed.
        done(Reason.Finished);
    }
    // If we get disposed before the timeout runs we should cleanup anyway
    d.add(() => done(Reason.Cancelled));
    return d.dispose;
}
function transition(node, base, from, to, entered, done) {
    let d = disposables();
    let _done = done !== undefined ? once(done) : () => { };
    removeClasses(node, ...entered);
    addClasses(node, ...base, ...from);
    d.nextFrame(() => {
        removeClasses(node, ...from);
        addClasses(node, ...to);
        d.add(waitForTransition(node, (reason) => {
            removeClasses(node, ...to, ...base);
            addClasses(node, ...entered);
            return _done(reason);
        }));
    });
    // Once we get disposed, we should ensure that we cleanup after ourselves. In case of an unmount,
    // the node itself will be nullified and will be a no-op. In case of a full transition the classes
    // are already removed which is also a no-op. However if you go from enter -> leave mid-transition
    // then we have some leftovers that should be cleaned.
    d.add(() => removeClasses(node, ...base, ...from, ...to));
    // When we get disposed early, than we should also call the done method but switch the reason.
    d.add(() => _done(Reason.Cancelled));
    return d.dispose;
}

/* node_modules\svelte-headlessui-combobox-temporary\components\transitions\common.svelte generated by Svelte v3.48.0 */
var TreeStates;

(function (TreeStates) {
	TreeStates["Visible"] = "visible";
	TreeStates["Hidden"] = "hidden";
})(TreeStates || (TreeStates = {}));

const TRANSITION_CONTEXT_NAME = "headlessui-transition-context";
const NESTING_CONTEXT_NAME = "headlessui-nesting-context";

function hasTransitionContext() {
	return getContext(TRANSITION_CONTEXT_NAME) !== undefined;
}

function useTransitionContext() {
	let context = getContext(TRANSITION_CONTEXT_NAME);

	if (context === undefined) {
		throw new Error("A <TransitionChild /> is used but it is missing a parent <TransitionRoot />.");
	}

	return context;
}

function useParentNesting() {
	let context = getContext(NESTING_CONTEXT_NAME);

	if (context === undefined) {
		throw new Error("A <TransitionChild /> is used but it is missing a parent <TransitionRoot />.");
	}

	return context;
}

function hasChildren(bag) {
	if ("children" in bag) return hasChildren(bag.children);
	return bag.filter(({ state }) => state === TreeStates.Visible).length > 0;
}

function useNesting(done) {
	let transitionableChildren = [];

	function unregister(childId, strategy = RenderStrategy.Hidden) {
		let idx = transitionableChildren.findIndex(({ id }) => id === childId);
		if (idx === -1) return;
		let hadChildren = hasChildren(transitionableChildren);

		match(strategy, {
			[RenderStrategy.Unmount]() {
				transitionableChildren.splice(idx, 1);
			},
			[RenderStrategy.Hidden]() {
				transitionableChildren[idx].state = TreeStates.Hidden;
			}
		});

		if (hadChildren && !hasChildren(transitionableChildren)) {
			done?.();
		}
	}

	function register(childId) {
		let child = transitionableChildren.find(({ id }) => id === childId);

		if (!child) {
			transitionableChildren.push({ id: childId, state: TreeStates.Visible });
		} else if (child.state !== TreeStates.Visible) {
			child.state = TreeStates.Visible;
		}

		return () => unregister(childId, RenderStrategy.Unmount);
	}

	return {
		children: transitionableChildren,
		register,
		unregister
	};
}

/* node_modules\svelte-headlessui-combobox-temporary\components\transitions\TransitionChild.svelte generated by Svelte v3.48.0 */

function create_default_slot$5(ctx) {
	let current;
	const default_slot_template = /*#slots*/ ctx[23].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[25], null);

	return {
		c() {
			if (default_slot) default_slot.c();
		},
		l(nodes) {
			if (default_slot) default_slot.l(nodes);
		},
		m(target, anchor) {
			if (default_slot) {
				default_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty[0] & /*$$scope*/ 33554432)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[25],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[25])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[25], dirty, null),
						null
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (default_slot) default_slot.d(detaching);
		}
	};
}

function create_fragment$d(ctx) {
	let render;
	let updating_el;
	let current;

	const render_spread_levels = [
		/*$$restProps*/ ctx[9],
		{ as: /*as*/ ctx[0] },
		{
			use: [.../*use*/ ctx[1], /*forwardEvents*/ ctx[5]]
		},
		{ slotProps: {} },
		{ name: "TransitionChild" },
		{ class: /*classes*/ ctx[4] },
		{
			visible: /*state*/ ctx[3] === TreeStates.Visible
		},
		{ features: Features$1.RenderStrategy }
	];

	function render_el_binding(value) {
		/*render_el_binding*/ ctx[24](value);
	}

	let render_props = {
		$$slots: { default: [create_default_slot$5] },
		$$scope: { ctx }
	};

	for (let i = 0; i < render_spread_levels.length; i += 1) {
		render_props = assign(render_props, render_spread_levels[i]);
	}

	if (/*container*/ ctx[2] !== void 0) {
		render_props.el = /*container*/ ctx[2];
	}

	render = new Render({ props: render_props });
	binding_callbacks.push(() => bind(render, 'el', render_el_binding));

	return {
		c() {
			create_component(render.$$.fragment);
		},
		l(nodes) {
			claim_component(render.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(render, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const render_changes = (dirty[0] & /*$$restProps, as, use, forwardEvents, classes, state*/ 571)
			? get_spread_update(render_spread_levels, [
					dirty[0] & /*$$restProps*/ 512 && get_spread_object(/*$$restProps*/ ctx[9]),
					dirty[0] & /*as*/ 1 && { as: /*as*/ ctx[0] },
					dirty[0] & /*use, forwardEvents*/ 34 && {
						use: [.../*use*/ ctx[1], /*forwardEvents*/ ctx[5]]
					},
					render_spread_levels[3],
					render_spread_levels[4],
					dirty[0] & /*classes*/ 16 && { class: /*classes*/ ctx[4] },
					dirty[0] & /*state*/ 8 && {
						visible: /*state*/ ctx[3] === TreeStates.Visible
					},
					dirty & /*Features*/ 0 && { features: Features$1.RenderStrategy }
				])
			: {};

			if (dirty[0] & /*$$scope*/ 33554432) {
				render_changes.$$scope = { dirty, ctx };
			}

			if (!updating_el && dirty[0] & /*container*/ 4) {
				updating_el = true;
				render_changes.el = /*container*/ ctx[2];
				add_flush_callback(() => updating_el = false);
			}

			render.$set(render_changes);
		},
		i(local) {
			if (current) return;
			transition_in(render.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(render.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(render, detaching);
		}
	};
}

function instance$d($$self, $$props, $$invalidate) {
	let strategy;
	let enterClasses;
	let enterFromClasses;
	let enterToClasses;
	let enteredClasses;
	let leaveClasses;
	let leaveFromClasses;
	let leaveToClasses;
	let classes;

	const omit_props_names = [
		"as","use","enter","enterFrom","enterTo","entered","leave","leaveFrom","leaveTo"
	];

	let $$restProps = compute_rest_props($$props, omit_props_names);
	let $transitionContext;
	let $nestingContext;
	let $nesting;
	let { $$slots: slots = {}, $$scope } = $$props;
	let { as = "div" } = $$props;
	let { use = [] } = $$props;
	let { enter = "" } = $$props;
	let { enterFrom = "" } = $$props;
	let { enterTo = "" } = $$props;
	let { entered = "" } = $$props;
	let { leave = "" } = $$props;
	let { leaveFrom = "" } = $$props;
	let { leaveTo = "" } = $$props;

	/***** Events *****/
	const dispatch = createEventDispatcher();

	const forwardEvents = forwardEventsBuilder(get_current_component(), ["beforeEnter", "beforeLeave", "afterEnter", "afterLeave"]);

	/***** Component *****/
	let container = null;

	let transitionContext = useTransitionContext();
	component_subscribe($$self, transitionContext, value => $$invalidate(21, $transitionContext = value));
	let nestingContext = useParentNesting();
	component_subscribe($$self, nestingContext, value => $$invalidate(22, $nestingContext = value));

	let state = $transitionContext.initialShow || $$props.unmount !== false
	? TreeStates.Visible
	: TreeStates.Hidden;

	let initial = true;
	let id = useId();
	let isTransitioning = false;

	let nesting = writable(useNesting(() => {
		// When all children have been unmounted we can only hide ourselves if and only if we are not
		// transitioning ourselves. Otherwise we would unmount before the transitions are finished.
		if (!isTransitioning) {
			$$invalidate(3, state = TreeStates.Hidden);
			$nestingContext.unregister(id);
			dispatch("afterLeave");
		}
	}));

	component_subscribe($$self, nesting, value => $$invalidate(34, $nesting = value));
	onMount(() => $nestingContext.register(id));

	function splitClasses(classes = "") {
		return classes.split(" ").filter(className => className.trim().length > 1);
	}

	let mounted = false;
	onMount(() => $$invalidate(18, mounted = true));

	function executeTransition(show, appear) {
		// Skipping initial transition
		let skip = initial && !appear;

		let node = container;
		if (!node || !(node instanceof HTMLElement)) return;
		if (skip) return;
		$$invalidate(17, isTransitioning = true);
		if (show) dispatch("beforeEnter");
		if (!show) dispatch("beforeLeave");

		return show
		? transition(node, enterClasses, enterFromClasses, enterToClasses, enteredClasses, reason => {
				$$invalidate(17, isTransitioning = false);
				if (reason === Reason.Finished) dispatch("afterEnter");
			})
		: transition(node, leaveClasses, leaveFromClasses, leaveToClasses, enteredClasses, reason => {
				$$invalidate(17, isTransitioning = false);
				if (reason !== Reason.Finished) return;

				// When we don't have children anymore we can safely unregister from the parent and hide
				// ourselves.
				if (!hasChildren($nesting)) {
					$$invalidate(3, state = TreeStates.Hidden);
					$nestingContext.unregister(id);
					dispatch("afterLeave");
				}
			});
	}

	let _cleanup = null;
	setContext(NESTING_CONTEXT_NAME, nesting);
	let openClosedState = writable(State.Closed);
	useOpenClosedProvider(openClosedState);

	function render_el_binding(value) {
		container = value;
		$$invalidate(2, container);
	}

	$$self.$$set = $$new_props => {
		$$invalidate(40, $$props = assign(assign({}, $$props), exclude_internal_props($$new_props)));
		$$invalidate(9, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('as' in $$new_props) $$invalidate(0, as = $$new_props.as);
		if ('use' in $$new_props) $$invalidate(1, use = $$new_props.use);
		if ('enter' in $$new_props) $$invalidate(10, enter = $$new_props.enter);
		if ('enterFrom' in $$new_props) $$invalidate(11, enterFrom = $$new_props.enterFrom);
		if ('enterTo' in $$new_props) $$invalidate(12, enterTo = $$new_props.enterTo);
		if ('entered' in $$new_props) $$invalidate(13, entered = $$new_props.entered);
		if ('leave' in $$new_props) $$invalidate(14, leave = $$new_props.leave);
		if ('leaveFrom' in $$new_props) $$invalidate(15, leaveFrom = $$new_props.leaveFrom);
		if ('leaveTo' in $$new_props) $$invalidate(16, leaveTo = $$new_props.leaveTo);
		if ('$$scope' in $$new_props) $$invalidate(25, $$scope = $$new_props.$$scope);
	};

	$$self.$$.update = () => {
		$$invalidate(20, strategy = $$props.unmount === false
		? RenderStrategy.Hidden
		: RenderStrategy.Unmount);

		if ($$self.$$.dirty[0] & /*strategy, $transitionContext, state, $nestingContext*/ 7340040) {
			{
				(() => {
					// If we are in another mode than the Hidden mode then ignore
					if (strategy !== RenderStrategy.Hidden) return;

					if (!id) return;

					// Make sure that we are visible
					if ($transitionContext.show && state !== TreeStates.Visible) {
						$$invalidate(3, state = TreeStates.Visible);
						return;
					}

					match(state, {
						[TreeStates.Hidden]: () => $nestingContext.unregister(id),
						[TreeStates.Visible]: () => $nestingContext.register(id)
					});
				})();
			}
		}

		if ($$self.$$.dirty[0] & /*enter*/ 1024) {
			enterClasses = splitClasses(enter);
		}

		if ($$self.$$.dirty[0] & /*enterFrom*/ 2048) {
			enterFromClasses = splitClasses(enterFrom);
		}

		if ($$self.$$.dirty[0] & /*enterTo*/ 4096) {
			enterToClasses = splitClasses(enterTo);
		}

		if ($$self.$$.dirty[0] & /*entered*/ 8192) {
			enteredClasses = splitClasses(entered);
		}

		if ($$self.$$.dirty[0] & /*leave*/ 16384) {
			leaveClasses = splitClasses(leave);
		}

		if ($$self.$$.dirty[0] & /*leaveFrom*/ 32768) {
			leaveFromClasses = splitClasses(leaveFrom);
		}

		if ($$self.$$.dirty[0] & /*leaveTo*/ 65536) {
			leaveToClasses = splitClasses(leaveTo);
		}

		if ($$self.$$.dirty[0] & /*mounted, _cleanup, $transitionContext*/ 2883584) {
			{
				if (mounted) {
					if (_cleanup) {
						_cleanup();
					}

					$$invalidate(19, _cleanup = executeTransition($transitionContext.show, $transitionContext.appear));
					initial = false;
				}
			}
		}

		if ($$self.$$.dirty[0] & /*state*/ 8) {
			openClosedState.set(match(state, {
				[TreeStates.Visible]: State.Open,
				[TreeStates.Hidden]: State.Closed
			}));
		}

		// This is not in the base headless UI library, but is needed to prevent re-renders during the transition
		// from blowing away the transition classes
		$$invalidate(4, classes = isTransitioning
		? container?.className
		: `${$$props.class || ""} ${entered}`);
	};

	$$props = exclude_internal_props($$props);

	return [
		as,
		use,
		container,
		state,
		classes,
		forwardEvents,
		transitionContext,
		nestingContext,
		nesting,
		$$restProps,
		enter,
		enterFrom,
		enterTo,
		entered,
		leave,
		leaveFrom,
		leaveTo,
		isTransitioning,
		mounted,
		_cleanup,
		strategy,
		$transitionContext,
		$nestingContext,
		slots,
		render_el_binding,
		$$scope
	];
}

class TransitionChild extends SvelteComponent {
	constructor(options) {
		super();

		init(
			this,
			options,
			instance$d,
			create_fragment$d,
			safe_not_equal,
			{
				as: 0,
				use: 1,
				enter: 10,
				enterFrom: 11,
				enterTo: 12,
				entered: 13,
				leave: 14,
				leaveFrom: 15,
				leaveTo: 16
			},
			null,
			[-1, -1]
		);
	}
}

/* node_modules\svelte-headlessui-combobox-temporary\components\transitions\TransitionRoot.svelte generated by Svelte v3.48.0 */

function create_if_block$8(ctx) {
	let transitionchild;
	let current;

	const transitionchild_spread_levels = [
		/*$$restProps*/ ctx[7],
		{ as: /*as*/ ctx[0] },
		{
			use: [.../*use*/ ctx[1], /*forwardEvents*/ ctx[3]]
		}
	];

	let transitionchild_props = {
		$$slots: { default: [create_default_slot$4] },
		$$scope: { ctx }
	};

	for (let i = 0; i < transitionchild_spread_levels.length; i += 1) {
		transitionchild_props = assign(transitionchild_props, transitionchild_spread_levels[i]);
	}

	transitionchild = new TransitionChild({ props: transitionchild_props });
	transitionchild.$on("afterEnter", /*afterEnter_handler*/ ctx[15]);
	transitionchild.$on("afterLeave", /*afterLeave_handler*/ ctx[16]);
	transitionchild.$on("beforeEnter", /*beforeEnter_handler*/ ctx[17]);
	transitionchild.$on("beforeLeave", /*beforeLeave_handler*/ ctx[18]);

	return {
		c() {
			create_component(transitionchild.$$.fragment);
		},
		l(nodes) {
			claim_component(transitionchild.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(transitionchild, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const transitionchild_changes = (dirty & /*$$restProps, as, use, forwardEvents*/ 139)
			? get_spread_update(transitionchild_spread_levels, [
					dirty & /*$$restProps*/ 128 && get_spread_object(/*$$restProps*/ ctx[7]),
					dirty & /*as*/ 1 && { as: /*as*/ ctx[0] },
					dirty & /*use, forwardEvents*/ 10 && {
						use: [.../*use*/ ctx[1], /*forwardEvents*/ ctx[3]]
					}
				])
			: {};

			if (dirty & /*$$scope*/ 524288) {
				transitionchild_changes.$$scope = { dirty, ctx };
			}

			transitionchild.$set(transitionchild_changes);
		},
		i(local) {
			if (current) return;
			transition_in(transitionchild.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(transitionchild.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(transitionchild, detaching);
		}
	};
}

// (69:2) <TransitionChild      {...$$restProps}      {as}      use={[...use, forwardEvents]}      on:afterEnter      on:afterLeave      on:beforeEnter      on:beforeLeave    >
function create_default_slot$4(ctx) {
	let current;
	const default_slot_template = /*#slots*/ ctx[14].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[19], null);

	return {
		c() {
			if (default_slot) default_slot.c();
		},
		l(nodes) {
			if (default_slot) default_slot.l(nodes);
		},
		m(target, anchor) {
			if (default_slot) {
				default_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 524288)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[19],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[19])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[19], dirty, null),
						null
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (default_slot) default_slot.d(detaching);
		}
	};
}

function create_fragment$c(ctx) {
	let if_block_anchor;
	let current;
	let if_block = (/*state*/ ctx[2] === TreeStates.Visible || /*$$props*/ ctx[6].unmount === false) && create_if_block$8(ctx);

	return {
		c() {
			if (if_block) if_block.c();
			if_block_anchor = empty();
		},
		l(nodes) {
			if (if_block) if_block.l(nodes);
			if_block_anchor = empty();
		},
		m(target, anchor) {
			if (if_block) if_block.m(target, anchor);
			insert_hydration(target, if_block_anchor, anchor);
			current = true;
		},
		p(ctx, [dirty]) {
			if (/*state*/ ctx[2] === TreeStates.Visible || /*$$props*/ ctx[6].unmount === false) {
				if (if_block) {
					if_block.p(ctx, dirty);

					if (dirty & /*state, $$props*/ 68) {
						transition_in(if_block, 1);
					}
				} else {
					if_block = create_if_block$8(ctx);
					if_block.c();
					transition_in(if_block, 1);
					if_block.m(if_block_anchor.parentNode, if_block_anchor);
				}
			} else if (if_block) {
				group_outros();

				transition_out(if_block, 1, 1, () => {
					if_block = null;
				});

				check_outros();
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			if (if_block) if_block.d(detaching);
			if (detaching) detach(if_block_anchor);
		}
	};
}

function instance$c($$self, $$props, $$invalidate) {
	const omit_props_names = ["as","use","show","appear"];
	let $$restProps = compute_rest_props($$props, omit_props_names);
	let $nestingBag;
	let $openClosedState;
	let { $$slots: slots = {}, $$scope } = $$props;
	const forwardEvents = forwardEventsBuilder(get_current_component(), ["beforeEnter", "beforeLeave", "afterEnter", "afterLeave"]);
	let { as = "div" } = $$props;
	let { use = [] } = $$props;
	let { show = undefined } = $$props;
	let { appear = false } = $$props;

	/***** Events *****/
	/***** Component *****/
	let openClosedState = useOpenClosed();

	component_subscribe($$self, openClosedState, value => $$invalidate(13, $openClosedState = value));

	function computeShow(show, openClosedState) {
		if (show === undefined && openClosedState !== undefined) {
			return match(openClosedState, {
				[State.Open]: true,
				[State.Closed]: false
			});
		}

		return show;
	}

	let shouldShow = computeShow(show, openClosedState !== undefined
	? $openClosedState
	: undefined);

	let initialShow = shouldShow;
	let state = shouldShow ? TreeStates.Visible : TreeStates.Hidden;

	let nestingBag = writable(useNesting(() => {
		$$invalidate(2, state = TreeStates.Hidden);
	}));

	component_subscribe($$self, nestingBag, value => $$invalidate(12, $nestingBag = value));
	let initial = true;
	let transitionBag = writable();

	onMount(() => {
		$$invalidate(11, initial = false);
	});

	setContext(NESTING_CONTEXT_NAME, nestingBag);
	setContext(TRANSITION_CONTEXT_NAME, transitionBag);

	function afterEnter_handler(event) {
		bubble.call(this, $$self, event);
	}

	function afterLeave_handler(event) {
		bubble.call(this, $$self, event);
	}

	function beforeEnter_handler(event) {
		bubble.call(this, $$self, event);
	}

	function beforeLeave_handler(event) {
		bubble.call(this, $$self, event);
	}

	$$self.$$set = $$new_props => {
		$$invalidate(6, $$props = assign(assign({}, $$props), exclude_internal_props($$new_props)));
		$$invalidate(7, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('as' in $$new_props) $$invalidate(0, as = $$new_props.as);
		if ('use' in $$new_props) $$invalidate(1, use = $$new_props.use);
		if ('show' in $$new_props) $$invalidate(8, show = $$new_props.show);
		if ('appear' in $$new_props) $$invalidate(9, appear = $$new_props.appear);
		if ('$$scope' in $$new_props) $$invalidate(19, $$scope = $$new_props.$$scope);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*show, $openClosedState, shouldShow*/ 9472) {
			{
				$$invalidate(10, shouldShow = computeShow(show, openClosedState !== undefined
				? $openClosedState
				: undefined));

				if (shouldShow !== true && shouldShow !== false) {
					throw new Error("A <Transition /> is used but it is missing a `show={true | false}` prop.");
				}
			}
		}

		if ($$self.$$.dirty & /*shouldShow, appear, initial*/ 3584) {
			transitionBag.set({
				show: !!shouldShow,
				appear: appear || !initial,
				initialShow: !!initialShow
			});
		}

		if ($$self.$$.dirty & /*initial, shouldShow, $nestingBag*/ 7168) {
			if (!initial) {
				if (shouldShow) {
					$$invalidate(2, state = TreeStates.Visible);
				} else if (!hasChildren($nestingBag)) {
					$$invalidate(2, state = TreeStates.Hidden);
				}
			}
		}
	};

	$$props = exclude_internal_props($$props);

	return [
		as,
		use,
		state,
		forwardEvents,
		openClosedState,
		nestingBag,
		$$props,
		$$restProps,
		show,
		appear,
		shouldShow,
		initial,
		$nestingBag,
		$openClosedState,
		slots,
		afterEnter_handler,
		afterLeave_handler,
		beforeEnter_handler,
		beforeLeave_handler,
		$$scope
	];
}

class TransitionRoot extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$c, create_fragment$c, safe_not_equal, { as: 0, use: 1, show: 8, appear: 9 });
	}
}

/* node_modules\svelte-headlessui-combobox-temporary\components\transitions\TransitionChildWrapper.svelte generated by Svelte v3.48.0 */

function create_else_block$2(ctx) {
	let transitionchild;
	let current;

	const transitionchild_spread_levels = [
		/*$$props*/ ctx[5],
		{ as: /*as*/ ctx[0] },
		{
			use: [.../*use*/ ctx[1], /*forwardEvents*/ ctx[2]]
		}
	];

	let transitionchild_props = {
		$$slots: { default: [create_default_slot_1$2] },
		$$scope: { ctx }
	};

	for (let i = 0; i < transitionchild_spread_levels.length; i += 1) {
		transitionchild_props = assign(transitionchild_props, transitionchild_spread_levels[i]);
	}

	transitionchild = new TransitionChild({ props: transitionchild_props });
	transitionchild.$on("afterEnter", /*afterEnter_handler_1*/ ctx[11]);
	transitionchild.$on("afterLeave", /*afterLeave_handler_1*/ ctx[12]);
	transitionchild.$on("beforeEnter", /*beforeEnter_handler_1*/ ctx[13]);
	transitionchild.$on("beforeLeave", /*beforeLeave_handler_1*/ ctx[14]);

	return {
		c() {
			create_component(transitionchild.$$.fragment);
		},
		l(nodes) {
			claim_component(transitionchild.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(transitionchild, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const transitionchild_changes = (dirty & /*$$props, as, use, forwardEvents*/ 39)
			? get_spread_update(transitionchild_spread_levels, [
					dirty & /*$$props*/ 32 && get_spread_object(/*$$props*/ ctx[5]),
					dirty & /*as*/ 1 && { as: /*as*/ ctx[0] },
					dirty & /*use, forwardEvents*/ 6 && {
						use: [.../*use*/ ctx[1], /*forwardEvents*/ ctx[2]]
					}
				])
			: {};

			if (dirty & /*$$scope*/ 32768) {
				transitionchild_changes.$$scope = { dirty, ctx };
			}

			transitionchild.$set(transitionchild_changes);
		},
		i(local) {
			if (current) return;
			transition_in(transitionchild.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(transitionchild.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(transitionchild, detaching);
		}
	};
}

// (21:0) {#if !hasTransition && hasOpen}
function create_if_block$7(ctx) {
	let transitionroot;
	let current;

	const transitionroot_spread_levels = [
		/*$$props*/ ctx[5],
		{ as: /*as*/ ctx[0] },
		{
			use: [.../*use*/ ctx[1], /*forwardEvents*/ ctx[2]]
		}
	];

	let transitionroot_props = {
		$$slots: { default: [create_default_slot$3] },
		$$scope: { ctx }
	};

	for (let i = 0; i < transitionroot_spread_levels.length; i += 1) {
		transitionroot_props = assign(transitionroot_props, transitionroot_spread_levels[i]);
	}

	transitionroot = new TransitionRoot({ props: transitionroot_props });
	transitionroot.$on("afterEnter", /*afterEnter_handler*/ ctx[7]);
	transitionroot.$on("afterLeave", /*afterLeave_handler*/ ctx[8]);
	transitionroot.$on("beforeEnter", /*beforeEnter_handler*/ ctx[9]);
	transitionroot.$on("beforeLeave", /*beforeLeave_handler*/ ctx[10]);

	return {
		c() {
			create_component(transitionroot.$$.fragment);
		},
		l(nodes) {
			claim_component(transitionroot.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(transitionroot, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const transitionroot_changes = (dirty & /*$$props, as, use, forwardEvents*/ 39)
			? get_spread_update(transitionroot_spread_levels, [
					dirty & /*$$props*/ 32 && get_spread_object(/*$$props*/ ctx[5]),
					dirty & /*as*/ 1 && { as: /*as*/ ctx[0] },
					dirty & /*use, forwardEvents*/ 6 && {
						use: [.../*use*/ ctx[1], /*forwardEvents*/ ctx[2]]
					}
				])
			: {};

			if (dirty & /*$$scope*/ 32768) {
				transitionroot_changes.$$scope = { dirty, ctx };
			}

			transitionroot.$set(transitionroot_changes);
		},
		i(local) {
			if (current) return;
			transition_in(transitionroot.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(transitionroot.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(transitionroot, detaching);
		}
	};
}

// (34:2) <TransitionChild      {...$$props}      {as}      use={[...use, forwardEvents]}      on:afterEnter      on:afterLeave      on:beforeEnter      on:beforeLeave    >
function create_default_slot_1$2(ctx) {
	let current;
	const default_slot_template = /*#slots*/ ctx[6].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[15], null);

	return {
		c() {
			if (default_slot) default_slot.c();
		},
		l(nodes) {
			if (default_slot) default_slot.l(nodes);
		},
		m(target, anchor) {
			if (default_slot) {
				default_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 32768)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[15],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[15])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[15], dirty, null),
						null
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (default_slot) default_slot.d(detaching);
		}
	};
}

// (22:2) <TransitionRoot      {...$$props}      {as}      use={[...use, forwardEvents]}      on:afterEnter      on:afterLeave      on:beforeEnter      on:beforeLeave    >
function create_default_slot$3(ctx) {
	let current;
	const default_slot_template = /*#slots*/ ctx[6].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[15], null);

	return {
		c() {
			if (default_slot) default_slot.c();
		},
		l(nodes) {
			if (default_slot) default_slot.l(nodes);
		},
		m(target, anchor) {
			if (default_slot) {
				default_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 32768)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[15],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[15])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[15], dirty, null),
						null
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (default_slot) default_slot.d(detaching);
		}
	};
}

function create_fragment$b(ctx) {
	let current_block_type_index;
	let if_block;
	let if_block_anchor;
	let current;
	const if_block_creators = [create_if_block$7, create_else_block$2];
	const if_blocks = [];

	function select_block_type(ctx, dirty) {
		if (!/*hasTransition*/ ctx[3] && /*hasOpen*/ ctx[4]) return 0;
		return 1;
	}

	current_block_type_index = select_block_type(ctx);
	if_block = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);

	return {
		c() {
			if_block.c();
			if_block_anchor = empty();
		},
		l(nodes) {
			if_block.l(nodes);
			if_block_anchor = empty();
		},
		m(target, anchor) {
			if_blocks[current_block_type_index].m(target, anchor);
			insert_hydration(target, if_block_anchor, anchor);
			current = true;
		},
		p(ctx, [dirty]) {
			if_block.p(ctx, dirty);
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			if_blocks[current_block_type_index].d(detaching);
			if (detaching) detach(if_block_anchor);
		}
	};
}

function instance$b($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	const forwardEvents = forwardEventsBuilder(get_current_component(), ["beforeEnter", "beforeLeave", "afterEnter", "afterLeave"]);
	let { as = "div" } = $$props;
	let { use = [] } = $$props;

	/***** Events *****/
	/***** Component *****/
	let hasTransition = hasTransitionContext();

	let hasOpen = hasOpenClosed();

	function afterEnter_handler(event) {
		bubble.call(this, $$self, event);
	}

	function afterLeave_handler(event) {
		bubble.call(this, $$self, event);
	}

	function beforeEnter_handler(event) {
		bubble.call(this, $$self, event);
	}

	function beforeLeave_handler(event) {
		bubble.call(this, $$self, event);
	}

	function afterEnter_handler_1(event) {
		bubble.call(this, $$self, event);
	}

	function afterLeave_handler_1(event) {
		bubble.call(this, $$self, event);
	}

	function beforeEnter_handler_1(event) {
		bubble.call(this, $$self, event);
	}

	function beforeLeave_handler_1(event) {
		bubble.call(this, $$self, event);
	}

	$$self.$$set = $$new_props => {
		$$invalidate(5, $$props = assign(assign({}, $$props), exclude_internal_props($$new_props)));
		if ('as' in $$new_props) $$invalidate(0, as = $$new_props.as);
		if ('use' in $$new_props) $$invalidate(1, use = $$new_props.use);
		if ('$$scope' in $$new_props) $$invalidate(15, $$scope = $$new_props.$$scope);
	};

	$$props = exclude_internal_props($$props);

	return [
		as,
		use,
		forwardEvents,
		hasTransition,
		hasOpen,
		$$props,
		slots,
		afterEnter_handler,
		afterLeave_handler,
		beforeEnter_handler,
		beforeLeave_handler,
		afterEnter_handler_1,
		afterLeave_handler_1,
		beforeEnter_handler_1,
		beforeLeave_handler_1,
		$$scope
	];
}

class TransitionChildWrapper extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$b, create_fragment$b, safe_not_equal, { as: 0, use: 1 });
	}
}

/* node_modules\svelte-headlessui-combobox-temporary\components\combobox\Combobox.svelte generated by Svelte v3.48.0 */

var ComboboxStates;

(function (ComboboxStates) {
	ComboboxStates[ComboboxStates["Open"] = 0] = "Open";
	ComboboxStates[ComboboxStates["Closed"] = 1] = "Closed";
})(ComboboxStates || (ComboboxStates = {}));

var ValueMode;

(function (ValueMode) {
	ValueMode[ValueMode["Single"] = 0] = "Single";
	ValueMode[ValueMode["Multi"] = 1] = "Multi";
})(ValueMode || (ValueMode = {}));

var ActivationTrigger;

(function (ActivationTrigger) {
	ActivationTrigger[ActivationTrigger["Pointer"] = 0] = "Pointer";
	ActivationTrigger[ActivationTrigger["Other"] = 1] = "Other";
})(ActivationTrigger || (ActivationTrigger = {}));

/* src\Modal\Modal.svelte generated by Svelte v3.48.0 */
const get_footer_slot_changes$1 = dirty => ({});
const get_footer_slot_context$1 = ctx => ({});
const get_content_slot_changes = dirty => ({});
const get_content_slot_context = ctx => ({});
const get_header_slot_changes$1 = dirty => ({});
const get_header_slot_context$1 = ctx => ({});

// (84:6) {#if depth == 1}
function create_if_block_7(ctx) {
	let transitionchild;
	let current;

	transitionchild = new TransitionChildWrapper({
			props: {
				enter: "ease-out duration-300",
				enterFrom: "opacity-0",
				enterTo: "opacity-100",
				leave: "ease-in duration-200",
				leaveFrom: "opacity-100",
				leaveTo: "opacity-0",
				$$slots: { default: [create_default_slot_3$1] },
				$$scope: { ctx }
			}
		});

	return {
		c() {
			create_component(transitionchild.$$.fragment);
		},
		l(nodes) {
			claim_component(transitionchild.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(transitionchild, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const transitionchild_changes = {};

			if (dirty & /*$$scope, dismissable*/ 32770) {
				transitionchild_changes.$$scope = { dirty, ctx };
			}

			transitionchild.$set(transitionchild_changes);
		},
		i(local) {
			if (current) return;
			transition_in(transitionchild.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(transitionchild.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(transitionchild, detaching);
		}
	};
}

// (85:8) <TransitionChild            enter="ease-out duration-300"            enterFrom="opacity-0"            enterTo="opacity-100"            leave="ease-in duration-200"            leaveFrom="opacity-100"            leaveTo="opacity-0"          >
function create_default_slot_3$1(ctx) {
	let dialogoverlay;
	let current;

	dialogoverlay = new DialogOverlay({
			props: {
				class: "fixed inset-0 bg-gray-500 bg-opacity-75 transition-opacity " + (/*dismissable*/ ctx[1] ? '' : 'pointer-events-none')
			}
		});

	return {
		c() {
			create_component(dialogoverlay.$$.fragment);
		},
		l(nodes) {
			claim_component(dialogoverlay.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(dialogoverlay, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const dialogoverlay_changes = {};
			if (dirty & /*dismissable*/ 2) dialogoverlay_changes.class = "fixed inset-0 bg-gray-500 bg-opacity-75 transition-opacity " + (/*dismissable*/ ctx[1] ? '' : 'pointer-events-none');
			dialogoverlay.$set(dialogoverlay_changes);
		},
		i(local) {
			if (current) return;
			transition_in(dialogoverlay.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(dialogoverlay.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(dialogoverlay, detaching);
		}
	};
}

// (137:35) 
function create_if_block_6(ctx) {
	let current;
	const header_slot_template = /*#slots*/ ctx[12].header;
	const header_slot = create_slot(header_slot_template, ctx, /*$$scope*/ ctx[15], get_header_slot_context$1);

	return {
		c() {
			if (header_slot) header_slot.c();
		},
		l(nodes) {
			if (header_slot) header_slot.l(nodes);
		},
		m(target, anchor) {
			if (header_slot) {
				header_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (header_slot) {
				if (header_slot.p && (!current || dirty & /*$$scope*/ 32768)) {
					update_slot_base(
						header_slot,
						header_slot_template,
						ctx,
						/*$$scope*/ ctx[15],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[15])
						: get_slot_changes(header_slot_template, /*$$scope*/ ctx[15], dirty, get_header_slot_changes$1),
						get_header_slot_context$1
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(header_slot, local);
			current = true;
		},
		o(local) {
			transition_out(header_slot, local);
			current = false;
		},
		d(detaching) {
			if (header_slot) header_slot.d(detaching);
		}
	};
}

// (116:10) {#if heading.length}
function create_if_block_3$1(ctx) {
	let div1;
	let div0;
	let h3;
	let t0;
	let t1;
	let t2;
	let current;
	let if_block0 = /*description*/ ctx[6] && create_if_block_5$1(ctx);
	let if_block1 = /*closeButton*/ ctx[3] == "inside" && create_if_block_4$1(ctx);

	return {
		c() {
			div1 = element("div");
			div0 = element("div");
			h3 = element("h3");
			t0 = text(/*heading*/ ctx[5]);
			t1 = space();
			if (if_block0) if_block0.c();
			t2 = space();
			if (if_block1) if_block1.c();
			this.h();
		},
		l(nodes) {
			div1 = claim_element(nodes, "DIV", { class: true });
			var div1_nodes = children(div1);
			div0 = claim_element(div1_nodes, "DIV", { class: true });
			var div0_nodes = children(div0);
			h3 = claim_element(div0_nodes, "H3", { class: true });
			var h3_nodes = children(h3);
			t0 = claim_text(h3_nodes, /*heading*/ ctx[5]);
			h3_nodes.forEach(detach);
			t1 = claim_space(div0_nodes);
			if (if_block0) if_block0.l(div0_nodes);
			div0_nodes.forEach(detach);
			t2 = claim_space(div1_nodes);
			if (if_block1) if_block1.l(div1_nodes);
			div1_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(h3, "class", "text-xl font-semibold text-gray-900");
			attr(div0, "class", "");
			attr(div1, "class", "flex items-center justify-between py-6 px-8");
		},
		m(target, anchor) {
			insert_hydration(target, div1, anchor);
			append_hydration(div1, div0);
			append_hydration(div0, h3);
			append_hydration(h3, t0);
			append_hydration(div0, t1);
			if (if_block0) if_block0.m(div0, null);
			append_hydration(div1, t2);
			if (if_block1) if_block1.m(div1, null);
			current = true;
		},
		p(ctx, dirty) {
			if (!current || dirty & /*heading*/ 32) set_data(t0, /*heading*/ ctx[5]);

			if (/*description*/ ctx[6]) {
				if (if_block0) {
					if_block0.p(ctx, dirty);
				} else {
					if_block0 = create_if_block_5$1(ctx);
					if_block0.c();
					if_block0.m(div0, null);
				}
			} else if (if_block0) {
				if_block0.d(1);
				if_block0 = null;
			}

			if (/*closeButton*/ ctx[3] == "inside") {
				if (if_block1) {
					if_block1.p(ctx, dirty);

					if (dirty & /*closeButton*/ 8) {
						transition_in(if_block1, 1);
					}
				} else {
					if_block1 = create_if_block_4$1(ctx);
					if_block1.c();
					transition_in(if_block1, 1);
					if_block1.m(div1, null);
				}
			} else if (if_block1) {
				group_outros();

				transition_out(if_block1, 1, 1, () => {
					if_block1 = null;
				});

				check_outros();
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block1);
			current = true;
		},
		o(local) {
			transition_out(if_block1);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div1);
			if (if_block0) if_block0.d();
			if (if_block1) if_block1.d();
		}
	};
}

// (122:16) {#if description}
function create_if_block_5$1(ctx) {
	let p;

	return {
		c() {
			p = element("p");
			this.h();
		},
		l(nodes) {
			p = claim_element(nodes, "P", { class: true });
			var p_nodes = children(p);
			p_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(p, "class", "mt-2 text-sm text-gray-500");
		},
		m(target, anchor) {
			insert_hydration(target, p, anchor);
			p.innerHTML = /*description*/ ctx[6];
		},
		p(ctx, dirty) {
			if (dirty & /*description*/ 64) p.innerHTML = /*description*/ ctx[6];		},
		d(detaching) {
			if (detaching) detach(p);
		}
	};
}

// (128:14) {#if closeButton == "inside"}
function create_if_block_4$1(ctx) {
	let button;
	let basesvg;
	let current;
	let mounted;
	let dispose;
	basesvg = new BaseSvg({ props: { iconName: "cross", size: 6 } });

	return {
		c() {
			button = element("button");
			create_component(basesvg.$$.fragment);
			this.h();
		},
		l(nodes) {
			button = claim_element(nodes, "BUTTON", { class: true });
			var button_nodes = children(button);
			claim_component(basesvg.$$.fragment, button_nodes);
			button_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(button, "class", "focus:outline-none flex h-6 w-6 items-center justify-center rounded text-gray-400 hover:bg-gray-100 focus:ring-2 focus:ring-blue-500");
		},
		m(target, anchor) {
			insert_hydration(target, button, anchor);
			mount_component(basesvg, button, null);
			current = true;

			if (!mounted) {
				dispose = listen(button, "click", /*click_handler*/ ctx[13]);
				mounted = true;
			}
		},
		p: noop,
		i(local) {
			if (current) return;
			transition_in(basesvg.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(basesvg.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(button);
			destroy_component(basesvg);
			mounted = false;
			dispose();
		}
	};
}

// (145:10) {:else}
function create_else_block$1(ctx) {
	let div;
	let current;
	const default_slot_template = /*#slots*/ ctx[12].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[15], null);

	return {
		c() {
			div = element("div");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			if (default_slot) default_slot.l(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", "relative flex-1 overflow-y-auto overscroll-y-contain px-8 pb-6");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);

			if (default_slot) {
				default_slot.m(div, null);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 32768)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[15],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[15])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[15], dirty, null),
						null
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			if (default_slot) default_slot.d(detaching);
		}
	};
}

// (141:10) {#if $$slots.content}
function create_if_block_2$2(ctx) {
	let div;
	let current;
	const content_slot_template = /*#slots*/ ctx[12].content;
	const content_slot = create_slot(content_slot_template, ctx, /*$$scope*/ ctx[15], get_content_slot_context);

	return {
		c() {
			div = element("div");
			if (content_slot) content_slot.c();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			if (content_slot) content_slot.l(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", "relative flex-1 overflow-y-auto overscroll-y-contain");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);

			if (content_slot) {
				content_slot.m(div, null);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (content_slot) {
				if (content_slot.p && (!current || dirty & /*$$scope*/ 32768)) {
					update_slot_base(
						content_slot,
						content_slot_template,
						ctx,
						/*$$scope*/ ctx[15],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[15])
						: get_slot_changes(content_slot_template, /*$$scope*/ ctx[15], dirty, get_content_slot_changes),
						get_content_slot_context
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(content_slot, local);
			current = true;
		},
		o(local) {
			transition_out(content_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			if (content_slot) content_slot.d(detaching);
		}
	};
}

// (153:10) {#if $$slots.footer}
function create_if_block_1$2(ctx) {
	let current;
	const footer_slot_template = /*#slots*/ ctx[12].footer;
	const footer_slot = create_slot(footer_slot_template, ctx, /*$$scope*/ ctx[15], get_footer_slot_context$1);

	return {
		c() {
			if (footer_slot) footer_slot.c();
		},
		l(nodes) {
			if (footer_slot) footer_slot.l(nodes);
		},
		m(target, anchor) {
			if (footer_slot) {
				footer_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (footer_slot) {
				if (footer_slot.p && (!current || dirty & /*$$scope*/ 32768)) {
					update_slot_base(
						footer_slot,
						footer_slot_template,
						ctx,
						/*$$scope*/ ctx[15],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[15])
						: get_slot_changes(footer_slot_template, /*$$scope*/ ctx[15], dirty, get_footer_slot_changes$1),
						get_footer_slot_context$1
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(footer_slot, local);
			current = true;
		},
		o(local) {
			transition_out(footer_slot, local);
			current = false;
		},
		d(detaching) {
			if (footer_slot) footer_slot.d(detaching);
		}
	};
}

// (158:8) {#if closeButton == "outside"}
function create_if_block$6(ctx) {
	let div;
	let button;
	let basesvg;
	let current;
	let mounted;
	let dispose;
	basesvg = new BaseSvg({ props: { iconName: "cross", size: 6 } });

	return {
		c() {
			div = element("div");
			button = element("button");
			create_component(basesvg.$$.fragment);
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			button = claim_element(div_nodes, "BUTTON", { class: true });
			var button_nodes = children(button);
			claim_component(basesvg.$$.fragment, button_nodes);
			button_nodes.forEach(detach);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(button, "class", "focus:outline-none flex h-10 w-10 items-center justify-center rounded-full bg-white bg-opacity-20 text-white hover:bg-opacity-30 focus:ring-2 focus:ring-blue-500");
			attr(div, "class", "flex justify-end");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			append_hydration(div, button);
			mount_component(basesvg, button, null);
			current = true;

			if (!mounted) {
				dispose = listen(button, "click", /*click_handler_1*/ ctx[14]);
				mounted = true;
			}
		},
		p: noop,
		i(local) {
			if (current) return;
			transition_in(basesvg.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(basesvg.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			destroy_component(basesvg);
			mounted = false;
			dispose();
		}
	};
}

// (101:6) <TransitionChild          class="relative flex min-h-0 flex-1 gap-1 xl:gap-2 max-w-screen-{width}"          enter="ease-out duration-300"          enterFrom="opacity-0 translate-y-4 sm:translate-y-0 sm:scale-95"          enterTo="opacity-100 translate-y-0 sm:scale-100"          leave="ease-in duration-200"          leaveFrom="opacity-100 translate-y-0 sm:scale-100"          leaveTo="opacity-0 translate-y-4 sm:translate-y-0 sm:scale-95"        >
function create_default_slot_2$1(ctx) {
	let div;
	let current_block_type_index;
	let if_block0;
	let t0;
	let current_block_type_index_1;
	let if_block1;
	let t1;
	let t2;
	let if_block3_anchor;
	let current;
	const if_block_creators = [create_if_block_3$1, create_if_block_6];
	const if_blocks = [];

	function select_block_type(ctx, dirty) {
		if (/*heading*/ ctx[5].length) return 0;
		if (/*$$slots*/ ctx[11].header) return 1;
		return -1;
	}

	if (~(current_block_type_index = select_block_type(ctx))) {
		if_block0 = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);
	}

	const if_block_creators_1 = [create_if_block_2$2, create_else_block$1];
	const if_blocks_1 = [];

	function select_block_type_1(ctx, dirty) {
		if (/*$$slots*/ ctx[11].content) return 0;
		return 1;
	}

	current_block_type_index_1 = select_block_type_1(ctx);
	if_block1 = if_blocks_1[current_block_type_index_1] = if_block_creators_1[current_block_type_index_1](ctx);
	let if_block2 = /*$$slots*/ ctx[11].footer && create_if_block_1$2(ctx);

	let div_levels = [
		{
			class: "flex min-h-0 flex-1 flex-col overflow-hidden rounded-lg"
		},
		{ style: "max-height:calc(100vh - 2rem)" },
		/*$$restProps*/ ctx[10]
	];

	let div_data = {};

	for (let i = 0; i < div_levels.length; i += 1) {
		div_data = assign(div_data, div_levels[i]);
	}

	let if_block3 = /*closeButton*/ ctx[3] == "outside" && create_if_block$6(ctx);

	return {
		c() {
			div = element("div");
			if (if_block0) if_block0.c();
			t0 = space();
			if_block1.c();
			t1 = space();
			if (if_block2) if_block2.c();
			t2 = space();
			if (if_block3) if_block3.c();
			if_block3_anchor = empty();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true, style: true });
			var div_nodes = children(div);
			if (if_block0) if_block0.l(div_nodes);
			t0 = claim_space(div_nodes);
			if_block1.l(div_nodes);
			t1 = claim_space(div_nodes);
			if (if_block2) if_block2.l(div_nodes);
			div_nodes.forEach(detach);
			t2 = claim_space(nodes);
			if (if_block3) if_block3.l(nodes);
			if_block3_anchor = empty();
			this.h();
		},
		h() {
			set_attributes(div, div_data);
			toggle_class(div, "bg-white", /*showBackground*/ ctx[4]);
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);

			if (~current_block_type_index) {
				if_blocks[current_block_type_index].m(div, null);
			}

			append_hydration(div, t0);
			if_blocks_1[current_block_type_index_1].m(div, null);
			append_hydration(div, t1);
			if (if_block2) if_block2.m(div, null);
			insert_hydration(target, t2, anchor);
			if (if_block3) if_block3.m(target, anchor);
			insert_hydration(target, if_block3_anchor, anchor);
			current = true;
		},
		p(ctx, dirty) {
			let previous_block_index = current_block_type_index;
			current_block_type_index = select_block_type(ctx);

			if (current_block_type_index === previous_block_index) {
				if (~current_block_type_index) {
					if_blocks[current_block_type_index].p(ctx, dirty);
				}
			} else {
				if (if_block0) {
					group_outros();

					transition_out(if_blocks[previous_block_index], 1, 1, () => {
						if_blocks[previous_block_index] = null;
					});

					check_outros();
				}

				if (~current_block_type_index) {
					if_block0 = if_blocks[current_block_type_index];

					if (!if_block0) {
						if_block0 = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);
						if_block0.c();
					} else {
						if_block0.p(ctx, dirty);
					}

					transition_in(if_block0, 1);
					if_block0.m(div, t0);
				} else {
					if_block0 = null;
				}
			}

			let previous_block_index_1 = current_block_type_index_1;
			current_block_type_index_1 = select_block_type_1(ctx);

			if (current_block_type_index_1 === previous_block_index_1) {
				if_blocks_1[current_block_type_index_1].p(ctx, dirty);
			} else {
				group_outros();

				transition_out(if_blocks_1[previous_block_index_1], 1, 1, () => {
					if_blocks_1[previous_block_index_1] = null;
				});

				check_outros();
				if_block1 = if_blocks_1[current_block_type_index_1];

				if (!if_block1) {
					if_block1 = if_blocks_1[current_block_type_index_1] = if_block_creators_1[current_block_type_index_1](ctx);
					if_block1.c();
				} else {
					if_block1.p(ctx, dirty);
				}

				transition_in(if_block1, 1);
				if_block1.m(div, t1);
			}

			if (/*$$slots*/ ctx[11].footer) {
				if (if_block2) {
					if_block2.p(ctx, dirty);

					if (dirty & /*$$slots*/ 2048) {
						transition_in(if_block2, 1);
					}
				} else {
					if_block2 = create_if_block_1$2(ctx);
					if_block2.c();
					transition_in(if_block2, 1);
					if_block2.m(div, null);
				}
			} else if (if_block2) {
				group_outros();

				transition_out(if_block2, 1, 1, () => {
					if_block2 = null;
				});

				check_outros();
			}

			set_attributes(div, div_data = get_spread_update(div_levels, [
				{
					class: "flex min-h-0 flex-1 flex-col overflow-hidden rounded-lg"
				},
				{ style: "max-height:calc(100vh - 2rem)" },
				dirty & /*$$restProps*/ 1024 && /*$$restProps*/ ctx[10]
			]));

			toggle_class(div, "bg-white", /*showBackground*/ ctx[4]);

			if (/*closeButton*/ ctx[3] == "outside") {
				if (if_block3) {
					if_block3.p(ctx, dirty);

					if (dirty & /*closeButton*/ 8) {
						transition_in(if_block3, 1);
					}
				} else {
					if_block3 = create_if_block$6(ctx);
					if_block3.c();
					transition_in(if_block3, 1);
					if_block3.m(if_block3_anchor.parentNode, if_block3_anchor);
				}
			} else if (if_block3) {
				group_outros();

				transition_out(if_block3, 1, 1, () => {
					if_block3 = null;
				});

				check_outros();
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block0);
			transition_in(if_block1);
			transition_in(if_block2);
			transition_in(if_block3);
			current = true;
		},
		o(local) {
			transition_out(if_block0);
			transition_out(if_block1);
			transition_out(if_block2);
			transition_out(if_block3);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);

			if (~current_block_type_index) {
				if_blocks[current_block_type_index].d();
			}

			if_blocks_1[current_block_type_index_1].d();
			if (if_block2) if_block2.d();
			if (detaching) detach(t2);
			if (if_block3) if_block3.d(detaching);
			if (detaching) detach(if_block3_anchor);
		}
	};
}

// (76:2) <Dialog      on:close={handleClose}      as="div"      class="z-60 fixed inset-0 overflow-y-auto"    >
function create_default_slot_1$1(ctx) {
	let div;
	let t;
	let transitionchild;
	let current;
	let if_block = /*depth*/ ctx[7] == 1 && create_if_block_7(ctx);

	transitionchild = new TransitionChildWrapper({
			props: {
				class: "relative flex min-h-0 flex-1 gap-1 xl:gap-2 max-w-screen-" + /*width*/ ctx[2],
				enter: "ease-out duration-300",
				enterFrom: "opacity-0 translate-y-4 sm:translate-y-0 sm:scale-95",
				enterTo: "opacity-100 translate-y-0 sm:scale-100",
				leave: "ease-in duration-200",
				leaveFrom: "opacity-100 translate-y-0 sm:scale-100",
				leaveTo: "opacity-0 translate-y-4 sm:translate-y-0 sm:scale-95",
				$$slots: { default: [create_default_slot_2$1] },
				$$scope: { ctx }
			}
		});

	return {
		c() {
			div = element("div");
			if (if_block) if_block.c();
			t = space();
			create_component(transitionchild.$$.fragment);
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			if (if_block) if_block.l(div_nodes);
			t = claim_space(div_nodes);
			claim_component(transitionchild.$$.fragment, div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", "flex h-screen min-h-screen items-end justify-center p-4 sm:items-center");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			if (if_block) if_block.m(div, null);
			append_hydration(div, t);
			mount_component(transitionchild, div, null);
			current = true;
		},
		p(ctx, dirty) {
			if (/*depth*/ ctx[7] == 1) {
				if (if_block) {
					if_block.p(ctx, dirty);

					if (dirty & /*depth*/ 128) {
						transition_in(if_block, 1);
					}
				} else {
					if_block = create_if_block_7(ctx);
					if_block.c();
					transition_in(if_block, 1);
					if_block.m(div, t);
				}
			} else if (if_block) {
				group_outros();

				transition_out(if_block, 1, 1, () => {
					if_block = null;
				});

				check_outros();
			}

			const transitionchild_changes = {};
			if (dirty & /*width*/ 4) transitionchild_changes.class = "relative flex min-h-0 flex-1 gap-1 xl:gap-2 max-w-screen-" + /*width*/ ctx[2];

			if (dirty & /*$$scope, open, closeButton, $$restProps, showBackground, $$slots, description, heading*/ 35961) {
				transitionchild_changes.$$scope = { dirty, ctx };
			}

			transitionchild.$set(transitionchild_changes);
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			transition_in(transitionchild.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			transition_out(transitionchild.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			if (if_block) if_block.d();
			destroy_component(transitionchild);
		}
	};
}

// (75:0) <Transition appear show={open} on:afterLeave={handleTransitionEnd}>
function create_default_slot$2(ctx) {
	let dialog;
	let current;

	dialog = new Dialog({
			props: {
				as: "div",
				class: "z-60 fixed inset-0 overflow-y-auto",
				$$slots: { default: [create_default_slot_1$1] },
				$$scope: { ctx }
			}
		});

	dialog.$on("close", /*handleClose*/ ctx[8]);

	return {
		c() {
			create_component(dialog.$$.fragment);
		},
		l(nodes) {
			claim_component(dialog.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(dialog, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const dialog_changes = {};

			if (dirty & /*$$scope, width, open, closeButton, $$restProps, showBackground, $$slots, description, heading, dismissable, depth*/ 36095) {
				dialog_changes.$$scope = { dirty, ctx };
			}

			dialog.$set(dialog_changes);
		},
		i(local) {
			if (current) return;
			transition_in(dialog.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(dialog.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(dialog, detaching);
		}
	};
}

function create_fragment$a(ctx) {
	let t;
	let transition;
	let current;
	let if_block = false ;

	transition = new TransitionRoot({
			props: {
				appear: true,
				show: /*open*/ ctx[0],
				$$slots: { default: [create_default_slot$2] },
				$$scope: { ctx }
			}
		});

	transition.$on("afterLeave", /*handleTransitionEnd*/ ctx[9]);

	return {
		c() {
			t = space();
			create_component(transition.$$.fragment);
		},
		l(nodes) {
			t = claim_space(nodes);
			claim_component(transition.$$.fragment, nodes);
		},
		m(target, anchor) {
			insert_hydration(target, t, anchor);
			mount_component(transition, target, anchor);
			current = true;
		},
		p(ctx, [dirty]) {
			const transition_changes = {};
			if (dirty & /*open*/ 1) transition_changes.show = /*open*/ ctx[0];

			if (dirty & /*$$scope, width, open, closeButton, $$restProps, showBackground, $$slots, description, heading, dismissable, depth*/ 36095) {
				transition_changes.$$scope = { dirty, ctx };
			}

			transition.$set(transition_changes);
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			transition_in(transition.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			transition_out(transition.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(t);
			destroy_component(transition, detaching);
		}
	};
}

function instance$a($$self, $$props, $$invalidate) {
	const omit_props_names = [
		"open","dismissable","width","closeButton","showBackground","heading","description","depth"
	];

	let $$restProps = compute_rest_props($$props, omit_props_names);
	let { $$slots: slots = {}, $$scope } = $$props;
	const $$slots = compute_slots(slots);
	const dispatch = createEventDispatcher();
	let { open = false } = $$props;
	let { dismissable = true } = $$props;
	let { width = "md" } = $$props;
	let { closeButton = "outside" } = $$props;
	let { showBackground = true } = $$props;
	let { heading = "" } = $$props;
	let { description = "" } = $$props;
	let { depth = 1 } = $$props;

	const handleClose = () => {
		$$invalidate(0, open = false);
	};

	const handleDispatch = openState => {
		if (!openState) dispatch("close");
	};

	function handleTransitionEnd() {
		dispatch("closed");
	}

	const click_handler = () => $$invalidate(0, open = false);
	const click_handler_1 = () => $$invalidate(0, open = false);

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(10, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('open' in $$new_props) $$invalidate(0, open = $$new_props.open);
		if ('dismissable' in $$new_props) $$invalidate(1, dismissable = $$new_props.dismissable);
		if ('width' in $$new_props) $$invalidate(2, width = $$new_props.width);
		if ('closeButton' in $$new_props) $$invalidate(3, closeButton = $$new_props.closeButton);
		if ('showBackground' in $$new_props) $$invalidate(4, showBackground = $$new_props.showBackground);
		if ('heading' in $$new_props) $$invalidate(5, heading = $$new_props.heading);
		if ('description' in $$new_props) $$invalidate(6, description = $$new_props.description);
		if ('depth' in $$new_props) $$invalidate(7, depth = $$new_props.depth);
		if ('$$scope' in $$new_props) $$invalidate(15, $$scope = $$new_props.$$scope);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*open*/ 1) {
			handleDispatch(open);
		}
	};

	return [
		open,
		dismissable,
		width,
		closeButton,
		showBackground,
		heading,
		description,
		depth,
		handleClose,
		handleTransitionEnd,
		$$restProps,
		$$slots,
		slots,
		click_handler,
		click_handler_1,
		$$scope
	];
}

class Modal extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$a, create_fragment$a, safe_not_equal, {
			open: 0,
			dismissable: 1,
			width: 2,
			closeButton: 3,
			showBackground: 4,
			heading: 5,
			description: 6,
			depth: 7
		});
	}
}

/* src\Sidepanel\Sidepanel.svelte generated by Svelte v3.48.0 */

const get_footer_slot_changes = dirty => ({});
const get_footer_slot_context = ctx => ({});
const get_header_slot_changes = dirty => ({});
const get_header_slot_context = ctx => ({});

// (49:4) {#if depth == 1}
function create_if_block_2$1(ctx) {
	let transitionchild;
	let current;

	transitionchild = new TransitionChildWrapper({
			props: {
				enterFrom: "opacity-0",
				enterTo: "opacity-100",
				leave: "ease-in-out duration-500",
				leaveFrom: "opacity-100",
				leaveTo: "opacity-0",
				entered: "opacity-100",
				$$slots: { default: [create_default_slot_3] },
				$$scope: { ctx }
			}
		});

	return {
		c() {
			create_component(transitionchild.$$.fragment);
		},
		l(nodes) {
			claim_component(transitionchild.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(transitionchild, target, anchor);
			current = true;
		},
		i(local) {
			if (current) return;
			transition_in(transitionchild.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(transitionchild.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(transitionchild, detaching);
		}
	};
}

// (50:6) <TransitionChild          enterFrom="opacity-0"          enterTo="opacity-100"          leave="ease-in-out duration-500"          leaveFrom="opacity-100"          leaveTo="opacity-0"          entered="opacity-100"        >
function create_default_slot_3(ctx) {
	let dialogoverlay;
	let current;

	dialogoverlay = new DialogOverlay({
			props: {
				class: "fixed inset-0 bg-gray-500 bg-opacity-75"
			}
		});

	return {
		c() {
			create_component(dialogoverlay.$$.fragment);
		},
		l(nodes) {
			claim_component(dialogoverlay.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(dialogoverlay, target, anchor);
			current = true;
		},
		p: noop,
		i(local) {
			if (current) return;
			transition_in(dialogoverlay.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(dialogoverlay.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(dialogoverlay, detaching);
		}
	};
}

// (83:12) {#if $$slots.header}
function create_if_block_1$1(ctx) {
	let current;
	const header_slot_template = /*#slots*/ ctx[6].header;
	const header_slot = create_slot(header_slot_template, ctx, /*$$scope*/ ctx[7], get_header_slot_context);

	return {
		c() {
			if (header_slot) header_slot.c();
		},
		l(nodes) {
			if (header_slot) header_slot.l(nodes);
		},
		m(target, anchor) {
			if (header_slot) {
				header_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (header_slot) {
				if (header_slot.p && (!current || dirty & /*$$scope*/ 128)) {
					update_slot_base(
						header_slot,
						header_slot_template,
						ctx,
						/*$$scope*/ ctx[7],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[7])
						: get_slot_changes(header_slot_template, /*$$scope*/ ctx[7], dirty, get_header_slot_changes),
						get_header_slot_context
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(header_slot, local);
			current = true;
		},
		o(local) {
			transition_out(header_slot, local);
			current = false;
		},
		d(detaching) {
			if (header_slot) header_slot.d(detaching);
		}
	};
}

// (91:10) {#if $$slots.footer}
function create_if_block$5(ctx) {
	let div;
	let current;
	const footer_slot_template = /*#slots*/ ctx[6].footer;
	const footer_slot = create_slot(footer_slot_template, ctx, /*$$scope*/ ctx[7], get_footer_slot_context);

	return {
		c() {
			div = element("div");
			if (footer_slot) footer_slot.c();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			if (footer_slot) footer_slot.l(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", "flex flex-shrink-0 justify-end px-4 py-4 border-t");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);

			if (footer_slot) {
				footer_slot.m(div, null);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (footer_slot) {
				if (footer_slot.p && (!current || dirty & /*$$scope*/ 128)) {
					update_slot_base(
						footer_slot,
						footer_slot_template,
						ctx,
						/*$$scope*/ ctx[7],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[7])
						: get_slot_changes(footer_slot_template, /*$$scope*/ ctx[7], dirty, get_footer_slot_changes),
						get_footer_slot_context
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(footer_slot, local);
			current = true;
		},
		o(local) {
			transition_out(footer_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			if (footer_slot) footer_slot.d(detaching);
		}
	};
}

// (62:4) <TransitionChild        class="pointer-events-none fixed inset-y-0 right-0 flex max-w-full"        enter="transform transition ease-in-out duration-500 sm:duration-700"        enterFrom="translate-x-full"        enterTo="translate-x-0"        leave="transform transition ease-in-out duration-500 sm:duration-700"        leaveFrom="translate-x-0"        leaveTo="translate-x-full"      >
function create_default_slot_2(ctx) {
	let div3;
	let div2;
	let div1;
	let t0;
	let div0;
	let t1;
	let div3_class_value;
	let current;
	let if_block0 = /*$$slots*/ ctx[5].header && create_if_block_1$1(ctx);
	const default_slot_template = /*#slots*/ ctx[6].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[7], null);
	let if_block1 = /*$$slots*/ ctx[5].footer && create_if_block$5(ctx);

	return {
		c() {
			div3 = element("div");
			div2 = element("div");
			div1 = element("div");
			if (if_block0) if_block0.c();
			t0 = space();
			div0 = element("div");
			if (default_slot) default_slot.c();
			t1 = space();
			if (if_block1) if_block1.c();
			this.h();
		},
		l(nodes) {
			div3 = claim_element(nodes, "DIV", { class: true });
			var div3_nodes = children(div3);
			div2 = claim_element(div3_nodes, "DIV", { class: true });
			var div2_nodes = children(div2);
			div1 = claim_element(div2_nodes, "DIV", { class: true });
			var div1_nodes = children(div1);
			if (if_block0) if_block0.l(div1_nodes);
			t0 = claim_space(div1_nodes);
			div0 = claim_element(div1_nodes, "DIV", { class: true });
			var div0_nodes = children(div0);
			if (default_slot) default_slot.l(div0_nodes);
			div0_nodes.forEach(detach);
			div1_nodes.forEach(detach);
			t1 = claim_space(div2_nodes);
			if (if_block1) if_block1.l(div2_nodes);
			div2_nodes.forEach(detach);
			div3_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div0, "class", "relative flex-1 p-4 sm:p-6");
			attr(div1, "class", "flex min-h-0 flex-1 flex-col overflow-y-scroll");
			attr(div2, "class", "flex h-full flex-col");
			toggle_class(div2, "shadow-2xl", /*depth*/ ctx[1] > 1);
			toggle_class(div2, "bg-gray-50", /*depth*/ ctx[1] > 1);
			toggle_class(div2, "shadow-xl", /*depth*/ ctx[1] == 1);
			toggle_class(div2, "bg-white", /*depth*/ ctx[1] == 1);
			attr(div3, "class", div3_class_value = "pointer-events-auto w-screen max-w-screen-" + /*width*/ ctx[2]);
			toggle_class(div3, "pl-16", /*depth*/ ctx[1] > 1);
		},
		m(target, anchor) {
			insert_hydration(target, div3, anchor);
			append_hydration(div3, div2);
			append_hydration(div2, div1);
			if (if_block0) if_block0.m(div1, null);
			append_hydration(div1, t0);
			append_hydration(div1, div0);

			if (default_slot) {
				default_slot.m(div0, null);
			}

			append_hydration(div2, t1);
			if (if_block1) if_block1.m(div2, null);
			current = true;
		},
		p(ctx, dirty) {
			if (/*$$slots*/ ctx[5].header) {
				if (if_block0) {
					if_block0.p(ctx, dirty);

					if (dirty & /*$$slots*/ 32) {
						transition_in(if_block0, 1);
					}
				} else {
					if_block0 = create_if_block_1$1(ctx);
					if_block0.c();
					transition_in(if_block0, 1);
					if_block0.m(div1, t0);
				}
			} else if (if_block0) {
				group_outros();

				transition_out(if_block0, 1, 1, () => {
					if_block0 = null;
				});

				check_outros();
			}

			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 128)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[7],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[7])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[7], dirty, null),
						null
					);
				}
			}

			if (/*$$slots*/ ctx[5].footer) {
				if (if_block1) {
					if_block1.p(ctx, dirty);

					if (dirty & /*$$slots*/ 32) {
						transition_in(if_block1, 1);
					}
				} else {
					if_block1 = create_if_block$5(ctx);
					if_block1.c();
					transition_in(if_block1, 1);
					if_block1.m(div2, null);
				}
			} else if (if_block1) {
				group_outros();

				transition_out(if_block1, 1, 1, () => {
					if_block1 = null;
				});

				check_outros();
			}

			if (dirty & /*depth*/ 2) {
				toggle_class(div2, "shadow-2xl", /*depth*/ ctx[1] > 1);
			}

			if (dirty & /*depth*/ 2) {
				toggle_class(div2, "bg-gray-50", /*depth*/ ctx[1] > 1);
			}

			if (dirty & /*depth*/ 2) {
				toggle_class(div2, "shadow-xl", /*depth*/ ctx[1] == 1);
			}

			if (dirty & /*depth*/ 2) {
				toggle_class(div2, "bg-white", /*depth*/ ctx[1] == 1);
			}

			if (!current || dirty & /*width*/ 4 && div3_class_value !== (div3_class_value = "pointer-events-auto w-screen max-w-screen-" + /*width*/ ctx[2])) {
				attr(div3, "class", div3_class_value);
			}

			if (dirty & /*width, depth*/ 6) {
				toggle_class(div3, "pl-16", /*depth*/ ctx[1] > 1);
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block0);
			transition_in(default_slot, local);
			transition_in(if_block1);
			current = true;
		},
		o(local) {
			transition_out(if_block0);
			transition_out(default_slot, local);
			transition_out(if_block1);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div3);
			if (if_block0) if_block0.d();
			if (default_slot) default_slot.d(detaching);
			if (if_block1) if_block1.d();
		}
	};
}

// (41:2) <Dialog      on:close={handleClose}      as="div"      class="relative z-10"      aria-labelledby="slide-over-title"      role="dialog"      aria-modal="true"    >
function create_default_slot_1(ctx) {
	let t;
	let transitionchild;
	let current;
	let if_block = /*depth*/ ctx[1] == 1 && create_if_block_2$1(ctx);

	transitionchild = new TransitionChildWrapper({
			props: {
				class: "pointer-events-none fixed inset-y-0 right-0 flex max-w-full",
				enter: "transform transition ease-in-out duration-500 sm:duration-700",
				enterFrom: "translate-x-full",
				enterTo: "translate-x-0",
				leave: "transform transition ease-in-out duration-500 sm:duration-700",
				leaveFrom: "translate-x-0",
				leaveTo: "translate-x-full",
				$$slots: { default: [create_default_slot_2] },
				$$scope: { ctx }
			}
		});

	return {
		c() {
			if (if_block) if_block.c();
			t = space();
			create_component(transitionchild.$$.fragment);
		},
		l(nodes) {
			if (if_block) if_block.l(nodes);
			t = claim_space(nodes);
			claim_component(transitionchild.$$.fragment, nodes);
		},
		m(target, anchor) {
			if (if_block) if_block.m(target, anchor);
			insert_hydration(target, t, anchor);
			mount_component(transitionchild, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			if (/*depth*/ ctx[1] == 1) {
				if (if_block) {
					if (dirty & /*depth*/ 2) {
						transition_in(if_block, 1);
					}
				} else {
					if_block = create_if_block_2$1(ctx);
					if_block.c();
					transition_in(if_block, 1);
					if_block.m(t.parentNode, t);
				}
			} else if (if_block) {
				group_outros();

				transition_out(if_block, 1, 1, () => {
					if_block = null;
				});

				check_outros();
			}

			const transitionchild_changes = {};

			if (dirty & /*$$scope, width, depth, $$slots*/ 166) {
				transitionchild_changes.$$scope = { dirty, ctx };
			}

			transitionchild.$set(transitionchild_changes);
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			transition_in(transitionchild.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			transition_out(transitionchild.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			if (if_block) if_block.d(detaching);
			if (detaching) detach(t);
			destroy_component(transitionchild, detaching);
		}
	};
}

// (40:0) <Transition appear show={open} on:afterLeave={handleTransitionEnd}>
function create_default_slot$1(ctx) {
	let dialog;
	let current;

	dialog = new Dialog({
			props: {
				as: "div",
				class: "relative z-10",
				"aria-labelledby": "slide-over-title",
				role: "dialog",
				"aria-modal": "true",
				$$slots: { default: [create_default_slot_1] },
				$$scope: { ctx }
			}
		});

	dialog.$on("close", /*handleClose*/ ctx[3]);

	return {
		c() {
			create_component(dialog.$$.fragment);
		},
		l(nodes) {
			claim_component(dialog.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(dialog, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const dialog_changes = {};

			if (dirty & /*$$scope, width, depth, $$slots*/ 166) {
				dialog_changes.$$scope = { dirty, ctx };
			}

			dialog.$set(dialog_changes);
		},
		i(local) {
			if (current) return;
			transition_in(dialog.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(dialog.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(dialog, detaching);
		}
	};
}

function create_fragment$9(ctx) {
	let transition;
	let current;

	transition = new TransitionRoot({
			props: {
				appear: true,
				show: /*open*/ ctx[0],
				$$slots: { default: [create_default_slot$1] },
				$$scope: { ctx }
			}
		});

	transition.$on("afterLeave", /*handleTransitionEnd*/ ctx[4]);

	return {
		c() {
			create_component(transition.$$.fragment);
		},
		l(nodes) {
			claim_component(transition.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(transition, target, anchor);
			current = true;
		},
		p(ctx, [dirty]) {
			const transition_changes = {};
			if (dirty & /*open*/ 1) transition_changes.show = /*open*/ ctx[0];

			if (dirty & /*$$scope, width, depth, $$slots*/ 166) {
				transition_changes.$$scope = { dirty, ctx };
			}

			transition.$set(transition_changes);
		},
		i(local) {
			if (current) return;
			transition_in(transition.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(transition.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(transition, detaching);
		}
	};
}

function instance$9($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	const $$slots = compute_slots(slots);
	const dispatch = createEventDispatcher();
	let { open = false } = $$props;
	let { depth = 1 } = $$props;
	let { width = "sm" } = $$props;

	function handleClose() {
		$$invalidate(0, open = false);
		dispatch("closing");
	}

	function handleTransitionEnd() {
		dispatch("closed");
	}

	$$self.$$set = $$props => {
		if ('open' in $$props) $$invalidate(0, open = $$props.open);
		if ('depth' in $$props) $$invalidate(1, depth = $$props.depth);
		if ('width' in $$props) $$invalidate(2, width = $$props.width);
		if ('$$scope' in $$props) $$invalidate(7, $$scope = $$props.$$scope);
	};

	return [open, depth, width, handleClose, handleTransitionEnd, $$slots, slots, $$scope];
}

class Sidepanel extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$9, create_fragment$9, safe_not_equal, { open: 0, depth: 1, width: 2 });
	}
}

/* src\Tabs\Tabs.svelte generated by Svelte v3.48.0 */

const get_default_slot_changes$2 = dirty => ({
	selectedTabIndex: dirty & /*selectedTabIndex*/ 16,
	tab: dirty & /*tabs, selectedTabIndex*/ 17
});

const get_default_slot_context$2 = ctx => ({
	class: "w-full",
	selectedTabIndex: /*selectedTabIndex*/ ctx[4],
	tab: /*tabs*/ ctx[0][/*selectedTabIndex*/ ctx[4]]
});

function get_each_context$1(ctx, list, i) {
	const child_ctx = ctx.slice();
	child_ctx[15] = list[i];
	child_ctx[17] = i;
	return child_ctx;
}

// (111:12) {#if tab.iconName}
function create_if_block$4(ctx) {
	let basesvg;
	let current;

	basesvg = new BaseSvg({
			props: {
				iconName: /*tab*/ ctx[15].iconName,
				size: 4,
				colour: /*iconColour*/ ctx[1]
			}
		});

	return {
		c() {
			create_component(basesvg.$$.fragment);
		},
		l(nodes) {
			claim_component(basesvg.$$.fragment, nodes);
		},
		m(target, anchor) {
			mount_component(basesvg, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const basesvg_changes = {};
			if (dirty & /*tabs*/ 1) basesvg_changes.iconName = /*tab*/ ctx[15].iconName;
			if (dirty & /*iconColour*/ 2) basesvg_changes.colour = /*iconColour*/ ctx[1];
			basesvg.$set(basesvg_changes);
		},
		i(local) {
			if (current) return;
			transition_in(basesvg.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(basesvg.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(basesvg, detaching);
		}
	};
}

// (94:8) {#each tabs as tab, i}
function create_each_block$1(ctx) {
	let button;
	let t0_value = /*tab*/ ctx[15].tabName + "";
	let t0;
	let t1;
	let t2;
	let button_id_value;
	let button_aria_controls_value;
	let button_aria_selected_value;
	let current;
	let mounted;
	let dispose;
	let if_block = /*tab*/ ctx[15].iconName && create_if_block$4(ctx);

	function click_handler() {
		return /*click_handler*/ ctx[11](/*i*/ ctx[17]);
	}

	return {
		c() {
			button = element("button");
			t0 = text(t0_value);
			t1 = space();
			if (if_block) if_block.c();
			t2 = space();
			this.h();
		},
		l(nodes) {
			button = claim_element(nodes, "BUTTON", {
				id: true,
				"aria-controls": true,
				"aria-selected": true,
				role: true,
				tabindex: true,
				class: true
			});

			var button_nodes = children(button);
			t0 = claim_text(button_nodes, t0_value);
			t1 = claim_space(button_nodes);
			if (if_block) if_block.l(button_nodes);
			t2 = claim_space(button_nodes);
			button_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(button, "id", button_id_value = /*tab*/ ctx[15].tabName);
			attr(button, "aria-controls", button_aria_controls_value = `${/*tab*/ ctx[15].tabName}-tabs`);
			attr(button, "aria-selected", button_aria_selected_value = /*i*/ ctx[17] == /*selectedTabIndex*/ ctx[4]);
			attr(button, "role", "tab");
			attr(button, "tabindex", "-1");
			attr(button, "class", "border border-transparent cursor-pointer flex items-center justify-center text-center text-gray-500 hover:text-gray-700 whitespace-nowrap py-4 px-1 font-medium text-sm focus:outline-none focus:ring-offset-blue-200 focus:ring-1 svelte-vnou5f");
			toggle_class(button, "active", /*i*/ ctx[17] == /*selectedTabIndex*/ ctx[4]);
			toggle_class(button, "border-b-2", /*i*/ ctx[17] == /*selectedTabIndex*/ ctx[4]);
			toggle_class(button, "flex-1", /*full*/ ctx[2]);
			toggle_class(button, "px-2", /*full*/ ctx[2]);
		},
		m(target, anchor) {
			insert_hydration(target, button, anchor);
			append_hydration(button, t0);
			append_hydration(button, t1);
			if (if_block) if_block.m(button, null);
			append_hydration(button, t2);
			current = true;

			if (!mounted) {
				dispose = listen(button, "click", click_handler);
				mounted = true;
			}
		},
		p(new_ctx, dirty) {
			ctx = new_ctx;
			if ((!current || dirty & /*tabs*/ 1) && t0_value !== (t0_value = /*tab*/ ctx[15].tabName + "")) set_data(t0, t0_value);

			if (/*tab*/ ctx[15].iconName) {
				if (if_block) {
					if_block.p(ctx, dirty);

					if (dirty & /*tabs*/ 1) {
						transition_in(if_block, 1);
					}
				} else {
					if_block = create_if_block$4(ctx);
					if_block.c();
					transition_in(if_block, 1);
					if_block.m(button, t2);
				}
			} else if (if_block) {
				group_outros();

				transition_out(if_block, 1, 1, () => {
					if_block = null;
				});

				check_outros();
			}

			if (!current || dirty & /*tabs*/ 1 && button_id_value !== (button_id_value = /*tab*/ ctx[15].tabName)) {
				attr(button, "id", button_id_value);
			}

			if (!current || dirty & /*tabs*/ 1 && button_aria_controls_value !== (button_aria_controls_value = `${/*tab*/ ctx[15].tabName}-tabs`)) {
				attr(button, "aria-controls", button_aria_controls_value);
			}

			if (!current || dirty & /*selectedTabIndex*/ 16 && button_aria_selected_value !== (button_aria_selected_value = /*i*/ ctx[17] == /*selectedTabIndex*/ ctx[4])) {
				attr(button, "aria-selected", button_aria_selected_value);
			}

			if (dirty & /*selectedTabIndex*/ 16) {
				toggle_class(button, "active", /*i*/ ctx[17] == /*selectedTabIndex*/ ctx[4]);
			}

			if (dirty & /*selectedTabIndex*/ 16) {
				toggle_class(button, "border-b-2", /*i*/ ctx[17] == /*selectedTabIndex*/ ctx[4]);
			}

			if (dirty & /*full*/ 4) {
				toggle_class(button, "flex-1", /*full*/ ctx[2]);
			}

			if (dirty & /*full*/ 4) {
				toggle_class(button, "px-2", /*full*/ ctx[2]);
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(button);
			if (if_block) if_block.d();
			mounted = false;
			dispose();
		}
	};
}

function create_fragment$8(ctx) {
	let div2;
	let div1;
	let div0;
	let nav;
	let t;
	let current;
	let mounted;
	let dispose;
	let each_value = /*tabs*/ ctx[0];
	let each_blocks = [];

	for (let i = 0; i < each_value.length; i += 1) {
		each_blocks[i] = create_each_block$1(get_each_context$1(ctx, each_value, i));
	}

	const out = i => transition_out(each_blocks[i], 1, 1, () => {
		each_blocks[i] = null;
	});

	const default_slot_template = /*#slots*/ ctx[10].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[9], get_default_slot_context$2);

	return {
		c() {
			div2 = element("div");
			div1 = element("div");
			div0 = element("div");
			nav = element("nav");

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].c();
			}

			t = space();
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			div2 = claim_element(nodes, "DIV", { class: true });
			var div2_nodes = children(div2);
			div1 = claim_element(div2_nodes, "DIV", {});
			var div1_nodes = children(div1);
			div0 = claim_element(div1_nodes, "DIV", { class: true });
			var div0_nodes = children(div0);

			nav = claim_element(div0_nodes, "NAV", {
				class: true,
				id: true,
				"aria-label": true,
				role: true,
				tabindex: true
			});

			var nav_nodes = children(nav);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].l(nav_nodes);
			}

			nav_nodes.forEach(detach);
			div0_nodes.forEach(detach);
			div1_nodes.forEach(detach);
			t = claim_space(div2_nodes);
			if (default_slot) default_slot.l(div2_nodes);
			div2_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(nav, "class", "flex w-100 space-x-8 focus:outline-none");
			attr(nav, "id", "svelte_tabs");
			attr(nav, "aria-label", "Tabs");
			attr(nav, "role", "tablist");
			attr(nav, "tabindex", "0");
			attr(div0, "class", "border-b border-gray-200");
			attr(div2, "class", "w-full");
		},
		m(target, anchor) {
			insert_hydration(target, div2, anchor);
			append_hydration(div2, div1);
			append_hydration(div1, div0);
			append_hydration(div0, nav);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].m(nav, null);
			}

			/*nav_binding*/ ctx[12](nav);
			append_hydration(div2, t);

			if (default_slot) {
				default_slot.m(div2, null);
			}

			current = true;

			if (!mounted) {
				dispose = [
					listen(nav, "focus", /*focus_handler*/ ctx[13]),
					listen(nav, "keyup", /*handleKeys*/ ctx[5])
				];

				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (dirty & /*tabs, selectedTabIndex, full, iconColour*/ 23) {
				each_value = /*tabs*/ ctx[0];
				let i;

				for (i = 0; i < each_value.length; i += 1) {
					const child_ctx = get_each_context$1(ctx, each_value, i);

					if (each_blocks[i]) {
						each_blocks[i].p(child_ctx, dirty);
						transition_in(each_blocks[i], 1);
					} else {
						each_blocks[i] = create_each_block$1(child_ctx);
						each_blocks[i].c();
						transition_in(each_blocks[i], 1);
						each_blocks[i].m(nav, null);
					}
				}

				group_outros();

				for (i = each_value.length; i < each_blocks.length; i += 1) {
					out(i);
				}

				check_outros();
			}

			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope, selectedTabIndex, tabs*/ 529)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[9],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[9])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[9], dirty, get_default_slot_changes$2),
						get_default_slot_context$2
					);
				}
			}
		},
		i(local) {
			if (current) return;

			for (let i = 0; i < each_value.length; i += 1) {
				transition_in(each_blocks[i]);
			}

			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			each_blocks = each_blocks.filter(Boolean);

			for (let i = 0; i < each_blocks.length; i += 1) {
				transition_out(each_blocks[i]);
			}

			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div2);
			destroy_each(each_blocks, detaching);
			/*nav_binding*/ ctx[12](null);
			if (default_slot) default_slot.d(detaching);
			mounted = false;
			run_all(dispose);
		}
	};
}

function instance$8($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	let { tabs = [] } = $$props;
	let { iconColour } = $$props;
	const iconSize = 4;
	let { startIndex = 0 } = $$props;
	let { full = true } = $$props;
	let navbar;
	let selectedTabIndex = startIndex;

	const handleKeys = e => {
		switch (e.key) {
			case "ArrowRight":
				if (selectedTabIndex == tabs.length - 1) return;
				$$invalidate(4, selectedTabIndex++, selectedTabIndex);
				break;
			case "ArrowLeft":
				if (selectedTabIndex == 0) return;
				$$invalidate(4, selectedTabIndex--, selectedTabIndex);
				break;
			case "Home":
				$$invalidate(4, selectedTabIndex = 0);
				break;
			case "End":
				$$invalidate(4, selectedTabIndex = tabs.length - 1);
				break;
			case "Tab":
				break;
			default:
				return;
		}

		const tabList = navbar.querySelectorAll("button");
		tabList[selectedTabIndex].focus();
	};

	const handleFocus = () => {
		let tabs = navbar.querySelectorAll("button");
		tabs[selectedTabIndex].focus();
	};

	const click_handler = i => $$invalidate(4, selectedTabIndex = i);

	function nav_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			navbar = $$value;
			$$invalidate(3, navbar);
		});
	}

	const focus_handler = () => handleFocus();

	$$self.$$set = $$props => {
		if ('tabs' in $$props) $$invalidate(0, tabs = $$props.tabs);
		if ('iconColour' in $$props) $$invalidate(1, iconColour = $$props.iconColour);
		if ('startIndex' in $$props) $$invalidate(8, startIndex = $$props.startIndex);
		if ('full' in $$props) $$invalidate(2, full = $$props.full);
		if ('$$scope' in $$props) $$invalidate(9, $$scope = $$props.$$scope);
	};

	return [
		tabs,
		iconColour,
		full,
		navbar,
		selectedTabIndex,
		handleKeys,
		handleFocus,
		iconSize,
		startIndex,
		$$scope,
		slots,
		click_handler,
		nav_binding,
		focus_handler
	];
}

class Tabs extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$8, create_fragment$8, safe_not_equal, {
			tabs: 0,
			iconColour: 1,
			iconSize: 7,
			startIndex: 8,
			full: 2
		});
	}

	get iconSize() {
		return this.$$.ctx[7];
	}
}

/* src\Tabs\TabContent.svelte generated by Svelte v3.48.0 */

function create_if_block$3(ctx) {
	let div;
	let div_id_value;
	let div_aria_labelledby_value;
	let current;
	const default_slot_template = /*#slots*/ ctx[4].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[3], null);

	return {
		c() {
			div = element("div");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", {
				id: true,
				class: true,
				"aria-labelledby": true,
				tabindex: true,
				role: true
			});

			var div_nodes = children(div);
			if (default_slot) default_slot.l(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "id", div_id_value = `${/*tab*/ ctx[2].tabName}-tabs`);
			attr(div, "class", "focus:outline-none");
			attr(div, "aria-labelledby", div_aria_labelledby_value = /*tab*/ ctx[2].tabName);
			attr(div, "tabindex", "0");
			attr(div, "role", "tabpanel");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);

			if (default_slot) {
				default_slot.m(div, null);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 8)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[3],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[3])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[3], dirty, null),
						null
					);
				}
			}

			if (!current || dirty & /*tab*/ 4 && div_id_value !== (div_id_value = `${/*tab*/ ctx[2].tabName}-tabs`)) {
				attr(div, "id", div_id_value);
			}

			if (!current || dirty & /*tab*/ 4 && div_aria_labelledby_value !== (div_aria_labelledby_value = /*tab*/ ctx[2].tabName)) {
				attr(div, "aria-labelledby", div_aria_labelledby_value);
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			if (default_slot) default_slot.d(detaching);
		}
	};
}

function create_fragment$7(ctx) {
	let if_block_anchor;
	let current;
	let if_block = /*activeIndex*/ ctx[0] == /*tabIndex*/ ctx[1] && create_if_block$3(ctx);

	return {
		c() {
			if (if_block) if_block.c();
			if_block_anchor = empty();
		},
		l(nodes) {
			if (if_block) if_block.l(nodes);
			if_block_anchor = empty();
		},
		m(target, anchor) {
			if (if_block) if_block.m(target, anchor);
			insert_hydration(target, if_block_anchor, anchor);
			current = true;
		},
		p(ctx, [dirty]) {
			if (/*activeIndex*/ ctx[0] == /*tabIndex*/ ctx[1]) {
				if (if_block) {
					if_block.p(ctx, dirty);

					if (dirty & /*activeIndex, tabIndex*/ 3) {
						transition_in(if_block, 1);
					}
				} else {
					if_block = create_if_block$3(ctx);
					if_block.c();
					transition_in(if_block, 1);
					if_block.m(if_block_anchor.parentNode, if_block_anchor);
				}
			} else if (if_block) {
				group_outros();

				transition_out(if_block, 1, 1, () => {
					if_block = null;
				});

				check_outros();
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			if (if_block) if_block.d(detaching);
			if (detaching) detach(if_block_anchor);
		}
	};
}

function instance$7($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	let { activeIndex } = $$props;
	let { tabIndex } = $$props;
	let { tab } = $$props;
	console.log(tab);

	$$self.$$set = $$props => {
		if ('activeIndex' in $$props) $$invalidate(0, activeIndex = $$props.activeIndex);
		if ('tabIndex' in $$props) $$invalidate(1, tabIndex = $$props.tabIndex);
		if ('tab' in $$props) $$invalidate(2, tab = $$props.tab);
		if ('$$scope' in $$props) $$invalidate(3, $$scope = $$props.$$scope);
	};

	return [activeIndex, tabIndex, tab, $$scope, slots];
}

class TabContent extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$7, create_fragment$7, safe_not_equal, { activeIndex: 0, tabIndex: 1, tab: 2 });
	}
}

/* src\TabsContext\TabsContainer.svelte generated by Svelte v3.48.0 */

function create_fragment$6(ctx) {
	let div;
	let current;
	const default_slot_template = /*#slots*/ ctx[3].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[2], null);
	let div_levels = [/*$$restProps*/ ctx[0]];
	let div_data = {};

	for (let i = 0; i < div_levels.length; i += 1) {
		div_data = assign(div_data, div_levels[i]);
	}

	return {
		c() {
			div = element("div");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", {});
			var div_nodes = children(div);
			if (default_slot) default_slot.l(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(div, div_data);
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);

			if (default_slot) {
				default_slot.m(div, null);
			}

			current = true;
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 4)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[2],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[2])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[2], dirty, null),
						null
					);
				}
			}

			set_attributes(div, div_data = get_spread_update(div_levels, [dirty & /*$$restProps*/ 1 && /*$$restProps*/ ctx[0]]));
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			if (default_slot) default_slot.d(detaching);
		}
	};
}

const TABS_KEY = {};

function instance$6($$self, $$props, $$invalidate) {
	const omit_props_names = ["selectedTab"];
	let $$restProps = compute_rest_props($$props, omit_props_names);
	let { $$slots: slots = {}, $$scope } = $$props;
	const tabs = [];
	let { selectedTab = writable(null) } = $$props;
	const navFocused = writable(false);

	setContext(TABS_KEY, {
		registerTab: tab => {
			tabs.push(tab);
			selectedTab.update(current => current || tab);

			onDestroy(() => {
				const i = tabs.indexOf(tab);
				tabs.splice(i, 1);

				selectedTab.update(current => current === tab
				? tabs[i] || tabs[tabs.length - 1]
				: current);
			});
		},
		selectTab: tab => {
			selectedTab.set(tab);
		},
		selectedTab,
		navFocused,
		tabs
	});

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(0, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('selectedTab' in $$new_props) $$invalidate(1, selectedTab = $$new_props.selectedTab);
		if ('$$scope' in $$new_props) $$invalidate(2, $$scope = $$new_props.$$scope);
	};

	return [$$restProps, selectedTab, $$scope, slots];
}

class TabsContainer extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$6, create_fragment$6, safe_not_equal, { selectedTab: 1 });
	}
}

/* src\TabsContext\TabBar.svelte generated by Svelte v3.48.0 */

const get_default_slot_changes$1 = dirty => ({
	selectedTabId: dirty & /*$selectedTab*/ 1
});

const get_default_slot_context$1 = ctx => ({ selectedTabId: /*$selectedTab*/ ctx[0] });

function create_fragment$5(ctx) {
	let div;
	let nav;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[7].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[6], get_default_slot_context$1);

	let nav_levels = [
		{
			class: "w-100 focus:outline-none flex space-x-8"
		},
		{ id: "svelte_tabs" },
		{ tabindex: "0" },
		{ role: "tablist" },
		{ "aria-label": "tabs" },
		/*$$restProps*/ ctx[5]
	];

	let nav_data = {};

	for (let i = 0; i < nav_levels.length; i += 1) {
		nav_data = assign(nav_data, nav_levels[i]);
	}

	return {
		c() {
			div = element("div");
			nav = element("nav");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);

			nav = claim_element(div_nodes, "NAV", {
				class: true,
				id: true,
				tabindex: true,
				role: true,
				"aria-label": true
			});

			var nav_nodes = children(nav);
			if (default_slot) default_slot.l(nav_nodes);
			nav_nodes.forEach(detach);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(nav, nav_data);
			toggle_class(nav, "svelte-1t8ba1j", true);
			attr(div, "class", "");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			append_hydration(div, nav);

			if (default_slot) {
				default_slot.m(nav, null);
			}

			current = true;

			if (!mounted) {
				dispose = [
					listen(nav, "focus", /*focus_handler*/ ctx[8]),
					listen(nav, "focusout", /*focusout_handler*/ ctx[9]),
					listen(nav, "keyup", /*handleKeys*/ ctx[4])
				];

				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope, $selectedTab*/ 65)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[6],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[6])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[6], dirty, get_default_slot_changes$1),
						get_default_slot_context$1
					);
				}
			}

			set_attributes(nav, nav_data = get_spread_update(nav_levels, [
				{
					class: "w-100 focus:outline-none flex space-x-8"
				},
				{ id: "svelte_tabs" },
				{ tabindex: "0" },
				{ role: "tablist" },
				{ "aria-label": "tabs" },
				dirty & /*$$restProps*/ 32 && /*$$restProps*/ ctx[5]
			]));

			toggle_class(nav, "svelte-1t8ba1j", true);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			if (default_slot) default_slot.d(detaching);
			mounted = false;
			run_all(dispose);
		}
	};
}

function instance$5($$self, $$props, $$invalidate) {
	const omit_props_names = [];
	let $$restProps = compute_rest_props($$props, omit_props_names);
	let $selectedTab;
	let $navFocused;
	let { $$slots: slots = {}, $$scope } = $$props;
	const { selectedTab, navFocused, tabs } = getContext(TABS_KEY);
	component_subscribe($$self, selectedTab, value => $$invalidate(0, $selectedTab = value));
	component_subscribe($$self, navFocused, value => $$invalidate(1, $navFocused = value));

	const handleKeys = e => {
		switch (e.key) {
			case "ArrowRight":
				if (tabs.indexOf($selectedTab) == tabs.length - 1) return;
				set_store_value(selectedTab, $selectedTab++, $selectedTab);
				break;
			case "ArrowLeft":
				if (tabs.indexOf($selectedTab) == 0) return;
				set_store_value(selectedTab, $selectedTab--, $selectedTab);
				break;
			case "Home":
				console.log(tabs);
				set_store_value(selectedTab, $selectedTab = tabs[0], $selectedTab);
				break;
			case "End":
				set_store_value(selectedTab, $selectedTab = tabs[tabs.length - 1], $selectedTab);
				break;
			default:
				return;
		}
	};

	const focus_handler = () => set_store_value(navFocused, $navFocused = true, $navFocused);
	const focusout_handler = () => set_store_value(navFocused, $navFocused = false, $navFocused);

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(5, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('$$scope' in $$new_props) $$invalidate(6, $$scope = $$new_props.$$scope);
	};

	return [
		$selectedTab,
		$navFocused,
		selectedTab,
		navFocused,
		handleKeys,
		$$restProps,
		$$scope,
		slots,
		focus_handler,
		focusout_handler
	];
}

class TabBar extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$5, create_fragment$5, safe_not_equal, {});
	}
}

/* src\TabsContext\TabPanel.svelte generated by Svelte v3.48.0 */

function create_if_block$2(ctx) {
	let div;
	let current;
	const default_slot_template = /*#slots*/ ctx[5].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[4], null);
	let div_levels = [{ tabindex: "0" }, { role: "tabpanel" }, /*$$restProps*/ ctx[3]];
	let div_data = {};

	for (let i = 0; i < div_levels.length; i += 1) {
		div_data = assign(div_data, div_levels[i]);
	}

	return {
		c() {
			div = element("div");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { tabindex: true, role: true });
			var div_nodes = children(div);
			if (default_slot) default_slot.l(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(div, div_data);
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);

			if (default_slot) {
				default_slot.m(div, null);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 16)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[4],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[4])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[4], dirty, null),
						null
					);
				}
			}

			set_attributes(div, div_data = get_spread_update(div_levels, [
				{ tabindex: "0" },
				{ role: "tabpanel" },
				dirty & /*$$restProps*/ 8 && /*$$restProps*/ ctx[3]
			]));
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			if (default_slot) default_slot.d(detaching);
		}
	};
}

function create_fragment$4(ctx) {
	let if_block_anchor;
	let current;
	let if_block = /*$selectedTab*/ ctx[1] === /*panelId*/ ctx[0] && create_if_block$2(ctx);

	return {
		c() {
			if (if_block) if_block.c();
			if_block_anchor = empty();
		},
		l(nodes) {
			if (if_block) if_block.l(nodes);
			if_block_anchor = empty();
		},
		m(target, anchor) {
			if (if_block) if_block.m(target, anchor);
			insert_hydration(target, if_block_anchor, anchor);
			current = true;
		},
		p(ctx, [dirty]) {
			if (/*$selectedTab*/ ctx[1] === /*panelId*/ ctx[0]) {
				if (if_block) {
					if_block.p(ctx, dirty);

					if (dirty & /*$selectedTab, panelId*/ 3) {
						transition_in(if_block, 1);
					}
				} else {
					if_block = create_if_block$2(ctx);
					if_block.c();
					transition_in(if_block, 1);
					if_block.m(if_block_anchor.parentNode, if_block_anchor);
				}
			} else if (if_block) {
				group_outros();

				transition_out(if_block, 1, 1, () => {
					if_block = null;
				});

				check_outros();
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			if (if_block) if_block.d(detaching);
			if (detaching) detach(if_block_anchor);
		}
	};
}

function instance$4($$self, $$props, $$invalidate) {
	const omit_props_names = ["panelId"];
	let $$restProps = compute_rest_props($$props, omit_props_names);
	let $selectedTab;
	let { $$slots: slots = {}, $$scope } = $$props;
	let { panelId } = $$props;
	const { selectedTab } = getContext(TABS_KEY);
	component_subscribe($$self, selectedTab, value => $$invalidate(1, $selectedTab = value));

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(3, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('panelId' in $$new_props) $$invalidate(0, panelId = $$new_props.panelId);
		if ('$$scope' in $$new_props) $$invalidate(4, $$scope = $$new_props.$$scope);
	};

	return [panelId, $selectedTab, selectedTab, $$restProps, $$scope, slots];
}

class TabPanel extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$4, create_fragment$4, safe_not_equal, { panelId: 0 });
	}
}

/* src\TabsContext\Tab.svelte generated by Svelte v3.48.0 */

const get_default_slot_changes = dirty => ({
	isActive: dirty & /*$selectedTab, TabId*/ 9,
	isFocused: dirty & /*$selectedTab, TabId, $navFocused*/ 13
});

const get_default_slot_context = ctx => ({
	isActive: /*$selectedTab*/ ctx[3] === /*TabId*/ ctx[0],
	isFocused: /*$selectedTab*/ ctx[3] == /*TabId*/ ctx[0] && /*$navFocused*/ ctx[2]
});

function create_fragment$3(ctx) {
	let button;
	let button_aria_selected_value;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[9].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[8], get_default_slot_context);

	let button_levels = [
		{
			class: "inline-block border border-transparent cursor-pointer focus:outline-none"
		},
		{ tabindex: "-1" },
		{ role: "tab" },
		{
			"aria-selected": button_aria_selected_value = /*$selectedTab*/ ctx[3] === /*TabId*/ ctx[0]
		},
		/*$$restProps*/ ctx[7]
	];

	let button_data = {};

	for (let i = 0; i < button_levels.length; i += 1) {
		button_data = assign(button_data, button_levels[i]);
	}

	return {
		c() {
			button = element("button");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			button = claim_element(nodes, "BUTTON", {
				class: true,
				tabindex: true,
				role: true,
				"aria-selected": true
			});

			var button_nodes = children(button);
			if (default_slot) default_slot.l(button_nodes);
			button_nodes.forEach(detach);
			this.h();
		},
		h() {
			set_attributes(button, button_data);
			toggle_class(button, "focused", /*$selectedTab*/ ctx[3] == /*TabId*/ ctx[0] && /*$navFocused*/ ctx[2]);
		},
		m(target, anchor) {
			insert_hydration(target, button, anchor);

			if (default_slot) {
				default_slot.m(button, null);
			}

			if (button.autofocus) button.focus();
			/*button_binding*/ ctx[11](button);
			current = true;

			if (!mounted) {
				dispose = [
					listen(button, "click", /*click_handler_1*/ ctx[12]),
					listen(button, "click", /*click_handler*/ ctx[10])
				];

				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope, $selectedTab, TabId, $navFocused*/ 269)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[8],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[8])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[8], dirty, get_default_slot_changes),
						get_default_slot_context
					);
				}
			}

			set_attributes(button, button_data = get_spread_update(button_levels, [
				{
					class: "inline-block border border-transparent cursor-pointer focus:outline-none"
				},
				{ tabindex: "-1" },
				{ role: "tab" },
				(!current || dirty & /*$selectedTab, TabId*/ 9 && button_aria_selected_value !== (button_aria_selected_value = /*$selectedTab*/ ctx[3] === /*TabId*/ ctx[0])) && {
					"aria-selected": button_aria_selected_value
				},
				dirty & /*$$restProps*/ 128 && /*$$restProps*/ ctx[7]
			]));

			toggle_class(button, "focused", /*$selectedTab*/ ctx[3] == /*TabId*/ ctx[0] && /*$navFocused*/ ctx[2]);
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(button);
			if (default_slot) default_slot.d(detaching);
			/*button_binding*/ ctx[11](null);
			mounted = false;
			run_all(dispose);
		}
	};
}

function instance$3($$self, $$props, $$invalidate) {
	const omit_props_names = ["TabId"];
	let $$restProps = compute_rest_props($$props, omit_props_names);
	let $navFocused;
	let $selectedTab;
	let { $$slots: slots = {}, $$scope } = $$props;
	let { TabId } = $$props;
	const { registerTab, selectedTab, navFocused } = getContext(TABS_KEY);
	component_subscribe($$self, selectedTab, value => $$invalidate(3, $selectedTab = value));
	component_subscribe($$self, navFocused, value => $$invalidate(2, $navFocused = value));
	registerTab(TabId);
	let tab;

	const handleClick = () => {
		set_store_value(selectedTab, $selectedTab = TabId, $selectedTab);
		set_store_value(navFocused, $navFocused = true, $navFocused);
	};

	function click_handler(event) {
		bubble.call(this, $$self, event);
	}

	function button_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			tab = $$value;
			$$invalidate(1, tab);
		});
	}

	const click_handler_1 = () => handleClick();

	$$self.$$set = $$new_props => {
		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
		$$invalidate(7, $$restProps = compute_rest_props($$props, omit_props_names));
		if ('TabId' in $$new_props) $$invalidate(0, TabId = $$new_props.TabId);
		if ('$$scope' in $$new_props) $$invalidate(8, $$scope = $$new_props.$$scope);
	};

	return [
		TabId,
		tab,
		$navFocused,
		$selectedTab,
		selectedTab,
		navFocused,
		handleClick,
		$$restProps,
		$$scope,
		slots,
		click_handler,
		button_binding,
		click_handler_1
	];
}

class Tab extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$3, create_fragment$3, safe_not_equal, { TabId: 0 });
	}
}

/* src\Tailwind\Tailwind.svelte generated by Svelte v3.48.0 */

class Tailwind extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, null, null, safe_not_equal, {});
	}
}

/* src\Toast\ToastNotification.svelte generated by Svelte v3.48.0 */
const get_action_slot_changes = dirty => ({});
const get_action_slot_context = ctx => ({});

// (68:8) {:else}
function create_else_block(ctx) {
	let svg;
	let path;

	return {
		c() {
			svg = svg_element("svg");
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			svg = claim_svg_element(nodes, "svg", {
				xmlns: true,
				class: true,
				fill: true,
				viewBox: true,
				stroke: true
			});

			var svg_nodes = children(svg);

			path = claim_svg_element(svg_nodes, "path", {
				"stroke-linecap": true,
				"stroke-linejoin": true,
				"stroke-width": true,
				d: true
			});

			children(path).forEach(detach);
			svg_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(path, "stroke-linecap", "round");
			attr(path, "stroke-linejoin", "round");
			attr(path, "stroke-width", "2");
			attr(path, "d", "M13 16h-1v-4h-1m1-4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z");
			attr(svg, "xmlns", "http://www.w3.org/2000/svg");
			attr(svg, "class", "h-6 w-6 text-blue-400");
			attr(svg, "fill", "none");
			attr(svg, "viewBox", "0 0 24 24");
			attr(svg, "stroke", "currentColor");
		},
		m(target, anchor) {
			insert_hydration(target, svg, anchor);
			append_hydration(svg, path);
		},
		d(detaching) {
			if (detaching) detach(svg);
		}
	};
}

// (53:42) 
function create_if_block_5(ctx) {
	let svg;
	let path;

	return {
		c() {
			svg = svg_element("svg");
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			svg = claim_svg_element(nodes, "svg", {
				xmlns: true,
				class: true,
				fill: true,
				viewBox: true,
				stroke: true
			});

			var svg_nodes = children(svg);

			path = claim_svg_element(svg_nodes, "path", {
				"stroke-linecap": true,
				"stroke-linejoin": true,
				"stroke-width": true,
				d: true
			});

			children(path).forEach(detach);
			svg_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(path, "stroke-linecap", "round");
			attr(path, "stroke-linejoin", "round");
			attr(path, "stroke-width", "2");
			attr(path, "d", "M12 9v2m0 4h.01m-6.938 4h13.856c1.54 0 2.502-1.667 1.732-3L13.732 4c-.77-1.333-2.694-1.333-3.464 0L3.34 16c-.77 1.333.192 3 1.732 3z");
			attr(svg, "xmlns", "http://www.w3.org/2000/svg");
			attr(svg, "class", "h-6 w-6 text-yellow-400");
			attr(svg, "fill", "none");
			attr(svg, "viewBox", "0 0 24 24");
			attr(svg, "stroke", "currentColor");
		},
		m(target, anchor) {
			insert_hydration(target, svg, anchor);
			append_hydration(svg, path);
		},
		d(detaching) {
			if (detaching) detach(svg);
		}
	};
}

// (38:42) 
function create_if_block_4(ctx) {
	let svg;
	let path;

	return {
		c() {
			svg = svg_element("svg");
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			svg = claim_svg_element(nodes, "svg", {
				xmlns: true,
				class: true,
				fill: true,
				viewBox: true,
				stroke: true
			});

			var svg_nodes = children(svg);

			path = claim_svg_element(svg_nodes, "path", {
				"stroke-linecap": true,
				"stroke-linejoin": true,
				"stroke-width": true,
				d: true
			});

			children(path).forEach(detach);
			svg_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(path, "stroke-linecap", "round");
			attr(path, "stroke-linejoin", "round");
			attr(path, "stroke-width", "2");
			attr(path, "d", "M9 12l2 2 4-4m6 2a9 9 0 11-18 0 9 9 0 0118 0z");
			attr(svg, "xmlns", "http://www.w3.org/2000/svg");
			attr(svg, "class", "h-6 w-6 text-green-400");
			attr(svg, "fill", "none");
			attr(svg, "viewBox", "0 0 24 24");
			attr(svg, "stroke", "currentColor");
		},
		m(target, anchor) {
			insert_hydration(target, svg, anchor);
			append_hydration(svg, path);
		},
		d(detaching) {
			if (detaching) detach(svg);
		}
	};
}

// (25:8) {#if toast.type == "error"}
function create_if_block_3(ctx) {
	let svg;
	let path;

	return {
		c() {
			svg = svg_element("svg");
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			svg = claim_svg_element(nodes, "svg", {
				xmlns: true,
				class: true,
				viewBox: true,
				fill: true
			});

			var svg_nodes = children(svg);

			path = claim_svg_element(svg_nodes, "path", {
				"fill-rule": true,
				d: true,
				"clip-rule": true
			});

			children(path).forEach(detach);
			svg_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(path, "fill-rule", "evenodd");
			attr(path, "d", "M4.293 4.293a1 1 0 011.414 0L10 8.586l4.293-4.293a1 1 0 111.414 1.414L11.414 10l4.293 4.293a1 1 0 01-1.414 1.414L10 11.414l-4.293 4.293a1 1 0 01-1.414-1.414L8.586 10 4.293 5.707a1 1 0 010-1.414z");
			attr(path, "clip-rule", "evenodd");
			attr(svg, "xmlns", "http://www.w3.org/2000/svg");
			attr(svg, "class", "h-5 w-5 text-red-400");
			attr(svg, "viewBox", "0 0 20 20");
			attr(svg, "fill", "currentColor");
		},
		m(target, anchor) {
			insert_hydration(target, svg, anchor);
			append_hydration(svg, path);
		},
		d(detaching) {
			if (detaching) detach(svg);
		}
	};
}

// (89:8) {#if toast.description}
function create_if_block_2(ctx) {
	let p;
	let raw_value = /*toast*/ ctx[0].description + "";

	return {
		c() {
			p = element("p");
			this.h();
		},
		l(nodes) {
			p = claim_element(nodes, "P", { class: true });
			var p_nodes = children(p);
			p_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(p, "class", "mt-1 text-sm text-gray-400");
		},
		m(target, anchor) {
			insert_hydration(target, p, anchor);
			p.innerHTML = raw_value;
		},
		p(ctx, dirty) {
			if (dirty & /*toast*/ 1 && raw_value !== (raw_value = /*toast*/ ctx[0].description + "")) p.innerHTML = raw_value;		},
		d(detaching) {
			if (detaching) detach(p);
		}
	};
}

// (95:6) {#if toast.dismissable}
function create_if_block_1(ctx) {
	let div;
	let button;
	let svg;
	let path;
	let mounted;
	let dispose;

	return {
		c() {
			div = element("div");
			button = element("button");
			svg = svg_element("svg");
			path = svg_element("path");
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			button = claim_element(div_nodes, "BUTTON", { type: true, class: true });
			var button_nodes = children(button);

			svg = claim_svg_element(button_nodes, "svg", {
				class: true,
				xmlns: true,
				viewBox: true,
				fill: true,
				"aria-hidden": true
			});

			var svg_nodes = children(svg);

			path = claim_svg_element(svg_nodes, "path", {
				"fill-rule": true,
				d: true,
				"clip-rule": true
			});

			children(path).forEach(detach);
			svg_nodes.forEach(detach);
			button_nodes.forEach(detach);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(path, "fill-rule", "evenodd");
			attr(path, "d", "M4.293 4.293a1 1 0 011.414 0L10 8.586l4.293-4.293a1 1 0 111.414 1.414L11.414 10l4.293 4.293a1 1 0 01-1.414 1.414L10 11.414l-4.293 4.293a1 1 0 01-1.414-1.414L8.586 10 4.293 5.707a1 1 0 010-1.414z");
			attr(path, "clip-rule", "evenodd");
			attr(svg, "class", "h-5 w-5");
			attr(svg, "xmlns", "http://www.w3.org/2000/svg");
			attr(svg, "viewBox", "0 0 20 20");
			attr(svg, "fill", "currentColor");
			attr(svg, "aria-hidden", "true");
			attr(button, "type", "button");
			attr(button, "class", "focus:outline-none inline-flex items-center rounded-md p-0.5 text-gray-400 hover:bg-gray-700 focus:ring-2 focus:ring-blue-300");
			attr(div, "class", "ml-4 flex flex-shrink-0");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			append_hydration(div, button);
			append_hydration(button, svg);
			append_hydration(svg, path);

			if (!mounted) {
				dispose = listen(button, "click", /*handleDismiss*/ ctx[1]);
				mounted = true;
			}
		},
		p: noop,
		d(detaching) {
			if (detaching) detach(div);
			mounted = false;
			dispose();
		}
	};
}

// (121:2) {#if $$slots.action}
function create_if_block$1(ctx) {
	let div;
	let button;
	let current;

	button = new Button({
			props: {
				kind: "primary",
				size: "small",
				$$slots: { default: [create_default_slot] },
				$$scope: { ctx }
			}
		});

	button.$on("click", /*handleAction*/ ctx[2]);

	return {
		c() {
			div = element("div");
			create_component(button.$$.fragment);
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			claim_component(button.$$.fragment, div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", "flex items-center border-l border-gray-600 px-4");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			mount_component(button, div, null);
			current = true;
		},
		p(ctx, dirty) {
			const button_changes = {};

			if (dirty & /*$$scope*/ 32) {
				button_changes.$$scope = { dirty, ctx };
			}

			button.$set(button_changes);
		},
		i(local) {
			if (current) return;
			transition_in(button.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(button.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			destroy_component(button);
		}
	};
}

// (123:6) <Button kind="primary" size="small" on:click={handleAction}>
function create_default_slot(ctx) {
	let current;
	const action_slot_template = /*#slots*/ ctx[4].action;
	const action_slot = create_slot(action_slot_template, ctx, /*$$scope*/ ctx[5], get_action_slot_context);

	return {
		c() {
			if (action_slot) action_slot.c();
		},
		l(nodes) {
			if (action_slot) action_slot.l(nodes);
		},
		m(target, anchor) {
			if (action_slot) {
				action_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (action_slot) {
				if (action_slot.p && (!current || dirty & /*$$scope*/ 32)) {
					update_slot_base(
						action_slot,
						action_slot_template,
						ctx,
						/*$$scope*/ ctx[5],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[5])
						: get_slot_changes(action_slot_template, /*$$scope*/ ctx[5], dirty, get_action_slot_changes),
						get_action_slot_context
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(action_slot, local);
			current = true;
		},
		o(local) {
			transition_out(action_slot, local);
			current = false;
		},
		d(detaching) {
			if (action_slot) action_slot.d(detaching);
		}
	};
}

function create_fragment$2(ctx) {
	let div4;
	let div3;
	let div2;
	let div0;
	let t0;
	let div1;
	let p;
	let raw_value = /*toast*/ ctx[0].title + "";
	let t1;
	let t2;
	let t3;
	let current;

	function select_block_type(ctx, dirty) {
		if (/*toast*/ ctx[0].type == "error") return create_if_block_3;
		if (/*toast*/ ctx[0].type == "success") return create_if_block_4;
		if (/*toast*/ ctx[0].type == "warning") return create_if_block_5;
		return create_else_block;
	}

	let current_block_type = select_block_type(ctx);
	let if_block0 = current_block_type(ctx);
	let if_block1 = /*toast*/ ctx[0].description && create_if_block_2(ctx);
	let if_block2 = /*toast*/ ctx[0].dismissable && create_if_block_1(ctx);
	let if_block3 = /*$$slots*/ ctx[3].action && create_if_block$1(ctx);

	return {
		c() {
			div4 = element("div");
			div3 = element("div");
			div2 = element("div");
			div0 = element("div");
			if_block0.c();
			t0 = space();
			div1 = element("div");
			p = element("p");
			t1 = space();
			if (if_block1) if_block1.c();
			t2 = space();
			if (if_block2) if_block2.c();
			t3 = space();
			if (if_block3) if_block3.c();
			this.h();
		},
		l(nodes) {
			div4 = claim_element(nodes, "DIV", { class: true });
			var div4_nodes = children(div4);
			div3 = claim_element(div4_nodes, "DIV", { class: true });
			var div3_nodes = children(div3);
			div2 = claim_element(div3_nodes, "DIV", { class: true });
			var div2_nodes = children(div2);
			div0 = claim_element(div2_nodes, "DIV", { class: true });
			var div0_nodes = children(div0);
			if_block0.l(div0_nodes);
			div0_nodes.forEach(detach);
			t0 = claim_space(div2_nodes);
			div1 = claim_element(div2_nodes, "DIV", { class: true });
			var div1_nodes = children(div1);
			p = claim_element(div1_nodes, "P", { class: true });
			var p_nodes = children(p);
			p_nodes.forEach(detach);
			t1 = claim_space(div1_nodes);
			if (if_block1) if_block1.l(div1_nodes);
			div1_nodes.forEach(detach);
			t2 = claim_space(div2_nodes);
			if (if_block2) if_block2.l(div2_nodes);
			div2_nodes.forEach(detach);
			div3_nodes.forEach(detach);
			t3 = claim_space(div4_nodes);
			if (if_block3) if_block3.l(div4_nodes);
			div4_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div0, "class", "flex-shrink-0");
			attr(p, "class", "text-sm font-medium text-white");
			attr(div1, "class", "ml-3 w-0 flex-1 pt-0.5");
			attr(div2, "class", "flex items-start");
			attr(div3, "class", "w-0 flex-1 p-4");
			attr(div4, "class", "pointer-events-auto my-2 flex w-full max-w-sm overflow-hidden rounded-lg bg-gray-900 shadow-lg ring-1 ring-black ring-opacity-5");
		},
		m(target, anchor) {
			insert_hydration(target, div4, anchor);
			append_hydration(div4, div3);
			append_hydration(div3, div2);
			append_hydration(div2, div0);
			if_block0.m(div0, null);
			append_hydration(div2, t0);
			append_hydration(div2, div1);
			append_hydration(div1, p);
			p.innerHTML = raw_value;
			append_hydration(div1, t1);
			if (if_block1) if_block1.m(div1, null);
			append_hydration(div2, t2);
			if (if_block2) if_block2.m(div2, null);
			append_hydration(div4, t3);
			if (if_block3) if_block3.m(div4, null);
			current = true;
		},
		p(ctx, [dirty]) {
			if (current_block_type !== (current_block_type = select_block_type(ctx))) {
				if_block0.d(1);
				if_block0 = current_block_type(ctx);

				if (if_block0) {
					if_block0.c();
					if_block0.m(div0, null);
				}
			}

			if ((!current || dirty & /*toast*/ 1) && raw_value !== (raw_value = /*toast*/ ctx[0].title + "")) p.innerHTML = raw_value;
			if (/*toast*/ ctx[0].description) {
				if (if_block1) {
					if_block1.p(ctx, dirty);
				} else {
					if_block1 = create_if_block_2(ctx);
					if_block1.c();
					if_block1.m(div1, null);
				}
			} else if (if_block1) {
				if_block1.d(1);
				if_block1 = null;
			}

			if (/*toast*/ ctx[0].dismissable) {
				if (if_block2) {
					if_block2.p(ctx, dirty);
				} else {
					if_block2 = create_if_block_1(ctx);
					if_block2.c();
					if_block2.m(div2, null);
				}
			} else if (if_block2) {
				if_block2.d(1);
				if_block2 = null;
			}

			if (/*$$slots*/ ctx[3].action) {
				if (if_block3) {
					if_block3.p(ctx, dirty);

					if (dirty & /*$$slots*/ 8) {
						transition_in(if_block3, 1);
					}
				} else {
					if_block3 = create_if_block$1(ctx);
					if_block3.c();
					transition_in(if_block3, 1);
					if_block3.m(div4, null);
				}
			} else if (if_block3) {
				group_outros();

				transition_out(if_block3, 1, 1, () => {
					if_block3 = null;
				});

				check_outros();
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block3);
			current = true;
		},
		o(local) {
			transition_out(if_block3);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div4);
			if_block0.d();
			if (if_block1) if_block1.d();
			if (if_block2) if_block2.d();
			if (if_block3) if_block3.d();
		}
	};
}

function instance$2($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	const $$slots = compute_slots(slots);
	let { toast } = $$props;
	const dispatch = createEventDispatcher();

	const handleDismiss = () => {
		dispatch("dismissed", toast);
	};

	const handleAction = () => {
		dispatch("action", toast);
	};

	$$self.$$set = $$props => {
		if ('toast' in $$props) $$invalidate(0, toast = $$props.toast);
		if ('$$scope' in $$props) $$invalidate(5, $$scope = $$props.$$scope);
	};

	return [toast, handleDismiss, handleAction, $$slots, slots, $$scope];
}

class ToastNotification extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$2, create_fragment$2, safe_not_equal, { toast: 0 });
	}
}

/* src\Toast\ToastOverlay.svelte generated by Svelte v3.48.0 */

function get_each_context(ctx, list, i) {
	const child_ctx = ctx.slice();
	child_ctx[3] = list[i];
	return child_ctx;
}

// (15:0) {#if $notifications && $notifications.length}
function create_if_block(ctx) {
	let div;
	let each_blocks = [];
	let each_1_lookup = new Map();
	let current;
	let each_value = /*$notifications*/ ctx[1];
	const get_key = ctx => /*toast*/ ctx[3].id;

	for (let i = 0; i < each_value.length; i += 1) {
		let child_ctx = get_each_context(ctx, each_value, i);
		let key = get_key(child_ctx);
		each_1_lookup.set(key, each_blocks[i] = create_each_block(key, child_ctx));
	}

	return {
		c() {
			div = element("div");

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].c();
			}

			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].l(div_nodes);
			}

			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", "fixed inset-0 flex flex-col items-end justify-end px-4 py-6 pointer-events-none z-50");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].m(div, null);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (dirty & /*$notifications, notifications*/ 3) {
				each_value = /*$notifications*/ ctx[1];
				group_outros();
				for (let i = 0; i < each_blocks.length; i += 1) each_blocks[i].r();
				each_blocks = update_keyed_each(each_blocks, dirty, get_key, 1, ctx, each_value, each_1_lookup, div, fix_and_outro_and_destroy_block, create_each_block, null, get_each_context);
				for (let i = 0; i < each_blocks.length; i += 1) each_blocks[i].a();
				check_outros();
			}
		},
		i(local) {
			if (current) return;

			for (let i = 0; i < each_value.length; i += 1) {
				transition_in(each_blocks[i]);
			}

			current = true;
		},
		o(local) {
			for (let i = 0; i < each_blocks.length; i += 1) {
				transition_out(each_blocks[i]);
			}

			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].d();
			}
		}
	};
}

// (19:4) {#each $notifications as toast (toast.id)}
function create_each_block(key_1, ctx) {
	let div;
	let toastnotification;
	let t;
	let div_transition;
	let rect;
	let stop_animation = noop;
	let current;
	toastnotification = new ToastNotification({ props: { toast: /*toast*/ ctx[3] } });
	toastnotification.$on("dismissed", /*dismissed_handler*/ ctx[2]);

	return {
		key: key_1,
		first: null,
		c() {
			div = element("div");
			create_component(toastnotification.$$.fragment);
			t = space();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			claim_component(toastnotification.$$.fragment, div_nodes);
			t = claim_space(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", "max-w-sm w-full");
			this.first = div;
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);
			mount_component(toastnotification, div, null);
			append_hydration(div, t);
			current = true;
		},
		p(new_ctx, dirty) {
			ctx = new_ctx;
			const toastnotification_changes = {};
			if (dirty & /*$notifications*/ 2) toastnotification_changes.toast = /*toast*/ ctx[3];
			toastnotification.$set(toastnotification_changes);
		},
		r() {
			rect = div.getBoundingClientRect();
		},
		f() {
			fix_position(div);
			stop_animation();
			add_transform(div, rect);
		},
		a() {
			stop_animation();
			stop_animation = create_animation(div, rect, flip$2, { duration: 500 });
		},
		i(local) {
			if (current) return;
			transition_in(toastnotification.$$.fragment, local);

			add_render_callback(() => {
				if (!div_transition) div_transition = create_bidirectional_transition(div, fly, { x: 300 }, true);
				div_transition.run(1);
			});

			current = true;
		},
		o(local) {
			transition_out(toastnotification.$$.fragment, local);
			if (!div_transition) div_transition = create_bidirectional_transition(div, fly, { x: 300 }, false);
			div_transition.run(0);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			destroy_component(toastnotification);
			if (detaching && div_transition) div_transition.end();
		}
	};
}

function create_fragment$1(ctx) {
	let if_block_anchor;
	let current;
	let if_block = /*$notifications*/ ctx[1] && /*$notifications*/ ctx[1].length && create_if_block(ctx);

	return {
		c() {
			if (if_block) if_block.c();
			if_block_anchor = empty();
		},
		l(nodes) {
			if (if_block) if_block.l(nodes);
			if_block_anchor = empty();
		},
		m(target, anchor) {
			if (if_block) if_block.m(target, anchor);
			insert_hydration(target, if_block_anchor, anchor);
			current = true;
		},
		p(ctx, [dirty]) {
			if (/*$notifications*/ ctx[1] && /*$notifications*/ ctx[1].length) {
				if (if_block) {
					if_block.p(ctx, dirty);

					if (dirty & /*$notifications*/ 2) {
						transition_in(if_block, 1);
					}
				} else {
					if_block = create_if_block(ctx);
					if_block.c();
					transition_in(if_block, 1);
					if_block.m(if_block_anchor.parentNode, if_block_anchor);
				}
			} else if (if_block) {
				group_outros();

				transition_out(if_block, 1, 1, () => {
					if_block = null;
				});

				check_outros();
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			if (if_block) if_block.d(detaching);
			if (detaching) detach(if_block_anchor);
		}
	};
}

function instance$1($$self, $$props, $$invalidate) {
	let $notifications,
		$$unsubscribe_notifications = noop,
		$$subscribe_notifications = () => ($$unsubscribe_notifications(), $$unsubscribe_notifications = subscribe(notifications, $$value => $$invalidate(1, $notifications = $$value)), notifications);

	$$self.$$.on_destroy.push(() => $$unsubscribe_notifications());
	let { notifications } = $$props;
	$$subscribe_notifications();
	const dismissed_handler = e => notifications.remove(e.detail);

	$$self.$$set = $$props => {
		if ('notifications' in $$props) $$subscribe_notifications($$invalidate(0, notifications = $$props.notifications));
	};

	return [notifications, $notifications, dismissed_handler];
}

class ToastOverlay extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$1, create_fragment$1, safe_not_equal, { notifications: 0 });
	}
}

const NOTIFICATION_TIMEOUT = 3500;

const createNotificationStore = () => {
  const _notifications = writable([]);

  const send = (title, description, dismissable, type = "info") => {
    _notifications.update(state => {
      return [...state, { id: id(), type, title, description, dismissable }]
    });
  };

  const notifications = derived(_notifications, ($_notifications, set) => {
    set($_notifications);
    if ($_notifications.length > 0) {
      const timeout = setTimeout(() => {
        _notifications.update(state => {
          state.shift();
          return state
        });
      }, NOTIFICATION_TIMEOUT);
      return () => {
        clearTimeout(timeout);
      }
    }
  });

  const remove = (notification) => {
    _notifications.update((current) => current.filter((n) => n.id != notification.id));
  };

  const { subscribe } = notifications;

  return {
    subscribe,
    send,
    remove,
    error: (title, description, dismissable) => send(title, description, dismissable, "error"),
    warning: (title, description, dismissable) => send(title, description, dismissable, "warning"),
    info: (title, description, dismissable) => send(title, description, dismissable, "info"),
    success: (title, description, dismissable) => send(title, description, dismissable, "success")
  }
};

function id() {
  return '_' + Math.random().toString(36).substr(2, 9);
}
const notifications = createNotificationStore();

// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
const toolTip = (node, options) => {
  let popperInstance;
  let componentInstance;
  let isActive = false;

  let text = options.text;

  // add small delay before showing tooltip
  node.addEventListener("mouseenter", show);
  node.addEventListener("mouseleave", hide);

  node.addEventListener("focusin", show);
  node.addEventListener("focusout", hide);

  node.addEventListener("click", hide);

  let tip;

  function show() {
    // prevent from two tips being created for tool tip if hover and focused
    if (isActive) {
      return;
    }

    // delay to tooltip displaying
    componentInstance = new Tip({
      target: document.body,
      props: { text },
    });

    // this will be the tip from the component instance;
    tip = componentInstance.$$.ctx[0];
    tip.setAttribute("data-show", "");
    buildPopper(tip);
    isActive = true;
  }

  const buildPopper = (tipNode) => {
    popperInstance = createPopper(node, tipNode, {
      placement: options.position,
      strategy: "fixed",
      modifiers: [
        {
          name: "offset",
          options: {
            offset: [0, 8],
          },
        },
        {
          name: "flip",
          options: {
            rootBoundary: "document",
          },
        },
      ],
    });
  };

  function hide() {
    if (tip) {
      tip.setAttribute("data-show", "");
    }

    if (popperInstance) {
      popperInstance.destroy();
      popperInstance = null;
    }

    if (componentInstance) {
      componentInstance.$destroy();
    }

    isActive = false;
  }

  return {
    destroy() {
      node.removeEventListener("mouseenter", show);
      node.removeEventListener("mouseleave", hide);
      node.removeEventListener("focusin", show);
      node.removeEventListener("focusout", hide);
      node.removeEventListener("click", hide);

      hide();
    },
    update(options) {
      text = options.text;
    },
  };
};

/* src\ToolTips\ToolTipWrapper.svelte generated by Svelte v3.48.0 */

function create_fragment(ctx) {
	let div;
	let toolTip_action;
	let current;
	let mounted;
	let dispose;
	const default_slot_template = /*#slots*/ ctx[3].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[2], null);

	return {
		c() {
			div = element("div");
			if (default_slot) default_slot.c();
			this.h();
		},
		l(nodes) {
			div = claim_element(nodes, "DIV", { class: true });
			var div_nodes = children(div);
			if (default_slot) default_slot.l(div_nodes);
			div_nodes.forEach(detach);
			this.h();
		},
		h() {
			attr(div, "class", "inline-block");
		},
		m(target, anchor) {
			insert_hydration(target, div, anchor);

			if (default_slot) {
				default_slot.m(div, null);
			}

			current = true;

			if (!mounted) {
				dispose = action_destroyer(toolTip_action = toolTip.call(null, div, {
					text: /*tip*/ ctx[0],
					position: /*position*/ ctx[1]
				}));

				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 4)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[2],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[2])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[2], dirty, null),
						null
					);
				}
			}

			if (toolTip_action && is_function(toolTip_action.update) && dirty & /*tip, position*/ 3) toolTip_action.update.call(null, {
				text: /*tip*/ ctx[0],
				position: /*position*/ ctx[1]
			});
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			if (default_slot) default_slot.d(detaching);
			mounted = false;
			dispose();
		}
	};
}

function instance($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	let { tip } = $$props;
	let { position = "bottom" } = $$props;

	$$self.$$set = $$props => {
		if ('tip' in $$props) $$invalidate(0, tip = $$props.tip);
		if ('position' in $$props) $$invalidate(1, position = $$props.position);
		if ('$$scope' in $$props) $$invalidate(2, $$scope = $$props.$$scope);
	};

	return [tip, position, $$scope, slots];
}

class ToolTipWrapper extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance, create_fragment, safe_not_equal, { tip: 0, position: 1 });
	}
}

/*!
* tabbable 5.3.0
* @license MIT, https://github.com/focus-trap/tabbable/blob/master/LICENSE
*/
var candidateSelectors = ['input', 'select', 'textarea', 'a[href]', 'button', '[tabindex]:not(slot)', 'audio[controls]', 'video[controls]', '[contenteditable]:not([contenteditable="false"])', 'details>summary:first-of-type', 'details'];
var candidateSelector = /* #__PURE__ */candidateSelectors.join(',');
var NoElement = typeof Element === 'undefined';
var matches = NoElement ? function () {} : Element.prototype.matches || Element.prototype.msMatchesSelector || Element.prototype.webkitMatchesSelector;
var getRootNode = !NoElement && Element.prototype.getRootNode ? function (element) {
  return element.getRootNode();
} : function (element) {
  return element.ownerDocument;
};
/**
 * @param {Element} el container to check in
 * @param {boolean} includeContainer add container to check
 * @param {(node: Element) => boolean} filter filter candidates
 * @returns {Element[]}
 */

var getCandidates = function getCandidates(el, includeContainer, filter) {
  var candidates = Array.prototype.slice.apply(el.querySelectorAll(candidateSelector));

  if (includeContainer && matches.call(el, candidateSelector)) {
    candidates.unshift(el);
  }

  candidates = candidates.filter(filter);
  return candidates;
};
/**
 * @callback GetShadowRoot
 * @param {Element} element to check for shadow root
 * @returns {ShadowRoot|boolean} ShadowRoot if available or boolean indicating if a shadowRoot is attached but not available.
 */

/**
 * @typedef {Object} CandidatesScope
 * @property {Element} scope contains inner candidates
 * @property {Element[]} candidates
 */

/**
 * @typedef {Object} IterativeOptions
 * @property {GetShadowRoot|boolean} getShadowRoot true if shadow support is enabled; falsy if not;
 *  if a function, implies shadow support is enabled and either returns the shadow root of an element
 *  or a boolean stating if it has an undisclosed shadow root
 * @property {(node: Element) => boolean} filter filter candidates
 * @property {boolean} flatten if true then result will flatten any CandidatesScope into the returned list
 */

/**
 * @param {Element[]} elements list of element containers to match candidates from
 * @param {boolean} includeContainer add container list to check
 * @param {IterativeOptions} options
 * @returns {Array.<Element|CandidatesScope>}
 */


var getCandidatesIteratively = function getCandidatesIteratively(elements, includeContainer, options) {
  var candidates = [];
  var elementsToCheck = Array.from(elements);

  while (elementsToCheck.length) {
    var element = elementsToCheck.shift();

    if (element.tagName === 'SLOT') {
      // add shadow dom slot scope (slot itself cannot be focusable)
      var assigned = element.assignedElements();
      var content = assigned.length ? assigned : element.children;
      var nestedCandidates = getCandidatesIteratively(content, true, options);

      if (options.flatten) {
        candidates.push.apply(candidates, nestedCandidates);
      } else {
        candidates.push({
          scope: element,
          candidates: nestedCandidates
        });
      }
    } else {
      // check candidate element
      var validCandidate = matches.call(element, candidateSelector);

      if (validCandidate && options.filter(element) && (includeContainer || !elements.includes(element))) {
        candidates.push(element);
      } // iterate over shadow content if possible


      var shadowRoot = element.shadowRoot || // check for an undisclosed shadow
      typeof options.getShadowRoot === 'function' && options.getShadowRoot(element);

      if (shadowRoot) {
        // add shadow dom scope IIF a shadow root node was given; otherwise, an undisclosed
        //  shadow exists, so look at light dom children as fallback BUT create a scope for any
        //  child candidates found because they're likely slotted elements (elements that are
        //  children of the web component element (which has the shadow), in the light dom, but
        //  slotted somewhere _inside_ the undisclosed shadow) -- the scope is created below,
        //  _after_ we return from this recursive call
        var _nestedCandidates = getCandidatesIteratively(shadowRoot === true ? element.children : shadowRoot.children, true, options);

        if (options.flatten) {
          candidates.push.apply(candidates, _nestedCandidates);
        } else {
          candidates.push({
            scope: element,
            candidates: _nestedCandidates
          });
        }
      } else {
        // there's not shadow so just dig into the element's (light dom) children
        //  __without__ giving the element special scope treatment
        elementsToCheck.unshift.apply(elementsToCheck, element.children);
      }
    }
  }

  return candidates;
};

var getTabindex = function getTabindex(node, isScope) {
  if (node.tabIndex < 0) {
    // in Chrome, <details/>, <audio controls/> and <video controls/> elements get a default
    // `tabIndex` of -1 when the 'tabindex' attribute isn't specified in the DOM,
    // yet they are still part of the regular tab order; in FF, they get a default
    // `tabIndex` of 0; since Chrome still puts those elements in the regular tab
    // order, consider their tab index to be 0.
    // Also browsers do not return `tabIndex` correctly for contentEditable nodes;
    // so if they don't have a tabindex attribute specifically set, assume it's 0.
    //
    // isScope is positive for custom element with shadow root or slot that by default
    // have tabIndex -1, but need to be sorted by document order in order for their
    // content to be inserted in the correct position
    if ((isScope || /^(AUDIO|VIDEO|DETAILS)$/.test(node.tagName) || node.isContentEditable) && isNaN(parseInt(node.getAttribute('tabindex'), 10))) {
      return 0;
    }
  }

  return node.tabIndex;
};

var sortOrderedTabbables = function sortOrderedTabbables(a, b) {
  return a.tabIndex === b.tabIndex ? a.documentOrder - b.documentOrder : a.tabIndex - b.tabIndex;
};

var isInput = function isInput(node) {
  return node.tagName === 'INPUT';
};

var isHiddenInput = function isHiddenInput(node) {
  return isInput(node) && node.type === 'hidden';
};

var isDetailsWithSummary = function isDetailsWithSummary(node) {
  var r = node.tagName === 'DETAILS' && Array.prototype.slice.apply(node.children).some(function (child) {
    return child.tagName === 'SUMMARY';
  });
  return r;
};

var getCheckedRadio = function getCheckedRadio(nodes, form) {
  for (var i = 0; i < nodes.length; i++) {
    if (nodes[i].checked && nodes[i].form === form) {
      return nodes[i];
    }
  }
};

var isTabbableRadio = function isTabbableRadio(node) {
  if (!node.name) {
    return true;
  }

  var radioScope = node.form || getRootNode(node);

  var queryRadios = function queryRadios(name) {
    return radioScope.querySelectorAll('input[type="radio"][name="' + name + '"]');
  };

  var radioSet;

  if (typeof window !== 'undefined' && typeof window.CSS !== 'undefined' && typeof window.CSS.escape === 'function') {
    radioSet = queryRadios(window.CSS.escape(node.name));
  } else {
    try {
      radioSet = queryRadios(node.name);
    } catch (err) {
      // eslint-disable-next-line no-console
      console.error('Looks like you have a radio button with a name attribute containing invalid CSS selector characters and need the CSS.escape polyfill: %s', err.message);
      return false;
    }
  }

  var checked = getCheckedRadio(radioSet, node.form);
  return !checked || checked === node;
};

var isRadio = function isRadio(node) {
  return isInput(node) && node.type === 'radio';
};

var isNonTabbableRadio = function isNonTabbableRadio(node) {
  return isRadio(node) && !isTabbableRadio(node);
};

var isZeroArea = function isZeroArea(node) {
  var _node$getBoundingClie = node.getBoundingClientRect(),
      width = _node$getBoundingClie.width,
      height = _node$getBoundingClie.height;

  return width === 0 && height === 0;
};

var isHidden = function isHidden(node, _ref) {
  var displayCheck = _ref.displayCheck,
      getShadowRoot = _ref.getShadowRoot;

  if (getComputedStyle(node).visibility === 'hidden') {
    return true;
  }

  var isDirectSummary = matches.call(node, 'details>summary:first-of-type');
  var nodeUnderDetails = isDirectSummary ? node.parentElement : node;

  if (matches.call(nodeUnderDetails, 'details:not([open]) *')) {
    return true;
  }

  if (!displayCheck || displayCheck === 'full') {
    if (typeof getShadowRoot === 'function') {
      // figure out if we should consider the node to be in an undisclosed shadow and use the
      //  'non-zero-area' fallback
      var originalNode = node;

      while (node) {
        var parentElement = node.parentElement;
        var rootNode = getRootNode(node);

        if (parentElement && !parentElement.shadowRoot && getShadowRoot(parentElement) === true // check if there's an undisclosed shadow
        ) {
          // node has an undisclosed shadow which means we can only treat it as a black box, so we
          //  fall back to a non-zero-area test
          return isZeroArea(node);
        } else if (node.assignedSlot) {
          // iterate up slot
          node = node.assignedSlot;
        } else if (!parentElement && rootNode !== node.ownerDocument) {
          // cross shadow boundary
          node = rootNode.host;
        } else {
          // iterate up normal dom
          node = parentElement;
        }
      }

      node = originalNode;
    } // else, `getShadowRoot` might be true, but all that does is enable shadow DOM support
    //  (i.e. it does not also presume that all nodes might have undisclosed shadows); or
    //  it might be a falsy value, which means shadow DOM support is disabled
    // didn't find it sitting in an undisclosed shadow (or shadows are disabled) so now we
    //  can just test to see if it would normally be visible or not
    // this works wherever the node is: if there's at least one client rect, it's
    //  somehow displayed; it also covers the CSS 'display: contents' case where the
    //  node itself is hidden in place of its contents; and there's no need to search
    //  up the hierarchy either


    return !node.getClientRects().length;
  } else if (displayCheck === 'non-zero-area') {
    return isZeroArea(node);
  }

  return false;
}; // form fields (nested) inside a disabled fieldset are not focusable/tabbable
//  unless they are in the _first_ <legend> element of the top-most disabled
//  fieldset


var isDisabledFromFieldset = function isDisabledFromFieldset(node) {
  if (/^(INPUT|BUTTON|SELECT|TEXTAREA)$/.test(node.tagName)) {
    var parentNode = node.parentElement; // check if `node` is contained in a disabled <fieldset>

    while (parentNode) {
      if (parentNode.tagName === 'FIELDSET' && parentNode.disabled) {
        // look for the first <legend> among the children of the disabled <fieldset>
        for (var i = 0; i < parentNode.children.length; i++) {
          var child = parentNode.children.item(i); // when the first <legend> (in document order) is found

          if (child.tagName === 'LEGEND') {
            // if its parent <fieldset> is not nested in another disabled <fieldset>,
            // return whether `node` is a descendant of its first <legend>
            return matches.call(parentNode, 'fieldset[disabled] *') ? true : !child.contains(node);
          }
        } // the disabled <fieldset> containing `node` has no <legend>


        return true;
      }

      parentNode = parentNode.parentElement;
    }
  } // else, node's tabbable/focusable state should not be affected by a fieldset's
  //  enabled/disabled state


  return false;
};

var isNodeMatchingSelectorFocusable = function isNodeMatchingSelectorFocusable(options, node) {
  if (node.disabled || isHiddenInput(node) || isHidden(node, options) || // For a details element with a summary, the summary element gets the focus
  isDetailsWithSummary(node) || isDisabledFromFieldset(node)) {
    return false;
  }

  return true;
};

var isNodeMatchingSelectorTabbable = function isNodeMatchingSelectorTabbable(options, node) {
  if (isNonTabbableRadio(node) || getTabindex(node) < 0 || !isNodeMatchingSelectorFocusable(options, node)) {
    return false;
  }

  return true;
};
/**
 * @param {Array.<Element|CandidatesScope>} candidates
 * @returns Element[]
 */


var sortByOrder = function sortByOrder(candidates) {
  var regularTabbables = [];
  var orderedTabbables = [];
  candidates.forEach(function (item, i) {
    var isScope = !!item.scope;
    var element = isScope ? item.scope : item;
    var candidateTabindex = getTabindex(element, isScope);
    var elements = isScope ? sortByOrder(item.candidates) : element;

    if (candidateTabindex === 0) {
      isScope ? regularTabbables.push.apply(regularTabbables, elements) : regularTabbables.push(element);
    } else {
      orderedTabbables.push({
        documentOrder: i,
        tabIndex: candidateTabindex,
        item: item,
        isScope: isScope,
        content: elements
      });
    }
  });
  return orderedTabbables.sort(sortOrderedTabbables).reduce(function (acc, sortable) {
    sortable.isScope ? acc.push.apply(acc, sortable.content) : acc.push(sortable.content);
    return acc;
  }, []).concat(regularTabbables);
};

var tabbable = function tabbable(el, options) {
  options = options || {};
  var candidates;

  if (options.getShadowRoot) {
    candidates = getCandidatesIteratively([el], options.includeContainer, {
      filter: isNodeMatchingSelectorTabbable.bind(null, options),
      flatten: false,
      getShadowRoot: options.getShadowRoot
    });
  } else {
    candidates = getCandidates(el, options.includeContainer, isNodeMatchingSelectorTabbable.bind(null, options));
  }

  return sortByOrder(candidates);
};

var focusable = function focusable(el, options) {
  options = options || {};
  var candidates;

  if (options.getShadowRoot) {
    candidates = getCandidatesIteratively([el], options.includeContainer, {
      filter: isNodeMatchingSelectorFocusable.bind(null, options),
      flatten: true,
      getShadowRoot: options.getShadowRoot
    });
  } else {
    candidates = getCandidates(el, options.includeContainer, isNodeMatchingSelectorFocusable.bind(null, options));
  }

  return candidates;
};

var isTabbable = function isTabbable(node, options) {
  options = options || {};

  if (!node) {
    throw new Error('No node provided');
  }

  if (matches.call(node, candidateSelector) === false) {
    return false;
  }

  return isNodeMatchingSelectorTabbable(options, node);
};

var focusableCandidateSelector = /* #__PURE__ */candidateSelectors.concat('iframe').join(',');

var isFocusable = function isFocusable(node, options) {
  options = options || {};

  if (!node) {
    throw new Error('No node provided');
  }

  if (matches.call(node, focusableCandidateSelector) === false) {
    return false;
  }

  return isNodeMatchingSelectorFocusable(options, node);
};

/*!
* focus-trap 6.8.0
* @license MIT, https://github.com/focus-trap/focus-trap/blob/master/LICENSE
*/

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    enumerableOnly && (symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    })), keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = null != arguments[i] ? arguments[i] : {};
    i % 2 ? ownKeys(Object(source), !0).forEach(function (key) {
      _defineProperty(target, key, source[key]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) {
      Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
    });
  }

  return target;
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

var activeFocusTraps = function () {
  var trapQueue = [];
  return {
    activateTrap: function activateTrap(trap) {
      if (trapQueue.length > 0) {
        var activeTrap = trapQueue[trapQueue.length - 1];

        if (activeTrap !== trap) {
          activeTrap.pause();
        }
      }

      var trapIndex = trapQueue.indexOf(trap);

      if (trapIndex === -1) {
        trapQueue.push(trap);
      } else {
        // move this existing trap to the front of the queue
        trapQueue.splice(trapIndex, 1);
        trapQueue.push(trap);
      }
    },
    deactivateTrap: function deactivateTrap(trap) {
      var trapIndex = trapQueue.indexOf(trap);

      if (trapIndex !== -1) {
        trapQueue.splice(trapIndex, 1);
      }

      if (trapQueue.length > 0) {
        trapQueue[trapQueue.length - 1].unpause();
      }
    }
  };
}();

var isSelectableInput = function isSelectableInput(node) {
  return node.tagName && node.tagName.toLowerCase() === 'input' && typeof node.select === 'function';
};

var isEscapeEvent = function isEscapeEvent(e) {
  return e.key === 'Escape' || e.key === 'Esc' || e.keyCode === 27;
};

var isTabEvent = function isTabEvent(e) {
  return e.key === 'Tab' || e.keyCode === 9;
};

var delay = function delay(fn) {
  return setTimeout(fn, 0);
}; // Array.find/findIndex() are not supported on IE; this replicates enough
//  of Array.findIndex() for our needs


var findIndex = function findIndex(arr, fn) {
  var idx = -1;
  arr.every(function (value, i) {
    if (fn(value)) {
      idx = i;
      return false; // break
    }

    return true; // next
  });
  return idx;
};
/**
 * Get an option's value when it could be a plain value, or a handler that provides
 *  the value.
 * @param {*} value Option's value to check.
 * @param {...*} [params] Any parameters to pass to the handler, if `value` is a function.
 * @returns {*} The `value`, or the handler's returned value.
 */


var valueOrHandler = function valueOrHandler(value) {
  for (var _len = arguments.length, params = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    params[_key - 1] = arguments[_key];
  }

  return typeof value === 'function' ? value.apply(void 0, params) : value;
};

var getActualTarget = function getActualTarget(event) {
  // NOTE: If the trap is _inside_ a shadow DOM, event.target will always be the
  //  shadow host. However, event.target.composedPath() will be an array of
  //  nodes "clicked" from inner-most (the actual element inside the shadow) to
  //  outer-most (the host HTML document). If we have access to composedPath(),
  //  then use its first element; otherwise, fall back to event.target (and
  //  this only works for an _open_ shadow DOM; otherwise,
  //  composedPath()[0] === event.target always).
  return event.target.shadowRoot && typeof event.composedPath === 'function' ? event.composedPath()[0] : event.target;
};

var createFocusTrap = function createFocusTrap(elements, userOptions) {
  // SSR: a live trap shouldn't be created in this type of environment so this
  //  should be safe code to execute if the `document` option isn't specified
  var doc = (userOptions === null || userOptions === void 0 ? void 0 : userOptions.document) || document;

  var config = _objectSpread2({
    returnFocusOnDeactivate: true,
    escapeDeactivates: true,
    delayInitialFocus: true
  }, userOptions);

  var state = {
    // containers given to createFocusTrap()
    // @type {Array<HTMLElement>}
    containers: [],
    // list of objects identifying tabbable nodes in `containers` in the trap
    // NOTE: it's possible that a group has no tabbable nodes if nodes get removed while the trap
    //  is active, but the trap should never get to a state where there isn't at least one group
    //  with at least one tabbable node in it (that would lead to an error condition that would
    //  result in an error being thrown)
    // @type {Array<{
    //   container: HTMLElement,
    //   tabbableNodes: Array<HTMLElement>, // empty if none
    //   focusableNodes: Array<HTMLElement>, // empty if none
    //   firstTabbableNode: HTMLElement|null,
    //   lastTabbableNode: HTMLElement|null,
    //   nextTabbableNode: (node: HTMLElement, forward: boolean) => HTMLElement|undefined
    // }>}
    containerGroups: [],
    // same order/length as `containers` list
    // references to objects in `containerGroups`, but only those that actually have
    //  tabbable nodes in them
    // NOTE: same order as `containers` and `containerGroups`, but __not necessarily__
    //  the same length
    tabbableGroups: [],
    nodeFocusedBeforeActivation: null,
    mostRecentlyFocusedNode: null,
    active: false,
    paused: false,
    // timer ID for when delayInitialFocus is true and initial focus in this trap
    //  has been delayed during activation
    delayInitialFocusTimer: undefined
  };
  var trap; // eslint-disable-line prefer-const -- some private functions reference it, and its methods reference private functions, so we must declare here and define later

  /**
   * Gets a configuration option value.
   * @param {Object|undefined} configOverrideOptions If true, and option is defined in this set,
   *  value will be taken from this object. Otherwise, value will be taken from base configuration.
   * @param {string} optionName Name of the option whose value is sought.
   * @param {string|undefined} [configOptionName] Name of option to use __instead of__ `optionName`
   *  IIF `configOverrideOptions` is not defined. Otherwise, `optionName` is used.
   */

  var getOption = function getOption(configOverrideOptions, optionName, configOptionName) {
    return configOverrideOptions && configOverrideOptions[optionName] !== undefined ? configOverrideOptions[optionName] : config[configOptionName || optionName];
  };
  /**
   * Finds the index of the container that contains the element.
   * @param {HTMLElement} element
   * @returns {number} Index of the container in either `state.containers` or
   *  `state.containerGroups` (the order/length of these lists are the same); -1
   *  if the element isn't found.
   */


  var findContainerIndex = function findContainerIndex(element) {
    // NOTE: search `containerGroups` because it's possible a group contains no tabbable
    //  nodes, but still contains focusable nodes (e.g. if they all have `tabindex=-1`)
    //  and we still need to find the element in there
    return state.containerGroups.findIndex(function (_ref) {
      var container = _ref.container,
          tabbableNodes = _ref.tabbableNodes;
      return container.contains(element) || // fall back to explicit tabbable search which will take into consideration any
      //  web components if the `tabbableOptions.getShadowRoot` option was used for
      //  the trap, enabling shadow DOM support in tabbable (`Node.contains()` doesn't
      //  look inside web components even if open)
      tabbableNodes.find(function (node) {
        return node === element;
      });
    });
  };
  /**
   * Gets the node for the given option, which is expected to be an option that
   *  can be either a DOM node, a string that is a selector to get a node, `false`
   *  (if a node is explicitly NOT given), or a function that returns any of these
   *  values.
   * @param {string} optionName
   * @returns {undefined | false | HTMLElement | SVGElement} Returns
   *  `undefined` if the option is not specified; `false` if the option
   *  resolved to `false` (node explicitly not given); otherwise, the resolved
   *  DOM node.
   * @throws {Error} If the option is set, not `false`, and is not, or does not
   *  resolve to a node.
   */


  var getNodeForOption = function getNodeForOption(optionName) {
    var optionValue = config[optionName];

    if (typeof optionValue === 'function') {
      for (var _len2 = arguments.length, params = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
        params[_key2 - 1] = arguments[_key2];
      }

      optionValue = optionValue.apply(void 0, params);
    }

    if (!optionValue) {
      if (optionValue === undefined || optionValue === false) {
        return optionValue;
      } // else, empty string (invalid), null (invalid), 0 (invalid)


      throw new Error("`".concat(optionName, "` was specified but was not a node, or did not return a node"));
    }

    var node = optionValue; // could be HTMLElement, SVGElement, or non-empty string at this point

    if (typeof optionValue === 'string') {
      node = doc.querySelector(optionValue); // resolve to node, or null if fails

      if (!node) {
        throw new Error("`".concat(optionName, "` as selector refers to no known node"));
      }
    }

    return node;
  };

  var getInitialFocusNode = function getInitialFocusNode() {
    var node = getNodeForOption('initialFocus'); // false explicitly indicates we want no initialFocus at all

    if (node === false) {
      return false;
    }

    if (node === undefined) {
      // option not specified: use fallback options
      if (findContainerIndex(doc.activeElement) >= 0) {
        node = doc.activeElement;
      } else {
        var firstTabbableGroup = state.tabbableGroups[0];
        var firstTabbableNode = firstTabbableGroup && firstTabbableGroup.firstTabbableNode; // NOTE: `fallbackFocus` option function cannot return `false` (not supported)

        node = firstTabbableNode || getNodeForOption('fallbackFocus');
      }
    }

    if (!node) {
      throw new Error('Your focus-trap needs to have at least one focusable element');
    }

    return node;
  };

  var updateTabbableNodes = function updateTabbableNodes() {
    state.containerGroups = state.containers.map(function (container) {
      var _config$tabbableOptio, _config$tabbableOptio2;

      var tabbableNodes = tabbable(container, {
        getShadowRoot: (_config$tabbableOptio = config.tabbableOptions) === null || _config$tabbableOptio === void 0 ? void 0 : _config$tabbableOptio.getShadowRoot
      }); // NOTE: if we have tabbable nodes, we must have focusable nodes; focusable nodes
      //  are a superset of tabbable nodes

      var focusableNodes = focusable(container, {
        getShadowRoot: (_config$tabbableOptio2 = config.tabbableOptions) === null || _config$tabbableOptio2 === void 0 ? void 0 : _config$tabbableOptio2.getShadowRoot
      });
      return {
        container: container,
        tabbableNodes: tabbableNodes,
        focusableNodes: focusableNodes,
        firstTabbableNode: tabbableNodes.length > 0 ? tabbableNodes[0] : null,
        lastTabbableNode: tabbableNodes.length > 0 ? tabbableNodes[tabbableNodes.length - 1] : null,

        /**
         * Finds the __tabbable__ node that follows the given node in the specified direction,
         *  in this container, if any.
         * @param {HTMLElement} node
         * @param {boolean} [forward] True if going in forward tab order; false if going
         *  in reverse.
         * @returns {HTMLElement|undefined} The next tabbable node, if any.
         */
        nextTabbableNode: function nextTabbableNode(node) {
          var forward = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
          // NOTE: If tabindex is positive (in order to manipulate the tab order separate
          //  from the DOM order), this __will not work__ because the list of focusableNodes,
          //  while it contains tabbable nodes, does not sort its nodes in any order other
          //  than DOM order, because it can't: Where would you place focusable (but not
          //  tabbable) nodes in that order? They have no order, because they aren't tabbale...
          // Support for positive tabindex is already broken and hard to manage (possibly
          //  not supportable, TBD), so this isn't going to make things worse than they
          //  already are, and at least makes things better for the majority of cases where
          //  tabindex is either 0/unset or negative.
          // FYI, positive tabindex issue: https://github.com/focus-trap/focus-trap/issues/375
          var nodeIdx = focusableNodes.findIndex(function (n) {
            return n === node;
          });

          if (nodeIdx < 0) {
            return undefined;
          }

          if (forward) {
            return focusableNodes.slice(nodeIdx + 1).find(function (n) {
              return isTabbable(n);
            });
          }

          return focusableNodes.slice(0, nodeIdx).reverse().find(function (n) {
            return isTabbable(n);
          });
        }
      };
    });
    state.tabbableGroups = state.containerGroups.filter(function (group) {
      return group.tabbableNodes.length > 0;
    }); // throw if no groups have tabbable nodes and we don't have a fallback focus node either

    if (state.tabbableGroups.length <= 0 && !getNodeForOption('fallbackFocus') // returning false not supported for this option
    ) {
      throw new Error('Your focus-trap must have at least one container with at least one tabbable node in it at all times');
    }
  };

  var tryFocus = function tryFocus(node) {
    if (node === false) {
      return;
    }

    if (node === doc.activeElement) {
      return;
    }

    if (!node || !node.focus) {
      tryFocus(getInitialFocusNode());
      return;
    }

    node.focus({
      preventScroll: !!config.preventScroll
    });
    state.mostRecentlyFocusedNode = node;

    if (isSelectableInput(node)) {
      node.select();
    }
  };

  var getReturnFocusNode = function getReturnFocusNode(previousActiveElement) {
    var node = getNodeForOption('setReturnFocus', previousActiveElement);
    return node ? node : node === false ? false : previousActiveElement;
  }; // This needs to be done on mousedown and touchstart instead of click
  // so that it precedes the focus event.


  var checkPointerDown = function checkPointerDown(e) {
    var target = getActualTarget(e);

    if (findContainerIndex(target) >= 0) {
      // allow the click since it ocurred inside the trap
      return;
    }

    if (valueOrHandler(config.clickOutsideDeactivates, e)) {
      // immediately deactivate the trap
      trap.deactivate({
        // if, on deactivation, we should return focus to the node originally-focused
        //  when the trap was activated (or the configured `setReturnFocus` node),
        //  then assume it's also OK to return focus to the outside node that was
        //  just clicked, causing deactivation, as long as that node is focusable;
        //  if it isn't focusable, then return focus to the original node focused
        //  on activation (or the configured `setReturnFocus` node)
        // NOTE: by setting `returnFocus: false`, deactivate() will do nothing,
        //  which will result in the outside click setting focus to the node
        //  that was clicked, whether it's focusable or not; by setting
        //  `returnFocus: true`, we'll attempt to re-focus the node originally-focused
        //  on activation (or the configured `setReturnFocus` node)
        returnFocus: config.returnFocusOnDeactivate && !isFocusable(target)
      });
      return;
    } // This is needed for mobile devices.
    // (If we'll only let `click` events through,
    // then on mobile they will be blocked anyways if `touchstart` is blocked.)


    if (valueOrHandler(config.allowOutsideClick, e)) {
      // allow the click outside the trap to take place
      return;
    } // otherwise, prevent the click


    e.preventDefault();
  }; // In case focus escapes the trap for some strange reason, pull it back in.


  var checkFocusIn = function checkFocusIn(e) {
    var target = getActualTarget(e);
    var targetContained = findContainerIndex(target) >= 0; // In Firefox when you Tab out of an iframe the Document is briefly focused.

    if (targetContained || target instanceof Document) {
      if (targetContained) {
        state.mostRecentlyFocusedNode = target;
      }
    } else {
      // escaped! pull it back in to where it just left
      e.stopImmediatePropagation();
      tryFocus(state.mostRecentlyFocusedNode || getInitialFocusNode());
    }
  }; // Hijack Tab events on the first and last focusable nodes of the trap,
  // in order to prevent focus from escaping. If it escapes for even a
  // moment it can end up scrolling the page and causing confusion so we
  // kind of need to capture the action at the keydown phase.


  var checkTab = function checkTab(e) {
    var target = getActualTarget(e);
    updateTabbableNodes();
    var destinationNode = null;

    if (state.tabbableGroups.length > 0) {
      // make sure the target is actually contained in a group
      // NOTE: the target may also be the container itself if it's focusable
      //  with tabIndex='-1' and was given initial focus
      var containerIndex = findContainerIndex(target);
      var containerGroup = containerIndex >= 0 ? state.containerGroups[containerIndex] : undefined;

      if (containerIndex < 0) {
        // target not found in any group: quite possible focus has escaped the trap,
        //  so bring it back in to...
        if (e.shiftKey) {
          // ...the last node in the last group
          destinationNode = state.tabbableGroups[state.tabbableGroups.length - 1].lastTabbableNode;
        } else {
          // ...the first node in the first group
          destinationNode = state.tabbableGroups[0].firstTabbableNode;
        }
      } else if (e.shiftKey) {
        // REVERSE
        // is the target the first tabbable node in a group?
        var startOfGroupIndex = findIndex(state.tabbableGroups, function (_ref2) {
          var firstTabbableNode = _ref2.firstTabbableNode;
          return target === firstTabbableNode;
        });

        if (startOfGroupIndex < 0 && (containerGroup.container === target || isFocusable(target) && !isTabbable(target) && !containerGroup.nextTabbableNode(target, false))) {
          // an exception case where the target is either the container itself, or
          //  a non-tabbable node that was given focus (i.e. tabindex is negative
          //  and user clicked on it or node was programmatically given focus)
          //  and is not followed by any other tabbable node, in which
          //  case, we should handle shift+tab as if focus were on the container's
          //  first tabbable node, and go to the last tabbable node of the LAST group
          startOfGroupIndex = containerIndex;
        }

        if (startOfGroupIndex >= 0) {
          // YES: then shift+tab should go to the last tabbable node in the
          //  previous group (and wrap around to the last tabbable node of
          //  the LAST group if it's the first tabbable node of the FIRST group)
          var destinationGroupIndex = startOfGroupIndex === 0 ? state.tabbableGroups.length - 1 : startOfGroupIndex - 1;
          var destinationGroup = state.tabbableGroups[destinationGroupIndex];
          destinationNode = destinationGroup.lastTabbableNode;
        }
      } else {
        // FORWARD
        // is the target the last tabbable node in a group?
        var lastOfGroupIndex = findIndex(state.tabbableGroups, function (_ref3) {
          var lastTabbableNode = _ref3.lastTabbableNode;
          return target === lastTabbableNode;
        });

        if (lastOfGroupIndex < 0 && (containerGroup.container === target || isFocusable(target) && !isTabbable(target) && !containerGroup.nextTabbableNode(target))) {
          // an exception case where the target is the container itself, or
          //  a non-tabbable node that was given focus (i.e. tabindex is negative
          //  and user clicked on it or node was programmatically given focus)
          //  and is not followed by any other tabbable node, in which
          //  case, we should handle tab as if focus were on the container's
          //  last tabbable node, and go to the first tabbable node of the FIRST group
          lastOfGroupIndex = containerIndex;
        }

        if (lastOfGroupIndex >= 0) {
          // YES: then tab should go to the first tabbable node in the next
          //  group (and wrap around to the first tabbable node of the FIRST
          //  group if it's the last tabbable node of the LAST group)
          var _destinationGroupIndex = lastOfGroupIndex === state.tabbableGroups.length - 1 ? 0 : lastOfGroupIndex + 1;

          var _destinationGroup = state.tabbableGroups[_destinationGroupIndex];
          destinationNode = _destinationGroup.firstTabbableNode;
        }
      }
    } else {
      // NOTE: the fallbackFocus option does not support returning false to opt-out
      destinationNode = getNodeForOption('fallbackFocus');
    }

    if (destinationNode) {
      e.preventDefault();
      tryFocus(destinationNode);
    } // else, let the browser take care of [shift+]tab and move the focus

  };

  var checkKey = function checkKey(e) {
    if (isEscapeEvent(e) && valueOrHandler(config.escapeDeactivates, e) !== false) {
      e.preventDefault();
      trap.deactivate();
      return;
    }

    if (isTabEvent(e)) {
      checkTab(e);
      return;
    }
  };

  var checkClick = function checkClick(e) {
    if (valueOrHandler(config.clickOutsideDeactivates, e)) {
      return;
    }

    var target = getActualTarget(e);

    if (findContainerIndex(target) >= 0) {
      return;
    }

    if (valueOrHandler(config.allowOutsideClick, e)) {
      return;
    }

    e.preventDefault();
    e.stopImmediatePropagation();
  }; //
  // EVENT LISTENERS
  //


  var addListeners = function addListeners() {
    if (!state.active) {
      return;
    } // There can be only one listening focus trap at a time


    activeFocusTraps.activateTrap(trap); // Delay ensures that the focused element doesn't capture the event
    // that caused the focus trap activation.

    state.delayInitialFocusTimer = config.delayInitialFocus ? delay(function () {
      tryFocus(getInitialFocusNode());
    }) : tryFocus(getInitialFocusNode());
    doc.addEventListener('focusin', checkFocusIn, true);
    doc.addEventListener('mousedown', checkPointerDown, {
      capture: true,
      passive: false
    });
    doc.addEventListener('touchstart', checkPointerDown, {
      capture: true,
      passive: false
    });
    doc.addEventListener('click', checkClick, {
      capture: true,
      passive: false
    });
    doc.addEventListener('keydown', checkKey, {
      capture: true,
      passive: false
    });
    return trap;
  };

  var removeListeners = function removeListeners() {
    if (!state.active) {
      return;
    }

    doc.removeEventListener('focusin', checkFocusIn, true);
    doc.removeEventListener('mousedown', checkPointerDown, true);
    doc.removeEventListener('touchstart', checkPointerDown, true);
    doc.removeEventListener('click', checkClick, true);
    doc.removeEventListener('keydown', checkKey, true);
    return trap;
  }; //
  // TRAP DEFINITION
  //


  trap = {
    activate: function activate(activateOptions) {
      if (state.active) {
        return this;
      }

      var onActivate = getOption(activateOptions, 'onActivate');
      var onPostActivate = getOption(activateOptions, 'onPostActivate');
      var checkCanFocusTrap = getOption(activateOptions, 'checkCanFocusTrap');

      if (!checkCanFocusTrap) {
        updateTabbableNodes();
      }

      state.active = true;
      state.paused = false;
      state.nodeFocusedBeforeActivation = doc.activeElement;

      if (onActivate) {
        onActivate();
      }

      var finishActivation = function finishActivation() {
        if (checkCanFocusTrap) {
          updateTabbableNodes();
        }

        addListeners();

        if (onPostActivate) {
          onPostActivate();
        }
      };

      if (checkCanFocusTrap) {
        checkCanFocusTrap(state.containers.concat()).then(finishActivation, finishActivation);
        return this;
      }

      finishActivation();
      return this;
    },
    deactivate: function deactivate(deactivateOptions) {
      if (!state.active) {
        return this;
      }

      clearTimeout(state.delayInitialFocusTimer); // noop if undefined

      state.delayInitialFocusTimer = undefined;
      removeListeners();
      state.active = false;
      state.paused = false;
      activeFocusTraps.deactivateTrap(trap);
      var onDeactivate = getOption(deactivateOptions, 'onDeactivate');
      var onPostDeactivate = getOption(deactivateOptions, 'onPostDeactivate');
      var checkCanReturnFocus = getOption(deactivateOptions, 'checkCanReturnFocus');

      if (onDeactivate) {
        onDeactivate();
      }

      var returnFocus = getOption(deactivateOptions, 'returnFocus', 'returnFocusOnDeactivate');

      var finishDeactivation = function finishDeactivation() {
        delay(function () {
          if (returnFocus) {
            tryFocus(getReturnFocusNode(state.nodeFocusedBeforeActivation));
          }

          if (onPostDeactivate) {
            onPostDeactivate();
          }
        });
      };

      if (returnFocus && checkCanReturnFocus) {
        checkCanReturnFocus(getReturnFocusNode(state.nodeFocusedBeforeActivation)).then(finishDeactivation, finishDeactivation);
        return this;
      }

      finishDeactivation();
      return this;
    },
    pause: function pause() {
      if (state.paused || !state.active) {
        return this;
      }

      state.paused = true;
      removeListeners();
      return this;
    },
    unpause: function unpause() {
      if (!state.paused || !state.active) {
        return this;
      }

      state.paused = false;
      updateTabbableNodes();
      addListeners();
      return this;
    },
    updateContainerElements: function updateContainerElements(containerElements) {
      var elementsAsArray = [].concat(containerElements).filter(Boolean);
      state.containers = elementsAsArray.map(function (element) {
        return typeof element === 'string' ? doc.querySelector(element) : element;
      });

      if (state.active) {
        updateTabbableNodes();
      }

      return this;
    }
  }; // initialize container elements

  trap.updateContainerElements(elements);
  return trap;
};

/**
 * @param {focusTrap.Options} options
 */
const trapFocus = (
  node,
  options = {
    allowOutsideClick: true,
    clickOutsideDeactivates: true,
    escapeDeactivates: false,
  }
) => {
  let trap = createFocusTrap(node, options);

  trap.activate();

  return {
    update(newOptions) {
      trap = createFocusTrap(node, newOptions);
      trap.activate();
    },
    destroy() {
      trap.deactivate({
        onDeactivate: null,
      });
    },
  };
};

export { Accordion, AccordionItem, Alert, AutoComplete, Badge, BaseSvg, Button, ButtonGroup, ButtonItem, CheckBox, CheckBoxGroup, Chip, ChipSet, ClipBoard, LinearProgress, List, ListItem, Menu, Modal, Pagination, RadioGroup, Select, SelectGrouped as SelectGroup, SelectMenu, Sidepanel, Switch, Tab, TabBar, TabContent, TabPanel, Tabs, TabsContainer, Tailwind, TextArea, TextInput, Tip, ToastNotification, ToastOverlay as ToastOverLay, ToolTipWrapper, clickOutside, notifications, toolTip, trapFocus };
//# sourceMappingURL=index.mjs.map
